/*
    ---------------------------------
        TITOLO    DF_SYN.INC
    ---------------------------------

    ---------------------------------
        AGGIORNAMENTO DEL : 29-03-2021
    ---------------------------------

    ---------------------------------
        CHIAMATA CON :include "df_syn.inc"
    ---------------------------------

    --------------------------------------
        DESCRIZIONE:

    Definizione sinonimi standard da usare nel PLC
    per CNC ECS 1401D, 2401D, 2701D
    (le modifiche sono riservate ad ECS)

    ATTENZIONE !!

    Definire i sinonimi seguendo le regole:

    - Massima lunghezza 8 caratteri
    - Solo MAIUSCOLI , NUMERI , UNDERSCORE ( _ )
    - Il primo carattere deve essere una lettera

    --------------------------------------

   MODIFICHE per RELEASE cnc 2701 V1.01:

   08-07-98   -   GALLI

   MODIFICA:
      Sostituito "pcnf->tr_232" con "swcnf.ikr"
      (sinonimo IKR)

   22-07-98   -   L.Gentili

   MODIFICA:
      Aggiunti OPE_WIN e WIN_... per gestione Windows PLC.

   28-07-98   -   Tesi

   MODIFICA:
      Al posto di "protoint.inc" viene inserito "winterf.inc".
      Questo file contiene i prototipi delle funzioni per il
      PLC comuni con il software di Interfaccia per WINDOWS.
      Il software di Interfaccia per DOS contiene un sottoinsieme
      di tali funzioni.

   24-08-98    -   GIOVANARDI

   MODIFICA:
      Aggiunto sinonimo ITSTFE in D0.bit._15 per gestione
      tastatore con modalita' vol. feed.

   08-09-98   -   L.Gentili

   MODIFICA:
      Aggiunti sinonimi RIMPV1,RIMPV2,RIMPV3
      per definire rapporto conteggio volantini per routine AGGVOL.

    --------------------------------------

   MODIFICHE per RELEASE cnc 2700 V1.02:

   11-12-98   -   Tesi

   MODIFICA:
      Aggiunti sinonimi FLGMENW, FLGMEN1, FLGMEN2, FLGMEN3, FLGMEN4,
      FLGMEN5, FLGMEN6, FLGMEN7, FLGMEN8N per bloccaggio del menu PLC.

   14-12-98   -   GALLI

   MODIFICA:
      Aggiunti sinonimi per asse gestito e movimentato da PLC

   14-12-1998      L.GENTILI

   MODIFICA:
      Aggiunti ABLAVMF, TESTON per test assi e cicli di misura

   17-12-1998      L.GENTILI

   MODIFICA:
      Portato a 200 gli allarmi  PLC (AALR06...12)
      Portato a 200 le attenzioni PLC (AATT06...12)

   03-02-1999   -   GALLI

   MODIFICA:
      Aggiunto sinonimi OBGMx per indicare se asse
      Gantry Master o Gantry Slave

    --------------------------------------

   MODIFICHE per RELEASE cnc 2701 V1.03:

   03-03-1999   -   Tesi P.

   MODIFICA:
      Aggiunto sinonimo ACTQMENU.

   03-03-1999   -   L.Gentili

   MODIFICA:
      Aggiunto sinonimo AJOGSTEP.

   08-03-1999   -   C.Giorgi

   MODIFICA:
      Aggiunto sinonimo AT_DISAB.

   18-03-99   -   GALLI

   MODIFICA:
      Spostato il sinonimo "IKR" da "swcnf.ikr" a "B7.bit._02".
      in quanto in "swcnf" non poteva essere visto.
      Il ricopiaggio da "swcnf" e' fatto in cp_aree().

   18-03-1999   -   L.Gentili

   MODIFICA:
      Ristrutturato, eliminato segnali non piu' usati, messi riferimenti
      per ricerca sinonimi per argomento in fase di sviluppo PLC, eliminati
      commenti ripetuti.

   24-03-1999   -   C.Giorgi

   MODIFICA:
      Aggiunto sinonimo AB_SHIFT per simulazione tasti [P1]..[P8] e [GoUp]
      tramite [Shift][F1]..[F8] e [Esc].

    --------------------------------------

   MODIFICHE per RELEASE cnc 2700 V2.00:

   13-04-1999   -   L.Gentili

   MODIFICA:
      Tolti sinonimi per funzioni CUSTOM: OFC, IAKFC, ONFC.

   20-04-1999   -   GALLI

   MODIFICA:
      Aggiunto sinonimi IDGSTSnn, ODGSTSnn, ODGMONnn.

   02-06-99   -   GALLI

   MODIFICATION:
      Aggiunto sinonimi IDGOFFnn

   16-07-99   -   L.Gentili

   MODIFICA:
      Aggiunto segnali per Assi con Drivers Digitali
      Aggiunti FILTROR FILTROF FILTROS per gestovr()
      Spostate in fondo le AREE C e D

   24-09-99   -   L.Gentili

   MODIFICA:
      Rinominato il segnale OHLD=C0.byte.l come OHLMND.
      OHLD viene generato internamente al sistema PLC in area B1.bit00
      come OHLD=(OHLMND && OHLAX).

   MODIFICHE per RELEASE cnc 2700 V2.01:

   26-11-99   -   L.Gentili

   MODIFICA:
      Aggiunto segnali per WOOD

   22-12-99   -   L.Gentili

   MODIFICA:
      Aggiunto sinonimi per convertitori D/A da VDA3 a VDA11

   18-01-2000   -   P. Tesi

   MODIFICA:
      Aggiunto sinonimi ALR100, ALR101 mancanti.

   16-02-2000   -   R.Galli

   MODIFICA:
      Ottimizzata la funzione TEMPQAL,
      considerando che i segnali TIME_00 ... TIME_95 sono e devono
      essere contigui; aggiunto commento cautelativo su tali segali.

   10-04-2000   -   L.Gentili
   MODIFICA:
      Aggiunto segnali WOOD_TYC e WOOD_ANI per WOOD.

   MODIFICHE per RELEASE CNC 2701 V2.02:

   22-05-2000   -   GALLI

   MODIFICATION:
      Aggiunto sinonimi IBSETnn, OBSETnn

   23-06-2000   -   Tesi Paolo

   MODIFICA:
      Aggiunti sinonimi ASKQMENU, STBQMENU.

   11-07-2000   -   GALLI

   MODIFICA:
     Tolti sinonimi variabile D0 (aggiunti in DF_CNC.INC).
     Aggiunto sinonimi OBALAXnn

   13-07-2000   -   L.Gentili

   MODIFICA:
     Cambiato sinonimo OK (B8.bit._06) in OKMND

   21-07-2000   -   L.Gentili

   MODIFICA:
     Aggiunti AITF03D, APITF03, HLDRTG84 per evitare che il mandrino
     riparta e faccia alcuni giri dopo Hold-Retract-Rel in G84 (RDM 833)

  04-10-2000   -   GALLI

   MODIFICATION:
     Il CODICE TASTO TASTIERA (CODTAS) viene mappato su
     B0.uword invece che su "keycod"
     (risoluzione BUG perdita rilascio JOG+ JOG-).

  27-10-2000   -   GALLI

   MODIFICATION:
     Aggiunto sinonimi IDGTARnn, IDGENAnn, IAXOFFnn.

  01-12-2000   -   L.Gentili

   MODIFICA:
     Tolto sinonimo CURAS perche' non esiste il bit  C31.bit._02 .
     Tolti, perche' errati e/o non usati, i sinonimi:
           DQALTCI  D_B9     DATI PER TCI
           DATIH    B9.word  DATI PER TCI (WORD PESANTE)
           DATIL    B10.word DATI PER TCI (WORD LEGGERA)
           DTCIQAL  D_B11    DATI TCI PER PLC
           DTCQAH   B11.word DATI TCI PER PLC (WORD PESANTE )
           DTCQAL   B12.word DATI TCI PER PLC (WORD LEGGERA )

  05-12-2000   -   GALLI

    MODIFICATION:
      Rinominato IDGENAnn come IDRVONnn.

   MODIFICHE per RELEASE cnc 2801 V1.00:

      09-06-99   -   GALLI

         MODIFICA:
            PLC su scheda ASSI: tolto riferimento ad aree
            DF_TIPLC, D_PLCVIS, AREE C, AREE D:
            "df_tiplc.inc", "d_plcvis.inc", "df_cd.inc"

      25-09-2000   -   GALLI

         MODIFICATION:
            Implementazione interfaccia CAN-Open per I/O remoto:
            aggiunto include df_can.h

   MODIFICHE per RELEASE cnc 2801 V1.00 beta9:

      31-01-2001   -   GALLI

         MODIFICATION:
            Aggiunto definizioni IOVR, IOVF, IOVS (tolte da "df_cnc.inc").

      06-02-2000   -   GALLI

         MODIFICATION:
            Il CODICE TASTO TASTIERA (CODTAS) deve essere "short"
            (B0.word invece che B0.uword), perche' puo' essere
            un codice negativo.

      28-02-2001   -   GALLI

         MODIFICA:
            Aggiunto sinonimo LKCNOUTB=last_keyout.

   MODIFICHE per RELEASE cnc 2801 V2.00:

      27-04-2001   -   GALLI

         MODIFICATION:
            Aggiunta funzionalita TOUCH/PROBE (LATCH delle quote):
            aggiunto sinonimo "IOSTPB".
            Per TORNIO-FRESA:
            aggiunto sinonimi OSYSMILL, OSYSTURN.

      15-06-2001   -   L.Gentili

         MODIFICATION:
            Aggiunta gestione richiesta Volantini FEED. (RDM686)
             Sinonimi RICVFED, VARVFED.

      18-07-2001   -   Gentili

         MODIFICATION:
            Aggiunto segnale G84ENT (G84 in fase di entrata) per abilitare
            solo in questa fase il Retract (RDM 1001)
            Corretti alcuni commenti

      13-09-2001   -   Giorgi

         MODIFICATION:
            Aggiunto sinonimo TASBASIC sul byte opzioni della tastiera.
            Aggiunto sinonimi MAXIMPF, MAXIMPS, MAXIMPR:
            per FEED, SPEED e RAPIDO ad encoder sono i numeri di impulsi
            ai quale si vuole fare coincidere il loro fondo-scala.
            Spostato AIOVR su keyovr.

   MODIFICHE per RELEASE cnc 2801 V2.01:

      29-11-2001   -   GALLI

         MODIFICATION:
            Aggiunto sinonimi: OBGSETxx, ONBAGMxx.

      31-01-2002   -   GALLI

         MODIFICATION:
            Aggiunto sinonimi "IFASTI1" e "IFASTI2",
            per lo stato dei contatti "FAST INPUT-1" e "FAST INPUT-2"
            propri della Cpu/Assi ELAN

   MODIFICHE per RELEASE cnc 2801 V2.02:

      05-04-2002   -   GALLI

         MODIFICA:
            Aggiunto ingressi "IADxx" per convertitori A/D "ESTERNI".
            Aggiunto sinonimo OCURRnn per asse.

   MODIFICHE per RELEASE cnc 2801 V2.03:

      17-06-2002   -   GALLI

         MODIFICATION:
            Spostato i TIME_xx dalle aree B53-B58 alle aree
            B256-B263, aggiungendo 32 nuovi TIME_xx (TIME_96-TIME_127)

      10-09-2002   -   GALLI

         MODIFICA:
            Aggiunto sinonimo OAXOFFnn per asse.

   MODIFICHE per RELEASE cnc 2801 V2.04:

      30-01-2003   -   GALLI

         MODIFICA:
            Eliminato le strutture AXOUT e AXIN cadute in disuso:
            cancellato i riferimenti ai sinonimi di tali strutture
            (AXOxx, AXIxx, I_VOLxx, O_VOLxx, VOLFRExx).

   MODIFICHE per RELEASE cnc 2801 V3.00:

      17-09-2001   -   Maddii Giorgio

         MODIFICA:
            Per TORNIO-FRESA
            Aggiunto segnali per gestione mandrino SECONDARIO ed altro:
            sinonimi: INCSS, FILTROSS, tutti i sinonimi in B11, B12, B67.

      02-10-2001   -   Bessi

         MODIFICA:
            Per TORNIO-FRESA
            Aggiunto segnali per gestione mandrino SECONDARIO mancanti
            spostato sinonimi che usavano solite aree
            spostato sinonimi per rendere word libere

      05-11-2001   -   GALLI

         MODIFICA:
            Aggiunto quarto volantino in DRF:
            Sinonimi aggiunti:
            - SVOL4  = SELEZIONA VOLANTINO IV (per DRF)
            - APVOL4 = APPOGGIO IV VOLANTINO
            - VVOL4  = VALORE VOLANTINO 4 DA INPUT SCHEDA ASSE
            Sinonimi tolti:
            - COVOL3 = APPOGGIO CALCOLI PER TERZO VOLANTINO

      12-02-2002   -   Maddii Giorgio

         MODIFICA:
            Per TORNIO-FRESA
            Aggiunto sinonimo: ISAMxx

      15-04-2002   -   L.Gentili

         MODIFICATION:
            Tolti segnali per G600 su B5.bit._00 ... B5.bit._13

      15-05-2002   -   Bessi

         MODIFICA:
            Per TORNIO-FRESA
            Aggiunto sinonimi per cosolle remota
            spostato le F_Bxx tutte insieme dato che ora sono distinte
            dalle Bxx  e occupano un'area a parte
            Aggiunto sinonimi per opzioni installate su cn

      21-05-2002   -   Maddii Giorgio

         MODIFICA:
            Per TORNIO-FRESA
            Aggiunto sinonimo: OSTMxx

      30-05-2002   -   Bessi

         MODIFICA:
            Tolto sinonimi ENABLE, PSND, ANCTS, RKEYCU
            Messo indicazioni di WORD libere

      07-06-2002   -   Bessi

         MODIFICA:
            Variato sinonimi per CONSOLE REMOTA

      17-06-2002   -   GALLI

         MODIFICATION:
            Spostato i TIME_xx dalle aree B53-B58 alle aree
            B256-B263, aggiungendo 32 nuovi TIME_xx (TIME_96-TIME_127)

      16-07-2002   -   Bessi

         MODIFICA:
            Aggiunto sinonimi per filtro volantini
            CODICR, CODITAS,CODIIKR,VMAXVOL
            Settati in AGGVOL.C e usati da FLTVOL.C
            Aggiunto sinonimi TAUCNC e TAUPLC in secondi

      19-06-2002   -   Bessi

         MODIFICA:
            Variato sinonimi per CONSOLE REMOTA

      17-07-2002   -   Cianfanelli - Tesi Paolo

         MODIFICATION:
            Eliminato DGTURNx DGRQTXx aggiunto DGVERSx

      04-09-2002   -   Cianfanelli

         MODIFICATION:
            Cambiato su AM05S da B11.bit._08 a B11.bit._09
            Aggiunto nome su tutte le OPZIONI presenti B120 B121 B122

      11-02-2003   -   Maddii

         MODIFICATION:
            Aggiunto nella WORD B13 i sinonimi per richiesta sospensione
            allarme fuga velocita' mandrino principale e secondario.
            Aggiunto OACCMxx

      05-03-2003   -   Maddii

         MODIFICATION:
            Aggiunto definizioni NEWSAT, NEWSMN, FATSAT e FATSMN

      17-03-2003   -   Tesi Paolo

         MODIFICA:
            Inserito #include "wactform.h".

      07-04-2003   -   Maddii

         MODIFICA:
            Inserito #include "tccomplc.h".


      24-04-2003   -   Maddii

         MODIFICA:
            Corretto #define OACCM11  c'era AX104.bit._12
            invece di AX114.bit_12.

      06-05-2003   -   Maddii

         MODIFICA:
            Tolto sinonimi per filtro volantini
            CODICR, CODITAS,CODIIKR,VMAXVOL

      07-05-2003   -   Maddii

         MODIFICA:
            Ripristinato sinonimi per filtro volantini
            CODICR, CODITAS,CODIIKR,VMAXVOL

      13-05-2003   -   Maddii

         MODIFICA:
            - Aggiunto sinonimo CR_HLX, CR_HLY, CR_HLZ per lampade hold assi
              in modo copia su console remota.
            - Aggiunto sinonimo CR_STO, CR_CPY, per lampade in
              modo copia su console remota.
            - Aggiunto sinonimi CR_IOVR, CR_RTCP, CR_JOYON, CR_JOYOFF
              per console remota.

      15-05-2003   -   Maddii

         MODIFICA:
            Aggiunto define :
               MEMOVF
               MEMOVS
               MEMOVR
               MEMOVSS

   MODIFICHE per RELEASE cnc 2800 V3.00A:

      18-06-2003   -   Maddii Giorgio

         MODIFICA:
            Per TORNIO-FRESA
            1) Aggiornato sinonimi per OPZIONI.
            2) Sostituito define OACCMxx con OSAMACxx

   MODIFICHE per RELEASE cnc 2800 V3.01:

      30-09-2003   -   L.Gentili

         MODIFICA:
            Messi commenti su ASKQMENU e STBQMENU

   MODIFICHE per RELEASE cnc 2801 V3.02 b2:

      12-12-2003   -   L.Gentili

         MODIFICA:
            Aggiunti commenti in Inglese, posti OBBLIGATORIAMENTE sulla
            seconda riga (per la funzione "Lista sinonimi" di Sviluppo PLC)
            Messe parole chiave in MAIUSCOLO
            (per la funzione "Lista sinonimi" di Sviluppo PLC).
            Tolti sinonimi MAXIMPF, MAXIMPS, MAXIMPR non piu' usati.
            Tolti segnali per WOOD (opzione non piu' presente)

   MODIFICHE per RELEASE cnc 2801 V3.02 b4:

      16-02-2004       Martinelli M.

         MODIFICA:
            inserita definizione per organi da ripozionare (ORIPOK);

   MODIFICHE per RELEASE cnc 2801 V4.00:

      22-12-2003   -  Galli

         MODIFICA:
            Portato il numero massimo di assi da 12 a 16:
            aggiunte le relative definizioni;
            aggiunte definizioni opzioni
            OP_AX13, OP_AX14, OP_AX15, OP_AX16;
            aggiunta la definizione "AXESNUM=NUMERO DI ASSI CONFIGURATI";
            i temporizzati degli assi di ordine 12, 13, 14, 15
            sono allocati nei TIME_112, TIME_113, TIME_114, TIME_115.

      06-04-2004   -   Galli

         MODIFICA:
            Modifiche per interfaccia MechatroLink:
            il segnale "IDRVONnn" e' valido sia per assi SERCOS,
            sia per assi MECHATROLINK.

      15-06-2004   -   Galli

         MODIFICA:
            Il segnale "IDRVONnn" e' valido anche per assi digitati EcsLink
            (adesso e' quindi valito per tutti gli assi digitali).

      12-07-2004   -   L.Gentili

         MODIFICA:
            Aggiunte variabili per limitazione velocita' massima in dry_run.

      13-07-2004   -   L.Gentili

         MODIFICA:
            Aggiunta variabile ESE_CMOD per aggmnd(); RDM 1581.

      30-08-2004   -   MADDII

         MODIFICA:
            Aggiunto variabili :
                RM5IMND
                OBMTMND
                ARM05
                RM5IMNDS
                OBMTMNDS
                ARM05S
            per aggmnd().

      8-10-2004   -   Giorgi

         MODIFICA:
            Aggiunta variabile ABIKRCAN per abilitazione IKR sul CAN.

      15-11-2004   -   Tesi Paolo

         MODIFICA:
            Inserito #define PARTPSTS.

   MODIFICHE per RELEASE cnc 2801 V4.00.05:

      23-11-2004   -   Maddii

         MODIFICATION:
            Aggiunto i seguenti sinonimi per prestazione RETRACT
            assi comandato da PLC: "OAXRTRx", "IRTR", "ORTR",
            "OPARTR", "OPARTRx", "PRIRTR".
            Aggiunto define G669 per macro sellatura flange.

      23-11-2004   -   L.Gentili

         MODIFICA:
            Aggiunte variabili per modifica logica per limitazione
            velocita' massima in DRY_RUN. (RDM 1592)

      24-11-2004   -   L.Gentili

         MODIFICA:
            Eliminato AT_DISAB. (RDM 1615)

   MODIFICHE per RELEASE cnc 2801 V4.01.1:

      08-03-2005   -   Galli

         MODIFICATION:
            Modifiche per gestione assi idraulici:
            aggiunto i seguenti sinonimi
            "IHYLIMx", "OHYLIMx", "OHYSTSx".

      22-03-2005   -   Galli

         MODIFICATION:
            Implementato un secondo tipo di "Asse T":
            aggiunti i sinonimi per asse "OTAXx".

      07-04-2005        Martinelli M.

        MODIFICA:
           aggiunta definizione di OP_TRB;

   MODIFICHE per RELEASE cnc 2801 V4.01.3:

      21-04-2005   -   Galli

         MODIFICATION:
            Modifiche per gestione assi idraulici:
            rivista la funzionalita' e quindi l'area dati:
            tolto il sinonimo "IHYLIMx".

      18-05-2005   -   GALLI

         MODIFICATION:
            Aggiunto l'include "syn_def.h" contenente
            le definizioni dei nuovi SINONIMI del CN.

    MODIFICHE per RELEASE cnc 2801 V4.01.5:

      08-07-2005   -   Cianfanelli

         MODIFICATION:
            Aggiunto sinonimo G663_662 per RDM 1711 2bug
            Aggiunto sinonimo OP_SELLA per RDM 1724

    MODIFICHE per RELEASE cnc 2801 V4.01.6:

      12-10-2005   -   Maddii

         MODIFICATION:
            Implementata prestazione per modifica
            Inversione SensoMotoTrasduttore
            e Riferimento:
            Aggiunto sinonimi per assi OITRAXxx per asse
            soggetto a inizializzazione.

      19-10-2005   -   Maddii

         MODIFICA:
            Aggiunto sinonimi per routine GetSmtRef() :
               ESMTREF, OSMTx, OREFx, OWSMT e OWREF

      21-11-2005        Claudio Giorgi
        MODIFICA:
           aggiunta definizione di OP_CAMOSS;

    MODIFICHE per RELEASE cnc 2801 V4.01.012:

      20-04-2006   -   Maddii

         MODIFICATION:
            Aggiunto sinonimo G184_950 per ciclo G184

   MODIFICHE per RELEASE cnc 2801 V5.00.000:

      07-12-2005   -   GALLI

         MODIFICA:
            Rinominato la variabile:
            "IAnalogDigital[]" come "IAnalogDigitalSlow[]"
            Aggiunto i sinonimi "IADCNFxx" (variabile AnalogDigitalCnf[]).
            Aggiunto i sinonimi "IADRTxx"  (variabile IAnalogDigitalRt[]).
            Aggiunto i sinonimi "EDVARCN0", "EDVARCN1", "WINVIS_STATUS".

      18-01-2006   -   GALLI

         MODIFICA:
            Modifiche per il controllo di altezza:
            aggiunti i sinonimi
            "OHCTRL", "OSTONHCTRL", "OSTSUSPHCTRL".

      02-03-2006   -   Martinelli M.

         MODIFICA:
            aggiunti, per gestione del riposizionamento automatico,
            i segnali IRIPAUT1, IRIPAUT2, ORIPAUT1, ORIPAUT2;

   MODIFICHE per RELEASE cnc 2801 V5.00.001:

      28-03-2006   -   GALLI

         MODIFICA:
            Modifiche per il controllo di altezza:
            aggiunti i sinonimi: "OVOLTHCTRL", "OSIGNHCTRL".

   MODIFICHE per RELEASE cnc 2801 V5.00.003:

      09-05-2006   -   Galli

         MODIFICA:
            Il sinonimo "OHCTRL" puo' assumere il valore
            3=Controllo sospeso per Tensione Limite.
            Aggiunto i sinonimi "IPSTATUSxx" associati alle
            parole B53 e B54.

      05-06-2006   -   Galli

         MODIFICA:
            Aggiunto il sinonimo "OTRAETOTAG".

   MODIFICHE per RELEASE cnc 2801 V5.00.004:

      06-06-2006   -   Cianfanelli

         MODIFICA:
            Per modifiche apportate da GALLI su segnali assi digitali
            Aggiunto: Segnale nuovo Input  IDGAMMA0-15 (bit 0)
            Aggiunto: Segnali nuovi Output
            DGAMMA0-15 stesso bit di DGMICR0-15
            DGSPND0-15 al posto di DGSETP0-15 che viene eliminato
            DGMCHL0-15 stesso bit di DGMON0-15

   MODIFICHE per RELEASE cnc 2801 V5.00.006:

      29-06-2006   -   Polidori

         MODIFICATION:
            Controllo di altezza macchine plasma, modifica per multitesta:
            - estesi i sinonimi OHCTRLxx, OVOLTHCTRLxx, OSIGNHCTRLxx,
              OSTONHCTRLxx.

   MODIFICHE per RELEASE cnc 2801 V5.00.007:

      14-09-2006        Martinelli M.

         MODIFICA:
            aggiunta definizione di OP_TAG;

      18-09-2006   -   Cianfanelli

         MODIFICATION:
	         Aggiunto G184_ESE CNC_MND e CNC_MNDS per G184/G183 - RDM1846


   MODIFICHE per RELEASE cnc 2801 V5.00.008:

      13-10-2006    Martinelli M.

         MODIFICA:
            Aggiunti define NEWM2 ecc. FATTOM2 ecc. per gestione di piu'
            M intermedie programmate nel solito blocco.

   MODIFICHE per RELEASE cnc 2801 V5.00.009:

      14-11-2006  -  Galli

         MODIFICA:
            Aggiunto il sinonimo "FVLN", per rendere configurabile
            dinamicamente da PLC il "FILTRO VOLANTINO".

      16-11-2006   -   Martinelli M.

         MODIFICA:
            aggiunto sinonimo SAVEPROG.

      29-11-2006  -  Galli

         MODIFICA:
            Aggiunto il sinonimo "CUSTOMVAR_SEC".

   MODIFICHE per RELEASE cnc 2801 V5.00.011:

      06-02-2007   -   Galli

         MODIFICA:
            Nuova funzionalita'
            "Formazione Origine per Asse Gestito da PLC":
            aggiunti i sinonimi OCORIGPLCx.


MODIFICHE per RELEASE cnc 2801 V5.01.000:

      29-02-2008    Martinelli M.

      MODIFICA:
              corretta definizione di OP_TAG, alla fine c'erano i
              caratteri di fine commento;


MODIFICHE per RELEASE cnc 2801 V6.00.004:

      04-06-2009    Martinelli M.

      MODIFICA:
              portati da byte a ubyte i define di APVOL, APVOL3, APVOL4;
              richiesta artf1115;

MODIFICHE per RELEASE cnc 900 :

      02-12-2009    Software

      MODIFICA:
              Modificato sinonimi per tastiera CNC 900
			  Vedi PCKEY.INC
			  Tolto define relativi a volantini da IKR e old tastiera
			  

   MODIFICHE per RELEASE cnc Ecs900uno V1.00.000:

      18-12-2009   -   Tesi Paolo

         MODIFICA:
            Introduzione variabili PARPLC900_xxxx:
            #define        PARPLC900_0000     F_B256
            ........................................
            #define        PARPLC900_0999     F_B2254
            PARAMETRI 0000 -:- 0999 PER WINDOW PLC
            (CNC serie 900).

      05-01-2010   -   Tesi Paolo

         MODIFICA:
			Commentato #include "df_can.h".

      05-01-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi per 
			gestione Byte di Controllo Dei Volantini
			vedi sinonimo ICTRLVOL

MODIFICHE per RELEASE Ecs900

	15-01-10	-	Sottili
	MODIFICA: DGAMMAn  spostato dal bit 0 al bit 1 per compatibilit
			  con i segnali EcsLink su Ecs900, il segnale TURN non veniva passato al plc e 
			  non veniva gestito dal plc.
			
      19-01-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi WORD B220....B250
			per gestione formati di visualizzazione da PLC.
			
      07-02-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi ABIL_ALVL1,ABIL_ALVL2,ABIL_ALVL3
			
      10-02-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi per gestione formato RTG e Tipo formato QUOTE & RTG
			
      04-03-2010   -   Software

         MODIFICA:
			Aggiunto sinonimo :
			 AOVERTS
			per gestione overrides Feed, Speed e Rapido da TOUCH SCREEN.
			
      05-03-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi per Informazione Formato ambiente attuale:
			 - OINFOFORMAT  (B57.ubyte.l)
				OFORMMU    Formato ambiente MU
				OFORMPRG   Formato ambiente PRG
				OFORMPLC   Formato ambiente PLC
				OFORMSETUP Formato ambiente SETUP
			
      25-03-2010   -   Software

         MODIFICA:
			Aggiunto sinonimi per Gestione Formati da PLC:
				- Formato RAPIDO
				- Formato FEED
				- Formato STATO CNC

	29-03-2010 - Software

		MODIFICA:
			Modificato sinonimi per "Gestione da PLC Formati di visualizzazione
			Interfaccia CNC900.

      31-03-2010    Giorgi C.
      MODIFICA:
              Aggiunto sinonimo opzione OP_DBT,
              DataBaseTecnologico per il Taglio.


      07-04-2010    software
      MODIFICA:
			Aggiunto sinonimi ISTBQUOTE e OACKQUOTE

      18-05-2010    software
      MODIFICA:
			Commentato sinonimi non utilizzati
			
      18-05-2010    Cavalleri
      MODIFICA:
			Aggiunto sinonimi per appoggio funzione GetStsCnc

      25-05-2010    Cavalleri
      MODIFICA:
			Aggiunto sinonimo NOOVSTS 
			
      26-05-2010    Cavalleri
      MODIFICA:
			Aggiunto sinonimo NOTSTCNCTS 

   31-05-2010   -   Software

    MODIFICA:
	 Aggiunto sinonimi :
		TIPOTWT, TIPOTWT0, TIPOTWT1, TIPOTWT2 e TIPOTWTD
	 per segnalazione tipo di twist attivo.

   13-06-2010   -   Software

    MODIFICA:
	 Aggiunto sinonimi :
		OLIVPASSWORD,ISTBLIVPSW e OACKLIVPSW 
		per gestione  password ( Livello di accesso )
		
   18-06-2010   -   Software

    MODIFICA:
	 Aggiunto sinonimi :
		VVOLIO1 -:- VVOLIO4	
		VOLDATAS per sapere se i volantini da tastiera sono configurati
		OLIVPSWACT
		INOVISMODICNC
	Tolto sinonimi per gestione password
		OLIVPASSWORD, ILIVPASSWORD, ISTBLIVPSW e OACKLIVPSW
		
		
   05-07-2010   -   Tesi Paolo

    MODIFICA:
	 Aggiunto sinonimi
	    KMUBOARD_... su word B164
	    KMULED_...  su word B167, B168, B169, B170.

   MODIFICHE per RELEASE cnc 900 V1.00.030 :

   02-08-2010   -   Software

   MODIFICA:
   Aggiornamento per gestione priorit volantini da I/O e da Tastiera
   aggiunto sinonimo NUMVOLIO

   01-09-2010   -   Software

   MODIFICA:
		Aggiunto sinonimi IANQEn per richiesta azzeramento QE asse n da PLC


   MODIFICHE per RELEASE cnc 900 V1.01.000 :

   16-09-2010   -   Software

   MODIFICA:
	Aggiunto Sinonimi Tastiera CNC 900 :
	-	K900_FWGIORNO  = GIORNO DELLA VERSIONE FIRMWARE TASTIERA 
	-   K900_FWMESE    = MESE DELLA VERSIONE FIRMWARE TASTIERA
	-   K900_FWANNO    = ANNO DELLA VERSIONE FIRMWARE TASTIERA
	-   K900_SERIAL    = SERIAL DELLA TASTIERA
	-   K900_TGRADIC   = TEMPERATURA INTERNA (GRADI CELSIUS) DELLA TASTIERA

    16-09-2010    Tesi Paolo

    MODIFICA:
       Assi analogici collegati ad I/O Ethercat (artf1213).
       Diagnostica asse analogico su iosignal.

   MODIFICHE per RELEASE cnc 900 V1.01.000.A2 :

	11/10/2010 Sottili 
		MODIFICA: Inseriti sinonimi su parola B171 per diagnostica IO Ecs

   MODIFICHE per RELEASE cnc 900 V1.02.000 :

   29-09-2010   -   Software

   MODIFICA:
	Tolto sinonimi Byte di controllo dei volantini.

   MODIFICHE per RELEASE cnc 900 V1.03.000 :

   16-11-2010   -   Software

   MODIFICA:
    Corretto errore su sinonimi K900_FWGIORNO,K900_FWMESE,K900_FWANNO,K900_SERIAL e K900_TGRADIC
	perch non visibili da PLC. Spostati i sinonimi in B177,B178,B179
	Rinominato K900_AA_VL1 come K900_ALAAVL1
	Rinominato K900_AA_VL2 come K900_ALAAVL2
	Rinominato K900_AA_VL3 come K900_ALAAVL3

   01-12-2010   -   Software

   MODIFICA:
	Tolto define delle seguenti Opzioni :
		Comuni : OP_IO80, OP_IO160
		Fresa  : OP_DGT
		Tornio : OP_CAMTR, OP_SELLA  
		
   13-12-2010   -   Software

   MODIFICA:
   Tolto sinonimo K900_SERIAL e rinominato sinonimi K900_FWGIORNO,K900_FWMESE,K900_FWANNO :
   - Data:K900_FW_DAY,K900_FW_MONTH,K900_FW_YEAR (dato in BCD)
   - Versione Firmware : K900_FW_VER_H,K900_FW_VER_M,K900_FW_VER_L (dato in BCD)
   - Revisione Firmware : K900_FW_REV_H,K900_FW_REV_L (Caratteri ASCII)
   Spostato sinonimi K900_PLDX e K900_PLSX dalla word B152 alla B118.
   Aggiunto nuovi sinonimi K900_ABILVL1 (come K900_PLDX ) e K900_OPTVL1 (come K900_PLSX)

	21-01-2011 Tommaso Sottili
	Rdm Artf1388: definizione IATT# e OATT#


   MODIFICHE per RELEASE cnc 900 V1.03.000 :

   16-11-2010   -   Software

   MODIFICA:
		Aggiunto sinonimi TASTO VIRTUALE per VIS900
			CODTASVIR pn_visplc->CodTastoVirtuale
			ISTBTASVIR pn_visplc->WstrobeTastoVirtuale
			OACKTASVIR pn_visplc->WackTastoVirtuale

   MODIFICHE per RELEASE cnc 900 V1.03.002 :

   07-03-2011   -   Software

   MODIFICA:
		artf1442.
		Aggiunto sinonimi PER SCELTA TIPO DI RICERCA
		WORD B172
		0 = automatica ( da FILE o da RTG se attiva ) 
		1 = da FILE                                   
		2 = da RTG 
		IMODRIC  	B172.uword
		IRICFILE  	B172.bit._00
		IRICRTG  	B172.bit._01

      13-04-2011    Cavalleri
      MODIFICA:
			eliminato sinonimo NOTSTCNCTS perche' sostituito da TSTCNCTS che 
			ora funziona in modo inverso: per abilitare tasti cnc touch occorre mettere a 1 il sinonimo.
			Modifica fatta perche' in caso di tastiera mu presente ma modulo tasti cnc non presente il 
			il pannello non si aveva.


   MODIFICHE per RELEASE cnc 900 V1.04.00x :

   02-05-2011   -   Software

   MODIFICA:
	Aggiunto sinonimo TSTJOGTS per abilitazione tasti JOG+ JOG-
	TOUCH SCREEN


   MODIFICHE per RELEASE cnc 900 V1.04.004 :

   19-05-2011   -   Software

   MODIFICA:
   Aggiunto sinonimi per Richiesta formati alternativi
   WORD B222  -> IFORMALT	IFRMFESPRA
   Aggiornata WORD B223 per Richiesta Non Visualizzazione Formati

   MODIFICHE per RELEASE cnc 900 V1.04.00x :

   24-05-2011   -   Software

   MODIFICA:
   Aggiunto sinonimo per Richiesta formati alternativi
   WORD B222  -> IFRMCNCOVR


   MODIFICHE per RELEASE cnc900 V1.04.004

   26-05-2011  Tesi Paolo
   MODIFICA:
      artf1483 Aggiunto sinonimo ETH_CCOMERR.
               Numero perdite consecutive cicli di comunicazione ethercat
               richiesto da PLC.

   26-05-2011   -   Software

   MODIFICA:
	- Risoluzione Artf 1469
	Sinonimo INUMAXVIS da uword a word, per permettere richiesta
	visualizzazione di tutti gli assi o ripristinare la visualizzazione 
	scelta da VIS900.
	- Risoluzione Artf 1487
    Aggiunto sinonimo	OFORMCLSCH  per segnalare al PLC "Pulizia Schermo"


	MODIFICHE per RELEASE V1.04.005

	28/06/2011 - Sottili
	MODIFICA:
	- Artf1539 - Sviluppo tastiera mu membrana,
	ripristinati  MEMOVF, MEMOVS, MEMOVR, MEMOVSS per gestione
	potenziometri incrementali

	04/07/2011 - Sottili
	MODIFICA:
	- Aggiunti sinonimi per gestione standard joystick
		B210-B215 e F_B16-F_B26

    13/07/2011 - Sottili
      Aggiunto sinonimo WIN_CLK
      
      
	MODIFICHE per RELEASE V1.04.006

   19-04-2012   -   Software

   MODIFICA:
	aGGIUNTO define Opzione :
		Tornio : OP_CAMTR  


MODIFICHE per RELEASE cnc 900 V1.05.002:

      06-06-2012   Martinelli M.

      MODIFICA:
               aggiunti i sinonimi OCTP_ind (artf1705);
      
      05-03-2010   -   Software

	MODIFICA:
	Aggiunto sinonimi per Informazione Formato ambiente attuale:
	 - OINFOFORMAT  (B57.ubyte.l)
		OFORMMU    Formato ambiente MU
		OFORMPRG   Formato ambiente PRG
		OFORMPLC   Formato ambiente PLC
		OFORMSETUP Formato ambiente SETUP

		OINFOFORMAT == 0 SE NESSUN FORM VISUALIZZATO
         
MODIFICHE per RELEASE cnc900 V1.05.003:

      28-06-2012    Software

      MODIFICA:
		Aggiunta Gestione CNC Low Level :
		- OMODEL_ZERO, OMODEL_UNO
		- OP_CUA, OP_FVS, OP_G69
		

MODIFICHE per RELEASE cnc900 V1.05.004:

      17-12-2012    Tesi Paolo

      MODIFICA:
		Artf1759 EoE e modulo ethercat EL6601.
		Aggiunto sinonimo EOE_ENABLE.		


   MODIFICHE per RELEASE cnc 900 V1.05.007 :

   14-05-2013  Tesi Paolo

   MODIFICA:
      artf1792 Doppio canale STBCOD.

   MODIFICHE per RELEASE cnc 900 V1.05.008 :

	03-07-2013    Tesi Paolo

	MODIFICA:
		Abilitazione EoE tramite sinonimo PLC.


   MODIFICHE per RELEASE cnc 900 V1.05.010 :

	30-09-2013    Tesi Paolo

	MODIFICA:
		Richiesta di definire solo variabili R e PARPLC900 per Slow PLC.

MODIFICHE per RELEASE cnc 900 V1.05.012:
	
	22/11/2013 Tommaso Sottili
		MODIFICA:
			Esteso il numero di messaggi disponibili a 64 (artf1864)
			Utilizzate B93 e B108.


MODIFICHE per RELEASE cnc 900 V2.02.002:

    23-02-2015     Martinelli M.

    MODIFICA:
            Aggiunto sinonimo di TIPOTWTA (artf2011);

    30-10-2015     Tesi Paolo

    MODIFICA:
            Spostato i sinonimi CNCACTMODE, CNCINEXE, TSTCNCTS,
            TSTJOGTS, SW_KEYB in synvis_def.h.


MODIFICHE per RELEASE cnc V3.00.003

	22/01/2016 T. Sottili
	
	MODIFICA
		#22: Creazione risorse personalizzate per applicazione Ecs
			Definiti allarmi, warning e timer_ecs da B264 a B299

	25-01-2016       Tesi Paolo

	MODIFICA:
		#95 Gestione 2 tastiere di macchina.


	MODIFICHE per RELEASE cnc900 V3.00.007
	
	26/10/2016 Tesi Paolo
	#1460 Visualizzazione delle quote assi programmate con istruzione G650.

MODIFICHE per RELEASE cnc900 V3.00.008

   10-11-2016  Tesi Paolo
   MODIFICA:
      #1478 Eliminare codice relativo a gestione asse idraulico.


MODIFICHE per RELEASE cnc 900 V3.00.009:

      12-01-2017    Martinelli M.

      MODIFICA:
               aggiunto bit IRIP2CER (#1276);


MODIFICHE per RELEASE cnc 900 V3.01.002

     09-10-2017    Andrea Zulien
		Risolve 1747: Aggiungere variabile per il conteggio delle transizioni ALT -> EXE

MODIFICHE per RELEASE CNC v3.01.003

	10-05-2018    Lorenzo Brandani
	MODIFICA:
	#1882: aggiunti sinonimi per funzionalit 'Capture' (drive OPDE)

MODIFICHE per RELEASE cnc 900 V3.02.000:

     27-09-2018    Tesi Paolo

     MODIFICA:
        #1970 Incremento numero variabili per:
        temporizzatori, area A, B, M


MODIFICHE per RELEASE cnc 900 V3.02.001:

     19-11-2018    Tesi Paolo

     MODIFICA:
        #1996 comunicazione dei codici degli allarmi/messaggi presenti (cnc --> plc)


MODIFICHE per RELEASE cnc V5.00.000

   07-02-2019  Tesi Paolo
   MODIFICA:
	  #2041 asse p.to p.to con target di posizione aggiornabile on-the-fly


	MODIFICHE per RELEASE cnc900 V3.02.005, V5.00.003

	14 - 05 - 2020 Tesi Paolo
	MODIFICA :
	#2254 gestione lato CNC della comunicazione dati, su linea seriale COM,
	tra CNC e scheda adattatore "Legacy HMI" (090F071)

MODIFICHE per RELEASE cnc v3.03.000, V5.01.000

      22-01-2021 Nucci Andrea
      MODIFICA:
      #2379 Modifiche per nuova scheda Inductosyn
      Aggiunti i sinonimi AXANDIAG7 e AXANDIAG8

MODIFICHE per RELEASE cnc900 V3.02.004P13, V5.00.002P14

    08-02-2021 Andrea Nucci
    MODIFICA : 
    #2419:Inseriti Sinonimi POSUT_X,POSUT_Y,POSUT_Z

*/

#pragma once 

///#ifdef QAL_SLOW abilita sinonimi anche per plc slow
	// Richiesta di definire solo variabili R e PARPLC900 per Slow PLC.
#include "navcpu.inc"
#include "df_vaplc.inc"
#include "df_bb.inc"
///#else

#include "df_coplc.inc"
#include "navcpu.inc"
#include "df_vaplc.inc"
#include "df_tmp.inc"
#include "df_seq.inc"
#include "df_aa.inc"
#include "df_bb.inc"
#include "df_ax.inc"
#include "df_rt.inc"
#include "df_m.inc"
#include "syn_def.h"
#include "synvis_def.h"
#include "df_app_spec.h"
#ifdef FUNPLC_DEF
#include "funplc.inc"
#endif
#include "wactform.h"
#include "tccomplc.h"


/* ---------------------------------------------- */
/*            INIZIO DEFINE AREE B                */
/* ---------------------------------------------- */


/* ------------------------------------ */
/*              WORD B0                 */
/* ------------------------------------ */

#define        CODTAS          B0.word
/* CODICE TASTO TASTIERA */
/* KEYBOARD KEY CODE */

/* ------------------------------------ */
/*              WORD B1                 */
/* ------------------------------------ */

#define        OHLD        B1.bit._00
/* CNC IN BLOCCO (ASSI + MANDRINO) */
/* CNC IN HOLD (AXES + SPINDLE) */

#define        RSTMUON     B1.bit._01
/* RICHIESTA RESET CNC: tastcnc() */
/* CNC RESET REQUEST: tastcnc() */

#define        ARST        B1.bit._02
/* RESET CNC INOLTRATO: tastcnc() */
/* CNC RESET FORWARDED: tastcnc() */

#define        ADRYRUN     B1.bit._03
/* RICHIESTA APERTURA WINDOW DRY_RUN */
/* REQUEST TO OPEN DRY_RUN WINDOW */

#define        ALIMDRYR    B1.bit._04
/* LIMITAZIONE FEED IN DRY_RUN ATTIVA */
/* FEED LIMITATION IN DRY_RUN ACTIVE */

#define        WDRYRUN     B1.bit._05
/* WINDOW DRY_RUN APERTA */
/* DRY_RUN WINDOW IS OPEN */

#define        LIMFEDON    B1.bit._06
/* LIMITAZIONE FEED ATTIVA */
/* FEED LIMITATION ACTIVE */

/* ------------------------------------ */
/*              WORD B2                 */
/* ------------------------------------ */

#define        NEWM        B2.bit._00
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */

#define        NEWFA2      B2.bit._01
/* STROBE NUOVA SECONDA F.A. */
/* NEW SECOND MISCELLANEOUS A.F. STROBE */

#define        NEWFA3      B2.bit._02
/* STROBE NUOVA TERZA F.A. */
/* NEW THIRD MISCELLANEOUS A.F. STROBE */

#define        NEWD        B2.bit._03
/* STROBE NUOVA F.A. D */
/* NEW D A.F. STROBE (TOOL corrector) */

#define        NEWT        B2.bit._04
/* STROBE NUOVA F.A. T */
/* NEW T A.F. STROBE (TOOL) */

#define        NEWGEN      B2.bit._05
/* STROBE NUOVA COMUNICAZIONE GENERICA (F.A.)*/
/* NEW GENERIC COMMUNICATION STROBE (A.F.)*/

#define        NEWS        B2.bit._06
/* STROBE NUOVA F.A. S (SPEED MANDRINO PRINCIPALE) */
/* NEW S A.F. STROBE (SPINDLE SPEED)*/

#define        NEWTCI      B2.bit._07
/* STROBE NUOVO CODICE DEL TCI AL PLC (F.A.)*/
/* NEW CODE STROBE OF THE TCI TO THE PLC (A.F.)*/

#define        NEWSMN      B2.bit._08
/* STROBE NUOVO COMANDO <SMN: > (SELEZIONE MANDRINO) */
/* NEW <SMN: > CODE STROBE (SPINDLE SELECTION) */

#define        NEWSAT      B2.bit._09
/* STROBE NUOVO CODICE <SAT: > (SELEZIONE APPARATO) */
/* NEW <SAT: > CODE STROBE (EQUIPMENT SELECTION) */

#define        NEWM2        B2.bit._10
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */

#define        NEWM3        B2.bit._11
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */

#define        NEWM4        B2.bit._12
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */

#define        NEWM5        B2.bit._13
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */

#define        NEWM6        B2.bit._14
/* STROBE NUOVA  F.A. M */
/* NEW MISCELLANEOUS A.F. */


/* ------------------------------------ */
/*              WORD B3                 */
/* ------------------------------------ */

#define        FATTOM      B3.bit._00
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */

#define        FATFA2      B3.bit._01
/* FATTO  SECONDA F.A. */
/* SECOND MISCELLANEOUS M A.F. DONE */

#define        FATFA3      B3.bit._02
/* FATTO  TERZA F.A. */
/* THIRD MISCELLANEOUS M A.F. DONE */

#define        FATTOD      B3.bit._03
/* FATTO  F.A. D */
/* D A.F. DONE (TOOL corrector) */

#define        FATTOT      B3.bit._04
/* FATTO  F.A. T */
/* T A.F. DONE (TOOL) */

#define        FATGEN      B3.bit._05
/* FATTO DEL PARAMETRO GENERICO (F.A.)*/
/* GENERIC COMMUNICATION DONE (A.F.)*/

#define        FATTOS      B3.bit._06
/* FATTO  F.A. S (SPEED MANDRINO)*/
/* S A.F. DONE (SPINDLE SPEED)*/

#define        FATTCI      B3.bit._07
/* FATTO COMANDO DEL TCI (F.A.)*/
/* COMMAND OF THE TCI TO THE PLC DONE (A.F.)*/

#define        FATSMN      B3.bit._08
/* FATTO COMANDO <SMN: > (SELEZIONE MANDRINO) */
/* <SMN: > COMMAND DONE (SPINDLE SELECTION) */

#define        FATSAT      B3.bit._09
/* FATTO F.A. <SAT: > (SELEZIONE APPARATO) */
/* <SAT: > A.F. COMMAND DONE (EQUIPMENT SELECTION) */

#define        FATTOM2      B3.bit._10
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */

#define        FATTOM3      B3.bit._11
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */

#define        FATTOM4      B3.bit._12
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */

#define        FATTOM5      B3.bit._13
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */

#define        FATTOM6      B3.bit._14
/* FATTO  F.A. M */
/* MISCELLANEOUS M A.F. DONE */


/* ------------------------------------ */
/*              WORD B4                 */
/* ------------------------------------ */

#define        NCTS        B4.bit._00
/* NUOVO CODICE  TASTO (TASTIERA)*/
/* NEW KEY CODE (KEYBOARD)*/

#define        CNOK        B4.bit._01
/* CNC PRONTO A RICEVERE NUOVO TASTO (TASTIERA)*/
/* CNC READY TO RECEIVE NEW KEY (KEYBOARD)*/

#define        PUSER       B4.bit._02
/* PREMUTO PULSANTE USER (TASTIERA)*/
/* USER KEY PRESSED (KEYBOARD)*/

#define        CKCN        B4.bit._03
/* CHIAVE PER BLOCCO TASTIERA */
/* KEY FOR KEYBOARD BLOCK */

#define        PUECS       B4.bit._04
/* PREMUTO PULSANTE ECS (255 < CODTAS < 1000) (TASTIERA)*/
/* ECS KEY PRESSED (255 < CODTAS < 1000) (KEYBOARD)*/

#define        PUSEECS     B4.bit._05
/* PREMUTO PULSANTE USER O ECS (CODTAS > 255) (TASTIERA)*/
/* ECS OR USER KEY PRESSED (CODTAS > 255) (KEYBOARD)*/

#define        PUCNC       B4.bit._06
/* PREMUTO PULSANTE CNC (CODTAS <= 255) (TASTIERA)*/
/* CNC KEY PRESSED (CODTAS <= 255) (KEYBOARD)*/

#define        APOPZI      B4.byte.h
/* APPOGGIO BYTE OPZIONI E TASTIERA PRESENTI */
/* OPTIONS AND KEYBOARD BYTE SUPPORT */

#define        INPOUT      B4.bit._08
/* PRESENZA SCHEDA INPUT OUTPUT SU TASTIERA 2700 */
/* OUTPUT INPUT CARD PRESENCE ON 2700 KEYBOARD */

#define        TAS2700     B4.bit._09
/* PRESENZA TASTIERA 2700 */
/* 2700 KEYBOARD PRESENCE */

#define        TASBASIC    B4.bit._10
/* PRESENZA TASTIERA BASIC */
/* BASIC KEYBOARD PRESENCE */

#define        IKR         B4.bit._11
/* SE 1 INSERITA IKR DA SWCNF.TAR */
/* IF 1 PRESENCE OF IKR BY SWCNF.TAR */

#define        VOLTAS      B4.bit._12
/* ABIL. INPUT VOLANTINO DA TASTIERA (PER AGGVOL) */
/* ACTIVATES HANDWHEEL INPUT FROM KEYBOARD (FOR AGGVOL) */

/*#define        AT_DISAB    B4.bit._13*/
/* =1 DISABILITA TUTTI I TASTI AT TRANNE F1..F12 (TASTIERA)*/
/* =1 DISABLE ALL THE AT KEYS BUT F1..F12 (KEYBOARD)*/

/*#define        B4_14       B4.bit._14*/
/* libero */
/* Not Used */

#define        AB_SHIFT    B4.bit._15
/* ABILITA SIMULAZIONE TASTI P1..P8 (TASTIERA) */
/* ENABLES P1..P8 KEYS SIMULATION (KEYBOARD) */

/* ------------------------------------ */
/*              WORD B5                 */
/* ------------------------------------ */

#define        OAFND_AUT   B5.bit._12
/* ABILITA PASSAGGIO RICERCA -> AUTOMATICO */
/* ABILITA PASSAGGIO RICERCA -> AUTOMATICO */

#define        G184_950    B5.bit._13
/* G184 - POSIZIONAMENTO ASSE TONDO CON G950 IN CORSO SU CNC (VARIE)*/
/* G184 - POSIZIONAMENTO ASSE TONDO CON G950 in progress on CNC (SUNDRIES)*/

#define        AOAUTO      B5.bit._14
/* APPOGGIO PER DISCRIMINARE PASSAGGI OAUTO <-> !OAUTO */
/* SUPPORT TO DISCRIMINATE OAUTO <-> !OAUTO TRANSITS*/

#define        G663_662    B5.bit._15
/* G662 oppure G663 IN CORSO SU CNC (VARIE)*/
/* G662 or G663 in progress on CNC (SUNDRIES)*/

/* ------------------------------------ */
/*              WORD B6                 */
/* ------------------------------------ */

#define        PSET        B6.bit._00
/* PROGRAMMATO <SET:..> (VARIE)*/
/* <SET:..> PROGRAMMED (SUNDRIES)*/

#define        G669        B6.bit._01
/* G669 IN CORSO SU CNC (VARIE)      */
/* G669 in progress on CNC (SUNDRIES)*/

#define        G84         B6.bit._02
/* G84 IN CORSO SU CNC (VARIE)*/
/* G84 in progress on CNC (SUNDRIES)*/

#define        G184        B6.bit._03
/* G184 IN CORSO SU CNC (VARIE)*/
/* G184 in progress on CNC (SUNDRIES)*/

#define        CK1SEC      B6.bit._04
/* CK DI 1 SECONDO (VARIE)*/
/* 1 SECOND CLOCK (SUNDRIES)*/

#define        SNGG84      B6.bit._05
/* RICHIESTA ESECUZIONE SINGOLA CON G84 IN CORSO (VARIE)*/
/* SINGLE EXECUTION REQUEST WITH G84 IN PROGRESS (SUNDRIES)*/

#define        OKESNG      B6.bit._06
/* PASSARE A CN TASTO ESEC. SING. RICHIESTO DURANTE G84 (VARIE)*/
/* PASS TO THE CNC THE SINGLE EXECUTION KEY REQUESTED DURING G84 (SUNDRIES)*/

#define        RETG84      B6.bit._07
/* RETRACT ASSE IN G84 (ASSI)*/
/* AXIS RETRACT IN G84 (AXES)*/

#define        AOMDG       B6.bit._08
/* AUSILIARIO PER ENTRATA IN MADIG (COPIA) */
/* AUXILIARY FOR ENTRANCE IN MADIG (DIGITIZING) */

#define        RSTEP       B6.bit._09
/* AUS. PER RICHIESTA STEP ASSE BLOCCATO IN MADIG (COPIA) */
/* AUX. FOR STOPPED AXIS STEP REQUEST IN MADIG (DIGITIZING) */

#define        RISST       B6.bit._10
/* AUSILIARIO PER SOSPENSIONE SICUREZZA TASTO (COPIA) */
/* AUXILIARY FOR PROBE SAFETY SUSPENSION (DIGITIZING) */

#define        HLDRTG84    B6.bit._11
/* HOLD MANDRINO CON RETRACT ASSE IN G84 */
/* SPINDLE HOLD WITH AXIS RETRACT IN G84 */

#define        AKEY98      B6.bit._12
/* RICHIESTA ATTIVAZIONE COPIATURA MANUALE; L<MADIG> (COPIA) */
/* MANUAL COPYING ACTIVATION REQUEST; L<MADIG> (DIGITIZING) */

#define        ABLAVMF     B6.bit._13
/* FLAG PER ABILITAZIONE MOVIMENTI DI LAVORO A MANDRINO FERMO */
/* FLAG FOR ACTIVATE WORK MOVEMENTS WITH SPINDLE STOPPED */

#define        TESTON      B6.bit._14
/* FLAG PER DISAB. SICUREZZE INTERVENTO CONTATTO PROBE ON/OFF */
/* FLAG FOR DISABLE CONTACT SAFETIES INTERVENTION IN ON/OFF PROBE TESTING */

#define        IOSTPB      B6.bit._15
/* Imput/Output contatto "TOUCH PROBE" */
/* Imput/Output contact of "TOUCH PROBE" */

/* ------------------------------------ */
/*              WORD B7                 */
/* ------------------------------------ */

#define        APPMOD      B7.ubyte.l
/* APPOGGIO PER MODO CNC RICHIESTO */
/* SUPPORT FOR REQUEST CNC MODE */

#define        ARCGMOD     B7.bit._08
/* MEMORIA RICHIESTO CAMBIO MODO */
/* MODE CHANGE REQUEST MEMORY*/

#define        ARICVOL     B7.bit._09
/* MEMORIA RICHIESTO VOLANTINO */
/* HANDWHEEL REQUEST MEMORY*/

#define        ABILIKR     B7.bit._10
/* ABIL. INPUT VOLANTINO DA IKR (PER AGGVOL) */
/* ACTIVATES HANDWHEEL INPUT FROM IKR (FOR AGGVOL) */

#define        VOLPBL      B7.bit._11
/* ABIL. INPUT VOLANTINO 1 PORTABILE  (PER AGGVOL) */
/* ACTIVATES PORTABLE HANDWHEEL 1 INPUT (FOR AGGVOL) */

#define        TASMUECS    B7.bit._12
/* PRESENZA TASTIERA M.U. ECS */
/* PRESENZA TASTIERA M.U. ECS */

#define        OSYSMILL    B7.bit._13
/* SE 1 il SISTEMA E' UNA FRESA */
/* if 1 the SYSTEM is a MILLING MACHINE */

#define        OSYSTURN    B7.bit._14
/* SE 1 il SISTEMA E' UNA TORNIO */
/* if 1 the SYSTEM is a LATHE */

#define        VOLDATAS    B7.bit._15
/* PRESENZA N. 3 VOLANTINI DA TASTIERA */
/* PRESENZA N. 3 VOLANTINI DA TASTIERA */

/* ------------------------------------ */
/*              WORD B8                 */
/* ------------------------------------ */

#define        ORIPOK      B8.bit._00
/* SE 1 GLI ORGANI SONO TUTTI RIPOSIZIONATI (VARIE) */
/* IF 1 THE PARTS ARE ALL REPOSITIONED (SUNDRIES) */

#define        CNTCOK      B8.bit._01
/* TCI HA RISPOSTO ALLA M06 DEL CN */
/* TCI HAVE ANSWERED TO THE M06 OF THE CN */

#define        FATRMCU     B8.bit._02
/* RICHIESTA FATTO A TCI DA ROUTINE MOVCU (MAGAZZINO TCI) */
/* DONE REQUEST TO TCI BY MOVCU ROUTINE (TCI WAREHOUSE) */

#define        AXNOPOS     B8.bit._03
/* ASSE NON IN POSIZIONE PER ROUTINE MOVCU (MAGAZZINO TCI) */
/* AXIS NOT IN POSITION FOR MOVCU ROUTINE (TCI WAREHOUSE) */

#define        BLOMND      B8.bit._04
/* MANDRINO BLOCCABILE ( = OBLC# ) */
/* BLOCKABLE SPINDLE ( = OBLC# ) */

#define        BLCRIT      B8.bit._05
/* MANDRINO BLOCCABILE RITARDATO */
/* DELAYED BLOCKABLE SPINDLE ( = OBLC# ) */

#define        OKMND       B8.bit._06
/* ASSE MANDRINO OK: aggmnd() (OBOK e OBAG e !OBALAX =1) */
/* SPINDLE AXIS OK: aggmnd() (OBOK e OBAG e !OBALAX =1) */

#define        BLCMND      B8.bit._07
/* ASSE MANDRINO BLOCCATO; aggmnd() */
/* SPINDLE AXIS BLOCKED; aggmnd() */

#define        RABMND      B8.bit._08
/* RICHIESTA ABILITAZIONE MANDRINO; aggmnd() */
/* REQUEST TO ACTIVATE SPINDLE; aggmnd() */

#define        ABMND       B8.bit._09
/* COMANDO ABILITAZIONE MANDRINO; aggmnd() */
/* COMMAND TO ACTIVATE SPINDLE; aggmnd() */

#define        AM19C       B8.bit._10
/* APPOGGIO M19 IN CORSO (MANDRINO)*/
/* M19 IN PROGRESS (SPINDLE)*/

#define        AITF03D     B8.bit._11
/* DERIVATA POSITIVA DI ITF03 */
/* POSITIVE DERIVATIVE OF ITF03 */

#define        APITF03     B8.bit._12
/* APPOGGIO PER DERIVATA DI ITF03 */
/* AUX. FOR DERIVATIVE OF ITF03 */

#define        G84ENT      B8.bit._13
/* G84 IN FASE DI ENTRATA (VARIE)*/
/* G84 IN PHASE OF ENTRANCE (SUNDRIES)*/

#define        ESE_CMOD    B8.bit._14
/* CAMBIO MODO IN ESECUZIONE; aggmnd() (VARIE)*/
/* CHANGE OF MODE IN PROGRESS; aggmnd() (SUNDRIES)*/

#define        PRIRTR      B8.bit._15
/* PREDISPOSIZIONE GESTIONE AUTOMATICA RETRACT ASSI DI EMERGENZA */

/* ------------------------------------ */
/*              WORD B9                 */
/* ------------------------------------ */
#define        AXESNUM     B9.word
/* NUMERO DI ASSI CONFIGURATI  (VARIE)*/
/* CNC AXES NUMBER (SUNDRIES)*/

/* ------------------------------------ */
/*              WORD B10                */
/* ------------------------------------ */
#define         OMODEL_ZERO	B10.bit._00
/* MODELLO CNC ZERO                     */
/* MODELLO CNC ZERO                     */

#define         OMODEL_UNO	B10.bit._01
/* MODELLO CNC UNO                      */
/* MODELLO CNC UNO                      */

/* ------------------------------------ */
/*              WORD B11                */
/* ------------------------------------ */

#define        BLOMNDS     B11.bit._00
/* MANDRINO SECONDARIO BLOCCABILE ( = OBLC# ) */
/* BLOCKABLE SECONDARY SPINDLE ( = OBLC# ) */

#define        BLCRITS     B11.bit._01
/* MANDRINO SECONDARIO BLOCCABILE RITARDATO */
/* DELAYED BLOCKABLE SECONDARY SPINDLE ( = OBLC# ) */

#define        OKMNDS      B11.bit._02
/* ASSE MANDRINO SECONDARIO OK: aggmnd() (OBOK e OBAG e !OBALAX =1) */
/* SECONDARY SPINDLE AXIS OK: aggmnd() (OBOK e OBAG e !OBALAX =1) */

#define        BLCMNDS     B11.bit._03
/* ASSE MANDRINO SECONDARIO BLOCCATO; aggmnd() */
/* SECONDATY SPINDLE AXIS BLOCKED; aggmnd() */

#define        RABMNDS     B11.bit._04
/* RICHIESTA ABILITAZIONE MANDRINO SECONDARIO; aggmnd() */
/* REQUEST TO ACTIVATE SECONDARY SPINDLE; aggmnd() */

#define        ABMNDS      B11.bit._05
/* COMANDO ABILITAZIONE MANDRINO SECONDARIO; aggmnd() */
/* COMMAND TO ACTIVATE SECONDARY SPINDLE; aggmnd() */

#define        AM19CS      B11.bit._06
/* APPOGGIO M19 IN CORSO (MANDRINO SECONDARIO ); aggmnd() */
/* M19 IN PROGRESS (SECONDARY SPINDLE); aggmnd() */

#define        AM03S       B11.bit._07
/* AUX. ABILITAZIONE MANDRINO SECONDARIO CON M03; aggmnd() */
/* AUX. TO ACTIVATE SECONDARY SPINDLE WITH M03; aggmnd() */

#define        AM04S       B11.bit._08
/* AUX. ABILITAZIONE MANDRINO SECONDARIO CON M04; aggmnd() */
/* AUX. TO ACTIVATE SECONDARY SPINDLE WITH M04; aggmnd() */

#define        AM05S       B11.bit._09
/* AUX. DISABILITAZIONE MANDRINO SECONDARIO CON M05; aggmnd() */
/* AUX. TO DEACTIVATE SECONDARY SPINDLE WITH M05; aggmnd() */

#define        AM19S       B11.bit._10
/* AUX. ABILITAZIONE MANDRINO SECONDARIO CON M19; aggmnd() */
/* AUX. TO ACTIVATE SECONDARY SPINDLE WITH M19; aggmnd() */

#define        ACGS        B11.bit._11
/* AUX. ABILITAZIONE MANDRINO SECONDARIO CON CAMBIO GAMMA; aggmnd() */
/* AUX. TO ACTIVATE SECONDARY SPINDLE WITH GEAR CHANGE; aggmnd() */

#define        VELCGS      B11.bit._12
/* VELOCITA' DI CAMBIO GAMMA MANDRINO SECONDARIO RAGGIUNTA; aggmnd() */
/* SPEED OF GEAR CHANGE FOR THE SECONDARY SPINDLE REACHED; aggmnd() */

#define        M19OKS      B11.bit._13
/* MANDRINO SECONDARIO ORIENTATO CON M19; aggmnd() */
/* SECONDARY SPINDLE ORIENTED WITH M19; aggmnd() */

#define        OSOKS       B11.bit._14
/* VELOCITA' MANDRINO SECONDARIO RAGGIUNTA; aggmnd() */
/* SECONDARY SPINDLE SPEED REACHED; aggmnd() */

/* ------------------------------------ */
/*              WORD B12                */
/* ------------------------------------ */
#define        IFASTI1     B12.bit._00
/* STATO DEL CONTATTO "FAST INPUT 1" PROPRIO DELLA CPU/ASSI ELAN */
/* STATUS OF THE CONTACT "FAST INPUT 1" CHARACTERISTIC OF THE ELAN AXES/CPU */

#define        IFASTI2     B12.bit._01
/* STATO DEL CONTATTO "FAST INPUT 2" PROPRIO DELLA CPU/ASSI ELAN */
/* STATUS OF THE CONTACT "FAST INPUT 2" CHARACTERISTIC OF THE ELAN AXES/CPU */

#define        IRIPAUT1    B12.bit._02
/* RICHIESTO IL MODO DI RIPOSIZIONAMENTO AUTOM. SENZA "RIENTRO TAGLIANDO" */
/* ..... */

#define        IRIPAUT2    B12.bit._03
/* RICHIESTO IL MODO DI RIPOSIZIONAMENTO AUTOM. CON "RIENTRO TAGLIANDO" */
/* ..... */

#define        ORIPAUT1    B12.bit._04
/* E' ATTIVO IL MODO DI RIPOSIZIONAMENTO AUTOM. SENZA "RIENTRO TAGLIANDO" */
/* ..... */

#define        ORIPAUT2    B12.bit._05
/* E' ATTIVO IL MODO DI RIPOSIZIONAMENTO AUTOM. CON "RIENTRO TAGLIANDO" */
/* ..... */

#define	G184_ESE	B12.bit._06
/* G184 IN CORSO di esecuzione SU CNC (VARIE)*/
/* ..... */

#define	CNC_MND	B12.bit._07
/* Mandrino principale agganciato CNC - Generato e Usato su AGGMND.C */
/* ..... */

#define	CNC_MNDS	B12.bit._08
/* Mandrino secondario agganciato CNC - Generato e Usato su AGGMND.C */
/* ..... */

/* ------------------------------------ */
/*              WORD B13                */
/* ------------------------------------ */
#define        RISAMP      B13.bit._00
/* RICHIESTA SOSPENSIONE ALLARME FUGA VELOCITA' MANDRINO PRINCIPALE */
/* SUSPEND ESCAPE ALARM ON THE MAIN SPINDLE */

#define        RM5IMND     B13.bit._01
/* RICHIESTA EMISSIONE M05 SENZA ATTESA MAND. PRI. FERMO; aggmnd() */
/* REQUEST TO ISSUE M05 WITHOUT WAITING FOR MAIN SPINDLE STILL; aggmnd() */

#define        OBMTMND     B13.bit._02
/* MANDRINO PRINCIPALE IN MOVIMENTO; aggmnd() */
/* MAIN SPINDLE IN MOTION; aggmnd() */

#define        ARM05       B13.bit._03
/* AUSILIARIO ATTESA MAND. PRI. FERMO PER DISABILITAZIONE CON M05; aggmnd() */
/* DELAY AUX. TO DEACTIVATE MAIN SPINDLE WITH M05; aggmnd() */

#define        RISAMS      B13.bit._04
/* RICHIESTA SOSPENSIONE ALLARME FUGA VELOCITA' MANDRINO SECONDARIO */
/* SUSPEND ESCAPE ALARM ON THE SECONDARY SPINDLE */

#define        RM5IMNDS    B13.bit._05
/* RICHIESTA EMISSIONE M05 SENZA ATTESA MANDRINO SECONDARIO FERMO; aggmnd() */
/* REQUEST TO ISSUE M05 WITHOUT WAITING FOR SECONDARY SPINDLE STILL; aggmnd() */

#define        OBMTMNDS    B13.bit._06
/* MANDRINO SECONDARIO IN MOVIMENTO; aggmnd() */
/* SECONDARY SPINDLE IN MOTION; aggmnd() */

#define        ARM05S      B13.bit._07
/* AUSILIARIO ATTESA MAND. SEC. FERMO PER DISABILITAZIONE CON M05; aggmnd()*/
/* DELAY AUX. TO DEACTIVATE SECONDARY SPINDLE WITH M05 ; aggmnd()*/

/* ------------------------------------ */
/*              WORD B14                */
/* ------------------------------------ */

#define        TVL1        B14.bit._00
/* TRASFERITO VALORE I VOLANTINO */
/* VALUE OF THE FIRST HANDWHEEL TANSFERED */

#define        TVL2        B14.bit._01
/* TRASFERITO VALORE II VOLANTINO */
/* VALUE OF THE SECOND HANDWHEEL TANSFERED */

#define        TVL3        B14.bit._02
/* TRASFERITO VALORE III VOLANTINO */
/* VALUE OF THE THIRD HANDWHEEL TANSFERED */

#define        RICVOL      B14.bit._03
/* RICHIESTA AGGANCIO VOLANTINO */
/* REQUEST ATTACHMENT OF HANDWHEELS */

#define        VARVOL      B14.bit._04
/* VARIAZIONE SU VOLANTINO */
/* STATUS OF HANDWHEEL CHANGED */

#define        DEF001      B14.bit._05
/* DEFINIZIONE 0.001 PER VOLANTINO */
/* HANDWHEEL DEFINITION: 0.001 */

#define        DEF010      B14.bit._06
/* DEFINIZIONE 0.01 PER VOLANTINO */
/* HANDWHEEL DEFINITION: 0.01 */

#define        DEF100      B14.bit._07
/* DEFINIZIONE 0.1 PER VOLANTINO */
/* HANDWHEEL DEFINITION: 0.1 */

#define        SVOL1       B14.bit._08
/* SELEZIONA VOLANTINO I */
/* SELECTION OF HANDWHEEL 1 */

#define        SVOL2       B14.bit._09
/* SELEZIONA VOLANTINO II */
/* SELECTION OF HANDWHEEL 2 */

#define        SVOL3       B14.bit._10
/* SELEZIONA VOLANTINO III */
/* SELECTION OF HANDWHEEL 3 */

#define        SVOL4       B14.bit._11
/* SELEZIONA VOLANTINO IV (per DRF) */
/* SELECTION OF HANDWHEEL 4 (for DRF) */

#define        RICDRF      B14.bit._12
/* RICHIESTA INSERIMENTO MODALITA' DRF (VOLANTINO) */
/* REQUEST DRF MODE (HANDWHEEL) */

#define        ARICDRF     B14.bit._13
/* APPOGGIO PER VARIAZIONE SU VOLANTINO DRF */
/* AUX. FOR CHANGE IN DRF HANDWHEEL */

#define        RICVFED     B14.bit._14
/* RICHIESTA INSERIMENTO VOLANTINO IN MODALITA' FEED */
/* REQUEST FEED MODE (HANDWHEEL) */

#define        VARVFED     B14.bit._15
/* VARIAZIONE SU VOLANTINO FEED */
/* STATUS OF FEED HANDWHEEL CHANGED */

/* ------------------------------------ */
/*              WORD B15                */
/* ------------------------------------ */

#define       ABIL_ALVL1  B15.bit._00
/*  ABILITAZIONE ALLARMI VOLANTINO 1 */
/*  ABILITAZIONE ALLARMI VOLANTINO 1 */

#define       ABIL_ALVL2  B15.bit._01
/*  ABILITAZIONE ALLARMI VOLANTINO 2 */
/*  ABILITAZIONE ALLARMI VOLANTINO 2 */

#define       ABIL_ALVL3  B15.bit._02
/*  ABILITAZIONE ALLARMI VOLANTINO 3 */
/*  ABILITAZIONE ALLARMI VOLANTINO 3 */

#define        NOOVSTS    B15.bit._07
/* NASCONDE VISUALIZZAZIONE OVERRIDE SPEED TOUCH SCREEN */
/* NASCONDE VISUALIZZAZIONE OVERRIDE SPEED TOUCH SCREEN */

#define        AOVR        B15.bit._08
/* PRESENZA OVERRIDE RAPIDO ASSE SEPARATO DA QUELLO DELLA FEEED */
/* INPUT FOR RAPID OVERRIDES IS SEPARATE FROM THAT FOR FEED */

#define        INCF        B15.bit._09
/* SEGNO INCREMENTO FEED LAVORO ASSE: gestovr(); 1= POSITIVO  0= NEGATIVO  */
/* AXIS WORK FEED INCREASE SIGN: gestovr(); 1= POSITIVE 0= NEGATIVE */

#define        INCR        B15.bit._10
/* SEGNO INCREMENTO FEED RAPIDO ASSE: gestovr(); 1= POSITIVO  0= NEGATIVO  */
/* AXIS RAPID FEED INCREASE SIGN: gestovr(); 1= POSITIVE 0= NEGATIVE */

#define        INCS        B15.bit._11
/* SEGNO INCREMENTO SPEED MANDRINO: gestovr(); 1= POSITIVO  0= NEGATIVO  */
/* SPINDLE SPEED INCREASE SIGN: gestovr(); 1= POSITIVE 0= NEGATIVE */

#define        INCSS       B15.bit._12
/* SEGNO INCREMENTO SPEED MANDRINO SECONDARIO : gestovr(); 1= POSITIVO  0= NEGATIVO  */
/* SECONDARY SPINDLE SPEED INCREASE SIGN: gestovr(); 1= POSITIVE 0= NEGATIVE */

#define        AOVSS       B15.bit._13
/* PRESENZA OVERRIDE SPEED MAND. SECONDARIO ESTERNO */
/* PRESENCE OF EXTERNAL SECONDARY SPINDLE SPEED OVERRIDE */

#define        AOVERTS     B15.bit._14
/* PRESENZA OVERRIDES FEED, RAPIDO E SPEED TOUCH SCREEN  */
/* PRESENZA OVERRIDES FEED, RAPIDO E SPEED TOUCH SCREEN  */

/* ------------------------------------ */
/*              WORD B16                */
/* ------------------------------------ */

#define        COMAZ       B16.ubyte.l
/* NUM. ORDINE ASSE DA MUOVERE DA TARATURA AZIONAMENTI */
/* ORDER NUMBER OF THE AXIS TO MOVE BY DRIVES SETTING */

#define        TARAZ       B16.bit._08
/* MODALITA' TARATURA AZIONAMENTI */
/* DRIVES SETTING MODE */

#define        JOGPAZ      B16.bit._09
/* JOG POSITIVO DA TARATURA AZIONAMENTI */
/* POSITIVE JOG BY DRIVES SETTING */

#define        JOGNAZ      B16.bit._10
/* JOG NEGATIVO DA TARATURA AZIONAMENTI */
/* NEGATIVE JOG BY DRIVES SETTING */

#define        ILSAZ       B16.bit._11
/* LIBERA SERVO DA TARATURA AZIONAMENTI */
/* REQUEST FOR SERVO FREE BY DRIVES SETTING */

#define        SWINTAT     B16.bit._12
/* SOFTWARE DI INTERFACCIA ATTIVO */
/* INTERFACE SOFTWARE ACTIVE */

#define        WSTEPJ      B16.bit._13
/* ATTIVATA WINDOW PER INPUT STEP PER JOG */
/* WINDOW FOR STEP INPUT FOR JOG ACTIVATED */

#define        AJOGSTEP    B16.bit._14
/* RICHIESTA APERTURA WINDOW JOG_STEP */
/* REQUEST TO OPEN JOG STEP WINDOW */

/* ------------------------------------ */
/*              WORD B17                */
/* ------------------------------------ */

#define        AIOVSS      B17.ubyte.l
/* VALORE OVERRIDE SPEED MAND. SECONDARIO DA ESTERNO */
/* SECONDARY SPINDLE SPEED OVERRIDE VALUE FROM KEYBOARD */

#define        COMAXS      B17.ubyte.h
/* APPOGGIO SELEZIONE ASSE per JOG e VOLANTINO: modijog() */
/* axis selection support for JOG and HANDWHEEL: modijog() */

/* ------------------------------------ */
/*              WORD B18                */
/* ------------------------------------ */

#define        COMOVR      B18.ubyte.l
/* VALORE OVERRIDE RAPIDO ASSE: gestovr() */
/* AXIS RAPID OVERRIDE VALUE: gestovr() */

#define        COMOVF      B18.ubyte.h
/* VALORE OVERRIDE FEED ASSE: gestovr() */
/* AXIS FEED OVERRIDE VALUE: gestovr() */

/* ------------------------------------ */
/*              WORD B19                */
/* ------------------------------------ */

#define        COMOVS      B19.ubyte.l
/* APPOGGIO OVERRIDE SPEED MANDRINO: gestovr() */
/* SPINDLE SPEED OVERRIDE SUPPORT: gestovr() */


#define        CODCOM      B19.ubyte.h
/* APPOGGIO PER SELEZIONE ASSE: aggvol() modijog() */
/* SUPPORT FOR AXIS SELECTION: aggvol() modijog() */

/* ------------------------------------ */
/*              WORD B20                */
/* ------------------------------------ */

#define        MINOVS      B20.ubyte.l
/* MINIMA SPEED OVERRIDE MANDRINO: gestovr() */
/* MIN. VALUE FOR SPINDLE SPEED OVERRIDE: gestovr() */

#define        MAXOVS      B20.ubyte.h
/* MAX. SPEED OVERRIDE MANDRINO: gestovr() */
/* MAX. VALUE FOR SPINDLE SPEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B21                */
/* ------------------------------------ */

#define        MAXOVR      B21.ubyte.l
/* MAX. FEED OVERRIDE RAPIDO ASSE: gestovr() */
/* MAX. VALUE FOR AXIS RAPID OVERRIDE: gestovr() */

#define        MAXOVF      B21.ubyte.h
/* MAX. FEED OVERRIDE FEED ASSE: gestovr() */
/* MAX. VALUE FOR AXIS FEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B22                */
/* ------------------------------------ */

#define        FILTROR     B22.ubyte.l
/* FILTRO PER OVERRIDE RAPIDO ASSE: gestovr() */
/* FILTER VALUE FOR AXIS RAPID OVERRIDE: gestovr() */

#define        FILTROF     B22.ubyte.h
/* FILTRO PER OVERRIDE FEED ASSE: gestovr() */
/* FILTER VALUE FOR AXIS FEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B23                */
/* ------------------------------------ */

#define        FILTROS     B23.ubyte.l
/* FILTRO PER OVERRIDE SPEED MANDRINO: gestovr() */
/* FILTER VALUE FOR SPINDLE SPEED OVERRIDE: gestovr() */

#define        FILTROSS     B23.ubyte.h
/* FILTRO PER OVERRIDE SPEED MANDRINO SECONDARIO: gestovr() */
/* FILTER VALUE FOR SECONDARY SPINDLE SPEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B24                */
/* ------------------------------------ */

#define        NAXJOG      B24.ubyte.l
/* NUMERO ASSI DA MUOVERE IN JOG */
/* NUMBER OF AXES TO MOVE IN JOG MODE */

#define        FILTRO      B24.ubyte.h
/* VALORE FILTRO PER DISTURBI SU OVERRIDE ASSI */
/* FILTER VALUE FOR TROUBLES ON AXES OVERRIDE */

/* ------------------------------------ */
/*              WORD B25                */
/* ------------------------------------ */

#define        STBCOD      B25.bit._00
/* STROBE PASSAGGIO TASTO ESTERNO  */
/* EXTERNAL KEY CODE SENDING STROBE  */

#define        PASEXT      B25.bit._02
/* PASSATO TASTO ESTERNO */
/* EXTERNAL KEY CODE PASSED */

#define        CODICE      B25.ubyte.h
/* CODICE TASTO ESTERNO DA INVIARE A CNC: tastcnc() */
/* EXTERNAL KEY CODE TO SEND TO CNC: tastcnc() */

/* ------------------------------------ */
/*              WORD B26                */
/* ------------------------------------ */

#define        NORESET     B26.bit._00
/* BLOCCA PROSECUZIONE FASE DI RESET */
/* STOPS PROSECUTION OF RESET PHASE */

#define        RKEYIM      B26.bit._01
/* RICHIESTA KEY IMMEDIATO (FUNZIONE KEY) */
/* IMMEDIATE KEY REQUEST (KEY FUNCTION) */

#define        RKEYSN      B26.bit._02
/* RICHIESTA KEY SINCRONO (FUNZIONE KEY) */
/* SYNCHRONOUS KEY REQUEST (KEY FUNCTION) */

#define        RKEYAS      B26.bit._03
/* RICHIESTA KEY ASINCRONO (FUNZIONE KEY) */
/* ASYNCHRONOUS KEY REQUEST (KEY FUNCTION) */

#define        STBCODECS  B26.bit._04
/* STROBE PASSAGGIO TASTO ESTERNO (SOLO PER ECS) */
/* EXTERNAL KEY CODE SENDING STROBE (ONLY FOR ECS) */

#define        CODECSEXE  B26.bit._05
/* TASTO ESTERNO PASSATO A CNC (SOLO PER ECS) */
/* EXTERNAL KEY SENT TO CNC (ONLY FOR ECS) */

#define        CODECS  B26.ubyte.h
/* CODICE TASTO ESTERNO DA INVIARE A CNC (SOLO PER ECS) */
/* EXTERNAL KEY CODE TO SEND TO CNC (ONLY FOR ECS) */

/* ------------------------------------ */
/*              WORD B27                */
/* ------------------------------------ */

#define        HLDFRE0     B27.bit._00
/* HOLD ASSE FRE DI ORDINE 0 */
/* HOLD FOR FRE AXIS OF ORDER 0 */
#define        HLDFRE1     B27.bit._01
#define        HLDFRE2     B27.bit._02
#define        HLDFRE3     B27.bit._03
#define        HLDFRE4     B27.bit._04
#define        HLDFRE5     B27.bit._05
#define        HLDFRE6     B27.bit._06
#define        HLDFRE7     B27.bit._07
#define        HLDFRE8     B27.bit._08
#define        HLDFRE9     B27.bit._09
#define        HLDFRE10    B27.bit._10
#define        HLDFRE11    B27.bit._11
#define        HLDFRE12    B27.bit._12
#define        HLDFRE13    B27.bit._13
#define        HLDFRE14    B27.bit._14
#define        HLDFRE15    B27.bit._15
/* HOLD ASSE FRE DI ORDINE 15 */
/* HOLD FOR FRE AXIS OF ORDER 15 */

/* ------------------------------------ */
/*              WORD B28                */
/* ------------------------------------ */

#define        OVF         B28.ubyte.l
/* APP. OVERRIDE LAVORO ASSI: gestovr() */
/* AUX. FOR AXES FEED OVERRIDE: gestovr() */

#define        OVR         B28.ubyte.h
/* APP. OVERRIDE RAPIDO ASSI: gestovr() */
/* AUX. FOR AXES RAPID OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B29                */
/* ------------------------------------ */

#define        OVS         B29.ubyte.l
/* APP. OVERRIDE SPEED MANDRINO: gestovr() */
/* AUX. FOR SPINDLE SPEED OVERRIDE: gestovr() */

#define        OVSS        B29.ubyte.h
/* APP. OVERRIDE SPEED MANDRINO SECONDARIO: gestovr() */
/* AUX. FOR SECONDARY SPINDLE SPEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B30                */
/* ------------------------------------ */

#define        ORDMAG      B30.byte.l
/* NUMERO ORDINE DI AXS.TAR ASSE MAGAZZINO (TCI)*/
/* ORDER NUMBER IN AXS.TAR OF THE WAREHOUSE AXIS (TCI)*/

#define        COMOVSS     B30.ubyte.h
/* APPOGGIO OVERRIDE SPEED MANDRINO SECONDARIO: gestovr() */
/* SECONDARY SPINDLE SPEED OVERRIDE SUPPORT: gestovr() */

/* ------------------------------------ */
/*              WORD B31                */
/* ------------------------------------ */

#define        BLCAX0      B31.bit._00
/* ASSE DI ORDINE 0 BLOCCATO (ASSI) */
/* AXIS OF ORDER 0 STOPPED (AXES) */
#define        BLCAX1      B31.bit._01
#define        BLCAX2      B31.bit._02
#define        BLCAX3      B31.bit._03
#define        BLCAX4      B31.bit._04
#define        BLCAX5      B31.bit._05
#define        BLCAX6      B31.bit._06
#define        BLCAX7      B31.bit._07
#define        BLCAX8      B31.bit._08
#define        BLCAX9      B31.bit._09
#define        BLCAX10     B31.bit._10
#define        BLCAX11     B31.bit._11
#define        BLCAX12     B31.bit._12
#define        BLCAX13     B31.bit._13
#define        BLCAX14     B31.bit._14
#define        BLCAX15     B31.bit._15
/* ASSE DI ORDINE 15 BLOCCATO (ASSI)*/
/* AXIS OF ORDER 15 STOPPED (AXES) */

/* ------------------------------------ */
/*              WORD B32                */
/* ------------------------------------ */

#define        RABIL0      B32.bit._00
/* RICHIESTA ABILITAZIONE ASSE DI ORDINE 0 (ASSI)*/
/* ACTIVATE REQUEST FOR ORDER 0 AXIS (AXES)*/
#define        RABIL1      B32.bit._01
#define        RABIL2      B32.bit._02
#define        RABIL3      B32.bit._03
#define        RABIL4      B32.bit._04
#define        RABIL5      B32.bit._05
#define        RABIL6      B32.bit._06
#define        RABIL7      B32.bit._07
#define        RABIL8      B32.bit._08
#define        RABIL9      B32.bit._09
#define        RABIL10     B32.bit._10
#define        RABIL11     B32.bit._11
#define        RABIL12     B32.bit._12
#define        RABIL13     B32.bit._13
#define        RABIL14     B32.bit._14
#define        RABIL15     B32.bit._15
/* RICHIESTA ABILITAZIONE ASSE DI ORDINE 15 (ASSI)*/
/* ACTIVATE REQUEST FOR ORDER 15 AXIS (AXES)*/

/* ------------------------------------ */
/*              WORD B33                */
/* ------------------------------------ */

#define        ABIL0       B33.bit._00
/* ASSE DI ORDINE 0 ABILITATO (ASSI)*/
/* AXIS OF ORDER 0 ACTIVATED (AXES)*/
#define        ABIL1       B33.bit._01
#define        ABIL2       B33.bit._02
#define        ABIL3       B33.bit._03
#define        ABIL4       B33.bit._04
#define        ABIL5       B33.bit._05
#define        ABIL6       B33.bit._06
#define        ABIL7       B33.bit._07
#define        ABIL8       B33.bit._08
#define        ABIL9       B33.bit._09
#define        ABIL10      B33.bit._10
#define        ABIL11      B33.bit._11
#define        ABIL12      B33.bit._12
#define        ABIL13      B33.bit._13
#define        ABIL14      B33.bit._14
#define        ABIL15      B33.bit._15
/* ASSE DI ORDINE 15 ABILITATO (ASSI)*/
/* AXIS OF ORDER 15 ACTIVATED (AXES)*/

/* ------------------------------------ */
/*              WORD B34                */
/* ------------------------------------ */

#define        RILS0       B34.bit._00
/* RICHIESTA LIBERA SERVO ASSE ORDINE 0 (ASSI)*/
/* REQUEST FOR FREE SERVO OF AXIS 0 (AXES)*/
#define        RILS1       B34.bit._01
#define        RILS2       B34.bit._02
#define        RILS3       B34.bit._03
#define        RILS4       B34.bit._04
#define        RILS5       B34.bit._05
#define        RILS6       B34.bit._06
#define        RILS7       B34.bit._07
#define        RILS8       B34.bit._08
#define        RILS9       B34.bit._09
#define        RILS10      B34.bit._10
#define        RILS11      B34.bit._11
#define        RILS12      B34.bit._12
#define        RILS13      B34.bit._13
#define        RILS14      B34.bit._14
#define        RILS15      B34.bit._15
/* RICHIESTA LIBERA SERVO ASSE ORDINE 15 (ASSI)*/
/* REQUEST FOR FREE SERVO OF AXIS 15 (AXES)*/

/* ------------------------------------ */
/*              WORD B35                */
/* ------------------------------------ */

#define        AM03        B35.bit._08
/* AUX. ABILITAZIONE MANDRINO CON M03 */
/* AUX. TO ACTIVATE SPINDLE IN M03; aggmnd() */

#define        AM04        B35.bit._09
/* AUX. ABILITAZIONE MANDRINO CON M04 */
/* AUX. TO ACTIVATE SECONDARY SPINDLE WITH M04; aggmnd() */

#define        AM05        B35.bit._10
/* AUX. DISABILITAZIONE MANDRINO CON M05 */
/* AUX. TO DEACTIVATE SPINDLE WITH M05; aggmnd() */

#define        AM19        B35.bit._11
/* AUX. ABILITAZIONE MANDRINO CON M19 */
/* AUX. TO ACTIVATE SPINDLE WITH M19; aggmnd() */

#define        ACG         B35.bit._12
/* AUX. ABILITAZIONE MANDRINO CON CAMBIO GAMMA; aggmnd()*/
/* AUX. TO ACTIVATE SPINDLE WITH GEAR CHANGE; aggmnd() */

#define        VELCG       B35.bit._13
/* VELOCITA' DI CAMBIO GAMMA MANDRINO RAGGIUNTA; aggmnd() */
/* SPEED OF GEAR CHANGE FOR THE SPINDLE REACHED; aggmnd() */

#define        M19OK       B35.bit._14
/* MANDRINO ORIENTATO CON M19; aggmnd() */
/* SPINDLE ORIENTED WITH M19; aggmnd() */

#define        OSOK        B35.bit._15
/* VELOCITA' MANDRINO RAGGIUNTA; aggmnd() */
/* SPINDLE SPEED REACHED; aggmnd() */

/* ------------------------------------ */
/*              WORD B36                */
/* ------------------------------------ */

#define        ORDMND      B36.word
/* NUMERO ORDINE DI AXS.TAR MANDRINO */
/* ORDER NUMBER IN AXS.TAR OF THE SPINDLE AXIS */

/* ------------------------------------ */
/*              WORD B37                */
/* ------------------------------------ */

#define        ORDMNDS     B37.word
/* NUMERO ORDINE DI AXS.TAR MANDRINO SECONDARIO */
/* ORDER NUMBER IN AXS.TAR OF THE SECONDARY SPINDLE AXIS */

/* ------------------------------------ */
/*              WORD B38                */
/* ------------------------------------ */

#define        LAMPW1      B38.word
/* APPOGGIO PRIMA WORD LAMPADE (VARIE)*/
/* WORD 1 FOR LAMPS (SUNDRIES)*/

#define        LPSET       B38.bit._00
/* LAMPADA MODO SET (VARIE) */
/* SET MODE LAMP (SUNDRIES) */

#define        LPJOG       B38.bit._01
/* LAMPADA MODO JOG (VARIE) */
/* JOG MODE LAMP (SUNDRIES) */

#define        LPMDI       B38.bit._02
/* LAMPADA MODO MANUALE (VARIE) */
/* MANUAL MODE LAMP (SUNDRIES) */

#define        LPAUTO      B38.bit._03
/* LAMPADA MODO AUTOMATICO (VARIE) */
/* AUTOMATIC MODE LAMP (SUNDRIES) */

#define        LPEXE       B38.bit._04
/* LAMPADA MODO ESECUZIONE (VARIE) */
/* EXECUTION MODE LAMP (SUNDRIES) */

#define        LPCNT       B38.bit._05
/* LAMPADA MODO CONTINUA (VARIE) */
/* CONTINUOUS MODE LAMP (SUNDRIES) */

#define        LPCOPIA     B38.bit._06
/* LAMPADA MODO COPIA (VARIE) */
/* DIGITIZING MODE LAMP (SUNDRIES) */


#define        LPJSTEP     B38.bit._08
/* LAMPADA MODO JOG ASSI A STEP */
/* STEP AXES JOG MODE LAMP */

#define        LPJVEL      B38.bit._09
/* LAMPADA MODO JOG ASSI VELOCITA' */
/* VELOCITY AXES JOG MODE LAMP */

#define        LPJRAP      B38.bit._10
/* LAMPADA MODO JOG ASSI RAPIDO */
/* RAPID AXES JOG MODE LAMP */

#define        LPVOL       B38.bit._11
/* LAMPADA MODO VOLANTINO */
/* HANDWHEEL MODE LAMP */

#define        LPJOGP      B38.bit._13
/* LAMPADA MODO JOG ASSI POSITIVO */
/* POSITIVE AXES JOG MODE LAMP */

#define        LPJOGN      B38.bit._14
/* LAMPADA MODO JOG ASSI NEGATIVO */
/* NEGATIVE AXES JOG MODE LAMP */

/* ------------------------------------ */
/*              WORD B39                */
/* ------------------------------------ */

#define        LAMPW2      B39.word
/* APPOGGIO SECONDA WORD LAMPADE (VARIE) */
/* WORD 2 FOR LAMPS (SUNDRIES) */

#define        LPS0001     B39.bit._00
/* LAMPADA JOG ASSI SPAZIO 1 micron */
/* AXES JOG LAMP: SPACE= 1 micron */

#define        LPS0010     B39.bit._01
/* LAMPADA JOG ASSI SPAZIO 10 micron */
/* AXES JOG LAMP: SPACE= 10 microns */

#define        LPS0100     B39.bit._02
/* LAMPADA JOG ASSI SPAZIO 100 micron */
/* AXES JOG LAMP: SPACE= 100 microns */

#define        LPS1        B39.bit._03
/* LAMPADA JOG ASSI SPAZIO 1 millimetro */
/* AXES JOG LAMP: SPACE= 1 millimeter */

#define        LPS10       B39.bit._04
/* LAMPADA JOG ASSI SPAZIO 10 millimetri */
/* AXES JOG LAMP: SPACE= 10 millimetres */

#define        LPS100      B39.bit._05
/* LAMPADA JOG ASSI SPAZIO 100 millimetri */
/* AXES JOG LAMP: SPACE= 100 millimetres */


#define        LPV1        B39.bit._11
/* LAMPADA PESO 1 VOLANTINO */
/* HANDWHEEL LAMP: STEP= 1 */

#define        LPV10       B39.bit._12
/* LAMPADA PESO 10 VOLANTINO */
/* HANDWHEEL LAMP: STEP= 10 */

#define        LPV100      B39.bit._13
/* LAMPADA PESO 100 VOLANTINO */
/* HANDWHEEL LAMP: STEP= 100 */

/* ------------------------------------ */
/*              WORD B40                */
/* ------------------------------------ */

#define        LAMPW3      B40.word
/* APPOGGIO TERZA WORD LAMPADE (VARIE) */
/* WORD 3 FOR LAMPS (SUNDRIES) */

#define        LPFAST      B40.bit._00
/* LAMPADA MODO FAST (VARIE) */
/* FAST MODE LAMP (SUNDRIES) */

#define        LPFIND      B40.bit._01
/* LAMPADA MODO RICERCA (VARIE) */
/* SEARCH MODE LAMP (SUNDRIES) */

#define        LPREP       B40.bit._02
/* LAMPADA MODO RIPOSIZIONAMENTO (VARIE) */
/* REPOSITIONING MODE LAMP (SUNDRIES) */


#define        LPSTORE     B40.bit._08
/* LAMPADA MODO STORE (COPIA) */
/* STORE MODE LAMP (DIGITIZING) */

#define        LPMADIG     B40.bit._09
/* LAMPADA MODO MADIG (COPIA) */
/* MADIG MODE LAMP (DIGITIZING) */

#define        LPHOLDX     B40.bit._10
/* LAMPADA HOLD ASSE X (COPIA) */
/* X AXIS HOLD LAMP (DIGITIZING) */

#define        LPHOLDY     B40.bit._11
/* LAMPADA HOLD ASSE Y (COPIA) */
/* Y AXIS HOLD LAMP (DIGITIZING) */

#define        LPHOLDZ     B40.bit._12
/* LAMPADA HOLD ASSE Z (COPIA) */
/* Z AXIS HOLD LAMP (DIGITIZING) */

#define        LPSTEP      B40.bit._13
/* LAMPADA MODO STEP (COPIA) */
/* STEP MODE LAMP (DIGITIZING) */

#define        LPISST      B40.bit._14
/* LAMPADA SOSPENSIONE SICUREZZA TASTO (COPIA) */
/* PROBE SAFETY SUSPENSION LAMP (DIGITIZING) */

/* ------------------------------------ */
/*              WORD B41                */
/* ------------------------------------ */

#define        WESITO      B41.word
/* ESITO WINDOW PER INPUT STEP PER JOG */
/* WINDOW RESULT FOR STEP INPUT FOR JOG */

/* ------------------------------------ */
/*              WORD B42 - B43          */
/* ------------------------------------ */

#define        INJS        D_B42
/* INCREMENTO IN MICRON JOG DI SPAZIO ASSI */
/* STEP, IN MICRONS, OF THE AXES STEP JOG */

/* ------------------------------------ */
/*              WORD B44                */
/* ------------------------------------ */

#define        WPLCTST     B44.word
/* Risultato del test sulla WINDOW PLC */
/* Output of the test on the PLC WINDOW */

/* ------------------------------------ */
/*              WORD B45                */
/* ------------------------------------ */

#define        OPE_WIN     B45.bit._00
/* Richiesta di apertura WINDOW PLC */
/* PLC WINDOW open request */

#define        WIN_PLC     B45.bit._01
/* Comando di apertura WINDOW PLC inoltrato*/
/* PLC WINDOW open request passed */

#define        WIN_OPN     B45.bit._02
/* WINDOW PLC aperta */
/* PLC WINDOW opened */

#define        WIN_VIS     B45.bit._03
/* WINDOW PLC visibile */
/* PLC WINDOW visible */

#define        WIN_ENT     B45.bit._04
/* Premuto ENTER per WINDOW PLC */
/* Pressed ENTER for PLC WINDOW */

#define        WIN_ESC     B45.bit._05
/* Premuto ESC per WINDOW PLC */
/* Pressed ESC for PLC WINDOW */

#define        WIN_CLK    B45.bit._06
/* Click fuori finestra per WINDOW PLC */
/* Out of window click for PLC WINDOW */


/* ------------------------------------ */
/*              WORD B46                */
/* ------------------------------------ */
#define        KCNINP     B46.word
/* WORD APPOGGIO PER INGRESSI DA TASTIERA */
/* SUPPORT WORD FOR INPUTS FROM KEYBOARD */
#define        KCNINP00    B46.bit._00
/* INGRESSI DA TASTIERA (Primo input)*/
/* INPUTS FROM KEYBOARD (First input)*/
#define        KCNINP01    B46.bit._01
#define        KCNINP02    B46.bit._02
#define        KCNINP03    B46.bit._03
#define        KCNINP04    B46.bit._04
#define        KCNINP05    B46.bit._05
#define        KCNINP06    B46.bit._06
#define        KCNINP07    B46.bit._07
#define        KCNINP08    B46.bit._08
#define        KCNINP09    B46.bit._09
#define        KCNINP10    B46.bit._10
#define        KCNINP11    B46.bit._11
#define        KCNINP12    B46.bit._12
#define        KCNINP13    B46.bit._13
#define        KCNINP14    B46.bit._14
#define        KCNINP15    B46.bit._15
/* INGRESSI DA TASTIERA (Ultimo input)*/
/* INPUTS FROM KEYBOARD (Last input)*/


/* ------------------------------------ */
/*              WORD B47                */
/* ------------------------------------ */
#define        KCNOUT     B47.ubyte.l
/* BYTE APPOGGIO USCITE SU TASTIERA */
/* SUPPORT BYTE FOR KEYBOARD OUTPUTS */
#define        KCNOUT00    B47.bit._00
/* USCITE SU TASTIERA (Primo Output)*/
/* KEYBOARD OUTPUTS (First Output)*/
#define        KCNOUT01    B47.bit._01
#define        KCNOUT02    B47.bit._02
#define        KCNOUT03    B47.bit._03
#define        KCNOUT04    B47.bit._04
#define        KCNOUT05    B47.bit._05
#define        KCNOUT06    B47.bit._06
#define        KCNOUT07    B47.bit._07
/* USCITE SU TASTIERA (Ultimo Output)*/
/* KEYBOARD OUTPUTS (Last Output)*/


/* ------------------------------------ */
/*              WORD B48                */
/* ------------------------------------ */

#define        IOVR        B48.ubyte.l
/* VALORE OVERRIDE RAPIDO ASSI (0...100%) */
/* AXES RAPID OVERRIDE VALUE (0...100%) */

#define        IOVF        B48.ubyte.h
/* VALORE OVERRIDE FEED ASSI (0...255%) */
/* AXES FEED OVERRIDE VALUE (0...255%) */

/* ------------------------------------ */
/*              WORD B49                */
/* ------------------------------------ */

#define        IOVS        B49.ubyte.l
/* VALORE OVERRIDE SPEED MANDRINO (0...255%) */
/* SPINDLE SPEED OVERRIDE VALUE (0...255%) */

#define        IOVSS       B49.ubyte.h
/* VALORE OVERRIDE SPEED MANDRINO SECONDARIO (0...255%) */
/* SECONDARY SPINDLE SPEED OVERRIDE VALUE (0...255%) */

/* ------------------------------------ */
/*              WORD B50                */
/* ------------------------------------ */

#define      RIMPV1       B50.ubyte.l
/* RAPPORTO CONTEGGIO PER VOLANTINO 1; Default = 4 */
/* SCALE RATIO FOR HANDWHEEL 1; DEFAULT = 4 */
#define      RIMPV2       B50.ubyte.h
/* RAPPORTO CONTEGGIO PER VOLANTINO 2; Default = 4 */
/* SCALE RATIO FOR HANDWHEEL 2; DEFAULT = 4 */

/* ------------------------------------ */
/*              WORD B51                */
/* ------------------------------------ */

#define      RIMPV3       B51.ubyte.l
/* RAPPORTO  CONTEGGIO PER VOLANTINO 3; Default = 4 */
/* SCALE RATIO FOR HANDWHEEL 3; DEFAULT = 4 */

/* ------------------------------------ */
/*              WORD B52                */
/* ------------------------------------ */

#define      DEDRYRUN       B52.word
/* RICHIESTO DATA-ENTRY PER DRY_RUN     */
/* DATA-ENTRY FOR DRY_RUN NEEDED        */

/* ------------------------------------ */
/*              WORD B53                */
/* ------------------------------------ */

/* STATUS WORD-0 PROGRAMMABILE DEL PLC */
/* PROGRAMMABLE PLC STATUS WORD-0      */
#define      IPSTATUSWORD0   B53.word
#define      IPSTATUS00      B53.bit._00
#define      IPSTATUS01      B53.bit._01
#define      IPSTATUS02      B53.bit._02
#define      IPSTATUS03      B53.bit._03
#define      IPSTATUS04      B53.bit._04
#define      IPSTATUS05      B53.bit._05
#define      IPSTATUS06      B53.bit._06
#define      IPSTATUS07      B53.bit._07
#define      IPSTATUS08      B53.bit._08
#define      IPSTATUS09      B53.bit._09
#define      IPSTATUS10      B53.bit._10
#define      IPSTATUS11      B53.bit._11
#define      IPSTATUS12      B53.bit._12
#define      IPSTATUS13      B53.bit._13
#define      IPSTATUS14      B53.bit._14
#define      IPSTATUS15      B53.bit._15

/* ------------------------------------ */
/*              WORD B54                */
/* ------------------------------------ */

/* STATUS WORD-1 PROGRAMMABILE DEL PLC */
/* PROGRAMMABLE PLC STATUS WORD-1      */
#define      IPSTATUSWORD1   B54.word
#define      IPSTATUS16      B54.bit._00
#define      IPSTATUS17      B54.bit._01
#define      IPSTATUS18      B54.bit._02
#define      IPSTATUS19      B54.bit._03
#define      IPSTATUS20      B54.bit._04
#define      IPSTATUS21      B54.bit._05
#define      IPSTATUS22      B54.bit._06
#define      IPSTATUS23      B54.bit._07
#define      IPSTATUS24      B54.bit._08
#define      IPSTATUS25      B54.bit._09
#define      IPSTATUS26      B54.bit._10
#define      IPSTATUS27      B54.bit._11
#define      IPSTATUS28      B54.bit._12
#define      IPSTATUS29      B54.bit._13
#define      IPSTATUS30      B54.bit._14
#define      IPSTATUS31      B54.bit._15

/* ------------------------------------ */
/*              WORD B55                */
/* ------------------------------------ */

#define      SAVEPROG       B55.word
/* INDICE "n" DEL FILE SAVEPROGn.TAR   */
/* INDEX  "n" OF  "SAVEPROGn.TAR" FILE */

/* ------------------------------------ */
/*              WORD B56                */
/* ------------------------------------ */

#define      CUSTOMVAR_SEC  B56.word
/* NUMERO "n" DELLA SEZIONE [NomeSezione.n] NEL FILE "CUSTOMVAR.xxx" */
/* SECTION NUMBER "n"       [SectionName.n] ON  "CUSTOMVAR.xxx" FILE */
/* INDEX  "n" ON  FILE NAME SAVEPROGn.TAR */

/* ------------------------------------ */
/*              WORD B57                */
/* OINFOFORMAT == 0 SE NESSUN FORM VIS. */
/* ------------------------------------ */
#define      OINFOFORMAT    B57.ubyte.l
/* INFORMAZIONE FORMATO AMBIENTE ATTUALE */
/* INFORMAZIONE FORMATO AMBIENTE ATTUALE */

#define      OFORMMU        B57.bit._00
/* ATTIVO FORMATO AMBIENTE M.U.          */
/* ATTIVO FORMATO AMBIENTE M.U.          */

#define      OFORMPRG       B57.bit._01
/* ATTIVO FORMATO AMBIENTE PRG           */
/* ATTIVO FORMATO AMBIENTE PRG           */

#define      OFORMPLC       B57.bit._02
/* ATTIVO FORMATO AMBIENTE PLC           */
/* ATTIVO FORMATO AMBIENTE PLC           */

#define      OFORMSETUP     B57.bit._03
/* ATTIVO FORMATO AMBIENTE SETUP         */
/* ATTIVO FORMATO AMBIENTE SETUP         */

#define      OFORMCLSCH     B57.bit._04
/* ATTIVO FORMATO PULIZIA SCHERMO         */
/* ATTIVO FORMATO PULIZIA SCHERMO         */

/* ------------------------------------ */
/*              WORD B58                */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B59                */
/* ------------------------------------ */

#define        CNQAL1      B59.ubyte.l
/* Contatore giri primo QAL slave (QAL1) */
/* Turns Counter of first Slave QAL (QAL1) */

#define        CNQAL2      B59.ubyte.h
/* Contatore giri secondo QAL slave (QAL2) */
/* Turns Counter of second Slave QAL (QAL2) */

/* ------------------------------------ */
/*              WORD B60                */
/* ------------------------------------ */

#define        AKEY00      B60.word
/* WORD APPOGGIO PER KEY 0 - 15 */
/* AUX. WORD FOR KEY 0 - 15 */
#define        KEY00       B60.bit._00
/* RICHIESTA ESECUZIONE FUNZIONE KEY 0 (Primo KEY) */
/* Execution request for KEY function 0 (First KEY) */
#define        KEY01       B60.bit._01
#define        KEY02       B60.bit._02
#define        KEY03       B60.bit._03
#define        KEY04       B60.bit._04
#define        KEY05       B60.bit._05
#define        KEY06       B60.bit._06
#define        KEY07       B60.bit._07
#define        KEY08       B60.bit._08
#define        KEY09       B60.bit._09
#define        KEY10       B60.bit._10
#define        KEY11       B60.bit._11
#define        KEY12       B60.bit._12
#define        KEY13       B60.bit._13
#define        KEY14       B60.bit._14
#define        KEY15       B60.bit._15

/* ------------------------------------ */
/*              WORD B61                */
/* ------------------------------------ */

#define        AKEY01      B61.word
/* WORD APPOGGIO PER KEY 16 - 31 */
/* AUX. WORD FOR KEY 16 - 31 */
#define        KEY16       B61.bit._00
#define        KEY17       B61.bit._01
#define        KEY18       B61.bit._02
#define        KEY19       B61.bit._03
#define        KEY20       B61.bit._04
#define        KEY21       B61.bit._05
#define        KEY22       B61.bit._06
#define        KEY23       B61.bit._07
#define        KEY24       B61.bit._08
#define        KEY25       B61.bit._09
#define        KEY26       B61.bit._10
#define        KEY27       B61.bit._11
#define        KEY28       B61.bit._12
#define        KEY29       B61.bit._13
#define        KEY30       B61.bit._14
#define        KEY31       B61.bit._15

/* ------------------------------------ */
/*              WORD B62                */
/* ------------------------------------ */

#define        AKEY02      B62.word
/* WORD APPOGGIO PER KEY 32 - 47 */
/* AUX. WORD FOR KEY 32 - 47 */
#define        KEY32       B62.bit._00
#define        KEY33       B62.bit._01
#define        KEY34       B62.bit._02
#define        KEY35       B62.bit._03
#define        KEY36       B62.bit._04
#define        KEY37       B62.bit._05
#define        KEY38       B62.bit._06
#define        KEY39       B62.bit._07
#define        KEY40       B62.bit._08
#define        KEY41       B62.bit._09
#define        KEY42       B62.bit._10
#define        KEY43       B62.bit._11
#define        KEY44       B62.bit._12
#define        KEY45       B62.bit._13
#define        KEY46       B62.bit._14
#define        KEY47       B62.bit._15

/* ------------------------------------ */
/*              WORD B63                */
/* ------------------------------------ */

#define        AKEY03      B63.word
/* WORD APPOGGIO PER KEY 48 - 63 */
/* AUX. WORD FOR KEY 48 - 63 */
#define        KEY48       B63.bit._00
#define        KEY49       B63.bit._01
#define        KEY50       B63.bit._02
#define        KEY51       B63.bit._03
#define        KEY52       B63.bit._04
#define        KEY53       B63.bit._05
#define        KEY54       B63.bit._06
#define        KEY55       B63.bit._07
#define        KEY56       B63.bit._08
#define        KEY57       B63.bit._09
#define        KEY58       B63.bit._10
#define        KEY59       B63.bit._11
#define        KEY60       B63.bit._12
#define        KEY61       B63.bit._13
#define        KEY62       B63.bit._14
#define        KEY63       B63.bit._15

/* ------------------------------------ */
/*              WORD B64                */
/* ------------------------------------ */

#define        AKEY04      B64.word
/* WORD APPOGGIO PER KEY 64 - 79 */
/* AUX. WORD FOR KEY 64 - 79 */
#define        KEY64       B64.bit._00
#define        KEY65       B64.bit._01
#define        KEY66       B64.bit._02
#define        KEY67       B64.bit._03
#define        KEY68       B64.bit._04
#define        KEY69       B64.bit._05
#define        KEY70       B64.bit._06
#define        KEY71       B64.bit._07
#define        KEY72       B64.bit._08
#define        KEY73       B64.bit._09
#define        KEY74       B64.bit._10
#define        KEY75       B64.bit._11
#define        KEY76       B64.bit._12
#define        KEY77       B64.bit._13
#define        KEY78       B64.bit._14
#define        KEY79       B64.bit._15

/* ------------------------------------ */
/*              WORD B65                */
/* ------------------------------------ */

#define        AKEY05      B65.word
/* WORD APPOGGIO PER KEY 80 - 95 */
/* AUX. WORD FOR KEY 80 - 95 */
#define        KEY80       B65.bit._00
#define        KEY81       B65.bit._01
#define        KEY82       B65.bit._02
#define        KEY83       B65.bit._03
#define        KEY84       B65.bit._04
#define        KEY85       B65.bit._05
#define        KEY86       B65.bit._06
#define        KEY87       B65.bit._07
#define        KEY88       B65.bit._08
#define        KEY89       B65.bit._09
#define        KEY90       B65.bit._10
#define        KEY91       B65.bit._11
#define        KEY92       B65.bit._12
#define        KEY93       B65.bit._13
#define        KEY94       B65.bit._14
#define        KEY95       B65.bit._15

/* ------------------------------------ */
/*              WORD B66                */
/* ------------------------------------ */

#define        AKEY06      B66.word
/* WORD APPOGGIO PER KEY 96 - 99 */
/* AUX. WORD FOR KEY 96 - 99 */
#define        KEY96       B66.bit._00
#define        KEY97       B66.bit._01
#define        KEY98       B66.bit._02
#define        KEY99       B66.bit._03
/* RICHIESTA ESECUZIONE FUNZIONE KEY 99 (Ultimo KEY)*/
/* Execution request for KEY function 99 (Last KEY) */

/* ------------------------------------ */
/*              WORD B67                */
/* ------------------------------------ */

#define        MINOVSS     B67.ubyte.l
/* MINIMA SPEED OVERRIDE MANDRINO SECONDARIO: gestovr() */
/* MINIM SECONDARY SPINDLE SPEED OVERRIDE: gestovr() */

#define        MAXOVSS     B67.ubyte.h
/* MAX. SPEED OVERRIDE MANDRINO SECONDARIO: gestovr() */
/* MAXIMUM SECONDARY SPINDLE SPEED OVERRIDE: gestovr() */

/* ------------------------------------ */
/*              WORD B68                */
/* ------------------------------------ */

#define        APVOL       B68.ubyte.l
/* APPOGGIO PER I E II VOLANTINO */
/* SUPPORT FOR THE FIRST AND SECOND HANDWHEEL */

#define        APVOL3      B68.ubyte.h
/* APPOGGIO III VOLANTINO (digit pesante) */
/* SUPPORT FOR THIRD HANDWHEEL (heavy digit) */

/* ------------------------------------ */
/*              WORD B69                */
/* ------------------------------------ */

#define        APVOL4      B69.ubyte.l
/* APPOGGIO IV VOLANTINO */
/* SUPPORT FOR FOURTH HANDWHEEL */

/* ------------------------------------ */
/*              WORD B70                */
/* ------------------------------------ */

#define        AALR00       B70.word
/* APPOGGIO PER ALLARMI 0 - 15 */
/* SUPPORT TO ALARMS 0 - 15 */

#define        ALR00        B70.bit._00
/* ATTIVAZIONE ALLARME 0 (Primo Allarme) */
/* ALARM 0 ACTIVATION (first alarm) */

#define        ALR01        B70.bit._01
#define        ALR02        B70.bit._02
#define        ALR03        B70.bit._03
#define        ALR04        B70.bit._04
#define        ALR05        B70.bit._05
#define        ALR06        B70.bit._06
#define        ALR07        B70.bit._07
#define        ALR08        B70.bit._08
#define        ALR09        B70.bit._09
#define        ALR10        B70.bit._10
#define        ALR11        B70.bit._11
#define        ALR12        B70.bit._12
#define        ALR13        B70.bit._13
#define        ALR14        B70.bit._14
#define        ALR15        B70.bit._15

/* ------------------------------------ */
/*              WORD B71                */
/* ------------------------------------ */

#define        AALR01       B71.word
/* APPOGGIO PER ALLARMI 16 - 31 */
/* SUPPORT TO ALARMS 16-31 */

#define        ALR16        B71.bit._00
#define        ALR17        B71.bit._01
#define        ALR18        B71.bit._02
#define        ALR19        B71.bit._03
#define        ALR20        B71.bit._04
#define        ALR21        B71.bit._05
#define        ALR22        B71.bit._06
#define        ALR23        B71.bit._07
#define        ALR24        B71.bit._08
#define        ALR25        B71.bit._09
#define        ALR26        B71.bit._10
#define        ALR27        B71.bit._11
#define        ALR28        B71.bit._12
#define        ALR29        B71.bit._13
#define        ALR30        B71.bit._14
#define        ALR31        B71.bit._15

/* ------------------------------------ */
/*              WORD B72                */
/* ------------------------------------ */

#define        AALR02       B72.word
/* APPOGGIO PER ALLARMI 32 - 47 */
/* SUPPORT TO ALARMS 32-47 */

#define        ALR32        B72.bit._00
#define        ALR33        B72.bit._01
#define        ALR34        B72.bit._02
#define        ALR35        B72.bit._03
#define        ALR36        B72.bit._04
#define        ALR37        B72.bit._05
#define        ALR38        B72.bit._06
#define        ALR39        B72.bit._07
#define        ALR40        B72.bit._08
#define        ALR41        B72.bit._09
#define        ALR42        B72.bit._10
#define        ALR43        B72.bit._11
#define        ALR44        B72.bit._12
#define        ALR45        B72.bit._13
#define        ALR46        B72.bit._14
#define        ALR47        B72.bit._15

/* ------------------------------------ */
/*              WORD B73                */
/* ------------------------------------ */

#define        AALR03       B73.word
/* APPOGGIO PER ALLARMI 48 - 63 */
/* SUPPORT TO ALARMS 48-63 */

#define        ALR48        B73.bit._00
#define        ALR49        B73.bit._01
#define        ALR50        B73.bit._02
#define        ALR51        B73.bit._03
#define        ALR52        B73.bit._04
#define        ALR53        B73.bit._05
#define        ALR54        B73.bit._06
#define        ALR55        B73.bit._07
#define        ALR56        B73.bit._08
#define        ALR57        B73.bit._09
#define        ALR58        B73.bit._10
#define        ALR59        B73.bit._11
#define        ALR60        B73.bit._12
#define        ALR61        B73.bit._13
#define        ALR62        B73.bit._14
#define        ALR63        B73.bit._15

/* ------------------------------------ */
/*              WORD B74                */
/* ------------------------------------ */

#define        AALR04       B74.word
/* APPOGGIO PER ALLARMI 64 - 79 */
/* SUPPORT TO ALARMS 64-79 */

#define        ALR64        B74.bit._00
#define        ALR65        B74.bit._01
#define        ALR66        B74.bit._02
#define        ALR67        B74.bit._03
#define        ALR68        B74.bit._04
#define        ALR69        B74.bit._05
#define        ALR70        B74.bit._06
#define        ALR71        B74.bit._07
#define        ALR72        B74.bit._08
#define        ALR73        B74.bit._09
#define        ALR74        B74.bit._10
#define        ALR75        B74.bit._11
#define        ALR76        B74.bit._12
#define        ALR77        B74.bit._13
#define        ALR78        B74.bit._14
#define        ALR79        B74.bit._15

/* ------------------------------------ */
/*              WORD B75                */
/* ------------------------------------ */

#define        AALR05       B75.word
/* APPOGGIO PER ALLARMI 80 - 95 */
/* SUPPORT TO ALARMS 80-95 */

#define        ALR80        B75.bit._00
#define        ALR81        B75.bit._01
#define        ALR82        B75.bit._02
#define        ALR83        B75.bit._03
#define        ALR84        B75.bit._04
#define        ALR85        B75.bit._05
#define        ALR86        B75.bit._06
#define        ALR87        B75.bit._07
#define        ALR88        B75.bit._08
#define        ALR89        B75.bit._09
#define        ALR90        B75.bit._10
#define        ALR91        B75.bit._11
#define        ALR92        B75.bit._12
#define        ALR93        B75.bit._13
#define        ALR94        B75.bit._14
#define        ALR95        B75.bit._15

/* ------------------------------------ */
/*              WORD B76                */
/* ------------------------------------ */

#define        AALR06       B76.word
/* APPOGGIO PER ALLARMI 96 - 111 */
/* SUPPORT TO ALARMS 96-111 */

#define        ALR96        B76.bit._00
#define        ALR97        B76.bit._01
#define        ALR98        B76.bit._02
#define        ALR99        B76.bit._03
#define        ALR100       B76.bit._04
#define        ALR101       B76.bit._05
#define        ALR102       B76.bit._06
#define        ALR103       B76.bit._07
#define        ALR104       B76.bit._08
#define        ALR105       B76.bit._09
#define        ALR106       B76.bit._10
#define        ALR107       B76.bit._11
#define        ALR108       B76.bit._12
#define        ALR109       B76.bit._13
#define        ALR110       B76.bit._14
#define        ALR111       B76.bit._15

/* ------------------------------------ */
/*              WORD B77                */
/* ------------------------------------ */

#define        AALR07       B77.word
/* APPOGGIO PER ALLARMI 112 - 127 */
/* SUPPORT TO ALARMS 112-127 */

#define        ALR112       B77.bit._00
#define        ALR113       B77.bit._01
#define        ALR114       B77.bit._02
#define        ALR115       B77.bit._03
#define        ALR116       B77.bit._04
#define        ALR117       B77.bit._05
#define        ALR118       B77.bit._06
#define        ALR119       B77.bit._07
#define        ALR120       B77.bit._08
#define        ALR121       B77.bit._09
#define        ALR122       B77.bit._10
#define        ALR123       B77.bit._11
#define        ALR124       B77.bit._12
#define        ALR125       B77.bit._13
#define        ALR126       B77.bit._14
#define        ALR127       B77.bit._15

/* ------------------------------------ */
/*              WORD B78                */
/* ------------------------------------ */

#define        AALR08       B78.word
/* APPOGGIO PER ALLARMI 128 - 143 */
/* SUPPORT TO ALARMS 128-143 */

#define        ALR128       B78.bit._00
#define        ALR129       B78.bit._01
#define        ALR130       B78.bit._02
#define        ALR131       B78.bit._03
#define        ALR132       B78.bit._04
#define        ALR133       B78.bit._05
#define        ALR134       B78.bit._06
#define        ALR135       B78.bit._07
#define        ALR136       B78.bit._08
#define        ALR137       B78.bit._09
#define        ALR138       B78.bit._10
#define        ALR139       B78.bit._11
#define        ALR140       B78.bit._12
#define        ALR141       B78.bit._13
#define        ALR142       B78.bit._14
#define        ALR143       B78.bit._15

/* ------------------------------------ */
/*              WORD B79                */
/* ------------------------------------ */

#define        AALR09       B79.word
/* APPOGGIO PER ALLARMI 144 - 159 */
/* SUPPORT TO ALARMS 144-159 */

#define        ALR144       B79.bit._00
#define        ALR145       B79.bit._01
#define        ALR146       B79.bit._02
#define        ALR147       B79.bit._03
#define        ALR148       B79.bit._04
#define        ALR149       B79.bit._05
#define        ALR150       B79.bit._06
#define        ALR151       B79.bit._07
#define        ALR152       B79.bit._08
#define        ALR153       B79.bit._09
#define        ALR154       B79.bit._10
#define        ALR155       B79.bit._11
#define        ALR156       B79.bit._12
#define        ALR157       B79.bit._13
#define        ALR158       B79.bit._14
#define        ALR159       B79.bit._15

/* ------------------------------------ */
/*              WORD B80                */
/* ------------------------------------ */

#define        AATT00       B80.word
/* APPOGGIO PER ATTENZIONI 0 - 15 */
/* SUPPORT FOR ATTENTIONS 0-15 */

#define        ATT00        B80.bit._00
/* ATTENZIONE 0 (Prima Attenzione)*/
/* ATTENTION 0 (first attention)*/

#define        ATT01        B80.bit._01
#define        ATT02        B80.bit._02
#define        ATT03        B80.bit._03
#define        ATT04        B80.bit._04
#define        ATT05        B80.bit._05
#define        ATT06        B80.bit._06
#define        ATT07        B80.bit._07
#define        ATT08        B80.bit._08
#define        ATT09        B80.bit._09
#define        ATT10        B80.bit._10
#define        ATT11        B80.bit._11
#define        ATT12        B80.bit._12
#define        ATT13        B80.bit._13
#define        ATT14        B80.bit._14
#define        ATT15        B80.bit._15

/* ------------------------------------ */
/*              WORD B81                */
/* ------------------------------------ */

#define        AATT01       B81.word
/* APPOGGIO PER ATTENZIONI 16 - 31 */
/* SUPPORT FOR ATTENTIONS 16-31 */

#define        ATT16        B81.bit._00
#define        ATT17        B81.bit._01
#define        ATT18        B81.bit._02
#define        ATT19        B81.bit._03
#define        ATT20        B81.bit._04
#define        ATT21        B81.bit._05
#define        ATT22        B81.bit._06
#define        ATT23        B81.bit._07
#define        ATT24        B81.bit._08
#define        ATT25        B81.bit._09
#define        ATT26        B81.bit._10
#define        ATT27        B81.bit._11
#define        ATT28        B81.bit._12
#define        ATT29        B81.bit._13
#define        ATT30        B81.bit._14
#define        ATT31        B81.bit._15

/* ------------------------------------ */
/*              WORD B82                */
/* ------------------------------------ */

#define        AATT02       B82.word
/* APPOGGIO PER ATTENZIONI 32 - 47 */
/* SUPPORT FOR ATTENTIONS 32-47 */

#define        ATT32        B82.bit._00
#define        ATT33        B82.bit._01
#define        ATT34        B82.bit._02
#define        ATT35        B82.bit._03
#define        ATT36        B82.bit._04
#define        ATT37        B82.bit._05
#define        ATT38        B82.bit._06
#define        ATT39        B82.bit._07
#define        ATT40        B82.bit._08
#define        ATT41        B82.bit._09
#define        ATT42        B82.bit._10
#define        ATT43        B82.bit._11
#define        ATT44        B82.bit._12
#define        ATT45        B82.bit._13
#define        ATT46        B82.bit._14
#define        ATT47        B82.bit._15

/* ------------------------------------ */
/*              WORD B83                */
/* ------------------------------------ */

#define        AATT03       B83.word
/* APPOGGIO PER ATTENZIONI 48 - 63 */
/* SUPPORT FOR ATTENTIONS 48-63 */

#define        ATT48        B83.bit._00
#define        ATT49        B83.bit._01
#define        ATT50        B83.bit._02
#define        ATT51        B83.bit._03
#define        ATT52        B83.bit._04
#define        ATT53        B83.bit._05
#define        ATT54        B83.bit._06
#define        ATT55        B83.bit._07
#define        ATT56        B83.bit._08
#define        ATT57        B83.bit._09
#define        ATT58        B83.bit._10
#define        ATT59        B83.bit._11
#define        ATT60        B83.bit._12
#define        ATT61        B83.bit._13
#define        ATT62        B83.bit._14
#define        ATT63        B83.bit._15

/* ------------------------------------ */
/*              WORD B84                */
/* ------------------------------------ */

#define        AATT04       B84.word
/* APPOGGIO PER ATTENZIONI 64 - 79 */
/* SUPPORT FOR ATTENTIONS 64-79 */

#define        ATT64        B84.bit._00
#define        ATT65        B84.bit._01
#define        ATT66        B84.bit._02
#define        ATT67        B84.bit._03
#define        ATT68        B84.bit._04
#define        ATT69        B84.bit._05
#define        ATT70        B84.bit._06
#define        ATT71        B84.bit._07
#define        ATT72        B84.bit._08
#define        ATT73        B84.bit._09
#define        ATT74        B84.bit._10
#define        ATT75        B84.bit._11
#define        ATT76        B84.bit._12
#define        ATT77        B84.bit._13
#define        ATT78        B84.bit._14
#define        ATT79        B84.bit._15

/* ------------------------------------ */
/*              WORD B85                */
/* ------------------------------------ */

#define        AATT05       B85.word
/* APPOGGIO PER ATTENZIONI 80 - 95 */
/* SUPPORT FOR ATTENTIONS 80-95 */

#define        ATT80        B85.bit._00
#define        ATT81        B85.bit._01
#define        ATT82        B85.bit._02
#define        ATT83        B85.bit._03
#define        ATT84        B85.bit._04
#define        ATT85        B85.bit._05
#define        ATT86        B85.bit._06
#define        ATT87        B85.bit._07
#define        ATT88        B85.bit._08
#define        ATT89        B85.bit._09
#define        ATT90        B85.bit._10
#define        ATT91        B85.bit._11
#define        ATT92        B85.bit._12
#define        ATT93        B85.bit._13
#define        ATT94        B85.bit._14
#define        ATT95        B85.bit._15

/* ------------------------------------ */
/*              WORD B86                */
/* ------------------------------------ */

#define        AATT06       B86.word
/* APPOGGIO PER ATTENZIONI 96 - 111 */
/* SUPPORT FOR ATTENTIONS 96-111 */

#define        ATT96        B86.bit._00
#define        ATT97        B86.bit._01
#define        ATT98        B86.bit._02
#define        ATT99        B86.bit._03
#define        ATT100       B86.bit._04
#define        ATT101       B86.bit._05
#define        ATT102       B86.bit._06
#define        ATT103       B86.bit._07
#define        ATT104       B86.bit._08
#define        ATT105       B86.bit._09
#define        ATT106       B86.bit._10
#define        ATT107       B86.bit._11
#define        ATT108       B86.bit._12
#define        ATT109       B86.bit._13
#define        ATT110       B86.bit._14
#define        ATT111       B86.bit._15

/* ------------------------------------ */
/*              WORD B87                */
/* ------------------------------------ */

#define        AATT07       B87.word
/* APPOGGIO PER ATTENZIONI 112 - 127 */
/* SUPPORT FOR ATTENTIONS 112-127 */

#define        ATT112       B87.bit._00
#define        ATT113       B87.bit._01
#define        ATT114       B87.bit._02
#define        ATT115       B87.bit._03
#define        ATT116       B87.bit._04
#define        ATT117       B87.bit._05
#define        ATT118       B87.bit._06
#define        ATT119       B87.bit._07
#define        ATT120       B87.bit._08
#define        ATT121       B87.bit._09
#define        ATT122       B87.bit._10
#define        ATT123       B87.bit._11
#define        ATT124       B87.bit._12
#define        ATT125       B87.bit._13
#define        ATT126       B87.bit._14
#define        ATT127       B87.bit._15

/* ------------------------------------ */
/*              WORD B88                */
/* ------------------------------------ */

#define        AATT08       B88.word
/* APPOGGIO PER ATTENZIONI 128 - 143 */
/* SUPPORT FOR ATTENTIONS 128-143 */

#define        ATT128       B88.bit._00
#define        ATT129       B88.bit._01
#define        ATT130       B88.bit._02
#define        ATT131       B88.bit._03
#define        ATT132       B88.bit._04
#define        ATT133       B88.bit._05
#define        ATT134       B88.bit._06
#define        ATT135       B88.bit._07
#define        ATT136       B88.bit._08
#define        ATT137       B88.bit._09
#define        ATT138       B88.bit._10
#define        ATT139       B88.bit._11
#define        ATT140       B88.bit._12
#define        ATT141       B88.bit._13
#define        ATT142       B88.bit._14
#define        ATT143       B88.bit._15

/* ------------------------------------ */
/*              WORD B89                */
/* ------------------------------------ */

#define        AATT09       B89.word
/* APPOGGIO PER ATTENZIONI 144 - 159 */
/* SUPPORT FOR ATTENTIONS 144-159 */

#define        ATT144       B89.bit._00
#define        ATT145       B89.bit._01
#define        ATT146       B89.bit._02
#define        ATT147       B89.bit._03
#define        ATT148       B89.bit._04
#define        ATT149       B89.bit._05
#define        ATT150       B89.bit._06
#define        ATT151       B89.bit._07
#define        ATT152       B89.bit._08
#define        ATT153       B89.bit._09
#define        ATT154       B89.bit._10
#define        ATT155       B89.bit._11
#define        ATT156       B89.bit._12
#define        ATT157       B89.bit._13
#define        ATT158       B89.bit._14
#define        ATT159       B89.bit._15

/* ------------------------------------ */
/*              WORD B90                */
/* ------------------------------------ */

#define        AECS00        B90.word
/* APPOGGIO PER MESSAGGI ECS 0 - 15 */
/* SUPPORT FOR ECS MESSAGES 0 - 15 */

#define        MECS00        B90.bit._00
/* APPOGGIO PER MESSAGGIO ECS 0 (primo messaggio ECS)*/
/* SUPPORT FOR ECS MESSAGE 0 (first ECS message) */

#define        MECS01        B90.bit._01
#define        MECS02        B90.bit._02
#define        MECS03        B90.bit._03
#define        MECS04        B90.bit._04
#define        MECS05        B90.bit._05
#define        MECS06        B90.bit._06
#define        MECS07        B90.bit._07
#define        MECS08        B90.bit._08
#define        MECS09        B90.bit._09
#define        MECS10        B90.bit._10
#define        MECS11        B90.bit._11
#define        MECS12        B90.bit._12
#define        MECS13        B90.bit._13
#define        MECS14        B90.bit._14
#define        MECS15        B90.bit._15
/* ------------------------------------ */
/*              WORD B91                */
/* ------------------------------------ */

#define        AECS01        B91.word
/* APPOGGIO PER MESSAGGI ECS 16 - 31 */
/* SUPPORT FOR ECS MESSAGES 16 - 31 */

#define        MECS16        B91.bit._00
#define        MECS17        B91.bit._01
#define        MECS18        B91.bit._02
#define        MECS19        B91.bit._03
#define        MECS20        B91.bit._04
#define        MECS21        B91.bit._05
#define        MECS22        B91.bit._06
#define        MECS23        B91.bit._07
#define        MECS24        B91.bit._08
#define        MECS25        B91.bit._09
#define        MECS26        B91.bit._10
#define        MECS27        B91.bit._11
#define        MECS28        B91.bit._12
#define        MECS29        B91.bit._13
#define        MECS30        B91.bit._14
#define        MECS31        B91.bit._15
/* APPOGGIO PER MESSAGGIO ECS 31 (ultimo messaggio ECS) */
/* SUPPORT FOR ECS MESSAGE 31 (last ECS message) */

/* ------------------------------------ */
/*              WORD B92                */
/* ------------------------------------ */

#define        ASKQMENU      B92.ubyte.l
/* Numero Menu PLC da attivare (TASTIERA) */
/* PLC menu number to activate (KEYBOARD) */

#define        STBQMENU      B92.bit._15
/* Strobe richiesta Menu PLC (TASTIERA) */
/* Strobe for PLC menu asked (KEYBOARD) */

/* ------------------------------------ */
/*              WORD B93                */
/* ------------------------------------ */
#define        AECS02        B93.word
/* APPOGGIO PER MESSAGGI ECS 32 - 47 */
/* SUPPORT FOR ECS MESSAGES 32 - 47 */

#define        MECS32        B93.bit._00
#define        MECS33        B93.bit._01
#define        MECS34        B93.bit._02
#define        MECS35        B93.bit._03
#define        MECS36        B93.bit._04
#define        MECS37        B93.bit._05
#define        MECS38        B93.bit._06
#define        MECS39        B93.bit._07
#define        MECS40        B93.bit._08
#define        MECS41        B93.bit._09
#define        MECS42        B93.bit._10
#define        MECS43        B93.bit._11
#define        MECS44        B93.bit._12
#define        MECS45        B93.bit._13
#define        MECS46        B93.bit._14
#define        MECS47        B93.bit._15

/* ------------------------------------ */
/*              WORD B94                */
/* ------------------------------------ */

#define        AALR10        B94.word
/* APPOGGIO PER ALLARMI 160 - 175 */
/* SUPPORT TO ALARMS 160-175 */

#define        ALR160       B94.bit._00
#define        ALR161       B94.bit._01
#define        ALR162       B94.bit._02
#define        ALR163       B94.bit._03
#define        ALR164       B94.bit._04
#define        ALR165       B94.bit._05
#define        ALR166       B94.bit._06
#define        ALR167       B94.bit._07
#define        ALR168       B94.bit._08
#define        ALR169       B94.bit._09
#define        ALR170       B94.bit._10
#define        ALR171       B94.bit._11
#define        ALR172       B94.bit._12
#define        ALR173       B94.bit._13
#define        ALR174       B94.bit._14
#define        ALR175       B94.bit._15

/* ------------------------------------ */
/*              WORD B95                */
/* ------------------------------------ */

#define        AALR11       B95.word
/* APPOGGIO PER ALLARMI 176 - 191 */
/* SUPPORT TO ALARMS 176 - 191 */

#define        ALR176       B95.bit._00
#define        ALR177       B95.bit._01
#define        ALR178       B95.bit._02
#define        ALR179       B95.bit._03
#define        ALR180       B95.bit._04
#define        ALR181       B95.bit._05
#define        ALR182       B95.bit._06
#define        ALR183       B95.bit._07
#define        ALR184       B95.bit._08
#define        ALR185       B95.bit._09
#define        ALR186       B95.bit._10
#define        ALR187       B95.bit._11
#define        ALR188       B95.bit._12
#define        ALR189       B95.bit._13
#define        ALR190       B95.bit._14
#define        ALR191       B95.bit._15

/* ------------------------------------ */
/*              WORD B96                */
/* ------------------------------------ */

#define        AALR12       B96.word
/* APPOGGIO PER ALLARMI 192 - 199 */
/* SUPPORT TO ALARMS 192-199 */

#define        ALR192       B96.bit._00
#define        ALR193       B96.bit._01
#define        ALR194       B96.bit._02
#define        ALR195       B96.bit._03
#define        ALR196       B96.bit._04
#define        ALR197       B96.bit._05
#define        ALR198       B96.bit._06
#define        ALR199       B96.bit._07
/* ATTIVAZIONE ALLARME 199 (Ultimo Allarme); ALLARMI COSTRUTTORE DA 19800 A 19999 */
/* ALARM 199 ACTIVATION (last alarm); BUILDER ALARMS FROM 19800 TO 19999  */

/* Fine appoggi per allarmi              */
/* I restanti 8 NON possono essere usati */

/* ------------------------------------ */
/*              WORD B97                */
/* ------------------------------------ */

#define        AATT10       B97.word
/* APPOGGIO PER ATTENZIONI 160 - 175 */
/* SUPPORT FOR ATTENTIONS 160-175 */

#define        ATT160       B97.bit._00
#define        ATT161       B97.bit._01
#define        ATT162       B97.bit._02
#define        ATT163       B97.bit._03
#define        ATT164       B97.bit._04
#define        ATT165       B97.bit._05
#define        ATT166       B97.bit._06
#define        ATT167       B97.bit._07
#define        ATT168       B97.bit._08
#define        ATT169       B97.bit._09
#define        ATT170       B97.bit._10
#define        ATT171       B97.bit._11
#define        ATT172       B97.bit._12
#define        ATT173       B97.bit._13
#define        ATT174       B97.bit._14
#define        ATT175       B97.bit._15

/* ------------------------------------ */
/*              WORD B98                */
/* ------------------------------------ */

#define        AATT11       B98.word
/* APPOGGIO PER ATTENZIONI 176 - 191 */
/* SUPPORT FOR ATTENTIONS 176-191 */

#define        ATT176       B98.bit._00
#define        ATT177       B98.bit._01
#define        ATT178       B98.bit._02
#define        ATT179       B98.bit._03
#define        ATT180       B98.bit._04
#define        ATT181       B98.bit._05
#define        ATT182       B98.bit._06
#define        ATT183       B98.bit._07
#define        ATT184       B98.bit._08
#define        ATT185       B98.bit._09
#define        ATT186       B98.bit._10
#define        ATT187       B98.bit._11
#define        ATT188       B98.bit._12
#define        ATT189       B98.bit._13
#define        ATT190       B98.bit._14
#define        ATT191       B98.bit._15

/* ------------------------------------ */
/*              WORD B99                */
/* ------------------------------------ */

#define        AATT12       B99.word
/* APPOGGIO PER ATTENZIONI 192 - 199 */
/* SUPPORT FOR ATTENTIONS 192-199 */

#define        ATT192       B99.bit._00
#define        ATT193       B99.bit._01
#define        ATT194       B99.bit._02
#define        ATT195       B99.bit._03
#define        ATT196       B99.bit._04
#define        ATT197       B99.bit._05
#define        ATT198       B99.bit._06
#define        ATT199       B99.bit._07
/* ATTENZIONE 199 (Ultima Attenzione);  ATTENZIONI COSTRUTTORE DA 19600 A 19799 */
/* ATTENTION 199 (last attention);  BUILDER ATTENTIONS FROM 19600 TO 19799 */

/* Fine appoggi per attenzioni            */
/* Le restanti 8 NON possono essere usate */

/* ------------------------------------ */
/*              WORD B100-B107          */
/* ------------------------------------ */

#define        DGSTSO0      B100.byte.l
/* Status di Output per Asse 0 con Driver Digitale (IDDCOM EDDCOM) */
/* Status of Output for Axis 0 with Digital Driver (IDDCOM EDDCOM) */

#define        DGMICR0      B100.bit._00
/* Micro di Zero Asse 0 da Driver Digitale (IDDCOM EDDCOM) */
/* Homing Micro of axis 0 from digital driver (IDDCOM EDDCOM) */

//Modifica per Ecs900 #define        DGAMMA0      B100.bit._00
#define        DGAMMA0      B100.bit._01
/* Se asse mandrino (DGVERS0=1 e DGSPND0=1) */
/* Con DGAMMA0=1 e' inserito gamma alta TRIANGOLO. Con DGAMMA0=0 gamma bassa STELLA */

#define        DGVERS0      B100.bit._02
/* Tipo driver: =0 IDD; =1 EDD; Driver Digitale Asse 0 (IDDCOM EDDCOM) */
/* Driver type: =0 IDD; =1 EDD; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGSPND0      B100.bit._03
/* Tipo driver:DGSPND15=1 e DGVERS0=1; Driver Digitale MANDRINO con  resolver Asse 0*/

#define        DGMON0       B100.bit._04
/* Dati Monitor Validi Driver Digitale Asse 0 (IDDCOM EDDCOM) */
/* Valid Monitor Data; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGMCHL0      B100.bit._04
/* DGMCHL0 valido solo con Mechatrolink. L' asse non puo' essere mosso*/
/* (deve essere tenuto il HOLD) in quanto NON in modo sicrono oppure comando in corso*/

#define        DGPOW0       B100.bit._05
/* Potenza Presente Driver Digitale Asse 0 (IDDCOM EDDCOM) */
/* Power OK; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGDROK0      B100.bit._06
/* Driver Digitale OK Asse 0 (IDDCOM EDDCOM) */
/* Driver OK; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGABIL0      B100.bit._07
/* Driver Digitale Abilitato Asse 0 (IDDCOM EDDCOM) */
/* Driver active; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGSTSO1      B100.byte.h
#define        DGMICR1      B100.bit._08
//Ecs900 #define        DGAMMA1      B100.bit._08
#define        DGAMMA1      B100.bit._09
#define        DGVERS1      B100.bit._10
#define        DGSPND1      B100.bit._11
#define        DGMON1       B100.bit._12
#define        DGMCHL1      B100.bit._12
#define        DGPOW1       B100.bit._13
#define        DGDROK1      B100.bit._14
#define        DGABIL1      B100.bit._15

#define        DGSTSO2      B101.byte.l
#define        DGMICR2      B101.bit._00
//Ecs900 #define        DGAMMA2      B101.bit._00
#define        DGAMMA2      B101.bit._01
#define        DGVERS2      B101.bit._02
#define        DGSPND2      B101.bit._03
#define        DGMON2       B101.bit._04
#define        DGMCHL2      B101.bit._04
#define        DGPOW2       B101.bit._05
#define        DGDROK2      B101.bit._06
#define        DGABIL2      B101.bit._07

#define        DGSTSO3      B101.byte.h
#define        DGMICR3      B101.bit._08
//Ecs900 #define        DGAMMA3      B101.bit._08
#define        DGAMMA3      B101.bit._09
#define        DGVERS3      B101.bit._10
#define        DGSPND3      B101.bit._11
#define        DGMON3       B101.bit._12
#define        DGMCHL3      B101.bit._12
#define        DGPOW3       B101.bit._13
#define        DGDROK3      B101.bit._14
#define        DGABIL3      B101.bit._15

#define        DGSTSO4      B102.byte.l
#define        DGMICR4      B102.bit._00
//Ecs900 #define        DGAMMA4      B102.bit._00
#define        DGAMMA4      B101.bit._01
#define        DGVERS4      B102.bit._02
#define        DGSPND4      B102.bit._03
#define        DGMON4       B102.bit._04
#define        DGMCHL4      B102.bit._04
#define        DGPOW4       B102.bit._05
#define        DGDROK4      B102.bit._06
#define        DGABIL4      B102.bit._07

#define        DGSTSO5      B102.byte.h
#define        DGMICR5      B102.bit._08
//Ecs900 #define        DGAMMA5      B102.bit._08
#define        DGAMMA5      B102.bit._09
#define        DGVERS5      B102.bit._10
#define        DGSPND5      B102.bit._11
#define        DGMON5       B102.bit._12
#define        DGMCHL5      B102.bit._12
#define        DGPOW5       B102.bit._13
#define        DGDROK5      B102.bit._14
#define        DGABIL5      B102.bit._15

#define        DGSTSO6      B103.byte.l
#define        DGMICR6      B103.bit._00
//Ecs900 #define        DGAMMA6      B103.bit._00
#define        DGAMMA6      B103.bit._01
#define        DGVERS6      B103.bit._02
#define        DGSPND6      B103.bit._03
#define        DGMON6       B103.bit._04
#define        DGMCHL6      B103.bit._04
#define        DGPOW6       B103.bit._05
#define        DGDROK6      B103.bit._06
#define        DGABIL6      B103.bit._07

#define        DGSTSO7      B103.byte.h
#define        DGMICR7      B103.bit._08
//Ecs900 #define        DGAMMA7      B103.bit._08
#define        DGAMMA7      B103.bit._09
#define        DGVERS7      B103.bit._10
#define        DGSPND7      B103.bit._11
#define        DGMON7       B103.bit._12
#define        DGMCHL7      B103.bit._12
#define        DGPOW7       B103.bit._13
#define        DGDROK7      B103.bit._14
#define        DGABIL7      B103.bit._15

#define        DGSTSO8      B104.byte.l
#define        DGMICR8      B104.bit._00
//Ecs900 #define        DGAMMA8      B104.bit._00
#define        DGAMMA8      B104.bit._01
#define        DGVERS8      B104.bit._02
#define        DGSPND8      B104.bit._03
#define        DGMON8       B104.bit._04
#define        DGMCHL8      B104.bit._04
#define        DGPOW8       B104.bit._05
#define        DGDROK8      B104.bit._06
#define        DGABIL8      B104.bit._07

#define        DGSTSO9      B104.byte.h
#define        DGMICR9      B104.bit._08
//Ecs900 #define        DGAMMA9      B104.bit._08
#define        DGAMMA9      B104.bit._09
#define        DGVERS9      B104.bit._10
#define        DGSPND9      B104.bit._11
#define        DGMON9       B104.bit._12
#define        DGMCHL9      B104.bit._12
#define        DGPOW9       B104.bit._13
#define        DGDROK9      B104.bit._14
#define        DGABIL9      B104.bit._15

#define        DGSTSO10     B105.byte.l
#define        DGMICR10     B105.bit._00
//Ecs900#define        DGAMMA10     B105.bit._00
#define        DGAMMA10     B105.bit._01
#define        DGVERS10     B105.bit._02
#define        DGSPND10     B105.bit._03
#define        DGMON10      B105.bit._04
#define        DGMCHL10     B105.bit._04
#define        DGPOW10      B105.bit._05
#define        DGDROK10     B105.bit._06
#define        DGABIL10     B105.bit._07

#define        DGSTSO11     B105.byte.h
#define        DGMICR11     B105.bit._08
//Ecs900 #define        DGAMMA11     B105.bit._08
#define        DGAMMA11     B105.bit._09
#define        DGVERS11     B105.bit._10
#define        DGSPND11     B105.bit._11
#define        DGMON11      B105.bit._12
#define        DGMCHL11     B105.bit._12
#define        DGPOW11      B105.bit._13
#define        DGDROK11     B105.bit._14
#define        DGABIL11     B105.bit._15

#define        DGSTSO12     B106.byte.l
#define        DGMICR12     B106.bit._00
//Ecs900 #define        DGAMMA12     B106.bit._00
#define        DGAMMA12     B106.bit._01
#define        DGVERS12     B106.bit._02
#define        DGSPND12     B106.bit._03
#define        DGMON12      B106.bit._04
#define        DGMCHL12     B106.bit._04
#define        DGPOW12      B106.bit._05
#define        DGDROK12     B106.bit._06
#define        DGABIL12     B106.bit._07

#define        DGSTSO13     B106.byte.h
#define        DGMICR13     B106.bit._08
//Ecs900 #define        DGAMMA13     B106.bit._08
#define        DGAMMA13     B106.bit._09
#define        DGVERS13     B106.bit._10
#define        DGSPND13     B106.bit._11
#define        DGMON13      B106.bit._12
#define        DGMCHL13     B106.bit._12
#define        DGPOW13      B106.bit._13
#define        DGDROK13     B106.bit._14
#define        DGABIL13     B106.bit._15

#define        DGSTSO14     B107.byte.l
#define        DGMICR14     B107.bit._00
//Ecs900 #define        DGAMMA14     B107.bit._00
#define        DGAMMA14     B107.bit._01
#define        DGVERS14     B107.bit._02
#define        DGSPND14     B107.bit._03
#define        DGMON14      B107.bit._04
#define        DGMCHL14     B107.bit._04
#define        DGPOW14      B107.bit._05
#define        DGDROK14     B107.bit._06
#define        DGABIL14     B107.bit._07

#define        DGSTSO15     B107.byte.h
/* Status di Output per Asse 15 con Driver Digitale (IDDCOM EDDCOM) */
/* Status of Output for Axis 15 with Digital Driver (IDDCOM EDDCOM) */

#define        DGMICR15     B107.bit._08
/* Micro di Zero Asse 15 da Driver Digitale (IDDCOM EDDCOM) */
/* Homing Micro of Axis 15 from Digital Driver (IDDCOM EDDCOM) */

//Ecs900 #define        DGAMMA15     B107.bit._08
#define        DGAMMA15     B107.bit._09
/* Se asse mandrino (DGVERS15=1 e DGSPND15=1) */
/* Con DGAMMA15=1 e' inserito gamma alta TRIANGOLO. Con DGAMMA15=0 gamma bassa STELLA */

#define        DGVERS15     B107.bit._10
/* Versione driver =0 IDD =1 EDD Driver Digitale Asse 15 (IDDCOM EDDCOM) */
/* Driver type: =0 IDD; =1 EDD; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

#define        DGSPND15     B107.bit._11
/* Tipo driver:DGSPND15=1 e DGVERS0=1; Driver Digitale MANDRINO con  resolver Asse 0*/

#define        DGMON15      B107.bit._12
/* Dati Monitor Validi Driver Digitale Asse 15 (IDDCOM EDDCOM) */
/* Valid Monitor Data; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

#define        DGMCHL15     B107.bit._12
/* DGMCHL15 valido solo con Mechatrolink. L' asse non puo' essere mosso*/
/* (deve essere tenuto il HOLD) in quanto NON in modo sicrono oppure comando in corso*/

#define        DGPOW15      B107.bit._13
/* Potenza Presente Driver Digitale Asse 15 (IDDCOM EDDCOM) */
/* Power OK; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

#define        DGDROK15     B107.bit._14
/* Driver Digitale OK Asse 15 (IDDCOM EDDCOM) */
/* Driver OK; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

#define        DGABIL15     B107.bit._15
/* Driver Digitale Abilitato Asse 15 (IDDCOM EDDCOM) */
/* Driver active; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

/* ------------------------------------ */
/*              WORD B108               */
/* ------------------------------------ */
#define        AECS03        B108.word
/* APPOGGIO PER MESSAGGI ECS 48 - 63 */
/* SUPPORT FOR ECS MESSAGES 48 - 63 */

#define        MECS48        B108.bit._00
#define        MECS49        B108.bit._01
#define        MECS50        B108.bit._02
#define        MECS51        B108.bit._03
#define        MECS52        B108.bit._04
#define        MECS53        B108.bit._05
#define        MECS54        B108.bit._06
#define        MECS55        B108.bit._07
#define        MECS56        B108.bit._08
#define        MECS57        B108.bit._09
#define        MECS58        B108.bit._10
#define        MECS59        B108.bit._11
#define        MECS60        B108.bit._12
#define        MECS61        B108.bit._13
#define        MECS62        B108.bit._14
#define        MECS63        B108.bit._15

/* ------------------------------------ */
/*              WORD B109               */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B110-B117          */
/* ------------------------------------ */

#define        DGSTSI0      B110.byte.l
/* Status di Input per Asse 0 con Driver Digitale (IDDCOM EDDCOM) */
/* Status of Input for Axis 0 with Digital Driver (IDDCOM EDDCOM) */

#define        IDGAMMA0     B110.bit._00
/* Valido solo con asse mandrino digitale (DGVERS0=1 e DGSPND0=1)*/
/* IDGAMMA0=1 Richiesto gamma alta TRIANGOLO */
/* IDGAMMA0=0 Richiesto gamma bassa STELLA */

#define        DRESET0      B110.bit._06
/* Reset Allarme Driver Digitale KO Asse 0 (IDDCOM EDDCOM) */
/* Alarm Reset; Digital Driver for Axis 0 (IDDCOM EDDCOM) */

#define        DGSTSI1      B110.byte.h
#define        IDGAMMA1     B110.bit._08
#define        DRESET1      B110.bit._14

#define        DGSTSI2      B111.byte.l
#define        IDGAMMA2     B111.bit._00
#define        DRESET2      B111.bit._06

#define        DGSTSI3      B111.byte.h
#define        IDGAMMA3     B111.bit._08
#define        DRESET3      B111.bit._14

#define        DGSTSI4      B112.byte.l
#define        IDGAMMA4     B112.bit._00
#define        DRESET4      B112.bit._06

#define        DGSTSI5      B112.byte.h
#define        IDGAMMA5     B112.bit._08
#define        DRESET5      B112.bit._14

#define        DGSTSI6      B113.byte.l
#define        IDGAMMA6     B113.bit._00
#define        DRESET6      B113.bit._06

#define        DGSTSI7      B113.byte.h
#define        IDGAMMA7     B113.bit._08
#define        DRESET7      B113.bit._14

#define        DGSTSI8      B114.byte.l
#define        IDGAMMA8     B114.bit._00
#define        DRESET8      B114.bit._06

#define        DGSTSI9      B114.byte.h
#define        IDGAMMA9     B114.bit._08
#define        DRESET9      B114.bit._14

#define        DGSTSI10     B115.byte.l
#define        IDGAMMA10    B115.bit._00
#define        DRESET10     B115.bit._06

#define        DGSTSI11     B115.byte.h
#define        IDGAMMA11    B115.bit._08
#define        DRESET11     B115.bit._14

#define        DGSTSI12     B116.byte.l
#define        IDGAMMA12    B116.bit._00
#define        DRESET12     B116.bit._06

#define        DGSTSI13     B116.byte.h
#define        IDGAMMA13    B116.bit._08
#define        DRESET13     B116.bit._14

#define        DGSTSI14     B117.byte.l
#define        IDGAMMA14    B117.bit._00
#define        DRESET14     B117.bit._06

#define        DGSTSI15     B117.byte.h
/* Status di Input per Asse 15 con Driver Digitale (IDDCOM EDDCOM) */
/* Status of Input for Axis 15 with Digital Driver (IDDCOM EDDCOM) */

#define        IDGAMMA15    B117.bit._08
/* Valido solo con asse mandrino digitale (DGVERS15=1 e DGSPND15=1)*/
/* IDGAMMA15=1 Richiesto gamma alta TRIANGOLO */
/* IDGAMMA15=0 Richiesto gamma bassa STELLA */

#define        DRESET15     B117.bit._14
/* Reset Allarme Driver Digitale KO Asse 15 (IDDCOM EDDCOM) */
/* Alarm Reset; Digital Driver for Axis 15 (IDDCOM EDDCOM) */

/* ------------------------------------ */
/*              WORD B118               */
/* ------------------------------------ */

#define        K900_PLDX     B118.bit._00
/* PULSANTE DESTRO VOLANTINO PORTABILE */
/* PULSANTE DESTRO VOLANTINO PORTABILE */

#define        K900_PLSX     B118.bit._01
/* PULSANTE SINISTRO VOLANTINO PORTABILE */
/* PULSANTE SINISTRO VOLANTINO PORTABILE */

#define        K900_ABILVL1  B118.bit._08
/* PULSANTE ABILITAZIONE VOLANTINO PORTABILE */
/* PULSANTE ABILITAZIONE VOLANTINO PORTABILE */

#define        K900_OPTVL1   B118.bit._09
/* PULSANTE OPZIONALE VOLANTINO PORTABILE */
/* PULSANTE OPZIONALE VOLANTINO PORTABILE */

/* ------------------------------------ */
/*              WORD B119               */
/* ------------------------------------ */

#define        OPARTR       B119.word
/* APPOGGIO ASSI PREDISPOSTI PER RETRACT DI EMERGENZA */

#define        OPARTR0      B119.bit._00
#define        OPARTR1      B119.bit._01
#define        OPARTR2      B119.bit._02
#define        OPARTR3      B119.bit._03
#define        OPARTR4      B119.bit._04
#define        OPARTR5      B119.bit._05
#define        OPARTR6      B119.bit._06
#define        OPARTR7      B119.bit._07
#define        OPARTR8      B119.bit._08
#define        OPARTR9      B119.bit._09
#define        OPARTR10     B119.bit._10
#define        OPARTR11     B119.bit._11
#define        OPARTR12     B119.bit._12
#define        OPARTR13     B119.bit._13
#define        OPARTR14     B119.bit._14
#define        OPARTR15     B119.bit._15

/* ------------------------------------ */
/*              WORD B120               */
/* ------------------------------------ */

#define        WOPZCN0      B120.word
/* APPOGGIO OPZIONI PRESENTI SU CN WORD 0 */
/* SUPPORT FOR OPTIONS ACTIVE ON CN; WORD 0 */

#define        OP_TWT       B120.bit._00
/* 1 = OPZIONE TWIST PRESENTE */
/* 1 = TWIST OPTION ACTIVE */

/*#define        OP_DGT       B120.bit._01 */
/* 1 = OPZIONE COPIA PRESENTE */
/* 1 = DIGITIZING OPTION ACTIVE */

#define        OP_GAN       B120.bit._02
/* 1 = OPZIONE ASSI GANTRY PRESENTE */
/* 1 = AXES GANTRY OPTION ACTIVE */

#define        OP_DRF       B120.bit._03
/* 1 = OPZIONE VOLANTINI IN DRF PRESENTE */
/* 1 = DRF HANDWHEEL OPTION ACTIVE */

#define        OP_03        B120.bit._04
/* 1 = OPZIONE COMP. ERRORI MUTUI PRESENTE */
/* 1 = AXES MUTUAL ERRORS COMPENSATION OPTION ACTIVE */

#define        OP_AX4       B120.bit._05
/* 1 = OPZIONE 4 ASSI PRESENTE */
/* 1 = 4 AXES OPTION ACTIVE */

#define        OP_AX5       B120.bit._06
/* 1 = OPZIONE 5 ASSI PRESENTE */
/* 1 = 5 AXES OPTION ACTIVE */

#define        OP_AX6       B120.bit._07
/* 1 = OPZIONE 6 ASSI PRESENTE */
/* 1 = 6 AXES OPTION ACTIVE */

#define        OP_AX7       B120.bit._08
/* 1 = OPZIONE 7 ASSI PRESENTE */
/* 1 = 7 AXES OPTION ACTIVE */

#define        OP_AX8       B120.bit._09
/* 1 = OPZIONE 8 ASSI PRESENTE */
/* 1 = 8 AXES OPTION ACTIVE */

/*#define      B120_10      B120.bit._10 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define      OP_V3D       B120.bit._11 */
/* 1 = OPZIONE VERIFICA TRIDIMENSIONALE  */
/* 1 = 3D GRAPHIC VERIFY OPTION ACTIVE */

#define        OP_SRL       B120.bit._12
/* 1 = OPZIONE Comunicazioni linea seriale */
/* 1 = RS232 Serial Line Communication OPTION ACTIVE */

#define        OP_TORFR     B120.bit._13
/* 1 = OPZIONE TORNIO_FRESA */
/* 1 = LATHE/MILLING OPTION ACTIVE */

#define        OP_NET       B120.bit._14
/* 1 = OPZIONE Gestione rete PRESENTE */
/* 1 = NET MENAGEMENT OPTION ACTIVE */

#define        OP_G31       B120.bit._15
/* 1 = OPZIONE modalita' galleggiamento G31 PRESENTE */
/* 1 = G31 profile offset management OPTION ACTIVE */

/* ------------------------------------ */
/*              WORD B121               */
/* ------------------------------------ */

#define        WOPZCN1      B121.word
/* APPOGGIO OPZIONI PRESENTI SU CN WORD 1 */
/* SUPPORT FOR OPTIONS ACTIVE ON CN; WORD 1 */

#define        OP_TRN       B121.bit._00
/* 1 = OPZIONE transmit G37 PRESENTE */
/* 1 = G37 TRANSMIT OPTION ACTIVE */

#define        OP_TAS       B121.bit._01
/* 1 = OPZIONE PROBE ON/OFF PRESENTE */
/* 1 = ON/OFF PROBE OPTION ACTIVE */

/*#define      OP_LASER     B121.bit._02 */
/* 1 = OPZIONE PROBE LASER           */
/* 1 = LASER PROBE OPTION ACTIVE */

#define        OP_VAX       B121.bit._03
/* 1 = OPZIONE ASSI virtuali PRESENTE */
/* 1 = VIRTUAL AXES OPTION ACTIVE */

#define        OP_TOP       B121.bit._04
/* 1 = OPZIONE macro lavandini PRESENTE */
/* 1 = MARBLE TOP OPTION ACTIVE */

#define        OP_FRETR     B121.bit._05
/* 1 = OPZIONE CNC FRESA e tornio PRESENTE */
/* 1 = MILLING/LATHE OPTION ACTIVE */

#define        OP_CAMTR     B121.bit._06
/* 1 = OPZIONE camtorni PRESENTE */
/* 1 = LATHE CAM OPTION ACTIVE */

#define        OP_AX9       B121.bit._07
/* 1 = OPZIONE 9 ASSI PRESENTE */
/* 1 = 9 AXES OPTION ACTIVE */

#define        OP_AX10      B121.bit._08
/* 1 = OPZIONE 10 ASSI PRESENTE */
/* 1 = 10 AXES OPTION ACTIVE */

#define        OP_AX11      B121.bit._09
/* 1 = OPZIONE 11 ASSI PRESENTE */
/* 1 = 11 AXES OPTION ACTIVE */

#define        OP_AX12      B121.bit._10
/* 1 = OPZIONE 12 ASSI PRESENTE */
/* 1 = 12 AXES OPTION ACTIVE */

#define        OP_GVUT      B121.bit._11
/* 1 = OPZIONE gestione vita usura UTENSILI PRESENTE */
/* 1 = TOOL WEAR & LIFE MANAGEMENT OPTION ACTIVE */

/* #define        OP_WOD       B121.bit._12 */
/* 1 = OPZIONE WOOD PRESENTE */
/* 1 = WOOD OPTION ACTIVE */

/*#define        OP_IO80      B121.bit._13 */
/* 1 = OPZIONE gestione bit inp/out da 81 a 160 PRESENTE */
/* 1 = 81 TO 160 INP/OUT OPTION ACTIVE */

/*#define        OP_IO160     B121.bit._14 */
/* 1 = OPZIONE gestione bit inp/out da 161 PRESENTE */
/* 1 = > 160 INP/OUT OPTION ACTIVE */

/*#define        B121_15      B121.bit._15 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/* ------------------------------------ */
/*              WORD B122               */
/* ------------------------------------ */

#define        WOPZCN2      B122.word
/* APPOGGIO OPZIONI PRESENTI SU CN WORD 2 */
/* SUPPORT FOR OPTIONS ACTIVE ON CN; WORD 2 */

#define        OP_MARMO     B122.bit._00
/* 1 = OPZIONE macro sgrossatura colonne marmo PRESENTE */
/* 1 = MARBLE COLUMNS ROUGHING OPTION ACTIVE */

#define        OP_I3D       B122.bit._01
/* 1 = OPZIONE interpolazione cilindrica PRESENTE */
/* 1 = CYLINDRICAL INTERPOLATION OPTION ACTIVE */

#define        OP_AX13      B122.bit._02
/* 1 = OPZIONE 13 ASSI PRESENTE */
/* 1 = 13 AXES OPTION ACTIVE */

#define        OP_AX14      B122.bit._03
/* 1 = OPZIONE 14 ASSI PRESENTE */
/* 1 = 14 AXES OPTION ACTIVE */

#define        OP_AX15      B122.bit._04
/* 1 = OPZIONE 15 ASSI PRESENTE */
/* 1 = 15 AXES OPTION ACTIVE */

#define        OP_AX16      B122.bit._05
/* 1 = OPZIONE 16 ASSI PRESENTE */
/* 1 = 16 AXES OPTION ACTIVE */

/*#define      OP_SELLA     B122.bit._06 */
/* 1 = OPZIONE  SELLATURA FLANGE PRESENTE */
/* 1 = ..... OPTION ACTIVE */

#define        OP_TRB       B122.bit._07
/* 1 = OPZIONE TAVOLA ROTOBASCULANTE PRESENTE */
/* 1 = TRB OPTION ACTIVE */

#define        OP_TAG       B122.bit._08
/* 1 = OPZIONE ABILITAZIONE AMBIENTE TAGLIO */
/* 1 = TAG OPTION ACTIVE */

#define        OP_DBT       B122.bit._09
/* 1 = OPZIONE ABILITAZIONE DATABASETAGLIO PRESENTE */
/* 1 = OP_DBT OPTION ACTIVE */

#define        OP_G666      B122.bit._10
/* 1 = OPZIONE MACRO G666 PRESENTE */
/* 1 = MACRO G666 OPTION ACTIVE */

#define        OP_FUI       B122.bit._11
/* 1 = OPZIONE FOLDINGUI PRESENTE */
/* 1 = FOLDINGUI OPTION ACTIVE */

#define        OP_DBTFULL   B122.bit._12
/* 1 = OPZIONE  GENERATORE PLASMATAGLIO PRESENTE */
/* 1 = GENERATORE PLASMATAGLIO OPTION ACTIVE */

/*#define        B122_13      B122.bit._13 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B122_14      B122.bit._14 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define      OP_CAMOSS    B122.bit._15 */
/* 1 = OPZIONE CAM OSSITAGLIO PRESENTE */
/* 1 = CAMOSS OPTION ACTIVE */

/* ------------------------------------ */
/*              WORD B123               */
/* ------------------------------------ */

#define        WOPZCN3      B123.word
/* APPOGGIO OPZIONI PRESENTI SU CN WORD 3 */
/* SUPPORT FOR OPTIONS ACTIVE ON CN; WORD 3 */

#define        OP_CUA       B123.bit._00
/* 1 = OPZIONE C.U. AUTOMATICO PRESENTE */
/* 1 = C.U. AUTOMATICO OPTION ACTIVE */

#define        OP_FVS       B123.bit._01
/* 1 = OPZIONE FVS PRESENTE */
/* 1 = FVS OPTION ACTIVE */

#define        OP_G69       B123.bit._02
/* 1 = OPZIONE G69 PRESENTE */
/* 1 = G69 OPTION ACTIVE */

/*#define        B123_03      B123.bit._03 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_04      B123.bit._04 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

#define        OP_LGY       B123.bit._05
/* 1 = OPZIONE LEGACY UI (PIEGATRICI) PRESENTE */
/* 1 = LEGACY UI (bending machines) OPTION ACTIVE */

/*#define        B123_06      B123.bit._06 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_07      B123.bit._07 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_08      B123.bit._08 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_09      B123.bit._09 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_10      B123.bit._10 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_11      B123.bit._11 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_12      B123.bit._12 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_13      B123.bit._13 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_14      B123.bit._14 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/*#define        B123_15      B123.bit._15 */
/* 1 = OPZIONE ........... PRESENTE */
/* 1 = ..... OPTION ACTIVE */

/* ------------------------------------ */
/*              WORD B124               */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B125               */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B126               */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B127               */
/* ------------------------------------ */

#define        NUMVOLIO      B127.uword
/* NUMERO VOLANTINI DA I/O CONFIGURATI */
/* NUMERO VOLANTINI DA I/O CONFIGURATI */

/* ------------------------------------ */
/*              WORD B128               */
/* ------------------------------------ */

#define        TIPOTWT      B128.word
/* BIT DEFINENTI IL TIPO DI TWT ATTIVO */
/* BIT DEFINENTI IL TIPO DI TWT ATTIVO */

#define        TIPOTWT0      B128.bit._00
/* =1 SE E' ATTIVO IL TWT DI TIPO NORMALE */
/* =1 SE E' ATTIVO IL TWT DI TIPO NORMALE */

#define        TIPOTWT1      B128.bit._01
/* =1 SE E' ATTIVO IL TWT DI TIPO 1  */
/* =1 SE E' ATTIVO IL TWT DI TIPO 1  */

#define        TIPOTWT2      B128.bit._02
/* =1 SE E' ATTIVO IL TWT DI TIPO 2  */
/* =1 SE E' ATTIVO IL TWT DI TIPO 2  */

#define        TIPOTWTD      B128.bit._03
/* =1 SE E' ATTIVO IL TWT DINAMICO */
/* =1 SE E' ATTIVO IL TWT DINAMICO */

#define        TIPOTWTA      B128.bit._04
/* =1 SE E' ATTIVO IL TWT AUTOMATICO */
/* =1 SE E' ATTIVO IL TWT AUTOMATICO */

/* ------------------------------------ */
/*              WORD B129               */
/* ------------------------------------ */

#define        VMAXVOL      B129.word
/* VALORE MAX AMMESSO FRA UN TAUPLC E L'ALTRO */
/* MAX HANDWHEEL DELTA VALUE ALLOVED BETWEEN TWO TAUPLC */

/* ------------------------------------ */
/*              WORD B130-B149          */
/* ------------------------------------ */

#define        STSCNC				D_B130
/* Bit stato del CNC aggiornato da QAL. */
/* CNC status bits updated by QAL. */

#define CNC_SSKP  		B130.bit._00
//SKP
#define CNC_SM00  		B130.bit._01
//M00
#define CNC_SM01  		B130.bit._02
//M01
#define CNC_SESE  		B130.bit._03
//RUN
#define CNC_SCUE  		B130.bit._04
//CUE
#define CNC_SDRYR 		B130.bit._05
//DRYR
#define CNC_SSET  		B130.bit._06
//SET
#define CNC_SRIP  		B130.bit._07 
//REP

//---------------------------------------
#define CNC_SHOLD 		B130.bit._08
//HOLD
#define CNC_SHLAX 		B130.bit._09
//AXESH 
#define CNC_SHMND  	B130.bit._10
//MNDH
#define CNC_SHLDXYZ	B130.bit._11
//HLDxyz

//---------------------------------------

#define CNC_SDLN 		B130.bit._12
//DLN
#define CNC_SDRA  		B130.bit._13
//DRA
#define CNC_SDRLN 		B130.bit._14
//DRLN
#define CNC_SDLN1 		B130.bit._15
//DLN1
#define CNC_SDLN2 		B131.bit._00
//DLN2
#define CNC_SDLN12		B131.bit._01
//DLN12
#define CNC_SDRLN1		B131.bit._02
//DRLN1
#define CNC_SDRLN2		B131.bit._03
//DRLN2
#define CNC_SDRLN12	B131.bit._04
//DRLN12
//---------------------------------------

#define CNC_SMNP			B131.bit._05
//MNP
#define CNC_SMNS			B131.bit._06
//MNS
#define CNC_SUTR			B131.bit._07
//UTR
//---------------------------------------

#define CNC_SMILL		B131.bit._08
//MILL
#define CNC_SLATHE		B131.bit._09
//LATHE
#define CNC_SCUT			B131.bit._10
//CUT
#define CNC_SCPY			B131.bit._11
//CPY

//---------------------------------------

#define CNC_SRPA			B131.bit._12
//RPA
#define CNC_SRPB			B131.bit._13
//RPB

//---------------------------------------

#define CNC_SRTRXYZ	B131.bit._14
//Assi Predisposti in RETRACT
#define CNC_SERTRXYZ	B131.bit._15
//Assi in Esecuzione 




/* ------------------------------------ */

/* ------------------------------------ */
/*           TASTIERA CNC 900			*/
/* ------------------------------------ */
/* ------------------------------------ */
/*              WORD B150				*/
/* ------------------------------------ */

#define        K900_INP      B150.word
/* WORD APPOGGIO PER INGRESSI DA TASTIERA */
/* SUPPORT WORD FOR INPUTS FROM KEYBOARD  */

#define        K900_INP00    B150.bit._00
/* INGRESSI DA TASTIERA (Primo input)*/
/* INPUTS FROM KEYBOARD (First input)*/
#define        K900_INP01    B150.bit._01
#define        K900_INP02    B150.bit._02
#define        K900_INP03    B150.bit._03
#define        K900_INP04    B150.bit._04
#define        K900_INP05    B150.bit._05
#define        K900_INP06    B150.bit._06
#define        K900_INP07    B150.bit._07
#define        K900_INP08    B150.bit._08
#define        K900_INP09    B150.bit._09
#define        K900_INP10    B150.bit._10
#define        K900_INP11    B150.bit._11
#define        K900_INP12    B150.bit._12
#define        K900_INP13    B150.bit._13
#define        K900_INP14    B150.bit._14
#define        K900_INP15    B150.bit._15
/* INGRESSI DA TASTIERA (Ultimo input)*/
/* INPUTS FROM KEYBOARD (Last input)  */

/* ------------------------------------ */
/*              WORD B151               */
/* ------------------------------------ */

#define        K900_OUT      B151.word
/* WORD APPOGGIO USCITE SU TASTIERA	*/
/* SUPPORT WORD FOR KEYBOARD OUTPUTS*/

#define        K900_OUT00    B151.bit._00
/* USCITE SU TASTIERA (Primo Output)*/
/* KEYBOARD OUTPUTS (First Output)	*/
#define        K900_OUT01    B151.bit._01
#define        K900_OUT02    B151.bit._02
#define        K900_OUT03    B151.bit._03
#define        K900_OUT04    B151.bit._04
#define        K900_OUT05    B151.bit._05
#define        K900_OUT06    B151.bit._06
#define        K900_OUT07    B151.bit._07
#define        K900_OUT08    B151.bit._08
#define        K900_OUT09    B151.bit._09
#define        K900_OUT10    B151.bit._10
#define        K900_OUT11    B151.bit._11
#define        K900_OUT12    B151.bit._12
#define        K900_OUT13    B151.bit._13
#define        K900_OUT14    B151.bit._14
#define        K900_OUT15    B151.bit._15
/* USCITE SU TASTIERA (Ultimo Output)*/
/* KEYBOARD OUTPUTS (Last Output)*/

/* ------------------------------------ */
/*              WORD B152               */
/* ------------------------------------ */

#define        K900_SELAX    B152.ubyte.l
/* BYTE APPOGGIO SELEZIONE MAX 5 ASSI PER VOLANTINO 1 */
/* BYTE APPOGGIO SELEZIONE MAX 5 ASSI PER VOLANTINO 1 */

#define        K900_SELX     B152.bit._00
/* SELEZIONE ASSE (Primo) */
/* SELEZIONE ASSE (Primo) */
#define        K900_SELY     B152.bit._01
#define        K900_SELZ     B152.bit._02
#define        K900_SEL4     B152.bit._03
#define        K900_SEL5     B152.bit._04
#define        K900_SEL6     B152.bit._05
/* SELEZIONE ASSE (Ultimo) */
/* SELEZIONE ASSE (Ultimo) */

#define        K900_SCALA    B152.ubyte.h
/* BYTE APPOGGIO SCALA E PULSANTI PER VOLANTINO 1 */
/* BYTE APPOGGIO SCALA E PULSANTI PER VOLANTINO 1 */

#define        K900_SC1      B152.bit._08
/* FATTORE SCALA x 1 */
/* FATTORE SCALA x 1 */

#define        K900_SC10     B152.bit._09
/* FATTORE SCALA x 10 */
/* FATTORE SCALA x 10 */

#define        K900_SC100    B152.bit._10
/* FATTORE SCALA x 100 */
/* FATTORE SCALA x 100 */

/* ------------------------------------ */
/*              WORD B153               */
/* ------------------------------------ */

#define        K900_ALVL1    B153.ubyte.l
/* BYTE APPOGGIO ALLARMI VOLANTINO 1 */
/* BYTE APPOGGIO ALLARMI VOLANTINO 1 */

#define        K900_ALAAVL1   B153.bit._00
/* ALLARME CANALE AA VOLANTINO 1 */
/* ALLARME CANALE AA VOLANTINO 1 */

#define        K900_ALBBVL1  B153.bit._01
/* ALLARME CANALE BB VOLANTINO 1 */
/* ALLARME CANALE BB VOLANTINO 1 */

#define        K900_ALSVVL1  B153.bit._02
/* ALLARME SOPRAVELOCITA VOLANTINO 1 */
/* ALLARME SOPRAVELOCITA VOLANTINO 1 */

#define        K900_ALOCVL1  B153.bit._03
/* ALLARME OVERCURRENT VOLANTINO 1 */
/* ALLARME OVERCURRENT VOLANTINO 1 */


/* ------------------------------------ */
/*              WORD B154               */
/* ------------------------------------ */

#define        K900_ALVL2    B154.ubyte.l
/* BYTE APPOGGIO ALLARMI VOLANTINO 2 */
/* BYTE APPOGGIO ALLARMI VOLANTINO 2 */

#define        K900_ALAAVL2   B154.bit._00
/* ALLARME CANALE AA VOLANTINO 2 */
/* ALLARME CANALE AA VOLANTINO 2 */

#define        K900_ALBBVL2  B154.bit._01
/* ALLARME CANALE BB VOLANTINO 2 */
/* ALLARME CANALE BB VOLANTINO 2 */

#define        K900_ALSVVL2  B154.bit._02
/* ALLARME SOPRAVELOCITA VOLANTINO 2 */
/* ALLARME SOPRAVELOCITA VOLANTINO 2 */

#define        K900_ALOCVL2  B154.bit._03
/* ALLARME OVERCURRENT VOLANTINO 2 */
/* ALLARME OVERCURRENT VOLANTINO 2 */

#define        K900_ALVL3    B154.ubyte.h
/* BYTE APPOGGIO ALLARMI VOLANTINO 3 */
/* BYTE APPOGGIO ALLARMI VOLANTINO 3 */

#define        K900_ALAAVL3   B154.bit._08
/* ALLARME CANALE AA VOLANTINO 3 */
/* ALLARME CANALE AA VOLANTINO 3 */

#define        K900_ALBBVL3  B154.bit._09
/* ALLARME CANALE BB VOLANTINO 3 */
/* ALLARME CANALE BB VOLANTINO 3 */

#define        K900_ALSVVL3  B154.bit._10
/* ALLARME SOPRAVELOCITA VOLANTINO 3 */
/* ALLARME SOPRAVELOCITA VOLANTINO 3 */

#define        K900_ALOCVL3  B154.bit._11
/* ALLARME OVERCURRENT VOLANTINO 3 */
/* ALLARME OVERCURRENT VOLANTINO 3 */

/* ------------------------------------ */
/*              WORD B155               */
/* ------------------------------------ */

#define        K900_ALARM    B155.ubyte.l
/* APPOGGIO ALLARMI PANNELLO CNC 900*/
/* APPOGGIO ALLARMI PANNELLO CNC 900*/

#define        K900_ALPANEL  B155.bit._00
/* ALLARME PANNELLO CNC CORTO SU 5volt */
/* ALLARME PANNELLO CNC CORTO SU 5volt */

#define        K900_ALOVER   B155.bit._01
/* ALLARME OVERRIDES CORTO SU 5volt */
/* ALLARME OVERRIDES CORTO SU 5volt */

#define        K900_ALMATRI  B155.bit._02
/* ALLARME MATRICE TASTI CORTO SU 5volt */
/* ALLARME MATRICE TASTI CORTO SU 5volt */

#define        K900_ALPS2    B155.bit._03
/* ALLARME PS2 NON COLLEGATA AL PC */
/* ALLARME PS2 NON COLLEGATA AL PC */

#define        K900_ALOVR    B155.ubyte.h
/* APPOGGIO ALLARMI OVERRIDE CNC 900*/
/* APPOGGIO ALLARMI OVERRIDE CNC 900*/

#define        K900_ALOVRR   B155.bit._08
/* ALLARME OVERRIDE RAPIDO */
/* ALLARME OVERRIDE RAPIDO */

#define        K900_ALORNC   B155.bit._09
/* ALLARME OVERRIDE RAPIDO NON COLLEGATO */
/* ALLARME OVERRIDE RAPIDO NON COLLEGATO */

#define        K900_ALOVRF   B155.bit._10
/* ALLARME OVERRIDE LAVORO */
/* ALLARME OVERRIDE LAVORO */

#define        K900_ALOFNC   B155.bit._11
/* ALLARME OVERRIDE LAVORO NON COLLEGATO */
/* ALLARME OVERRIDE LAVORO NON COLLEGATO */

#define        K900_ALOVRS   B155.bit._12
/* ALLARME OVERRIDE SPEED */
/* ALLARME OVERRIDE SPEED */

#define        K900_ALOSNC   B155.bit._13
/* ALLARME OVERRIDE SPEED NON COLLEGATO */
/* ALLARME OVERRIDE SPEED NON COLLEGATO */

/* ------------------------------------ */
/*              WORD B156               */
/* ------------------------------------ */

#define        K900_JKS1     B156.bit._00
/* Selettore Joystick S1 */
/* Selettore Joystick S1 */

#define        K900_JKS2     B156.bit._01
/* Selettore Joystick S2 */
/* Selettore Joystick S2 */

/* ------------------------------------ */
/*              WORD B157               */
/* ------------------------------------ */
#define		   KMU_LED		B157.uword
/* WORD APPOGGIO LED SEGNALAZIONE TASTI */
/* WORD APPOGGIO LED SEGNALAZIONE TASTI */

#define        KMU_LED00	B157.bit._00
/* LED 0 ( Pannello CHIAVE x Pulsante )*/
/* LED 0 ( Pannello CHIAVE x Pulsante )*/

#define        KMU_LED01	B157.bit._01
/* LED 1 */
/* LED 1 */

#define        KMU_LED02	B157.bit._02
/* LED 2 */
/* LED 2 */

#define        KMU_LED03	B157.bit._03
/* LED 3 */
/* LED 3 */

#define        KMU_LED04	B157.bit._04
/* LED 4 */
/* LED 4 */

#define        KMU_LED05	B157.bit._05
/* LED 5 */
/* LED 5 */

#define        KMU_LED06	B157.bit._06
/* LED 6 */
/* LED 6 */

#define        KMU_LED07	B157.bit._07
/* LED 7 */
/* LED 7 */

#define        KMU_LED08	B157.bit._08
/* LED 8 */
/* LED 8 */

#define        KMU_LED09	B157.bit._09
/* LED 9 */
/* LED 9 */

#define        KMU_LED10	B157.bit._10
/* LED 10 */
/* LED 10 */

#define        KMU_LED11	B157.bit._11
/* LED 11 */
/* LED 11 */

#define        KMU_LED12	B157.bit._12
/* LED 12 */
/* LED 12 */

#define        KMU_LED13	B157.bit._13
/* LED 13 ( Non utilizzato ) */
/* LED 13 ( Non utilizzato ) */

#define        KMU_LED14	B157.bit._14
/* LED 14 ( Non utilizzato ) */
/* LED 14 ( Non utilizzato ) */

#define        KMU_LED15	B157.bit._15
/* LED 15 ( Non utilizzato ) */
/* LED 15 ( Non utilizzato ) */


/* ------------------------------------ */
/*              WORD B158               */
/* PANNELLO: EMERGENZA-CHIAVE-POWER ON 	*/
/*         Assieme "Base"               */
/* ------------------------------------ */

#define        KMU_BASEDX	B158.bit._00
/*POSIZIONE CHIAVE DESTRA*/
/*POSIZIONE CHIAVE DESTRA*/

#define        KMU_BASESX	B158.bit._01
/*POSIZIONE CHIAVE SINISTRA*/
/*POSIZIONE CHIAVE SINISTRA*/

#define        KMU_BASEP	B158.bit._02
/*PULSANTE 1 */
/*PULSANTE 1 */

/* ------------------------------------ */
/*              WORD B159               */
/*        PANNELLO: N. 9 TASTI CNC  	*/
/*             Assieme "CNC"            */
/* ------------------------------------ */

#define        KMU_CNC01	B159.bit._00
/*PULSANTE 1 */
/*PULSANTE 1 */

#define        KMU_CNC02	B159.bit._01
/*PULSANTE 2 */
/*PULSANTE 2 */

#define        KMU_CNC03	B159.bit._02
/*PULSANTE 3 */
/*PULSANTE 3 */

#define        KMU_CNC04	B159.bit._03
/*PULSANTE 4 */
/*PULSANTE 4 */

#define        KMU_CNC05	B159.bit._04
/*PULSANTE 5 */
/*PULSANTE 5 */

#define        KMU_CNC06	B159.bit._05
/*PULSANTE 6 */
/*PULSANTE 6 */

#define        KMU_CNC07	B159.bit._06
/*PULSANTE 7 */
/*PULSANTE 7 */

#define        KMU_CNC08	B159.bit._07
/*PULSANTE 8 */
/*PULSANTE 8 */

#define        KMU_CNC09	B159.bit._08
/*PULSANTE 9 */
/*PULSANTE 9 */


/* ------------------------------------ */
/*              WORD B160               */
/*     PANNELLO N.12 PULSANTI 			*/
/*   	 Assieme "ESP_PULS"             */
/* ------------------------------------ */

#define        KMU_PULS01	B160.bit._00
/*PULSANTE 1 */
/*PULSANTE 1 */

#define        KMU_PULS02	B160.bit._01
/*PULSANTE 2 */
/*PULSANTE 2 */

#define        KMU_PULS03	B160.bit._02
/*PULSANTE 3 */
/*PULSANTE 3 */

#define        KMU_PULS04	B160.bit._03
/*PULSANTE 4 */
/*PULSANTE 4 */

#define        KMU_PULS05	B160.bit._04
/*PULSANTE 5 */
/*PULSANTE 5 */

#define        KMU_PULS06	B160.bit._05
/*PULSANTE 6 */
/*PULSANTE 6 */

#define        KMU_PULS07	B160.bit._06
/*PULSANTE 7 */
/*PULSANTE 7 */

#define        KMU_PULS08	B160.bit._07
/*PULSANTE 8 */
/*PULSANTE 8 */

#define        KMU_PULS09	B160.bit._08
/*PULSANTE 9 */
/*PULSANTE 9 */

#define        KMU_PULS10	B160.bit._09
/*PULSANTE 10 */
/*PULSANTE 10 */

#define        KMU_PULS11	B160.bit._10
/*PULSANTE 11 */
/*PULSANTE 11 */

#define        KMU_PULS12	B160.bit._11
/*PULSANTE 12 */
/*PULSANTE 12 */


/* ------------------------------------ */
/*              WORD B161               */
/*      PANNELLO N.6 COMMUTATORI 		*/
/*         Assieme "ESP_COM"            */
/* ------------------------------------ */

#define        KMU_COM1SX	B161.bit._00
/*COMMUTATORE 1 POSIZIONE SX */
/*COMMUTATORE 1 POSIZIONE SX */

#define        KMU_COM1DX	B161.bit._01
/*COMMUTATORE 1 POSIZIONE DX */
/*COMMUTATORE 1 POSIZIONE DX */

#define        KMU_COM2SX	B161.bit._02
/*COMMUTATORE 2 POSIZIONE SX */
/*COMMUTATORE 2 POSIZIONE SX */

#define        KMU_COM2DX	B161.bit._03
/*COMMUTATORE 2 POSIZIONE DX */
/*COMMUTATORE 2 POSIZIONE DX */

#define        KMU_COM3SX	B161.bit._04
/*COMMUTATORE 3 POSIZIONE SX */
/*COMMUTATORE 3 POSIZIONE SX */

#define        KMU_COM3DX	B161.bit._05
/*COMMUTATORE 3 POSIZIONE DX */
/*COMMUTATORE 3 POSIZIONE DX */

#define        KMU_COM4SX	B161.bit._06
/*COMMUTATORE 4 POSIZIONE SX */
/*COMMUTATORE 4 POSIZIONE SX */

#define        KMU_COM4DX	B161.bit._07
/*COMMUTATORE 4 POSIZIONE DX */
/*COMMUTATORE 4 POSIZIONE DX */

#define        KMU_COM5SX	B161.bit._08
/*COMMUTATORE 5 POSIZIONE SX */
/*COMMUTATORE 5 POSIZIONE SX */

#define        KMU_COM5DX	B161.bit._09
/*COMMUTATORE 5 POSIZIONE DX */
/*COMMUTATORE 5 POSIZIONE DX */

#define        KMU_COM6SX	B161.bit._10
/*COMMUTATORE 6 POSIZIONE SX */
/*COMMUTATORE 6 POSIZIONE SX */

#define        KMU_COM6DX	B161.bit._11
/*COMMUTATORE 6 POSIZIONE DX */
/*COMMUTATORE 6 POSIZIONE DX */

/* ------------------------------------ */
/*              WORD B162               */
/* PANNELLO 6 TASTI + 3 COMMUTATORI     */
/*        Assieme "ESP_BC"              */
/* ------------------------------------ */

#define        KMU_BCP01	B162.bit._00
/*PULSANTE 1 */
/*PULSANTE 1 */

#define        KMU_BCP02	B162.bit._01
/*PULSANTE 2 */
/*PULSANTE 2 */

#define        KMU_BCP03	B162.bit._02
/*PULSANTE 3 */
/*PULSANTE 3 */

#define        KMU_BCP04	B162.bit._03
/*PULSANTE 4 */
/*PULSANTE 4 */

#define        KMU_BCP05	B162.bit._04
/*PULSANTE 5 */
/*PULSANTE 5 */

#define        KMU_BCP06	B162.bit._05
/*PULSANTE 6 */
/*PULSANTE 6 */

#define        KMU_BC1SX	B162.bit._06
/*COMMUTATORE 1 POSIZIONE SX */
/*COMMUTATORE 1 POSIZIONE SX */

#define        KMU_BC1DX	B162.bit._07
/*COMMUTATORE 1 POSIZIONE DX */
/*COMMUTATORE 1 POSIZIONE DX */

#define        KMU_BC2SX	B162.bit._08
/*COMMUTATORE 2 POSIZIONE SX */
/*COMMUTATORE 2 POSIZIONE SX */

#define        KMU_BC2DX	B162.bit._09
/*COMMUTATORE 2 POSIZIONE DX */
/*COMMUTATORE 2 POSIZIONE DX */

#define        KMU_BC3SX	B162.bit._10
/*COMMUTATORE 3 POSIZIONE SX */
/*COMMUTATORE 3 POSIZIONE SX */

#define        KMU_BC3DX	B162.bit._11
/*COMMUTATORE 3 POSIZIONE DX */
/*COMMUTATORE 3 POSIZIONE DX */

/* ------------------------------------ */
/*              WORD B163               */
/*     Pulsanti per Nuovo Pannello      */
/* v1.04.005 sinonimi non utilizzati	*/
/*	da cancellare						*/
/* ------------------------------------ */
//
//#define        KMU_PNP01	B163.bit._00
///*PULSANTE MATRICE 0x6 */
///*PULSANTE MATRICE 0x6 */
//
//#define        KMU_PNP02	B163.bit._01
///*PULSANTE MATRICE 0x7 */
///*PULSANTE MATRICE 0x7 */
//
//#define        KMU_PNP03	B163.bit._02
///*PULSANTE MATRICE 1x6 */
///*PULSANTE MATRICE 1x6 */
//
//#define        KMU_PNP04	B163.bit._03
///*PULSANTE MATRICE 1x7 */
///*PULSANTE MATRICE 1x7 */
//
//#define        KMU_PNP05	B163.bit._04
///*PULSANTE MATRICE 2x6 */
///*PULSANTE MATRICE 2x6 */
//
//#define        KMU_PNP06	B163.bit._05
///*PULSANTE MATRICE 2x7 */
///*PULSANTE MATRICE 2x7 */
//
//#define        KMU_PNP07	B163.bit._06
///*PULSANTE MATRICE 3x6 */
///*PULSANTE MATRICE 3x6 */
//
//#define        KMU_PNP08	B163.bit._07
///*PULSANTE MATRICE 3x7 */
///*PULSANTE MATRICE 3x7 */

/* ------------------------------------ */
/*              WORD B164               */
/* ------------------------------------ */
#define		   KMUBOARD	B164.uword
/* WORD APPOGGIO SCHEDE MU PRESENTI     */
/* SUPPORT WORD FOR AVAILABLE MU BOARDS */

#define		   KMUBOARD_BASE	B164.bit._00
/* SCHEDA BASE PRESENTE                 */
/* BASE BOARD AVAILABLE                 */

#define		   KMUBOARD_OVR	B164.bit._01
/* SCHEDA OVR PRESENTE              */
/* OVR BOARD AVAILABLE              */

#define		   KMUBOARD_CNC	B164.bit._02
/* SCHEDA CNC PRESENTE                  */
/* CNC BOARD AVAILABLE                  */

#define		   KMUBOARD_PC	B164.bit._03
/* SCHEDA P_C PRESENTE                  */
/* P_C BOARD AVAILABLE                  */

#define		   KMUBOARD_PULS	B164.bit._04
/* SCHEDA PULS PRESENTE                 */
/* PULS BOARD AVAILABLE                 */

#define		   KMUBOARD_COM	B164.bit._05
/* SCHEDA COM PRESENTE                  */
/* COM BOARD AVAILABLE                  */

#define		   KMUBOARD_JOY	B164.bit._06
/* SCHEDA JOY PRESENTE              */
/* JOY BOARD AVAILABLE              */

#define		   KMUBOARD_MEMB B164.bit._07
/* TASTIERA MU MEMBRANA PRESENTE */
/* MEMBRANE KEYBOARD PRESENT  */

#define		   KMUBOARD_ECS  B164.bit._08
/* TASTIERA MU MEMBRANA ECS PRESENTE */
/* ECS MEMBRANE KEYBOARD PRESENT  */

#define		   KMUBOARD_CST1  B164.bit._09
/* TASTIERA MU MEMBRANA 091H559 PRESENTE */
/* 091H559 MEMBRANE KEYBOARD PRESENT  */

#define		   KMUBOARD_SERIAL  B164.bit._10
/* TASTIERA 091F211 PRESENTE          */
/* KEYBOARD 091F211 PRESENT           */


/* ------------------------------------ */
/*              WORD B165               */
/*       ALLARMI USCITE DIGITALI        */
/* ------------------------------------ */

#define		   KCN_ALOUT	B165.uword
/* WORD APPOGGIO ALLARMI USCITE DIGITALI */
/* WORD APPOGGIO ALLARMI USCITE DIGITALI */

/* ------------------------------------ */
/*              WORD B166               */
/* Errori consecutivi ciclo di comunica-*/
/* zione ethercat.                      */
/* ------------------------------------ */
#define		   ETH_CCOMERR	B166.uword
/* Errori consec. comunicazione ethercat*/
/* Errori consec. comunicazione ethercat*/

/* ------------------------------------ */
/*              WORD B167               */
/* ------------------------------------ */
#define		   KMULED_CNC	B167.uword
/* WORD APPOGGIO LED PER SCHEDA CNC     */
/* SUPPORT WORD FOR CNC BOARD LED       */

#define		   KMULED_CNC01	B167.bit._00
/* LED NUMERO 1 SCHEDA CNC              */
/* NUMBER 1 LED OF CNC BOARD            */

#define		   KMULED_CNC02	B167.bit._01
/* LED NUMERO 2 SCHEDA CNC              */
/* NUMBER 2 LED OF CNC BOARD            */

#define		   KMULED_CNC03	B167.bit._02
/* LED NUMERO 3 SCHEDA CNC              */
/* NUMBER 3 LED OF CNC BOARD            */

#define		   KMULED_CNC04	B167.bit._03
/* LED NUMERO 4 SCHEDA CNC              */
/* NUMBER 4 LED OF CNC BOARD            */

#define		   KMULED_CNC05	B167.bit._04
/* LED NUMERO 5 SCHEDA CNC              */
/* NUMBER 5 LED OF CNC BOARD            */

#define		   KMULED_CNC06	B167.bit._05
/* LED NUMERO 6 SCHEDA CNC              */
/* NUMBER 6 LED OF CNC BOARD            */

#define		   KMULED_CNC07	B167.bit._06
/* LED NUMERO 7 SCHEDA CNC              */
/* NUMBER 7 LED OF CNC BOARD            */

#define		   KMULED_CNC08	B167.bit._07
/* LED NUMERO 8 SCHEDA CNC              */
/* NUMBER 8 LED OF CNC BOARD            */

#define		   KMULED_CNC09	B167.bit._08
/* LED NUMERO 9 SCHEDA CNC              */
/* NUMBER 9 LED OF CNC BOARD            */


/* ------------------------------------ */
/*              WORD B168               */
/* ------------------------------------ */
#define		   KMULED_PULS	B168.uword
/* WORD APPOGGIO LED PER SCHEDA PULS    */
/* SUPPORT WORD FOR PULS BOARD LED      */

#define		   KMULED_PULS01	B168.bit._00
/* LED NUMERO 1 SCHEDA PULS             */
/* NUMBER 1 LED OF PULS BOARD           */

#define		   KMULED_PULS02	B168.bit._01
/* LED NUMERO 2 SCHEDA PULS             */
/* NUMBER 2 LED OF PULS BOARD           */

#define		   KMULED_PULS03	B168.bit._02
/* LED NUMERO 3 SCHEDA PULS             */
/* NUMBER 3 LED OF PULS BOARD           */

#define		   KMULED_PULS04	B168.bit._03
/* LED NUMERO 4 SCHEDA PULS             */
/* NUMBER 4 LED OF PULS BOARD           */

#define		   KMULED_PULS05	B168.bit._04
/* LED NUMERO 5 SCHEDA PULS             */
/* NUMBER 5 LED OF PULS BOARD           */

#define		   KMULED_PULS06	B168.bit._05
/* LED NUMERO 6 SCHEDA PULS             */
/* NUMBER 6 LED OF PULS BOARD           */

#define		   KMULED_PULS07	B168.bit._06
/* LED NUMERO 7 SCHEDA PULS             */
/* NUMBER 7 LED OF PULS BOARD           */

#define		   KMULED_PULS08	B168.bit._07
/* LED NUMERO 8 SCHEDA PULS             */
/* NUMBER 8 LED OF PULS BOARD           */

#define		   KMULED_PULS09	B168.bit._08
/* LED NUMERO 9 SCHEDA PULS             */
/* NUMBER 9 LED OF PULS BOARD           */

#define		   KMULED_PULS10	B168.bit._09
/* LED NUMERO 10 SCHEDA PULS            */
/* NUMBER 10 LED OF PULS BOARD          */

#define		   KMULED_PULS11	B168.bit._10
/* LED NUMERO 11 SCHEDA PULS            */
/* NUMBER 11 LED OF PULS BOARD          */

#define		   KMULED_PULS12	B168.bit._11
/* LED NUMERO 12 SCHEDA PULS            */
/* NUMBER 12 LED OF PULS BOARD          */


/* ------------------------------------ */
/*              WORD B169               */
/* ------------------------------------ */
#define		   KMULED_PC	B169.uword
/* WORD APPOGGIO LED PER SCHEDA P_C     */
/* SUPPORT WORD FOR P_C BOARD LED       */

#define		   KMULED_PC01	B169.bit._00
/* LED NUMERO 1 SCHEDA P_C              */
/* NUMBER 1 LED OF P_C BOARD            */

#define		   KMULED_PC02	B169.bit._01
/* LED NUMERO 2 SCHEDA P_C              */
/* NUMBER 2 LED OF P_C BOARD            */

#define		   KMULED_PC03	B169.bit._02
/* LED NUMERO 3 SCHEDA P_C              */
/* NUMBER 3 LED OF P_C BOARD            */

#define		   KMULED_PC04	B169.bit._03
/* LED NUMERO 4 SCHEDA P_C              */
/* NUMBER 4 LED OF P_C BOARD            */

#define		   KMULED_PC05	B169.bit._04
/* LED NUMERO 5 SCHEDA P_C              */
/* NUMBER 5 LED OF P_C BOARD            */

#define		   KMULED_PC06	B169.bit._05
/* LED NUMERO 6 SCHEDA P_C              */
/* NUMBER 6 LED OF P_C BOARD            */

#define		   KMULED_PC07	B169.bit._06
/* LED NUMERO 7 SCHEDA P_C              */
/* NUMBER 7 LED OF P_C BOARD            */

#define		   KMULED_PC08	B169.bit._07
/* LED NUMERO 8 SCHEDA P_C              */
/* NUMBER 8 LED OF P_C BOARD            */

#define		   KMULED_PC09	B169.bit._08
/* LED NUMERO 9 SCHEDA P_C              */
/* NUMBER 9 LED OF P_C BOARD            */


/* ------------------------------------ */
/*              WORD B170               */
/* ------------------------------------ */
#define		   KMULED_COM	B170.uword
/* WORD APPOGGIO LED PER SCHEDA COM     */
/* SUPPORT WORD FOR COM BOARD LED       */

#define		   KMULED_COM01	B170.bit._00
/* LED NUMERO 1 SCHEDA COM            */
/* NUMBER 1 LED OF COM BOARD          */

#define		   KMULED_COM02	B170.bit._01
/* LED NUMERO 2 SCHEDA COM            */
/* NUMBER 2 LED OF COM BOARD          */

#define		   KMULED_COM03	B170.bit._02
/* LED NUMERO 3 SCHEDA COM            */
/* NUMBER 3 LED OF COM BOARD          */

#define		   KMULED_COM04	B170.bit._03
/* LED NUMERO 4 SCHEDA COM            */
/* NUMBER 4 LED OF COM BOARD          */

#define		   KMULED_COM05	B170.bit._04
/* LED NUMERO 5 SCHEDA COM            */
/* NUMBER 5 LED OF COM BOARD          */

#define		   KMULED_COM06	B170.bit._05
/* LED NUMERO 6 SCHEDA COM            */
/* NUMBER 6 LED OF COM BOARD          */


/* ------------------------------------ */
/*              WORD B171               */
/* ------------------------------------ */
// Utilizzata per sinonimi diagnostica moduli IO Ecs

// impostato ad 1 quando c'e' un allarme sui moduli IO Ecs
#define IOECS_ALARM			B171.bit._00

// Errore di mancanza 24 Volt
#define IOECS_NO24V			B171.bit._01

// Failure in un modulo IO
#define IOECS_FAULT			B171.bit._02

// Manca 24 V o Failure modulo IO 
// (alcuni moduli emettono quesot errore e basta)
#define IOECS_ERROR			B171.bit._03

// Indica la scheda EcsLink+IO cui  connesso il modulo in errore
// (la prima scheda corrisponde ad 0)
#define IOECS_BOARD			B171.bit._04

// non utilizzati
// #define					B171.bit._05
// #define					B171.bit._06
// #define					B171.bit._07

// Indica il modulo in errore
// (il primo modulo corrisponde ad 1)
#define IOECS_MODULE		B171.byte.h

/* --------------------------------------------- */
/*              WORD B172                        */
/* WORD PER SCELTA TIPO DI RICERCA               */
/* 0 = automatica ( da FILE o da RTG se attiva ) */
/* 1 = da FILE                                   */
/* 2 = da RTG                                    */
/* --------------------------------------------- */
#define		   IMODRIC  	B172.uword
/* WORD RICHIESTA MODALITA' RICERCA     */
/* WORD SEARCH MODALITY REQUEST         */

#define		   IRICFILE  	B172.bit._00
/* RICHIESTA RICERCA DA FILE            */
/* SEARCH FROM FILE REQUEST             */

#define		   IRICRTG  	B172.bit._01
/* RICHIESTA RICERCA DA RTG ( grafica ) */
/* SEARCH FROM RTG REQUEST              */

/* ------------------------------------ */
/*              WORD B173               */
/* word timers Realtime					*/
/* ------------------------------------ */
#define		   TIM_C  	B173.uword
#define		   TIM_REQRST B173.bit._00
/* RICHIESTA RESET VALORI DEI TIMER RT  */
/* REQUEST TO RESET VALUES OF RT TIMERS */
#define		   TIM_REQRSTEXE B173.bit._01
/* ESEGUITO RESET VALORI DEI TIMER RT  */
/* RESET VALUES OF RT TIMERS EXECUTED  */
#define		   TIM_REQENA B173.bit._02
/* AGGIORNA I VALORI DI TUTTI I TIMER RT */
/* UPDATES ALL TIMER RT VALUES           */

/* ------------------------------------ */
/*              WORD B174               */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B175               */
/*    Info Firmware Tastiera ECS        */
/*          da B175 a B179              */
/* ------------------------------------ */

#define        K900_FW_VER_M  B175.ubyte.l
/* VERSIONE FIRMWARE TASTIERA (BCD) */
/* VERSIONE FIRMWARE TASTIERA (BCD) */

#define        K900_FW_VER_H  B175.ubyte.h
/* VERSIONE FIRMWARE TASTIERA (BCD) */
/* VERSIONE FIRMWARE TASTIERA (BCD) */

/* ------------------------------------ */
/*              WORD B176               */
/* ------------------------------------ */

#define        K900_FW_VER_L  B176.ubyte.l
/* VERSIONE FIRMWARE TASTIERA (BCD) */
/* VERSIONE FIRMWARE TASTIERA (BCD) */

/* ------------------------------------ */
/*              WORD B177               */
/* ------------------------------------ */

#define        K900_FW_REV_L  B177.ubyte.l
/* REVISIONE FIRMWARE TASTIERA (ASCII) */
/* REVISIONE FIRMWARE TASTIERA (ASCII) */

#define        K900_FW_REV_H  B177.ubyte.h
/* REVISIONE FIRMWARE TASTIERA (ASCII) */
/* REVISIONE FIRMWARE TASTIERA (ASCII) */

/* ------------------------------------ */
/*              WORD B178               */
/* ------------------------------------ */

#define        K900_FW_DAY   B178.ubyte.l
/* GIORNO DELLA VERSIONE FIRMWARE TASTIERA */
/* GIORNO DELLA VERSIONE FIRMWARE TASTIERA */

#define        K900_FW_MONTH B178.ubyte.h
/* MESE DELLA VERSIONE FIRMWARE TASTIERA */
/* MESE DELLA VERSIONE FIRMWARE TASTIERA */

/* ------------------------------------ */
/*              WORD B179               */
/* ------------------------------------ */

#define        K900_FW_YEAR B179.ubyte.l
/* ANNO DELLA VERSIONE FIRMWARE TASTIERA */
/* ANNO DELLA VERSIONE FIRMWARE TASTIERA */


#define        K900_TGRADIC B179.byte.h
/* TEMPERATURA INTERNA (GRADI CELSIUS) DELLA TASTIERA */
/* TEMPERATURA INTERNA (GRADI CELSIUS) DELLA TASTIERA */

/* ------------------------------------ */
/*              WORD B180               */
/* ------------------------------------ */

#define        OWSMT        B180.word
/* APPOGGIO ASSI CON SENSO MOTO TRASDUTTORE */
/* INVERTITO RISPETTO A TARATURA            */

#define        OSMT0      B180.bit._00
#define        OSMT1      B180.bit._01
#define        OSMT2      B180.bit._02
#define        OSMT3      B180.bit._03
#define        OSMT4      B180.bit._04
#define        OSMT5      B180.bit._05
#define        OSMT6      B180.bit._06
#define        OSMT7      B180.bit._07
#define        OSMT8      B180.bit._08
#define        OSMT9      B180.bit._09
#define        OSMT10     B180.bit._10
#define        OSMT11     B180.bit._11
#define        OSMT12     B180.bit._12
#define        OSMT13     B180.bit._13
#define        OSMT14     B180.bit._14
#define        OSMT15     B180.bit._15

/* ------------------------------------ */
/*              WORD B181               */
/* ------------------------------------ */

#define        OWREF        B181.word
/* APPOGGIO ASSI CON RIFERIMENTO        */
/* INVERTITO RISPETTO A TARATURA        */

#define        OREF0      B181.bit._00
#define        OREF1      B181.bit._01
#define        OREF2      B181.bit._02
#define        OREF3      B181.bit._03
#define        OREF4      B181.bit._04
#define        OREF5      B181.bit._05
#define        OREF6      B181.bit._06
#define        OREF7      B181.bit._07
#define        OREF8      B181.bit._08
#define        OREF9      B181.bit._09
#define        OREF10     B181.bit._10
#define        OREF11     B181.bit._11
#define        OREF12     B181.bit._12
#define        OREF13     B181.bit._13
#define        OREF14     B181.bit._14
#define        OREF15     B181.bit._15

/* ------------------------------------ */
/*              WORD B182               */
/* ------------------------------------ */

#define        ESMTREF        B182.word
/* ESITO FUNZIONE GetSmtRef()           */
/* 0 = OK                               */
/* 1 = NUMERO ORDINE ASSE ERRATO        */
/* 2 = COMANDO INIZIALIZZAZIONE ASSI IN */
/*     CORSO (Segnale OISMTREF = 1)     */

/* ------------------------------------ */
/*              WORD B183               */
/* ------------------------------------ */

#define        OLIVPSWACT     B183.uword
/* VALORE LIVELLO PASSWORD ATTUALE      */
/* VALORE LIVELLO PASSWORD ATTUALE      */

/* ------------------------------------ */
/*              WORD B200 - B210        */
/* WORD RISERVATE PER TASTIERA MEMBRANA */
/* CNC Serie 900					    */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B200		        */
/* TASTIERA MEMBRANA: TASTI CNC + AUXON */
/* + TASTI SPECIALI						*/
/* ------------------------------------ */

#define			KMB_BTN_CNC		B200.uword
/* TASTI CNC TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD CNC BUTTONS */

#define			KMB_START	B200.bit._00
/* TASTO START TASTIERA MU MEMBRANA       */
/* MACHINE MEMBRANE KEYBOARD START BUTTON */

#define			KMB_REL		B200.bit._01
/* TASTO REL TASTIERA MU MEMBRANA         */
/* MACHINE MEMBRANE KEYBOARD REL BUTTON   */

#define			KMB_HLD		B200.bit._02
/* TASTO HOLD TASTIERA MU MEMBRANA        */
/* MACHINE MEMBRANE KEYBOARD HOLD BUTTON  */

#define			KMB_HLDA	B200.bit._03
/* TASTO HLDA TASTIERA MU MEMBRANA        */
/* MACHINE MEMBRANE KEYBOARD HLDA BUTTON  */

#define			KMB_RESET	B200.bit._04
/* TASTO RESET TASTIERA MU MEMBRANA       */
/* MACHINE MEMBRANE KEYBOARD RESET BUTTON */

#define			KMB_AUXON	B200.bit._05
/* TASTO AUXON TASTIERA MU MEMBRANA       */
/* MACHINE MEMBRANE KEYBOARD AUXON BUTTON */

#define			KMB_KEYSX	B200.bit._06
/* CHIAVE SX TASTIERA MU MEMBRANA         */
/* MACHINE MEMBRANE KEYBOARD KEY ON LEFT  */

#define			KMB_KEYDX	B200.bit._07
/* CHIAVE DX TASTIERA MU MEMBRANA         */
/* MACHINE MEMBRANE KEYBOARD KEY ON RIGHT */

#define			KMB_SBTN1	B200.bit._08
/* TASTO SPECIALE 1 SU TASTIERA MU MEMBRANA   */
/* MACHINE MEMBRANE KEYBOARD SPECIAL BUTTON 1 */

#define			KMB_SBTN2	B200.bit._09
/* TASTO SPECIALE 2 SU TASTIERA MU MEMBRANA   */
/* MACHINE MEMBRANE KEYBOARD SPECIAL BUTTON 2 */

/* ------------------------------------ */
/*              WORD B201		        */
/* TASTIERA MEMBRANA: PRIMA FILA TASTI  */
/* ------------------------------------ */

#define			KMB_BTN_TOP		B201.uword
/* TASTI 1-12 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD BUTTON 1-12*/

#define			KMB_BTN01		B201.bit._00
/* TASTO 1 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 1   */ 

#define			KMB_BTN02		B201.bit._01
/* TASTO 2 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 2   */ 

#define			KMB_BTN03		B201.bit._02
/* TASTO 3 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 3   */ 

#define			KMB_BTN04		B201.bit._03
/* TASTO 4 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 4   */ 

#define			KMB_BTN05		B201.bit._04
/* TASTO 5 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 5   */ 

#define			KMB_BTN06		B201.bit._05
/* TASTO 6 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 6   */ 

#define			KMB_BTN07		B201.bit._06
/* TASTO 7 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 7   */ 

#define			KMB_BTN08		B201.bit._07
/* TASTO 8 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 8   */ 

#define			KMB_BTN09		B201.bit._08
/* TASTO 9 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 9   */ 

#define			KMB_BTN10		B201.bit._09
/* TASTO 10 TASTIERA MU MEMBRANA		*/
/* MEMBRANE MACHINE KEYBOARD BUTTON 10  */ 

#define			KMB_BTN11		B201.bit._10
/* TASTO 11 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 11  */  

#define			KMB_BTN12		B201.bit._11
/* TASTO 12 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 12  */  

/* ------------------------------------ */
/*              WORD B202		        */
/* TASTIERA MEMBRANA: SECONDA FILA TASTI*/
/* ------------------------------------ */

#define			KMB_BTN_BOT		B202.uword
/* TASTI 17-28 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD BUTTON 17-28*/

#define			KMB_BTN17		B202.bit._00
/* TASTO 17 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 17   */ 

#define			KMB_BTN18		B202.bit._01
/* TASTO 18 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 18   */ 

#define			KMB_BTN19		B202.bit._02
/* TASTO 19 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 19   */ 

#define			KMB_BTN20		B202.bit._03
/* TASTO 20 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 20   */ 

#define			KMB_BTN21		B202.bit._04
/* TASTO 21 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 21   */ 

#define			KMB_BTN22		B202.bit._05
/* TASTO 22 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 22  */ 

#define			KMB_BTN23		B202.bit._06
/* TASTO 23 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 23  */ 

#define			KMB_BTN24		B202.bit._07
/* TASTO 24 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 24   */ 

#define			KMB_BTN25		B202.bit._08
/* TASTO 25 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD BUTTON 25   */ 

#define			KMB_BTN26		B202.bit._09
/* TASTO 26 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 26  */ 

#define			KMB_BTN27		B202.bit._10
/* TASTO 27 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 27  */  

#define			KMB_BTN28		B202.bit._11
/* TASTO 28 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD BUTTON 28  */  

/* ------------------------------------ */
/*              WORD B203		        */
/* TASTIERA MEMBRANA: LED SX PRIMA FILA TASTI  */
/* ------------------------------------ */

#define			KMB_LEDSX_TOP		B203.uword
/* TASTI 1-12 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD LEDSX 1-12*/

#define			KMB_LEDSX01		B203.bit._00
/* LEDSX 1 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 1   */ 

#define			KMB_LEDSX02		B203.bit._01
/* LEDSX 2 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 2   */ 

#define			KMB_LEDSX03		B203.bit._02
/* LEDSX 3 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 3   */ 

#define			KMB_LEDSX04		B203.bit._03
/* LEDSX 4 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 4   */ 

#define			KMB_LEDSX05		B203.bit._04
/* LEDSX 5 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 5   */ 

#define			KMB_LEDSX06		B203.bit._05
/* LEDSX 6 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 6   */ 

#define			KMB_LEDSX07		B203.bit._06
/* LEDSX 7 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 7   */ 

#define			KMB_LEDSX08		B203.bit._07
/* LEDSX 8 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 8   */ 

#define			KMB_LEDSX09		B203.bit._08
/* LEDSX 9 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 9   */ 

#define			KMB_LEDSX10		B203.bit._09
/* LEDSX 10 TASTIERA MU MEMBRANA		*/
/* MEMBRANE MACHINE KEYBOARD LEFT LED 10  */ 

#define			KMB_LEDSX11		B203.bit._10
/* LEDSX 11 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 11  */  

#define			KMB_LEDSX12		B203.bit._11
/* LEDSX 12 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 12  */  

/* ------------------------------------ */
/*              WORD B204		        */
/* TASTIERA MEMBRANA: LED DX PRIMA FILA TASTI  */
/* ------------------------------------ */

#define			KMB_LEDDX_TOP		B204.uword
/* TASTI 1-12 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD LEDDX 1-12*/

#define			KMB_LEDDX01		B204.bit._00
/* LEDDX 1 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 1   */ 

#define			KMB_LEDDX02		B204.bit._01
/* LEDDX 2 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 2   */ 

#define			KMB_LEDDX03		B204.bit._02
/* LEDDX 3 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 3   */ 

#define			KMB_LEDDX04		B204.bit._03
/* LEDDX 4 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 4   */ 

#define			KMB_LEDDX05		B204.bit._04
/* LEDDX 5 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 5   */ 

#define			KMB_LEDDX06		B204.bit._05
/* LEDDX 6 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 6   */ 

#define			KMB_LEDDX07		B204.bit._06
/* LEDDX 7 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 7   */ 

#define			KMB_LEDDX08		B204.bit._07
/* LEDDX 8 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 8   */ 

#define			KMB_LEDDX09		B204.bit._08
/* LEDDX 9 TASTIERA MU MEMBRANA			*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 9   */ 

#define			KMB_LEDDX10		B204.bit._09
/* LEDDX 10 TASTIERA MU MEMBRANA		*/
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 10  */ 

#define			KMB_LEDDX11		B204.bit._10
/* LEDDX 11 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 11  */  

#define			KMB_LEDDX12		B204.bit._11
/* LEDDX 12 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 12  */  

/* ------------------------------------ */
/*              WORD B205		        */
/* TASTIERA MEMBRANA: SECONDA FILA LED SX*/
/* ------------------------------------ */

#define			KMB_LEDSX_BOT		B205.uword
/* LEDSX 17-28 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 17-28*/

#define			KMB_LEDSX17		B205.bit._00
/* LEDSX 17 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 17   */ 

#define			KMB_LEDSX18		B205.bit._01
/* LEDSX 18 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 18   */ 

#define			KMB_LEDSX19		B205.bit._02
/* LEDSX 19 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 19   */ 

#define			KMB_LEDSX20		B205.bit._03
/* LEDSX 20 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 20   */ 

#define			KMB_LEDSX21		B205.bit._04
/* LEDSX 21 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 21   */ 

#define			KMB_LEDSX22		B205.bit._05
/* LEDSX 22 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 22  */ 

#define			KMB_LEDSX23		B205.bit._06
/* LEDSX 23 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 23  */ 

#define			KMB_LEDSX24		B205.bit._07
/* LEDSX 24 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 24   */ 

#define			KMB_LEDSX25		B205.bit._08
/* LEDSX 25 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 25   */ 

#define			KMB_LEDSX26		B205.bit._09
/* LEDSX 26 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 26  */ 

#define			KMB_LEDSX27		B205.bit._10
/* LEDSX 27 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 27  */  

#define			KMB_LEDSX28		B205.bit._11
/* LEDSX 28 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD LEFT LED 28  */  

/* ------------------------------------ */
/*              WORD B206		        */
/* TASTIERA MEMBRANA: SECONDA FILA LED DX*/
/* ------------------------------------ */

#define			KMB_LEDDX_BOT		B206.uword
/* LEDDX 17-28 TASTIERA MU MEMBRANA      */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 17-28*/

#define			KMB_LEDDX17		B206.bit._00
/* LED DX 17 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 17   */ 

#define			KMB_LEDDX18		B206.bit._01
/* LED DX 18 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 18   */ 

#define			KMB_LEDDX19		B206.bit._02
/* LED DX 19 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 19   */ 

#define			KMB_LEDDX20		B206.bit._03
/* LED DX 20 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 20   */ 

#define			KMB_LEDDX21		B206.bit._04
/* LED DX 21 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 21   */ 

#define			KMB_LEDDX22		B206.bit._05
/* LED DX 22 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 22  */ 

#define			KMB_LEDDX23		B206.bit._06
/* LED DX 23 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 23  */ 

#define			KMB_LEDDX24		B206.bit._07
/* LED DX 24 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 24   */ 

#define			KMB_LEDDX25		B206.bit._08
/* LED DX 25 TASTIERA MU MEMBRANA         */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 25   */ 

#define			KMB_LEDDX26		B206.bit._09
/* LED DX 26 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 26  */ 

#define			KMB_LEDDX27		B206.bit._10
/* LED DX 27 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 27  */  

#define			KMB_LEDDX28		B206.bit._11
/* LED DX 28 TASTIERA MU MEMBRANA        */
/* MEMBRANE MACHINE KEYBOARD RIGHT LED 28  */  

/* ------------------------------------ */
/*              WORD B207		        */
/* TASTIERA MEMBRANA: ALTRI LED			*/
/* ------------------------------------ */

#define			KMB_LED 		B207.uword
/* LED HLDA/HLD/AUXON LED TASTIEREA MU MEMBRANA*/
/* MEMBRANE MACHINE KEYBOARD HLDA HLD AUXON LEDS*/

#define KMB_LEDHLDA					B207.bit._00
/* LED TASTO HOLD ASSI TASTIERA MU MEMBRANA */
/* MEMBRANE MACHINE KEYBOARD AXES HOLD LED*/  

#define KMB_LEDHLD					B207.bit._01
/* LED TASTO HOLD TASTIERA MU MEMBRANA */
/* MEMBRANE MACHINE KEYBOARD HOLD LED*/  

#define KMB_LEDAUXON				B207.bit._02
/* LED TASTO AUXON TASTIERA MU MEMBRANA */
/* MEMBRANE MACHINE KEYBOARD AUXON LED*/  

/* ------------------------------------ */
/*              WORD B208 - B209        */
/* Libere ma riservate per tastiera		*/
/* membrana								*/
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B210 - B215        */
/* Sinonimi per gestione default 		*/
/* JOYSTICK								*/
/* ------------------------------------ */


/* ------------------------------------ */
/*              WORD B210		        */
/* ORDINI ASSI DEL JIOYSTIC				*/
/* ------------------------------------ */

#define       ASSE_JOY1           B210.ubyte.l
/*ORDINE ASSE PER DIREZIONE 1 JOYSTICK  */
/*JOYSTICK DIRECTION 1 AXIS ORDER	    */

#define       ASSE_JOY2           B210.ubyte.h
/*ORDINE ASSE PER DIREZIONE 2 JOYSTICK  */
/*JOYSTICK DIRECTION 2 AXIS ORDER	    */

/* ------------------------------------ */
/*              WORD B211		        */
/* ORDINI ASSI DEL JIOYSTIC				*/
/* ------------------------------------ */

#define       ASSE_JOY3           B211.ubyte.l
/*ORDINE ASSE PER DIREZIONE 3 JOYSTICK  */
/*JOYSTICK DIRECTION 3 AXIS ORDER	    */

/* ------------------------------------ */
/*              WORD B212		        */
/* FILTRO CONTI CANALE 1 JOYSTIC    	*/
/* ------------------------------------ */

#define       FILTRO_JOY1         B212.word
/* FILTRO CONTI CANALE 1 JOYSTICK	    */
/* JOYSTICK CHANNEL 1 COUNT FILTER	    */

/* ------------------------------------ */
/*              WORD B213		        */
/* FILTRO CONTI CANALE 2 JOYSTIC    	*/
/* ------------------------------------ */

#define       FILTRO_JOY2         B213.word
/* FILTRO CONTI CANALE 2 JOYSTICK	    */
/* JOYSTICK CHANNEL 2 COUNT FILTER	    */

/* ------------------------------------ */
/*              WORD B2134		        */
/* FILTRO CONTI CANALE 3 JOYSTIC    	*/
/* ------------------------------------ */

#define       FILTRO_JOY3         B214.word
/* FILTRO CONTI CANALE 3 JOYSTICK	    */
/* JOYSTICK CHANNEL 3 COUNT FILTER	    */

/* ------------------------------------ */
/*              WORD B215		        */
/* COMANDI JOYSTICK                     */
/* ------------------------------------ */

#define       DIRP_JOY            B215.ubyte.l
/* COMANDI DIREZIONE POSITIVA JOYSTICK  */
/* POSITIVE DIRECTION JOYSTICK COMMAND	*/

#define       DIRP_JOY1           B215.bit._00
/* COMANDI DIREZIONE POSITIVA JOYSTICK  CANALE 1 */
/* CHANNEL 1 POSITIVE DIRECTION JOYSTICK COMMAND */

#define       DIRP_JOY2           B215.bit._01
/* COMANDI DIREZIONE POSITIVA JOYSTICK  CANALE 2 */
/* CHANNEL 2 POSITIVE DIRECTION JOYSTICK COMMAND */

#define       DIRP_JOY3           B215.bit._02
/* COMANDI DIREZIONE POSITIVA JOYSTICK  CANALE 3 */
/* CHANNEL 3 POSITIVE DIRECTION JOYSTICK COMMAND */

#define       DIRN_JOY            B215.ubyte.h
/* COMANDI DIREZIONE NEGATIVA JOYSTICK */
/* NEGATIVE DIRECTION JOYSTICK COMMAND */

#define       DIRN_JOY1           B215.bit._08
/* COMANDI DIREZIONE NEGATIVA JOYSTICK  CANALE 1 */
/* CHANNEL 1 NEGATIVE DIRECTION JOYSTICK COMMAND */

#define       DIRN_JOY2           B215.bit._09
/* COMANDI DIREZIONE POSITIVA JOYSTICK  CANALE 2 */
/* CHANNEL 2 POSITIVE DIRECTION JOYSTICK COMMAND */

#define       DIRN_JOY3           B215.bit._10
/* COMANDI DIREZIONE POSITIVA JOYSTICK  CANALE 3 */
/* CHANNEL 3 POSITIVE DIRECTION JOYSTICK COMMAND */

/* ------------------------------------ */
/*              WORD B216 - B220        */
/* Libere								*/
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B220-B250          */
/* WORD RISERVATE PER GESTIONE VISUALIZ.*/
/* FORMATI INTERFACCIA VIS 900          */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B221               */
/* Richiesta visualizzazione quote assi */
/* ------------------------------------ */
#define		IQV_EXCLUDE_MDIN B221.bit._00
/*NON APPLICA MAT. DINAMICA A QUOTA VIS.*/
/*NOT APPLY DYNAMIC MATRIX TO DIS. QUOTA*/

/* ------------------------------------ */
/*              WORD B222               */
/*Richiesta Visualizzazione Formati     */
/* Alternativi                          */
/* ------------------------------------ */
#define		IFORMALT		B222.uword
/*RICHIESTA VISUAL. FORMATI ALTERNATIVI */
/*RICHIESTA VISUAL. FORMATI ALTERNATIVI */

#define		IFRMFESPRA		B222.bit._00
/*VISUALIZZA FORMATO FEED SPEED RAPIDO  */
/*VISUALIZZA FORMATO FEED SPEED RAPIDO  */

#define		IFRMMDIIPP		B222.bit._01
/*VISUALIZZA FORMATO MDI E INFO P.P.    */
/*VISUALIZZA FORMATO MDI E INFO P.P.    */

#define		IFRMCNCOVR		B222.bit._02
/*VISUALIZZA TASTI CNC E OVERRIDES T.S. */
/*VISUALIZZA TASTI CNC E OVERRIDES T.S. */

/* ------------------------------------ */
/*              WORD B223               */
/*Richiesta Non Visualizzazione Formati */
/* ------------------------------------ */
#define		INOVISFMT		B223.uword
/*RICHIESTA NON VISUALIZZAZIONE FORMATI */
/*RICHIESTA NON VISUALIZZAZIONE FORMATI */

#define		INOVISQUOTE		B223.bit._00
/*NON VISUALIZZA FORMATO QUOTE          */
/*NON VISUALIZZA FORMATO QUOTE          */

#define		INOVISTOOL		B223.bit._01
/*NON VISUALIZZA FORMATO TOOL           */
/*NON VISUALIZZA FORMATO TOOL           */

#define		INOVISRAP		B223.bit._02
/*NON VISUALIZZA FORMATO RAPIDO         */
/*NON VISUALIZZA FORMATO RAPIDO         */

#define		INOVISFEED		B223.bit._03
/*NON VISUALIZZA FORMATO FEED           */
/*NON VISUALIZZA FORMATO FEED           */

#define		INOVISSPEED		B223.bit._04
/*NON VISUALIZZA FORMATO SPEED          */
/*NON VISUALIZZA FORMATO SPEED          */

#define		INOVISSTSCNC	B223.bit._05
/*NON VISUALIZZA FORMATO STATO CNC      */
/*NON VISUALIZZA FORMATO STATO CNC      */

#define		INOVISMODICNC	B223.bit._06
/*NON VISUALIZZA FORMATO MODI CNC       */
/*NON VISUALIZZA FORMATO MODI CNC       */

#define		INOVISORIG  	B223.bit._07
/*NON VISUALIZZA ORIGINE ATTIVA         */
/*NON VISUALIZZA ORIGINE ATTIVA         */

#define		INOVISFUNZG 	B223.bit._08
/*NON VISUALIZZA FORMATO FUNZIONI G     */
/*NON VISUALIZZA FORMATO FUNZIONI G     */

#define		INOVISFUNZM 	B223.bit._09
/*NON VISUALIZZA FORMATO FUNZIONI M     */
/*NON VISUALIZZA FORMATO FUNZIONI M     */

#define		INOVISPPESE 	B223.bit._10
/*NON VISUALIZZA P.P. IN ESECUZIONE     */
/*NON VISUALIZZA P.P. IN ESECUZIONE     */

#define		INOVISRTG   	B223.bit._11
/*NON VISUALIZZA FORMATO RTG            */
/*NON VISUALIZZA FORMATO RTG            */

#define		INOVISINFOPP	B223.bit._12
/*NON VISUALIZZA INFO PART PROGRAM      */
/*NON VISUALIZZA INFO PART PROGRAM      */

#define		INOVISDEMDI 	B223.bit._13
/*NON VISUALIZZA DATA ENTRY MDI         */
/*NON VISUALIZZA DATA ENTRY MDI         */

#define		INOVISCMDMDI	B223.bit._14
/*NON VISUALIZZA COMANDI MDI            */
/*NON VISUALIZZA COMANDI MDI            */

/* ------------------------------------ */
/*              WORD B224               */
/* Numero assi da visualizzare nel      */
/* Formato Quote                        */
/* ------------------------------------ */
#define		INUMAXVIS		B224.word
/*NUMERO ASSI DA VISUALIZZARE           */
/*NUMERO ASSI DA VISUALIZZARE           */

/* ------------------------------------ */
/*              WORD B225               */
/* ------------------------------------ */
#define		IORDAXVIS01		B225.uword
/*ORDINE ASSE DA VISUALIZZARE PER 1^    */
/*ORDINE ASSE DA VISUALIZZARE PER 1^    */

/* ------------------------------------ */
/*              WORD B226               */
/* ------------------------------------ */
#define		IORDAXVIS02		B226.uword
/*ORDINE ASSE DA VISUALIZZARE PER 2^    */
/*ORDINE ASSE DA VISUALIZZARE PER 2^    */

/* ------------------------------------ */
/*              WORD B227               */
/* ------------------------------------ */
#define		IORDAXVIS03		B227.uword
/*ORDINE ASSE DA VISUALIZZARE PER 3^    */
/*ORDINE ASSE DA VISUALIZZARE PER 3^    */

/* ------------------------------------ */
/*              WORD B228               */
/* ------------------------------------ */
#define		IORDAXVIS04		B228.uword
/*ORDINE ASSE DA VISUALIZZARE PER 4^    */
/*ORDINE ASSE DA VISUALIZZARE PER 4^    */

/* ------------------------------------ */
/*              WORD B229               */
/* ------------------------------------ */
#define		IORDAXVIS05		B229.uword
/*ORDINE ASSE DA VISUALIZZARE PER 5^    */
/*ORDINE ASSE DA VISUALIZZARE PER 5^    */

/* ------------------------------------ */
/*              WORD B230               */
/* ------------------------------------ */
#define		IORDAXVIS06		B230.uword
/*ORDINE ASSE DA VISUALIZZARE PER 6^    */
/*ORDINE ASSE DA VISUALIZZARE PER 6^    */

/* ------------------------------------ */
/*              WORD B231               */
/* ------------------------------------ */
#define		IORDAXVIS07		B231.uword
/*ORDINE ASSE DA VISUALIZZARE PER 7^    */
/*ORDINE ASSE DA VISUALIZZARE PER 7^    */

/* ------------------------------------ */
/*              WORD B232               */
/* ------------------------------------ */
#define		IORDAXVIS08		B232.uword
/*ORDINE ASSE DA VISUALIZZARE PER 8^    */
/*ORDINE ASSE DA VISUALIZZARE PER 8^    */

/* ------------------------------------ */
/*              WORD B233               */
/* ------------------------------------ */
#define		IORDAXVIS09		B233.uword
/*ORDINE ASSE DA VISUALIZZARE PER 9^    */
/*ORDINE ASSE DA VISUALIZZARE PER 9^    */

/* ------------------------------------ */
/*              WORD B234               */
/* ------------------------------------ */
#define		IORDAXVIS10		B234.uword
/*ORDINE ASSE DA VISUALIZZARE PER 10^   */
/*ORDINE ASSE DA VISUALIZZARE PER 10^   */

/* ------------------------------------ */
/*              WORD B235               */
/* ------------------------------------ */
#define		IORDAXVIS11		B235.uword
/*ORDINE ASSE DA VISUALIZZARE PER 11^   */
/*ORDINE ASSE DA VISUALIZZARE PER 11^   */

/* ------------------------------------ */
/*              WORD B236               */
/* ------------------------------------ */
#define		IORDAXVIS12		B236.uword
/*ORDINE ASSE DA VISUALIZZARE PER 12^   */
/*ORDINE ASSE DA VISUALIZZARE PER 12^   */

/* ------------------------------------ */
/*              WORD B237               */
/* ------------------------------------ */
#define		IORDAXVIS13		B237.uword
/*ORDINE ASSE DA VISUALIZZARE PER 13^   */
/*ORDINE ASSE DA VISUALIZZARE PER 13^   */

/* ------------------------------------ */
/*              WORD B238               */
/* ------------------------------------ */
#define		IORDAXVIS14		B238.uword
/*ORDINE ASSE DA VISUALIZZARE PER 14^   */
/*ORDINE ASSE DA VISUALIZZARE PER 14^   */

/* ------------------------------------ */
/*              WORD B239               */
/* ------------------------------------ */
#define		IORDAXVIS15		B239.uword
/*ORDINE ASSE DA VISUALIZZARE PER 15^   */
/*ORDINE ASSE DA VISUALIZZARE PER 15^   */

/* ------------------------------------ */
/*              WORD B240               */
/* ------------------------------------ */
#define		IORDAXVIS16		B240.uword
/*ORDINE ASSE DA VISUALIZZARE PER 16^   */
/*ORDINE ASSE DA VISUALIZZARE PER 16^   */


/* ------------------------------------ */
/*              WORD B241               */
/* ------------------------------------ */
#define        AOVEREXT    		B241.bit._00
/* PRESENZA OVERRIDES FEED, RAPIDO E SPEED ESTERNI */
/* EXTERNAL OVERRIDES FEED, RAPID AND SPEED */

#define        ALFA_KEYB    	B241.bit._01
/* ATTIVAZIONE TASTIERA ALFANUMERICA */
/* ALPHANUMERIC KEYBOARD ON */

#define        NUM_KEYB    		B241.bit._02
/* ATTIVAZIONE TASTIERA NUMERICA */
/* NUMERIC KEYBOARD ON */

#define        KEYB_ABC    		B241.bit._04
/* ATTIVAZIONE TASTIERA ALFANUMERICA */
/* ALPHANUMERIC KEYBOARD ON */

#define        AUXON_SHUTDW		B241.bit._05
/* ATTIVAZIONE PANNELLO AUX ON / SHUTDOWN */
/* PANEL ACTIVATION AUX ON / SHUTDOWN */

#define        MACHINE_ON		B241.bit._06
/* AUSILIARI MACCHINA INSERITI */
/* MACHINE AUX ON */

#define        R_SHUTDW			B241.bit._07
/* RICHIESTA SHUTDOWN */
/* REQUEST SHUTDOWN */

#define        R_AUXON			B241.bit._08
/* RICHIESTA AUX ON */
/* REQUEST AUX ON */

/* ------------------------------------ */
/*              WORD B242               */
/* ------------------------------------ */
/*			Segnali Capture				*/
/*			Capture signals				*/
/* ------------------------------------ */
#define		   CAPTURE			B242.uword
/* Valore Capture su assi 0-15			*/
/* Capture value on axes 0-15			*/
#define        CAPTURE0    		B242.bit._00
/* Valore Capture su asse di ordine 0	*/
/* Capture value on order 0 axis		*/
#define        CAPTURE1    		B242.bit._01
#define        CAPTURE2    		B242.bit._02
#define        CAPTURE3    		B242.bit._03
#define        CAPTURE4    		B242.bit._04
#define        CAPTURE5    		B242.bit._05
#define        CAPTURE6    		B242.bit._06
#define        CAPTURE7    		B242.bit._07
#define        CAPTURE8    		B242.bit._08
#define        CAPTURE9   		B242.bit._09
#define        CAPTURE10   		B242.bit._10
#define        CAPTURE11   		B242.bit._11
#define        CAPTURE12   		B242.bit._12
#define        CAPTURE13   		B242.bit._13
#define        CAPTURE14   		B242.bit._14
#define        CAPTURE15   		B242.bit._15
/* Valore Capture su asse di ordine 15	*/
/* Capture value on order 15 axis		*/

/* ------------------------------------ */
/*              WORD B243               */
/* ------------------------------------ */
/*			Timeout Capture 			*/
/*			Capture Timeout 			*/
/* ------------------------------------ */
#define	   CAPTURE_TIMEOUT		B243.uword
/* Timeout Capture su assi 0-15			*/
/* Capture timeout on axes 0-15			*/
#define    CAPTURE0_TIMEOUT		B243.bit._00
/* Timeout Capture su asse di ordine 0	*/
/* Capture timeout on order 0 axis		*/
#define    CAPTURE1_TIMEOUT     B243.bit._01
#define    CAPTURE2_TIMEOUT     B243.bit._02
#define    CAPTURE3_TIMEOUT     B243.bit._03
#define    CAPTURE4_TIMEOUT     B243.bit._04
#define	   CAPTURE5_TIMEOUT     B243.bit._05
#define	   CAPTURE6_TIMEOUT     B243.bit._06
#define    CAPTURE7_TIMEOUT     B243.bit._07
#define    CAPTURE8_TIMEOUT     B243.bit._08
#define    CAPTURE9_TIMEOUT     B243.bit._09
// #define    CAPTURE10_TIMEOUT	B243.bit._10
// #define    CAPTURE11_TIMEOUT    B243.bit._11
// #define    CAPTURE12_TIMEOUT    B243.bit._12
// #define    CAPTURE13_TIMEOUT    B243.bit._13
// #define    CAPTURE14_TIMEOUT    B243.bit._14
// #define    CAPTURE15_TIMEOUT    B243.bit._15
/* Timeout Capture su asse di ordine 15	*/
/* Capture timeout on order 15 axis		*/

/* ------------------------------------ */
/*              WORD B256               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:     !!! I segnali TIME_xx devono essere contigui !!!   */
/*       Cambiando l'assegnazione o l'ordine dei segnali       */
/*       TIME_xx, occorre modificare la funzione TEMPQAL, che  */
/*       ottimizza il trasferimento di aree contigue !!!!      */
/*                                                             */
/* N.B:  !!! TIME_xx signal must be adjacent to each other !!! */
/*       Changing TIME_xx signal assignment/order, it is       */
/*       required to modify TEMPQAL function, which optimize   */
/*       adjacent data area moving                             */
/***************************************************************/
#define         TIME_00    B256.bit._00
/* SEGNALE PILOTA PER TEMPORIZZATORE 00 (Primo ECS)*/
/* PILOT SIGNAL FOR TIMER 00 (first ECS timer)*/
#define         TIME_01    B256.bit._01
#define         TIME_02    B256.bit._02
#define         TIME_03    B256.bit._03
#define         TIME_04    B256.bit._04
#define         TIME_05    B256.bit._05
#define         TIME_06    B256.bit._06
#define         TIME_07    B256.bit._07
#define         TIME_08    B256.bit._08
#define         TIME_09    B256.bit._09
#define         TIME_10    B256.bit._10
#define         TIME_11    B256.bit._11

#define         TIME_12    B256.bit._12
/* SEGNALE PILOTA PER TEMPORIZZATORE 12 (Primo User)*/
/* PILOT SIGNAL FOR TIMER 12 (first User timer)*/
#define         TIME_13    B256.bit._13
#define         TIME_14    B256.bit._14
#define         TIME_15    B256.bit._15

/* ------------------------------------ */
/*              WORD B257               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_16    B257.bit._00
#define         TIME_17    B257.bit._01
#define         TIME_18    B257.bit._02
#define         TIME_19    B257.bit._03
#define         TIME_20    B257.bit._04
#define         TIME_21    B257.bit._05
#define         TIME_22    B257.bit._06
#define         TIME_23    B257.bit._07
#define         TIME_24    B257.bit._08
#define         TIME_25    B257.bit._09
#define         TIME_26    B257.bit._10
#define         TIME_27    B257.bit._11
#define         TIME_28    B257.bit._12
#define         TIME_29    B257.bit._13
#define         TIME_30    B257.bit._14
#define         TIME_31    B257.bit._15

/* ------------------------------------ */
/*              WORD B258               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_32    B258.bit._00
#define         TIME_33    B258.bit._01
#define         TIME_34    B258.bit._02
#define         TIME_35    B258.bit._03
#define         TIME_36    B258.bit._04
#define         TIME_37    B258.bit._05
#define         TIME_38    B258.bit._06
#define         TIME_39    B258.bit._07
#define         TIME_40    B258.bit._08
#define         TIME_41    B258.bit._09
#define         TIME_42    B258.bit._10
#define         TIME_43    B258.bit._11
#define         TIME_44    B258.bit._12
#define         TIME_45    B258.bit._13
#define         TIME_46    B258.bit._14
#define         TIME_47    B258.bit._15

/* ------------------------------------ */
/*              WORD B259               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_48    B259.bit._00
#define         TIME_49    B259.bit._01
#define         TIME_50    B259.bit._02
#define         TIME_51    B259.bit._03
#define         TIME_52    B259.bit._04
#define         TIME_53    B259.bit._05
#define         TIME_54    B259.bit._06
#define         TIME_55    B259.bit._07
#define         TIME_56    B259.bit._08
#define         TIME_57    B259.bit._09
#define         TIME_58    B259.bit._10
#define         TIME_59    B259.bit._11
#define         TIME_60    B259.bit._12
#define         TIME_61    B259.bit._13
#define         TIME_62    B259.bit._14
#define         TIME_63    B259.bit._15

/* ------------------------------------ */
/*              WORD B260               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_64    B260.bit._00
#define         TIME_65    B260.bit._01
#define         TIME_66    B260.bit._02
#define         TIME_67    B260.bit._03
#define         TIME_68    B260.bit._04
#define         TIME_69    B260.bit._05
#define         TIME_70    B260.bit._06
#define         TIME_71    B260.bit._07
#define         TIME_72    B260.bit._08
#define         TIME_73    B260.bit._09
#define         TIME_74    B260.bit._10
#define         TIME_75    B260.bit._11
#define         TIME_76    B260.bit._12
#define         TIME_77    B260.bit._13
#define         TIME_78    B260.bit._14
#define         TIME_79    B260.bit._15

/* ------------------------------------ */
/*              WORD B261               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_80    B261.bit._00
#define         TIME_81    B261.bit._01
#define         TIME_82    B261.bit._02
#define         TIME_83    B261.bit._03
#define         TIME_84    B261.bit._04
#define         TIME_85    B261.bit._05
#define         TIME_86    B261.bit._06
#define         TIME_87    B261.bit._07
#define         TIME_88    B261.bit._08
#define         TIME_89    B261.bit._09
/* SEGNALE PILOTA PER TEMPORIZZATORE 89 (Ultimo User)*/
/* PILOT SIGNAL FOR TIMER 89 (last User timer)*/

#define         TIME_90    B261.bit._10
#define         TIME_91    B261.bit._11
#define         TIME_92    B261.bit._12
#define         TIME_93    B261.bit._13
#define         TIME_94    B261.bit._14
#define         TIME_95    B261.bit._15

/* ------------------------------------ */
/*              WORD B262               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_96    B262.bit._00
#define         TIME_97    B262.bit._01
#define         TIME_98    B262.bit._02
#define         TIME_99    B262.bit._03
#define         TIME_100   B262.bit._04
#define         TIME_101   B262.bit._05
#define         TIME_102   B262.bit._06
#define         TIME_103   B262.bit._07
#define         TIME_104   B262.bit._08
#define         TIME_105   B262.bit._09
#define         TIME_106   B262.bit._10
#define         TIME_107   B262.bit._11
#define         TIME_108   B262.bit._12
#define         TIME_109   B262.bit._13
#define         TIME_110   B262.bit._14
#define         TIME_111   B262.bit._15

/* ------------------------------------ */
/*              WORD B263               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
/* SEGNALI PILOTA PER TEMPORIZZATORI 112-115 (ASSI ORDINE 12, 13, 14, 15) */
/* PILOT SIGNAL FOR TIMER 112-115 (AXES ORDER 12, 13, 14, 15) */
#define         TIME_112   B263.bit._00
#define         TIME_113   B263.bit._01
#define         TIME_114   B263.bit._02
#define         TIME_115   B263.bit._03
/* SEGNALI PILOTA PER TEMPORIZZATORI 112-115 (ASSI ORDINE 12, 13, 14, 15) */
/* PILOT SIGNAL FOR TIMER 112-115 (AXES ORDER 12, 13, 14, 15) */

#define         TIME_116   B263.bit._04
#define         TIME_117   B263.bit._05
#define         TIME_118   B263.bit._06
#define         TIME_119   B263.bit._07
#define         TIME_120   B263.bit._08
#define         TIME_121   B263.bit._09
#define         TIME_122   B263.bit._10
#define         TIME_123   B263.bit._11
#define         TIME_124   B263.bit._12
#define         TIME_125   B263.bit._13
#define         TIME_126   B263.bit._14
#define         TIME_127   B263.bit._15
/* SEGNALE PILOTA PER TEMPORIZZATORE 127 (Ultimo)*/
/* PILOT SIGNAL FOR TIMER 127 (last timer)*/

/* ------------------------------------ */
/*              WORD B264-273           */
/* allarmi application specific (ASA)   */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B264	            */
/*		 word ASA: ASA00-ASA15			*/
/* ------------------------------------ */

#define        AASA00       B264.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 0 - 15 */
/* SUPPORT TO APPLICATION ALARMS 0 - 15 */

#define        ASA00        B264.bit._00
/* ATTIVAZIONE ASA 0 (Primo Allarme) */
/* ASA 0 ACTIVATION (first alarm) */

#define        ASA01        B264.bit._01
#define        ASA02        B264.bit._02
#define        ASA03        B264.bit._03
#define        ASA04        B264.bit._04
#define        ASA05        B264.bit._05
#define        ASA06        B264.bit._06
#define        ASA07        B264.bit._07
#define        ASA08        B264.bit._08
#define        ASA09        B264.bit._09
#define        ASA10        B264.bit._10
#define        ASA11        B264.bit._11
#define        ASA12        B264.bit._12
#define        ASA13        B264.bit._13
#define        ASA14        B264.bit._14
#define        ASA15        B264.bit._15

/* ------------------------------------ */
/*              WORD B265	            */
/*		 word ASA: ASA16-ASA31			*/
/* ------------------------------------ */

#define        AASA01       B265.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 16 - 31 */
/* SUPPORT TO APPLICATION ALARMS 16 - 31 */

#define        ASA16        B265.bit._00
#define        ASA17        B265.bit._01
#define        ASA18        B265.bit._02
#define        ASA19        B265.bit._03
#define        ASA20        B265.bit._04
#define        ASA21        B265.bit._05
#define        ASA22        B265.bit._06
#define        ASA23        B265.bit._07
#define        ASA24        B265.bit._08
#define        ASA25        B265.bit._09
#define        ASA26        B265.bit._10
#define        ASA27        B265.bit._11
#define        ASA28        B265.bit._12
#define        ASA29        B265.bit._13
#define        ASA30        B265.bit._14
#define        ASA31        B265.bit._15

/* ------------------------------------ */
/*              WORD B266	            */
/*		 word ASA: ASA32-ASA47			*/
/* ------------------------------------ */

#define        AASA02       B266.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 32-47 */
/* SUPPORT TO APPLICATION ALARMS 32-47*/

#define        ASA32        B266.bit._00
#define        ASA33        B266.bit._01
#define        ASA34        B266.bit._02
#define        ASA35        B266.bit._03
#define        ASA36        B266.bit._04
#define        ASA37        B266.bit._05
#define        ASA38        B266.bit._06
#define        ASA39        B266.bit._07
#define        ASA40        B266.bit._08
#define        ASA41        B266.bit._09
#define        ASA42        B266.bit._10
#define        ASA43        B266.bit._11
#define        ASA44        B266.bit._12
#define        ASA45        B266.bit._13
#define        ASA46        B266.bit._14
#define        ASA47        B266.bit._15

/* ------------------------------------ */
/*              WORD B267	            */
/*		 word ASA: ASA48-ASA63			*/
/* ------------------------------------ */

#define        AASA03       B267.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 48-63 */
/* SUPPORT TO APPLICATION ALARMS 38-63 */

#define        ASA48        B267.bit._00
#define        ASA49        B267.bit._01
#define        ASA50        B267.bit._02
#define        ASA51        B267.bit._03
#define        ASA52        B267.bit._04
#define        ASA53        B267.bit._05
#define        ASA54        B267.bit._06
#define        ASA55        B267.bit._07
#define        ASA56        B267.bit._08
#define        ASA57        B267.bit._09
#define        ASA58        B267.bit._10
#define        ASA59        B267.bit._11
#define        ASA60        B267.bit._12
#define        ASA61        B267.bit._13
#define        ASA62        B267.bit._14
#define        ASA63        B267.bit._15

/* ------------------------------------ */
/*              WORD B268	            */
/*		 word ASA: ASA64-ASA79			*/
/* ------------------------------------ */

#define        AASA04       B268.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 64-79 */
/* SUPPORT TO APPLICATION ALARMS 64-79 */

#define        ASA64        B268.bit._00
#define        ASA65        B268.bit._01
#define        ASA66        B268.bit._02
#define        ASA67        B268.bit._03
#define        ASA68        B268.bit._04
#define        ASA69        B268.bit._05
#define        ASA70        B268.bit._06
#define        ASA71        B268.bit._07
#define        ASA72        B268.bit._08
#define        ASA73        B268.bit._09
#define        ASA74        B268.bit._10
#define        ASA75        B268.bit._11
#define        ASA76        B268.bit._12
#define        ASA77        B268.bit._13
#define        ASA78        B268.bit._14
#define        ASA79        B268.bit._15

/* ------------------------------------ */
/*              WORD B269	            */
/*		 word ASA: ASA80-ASA95 			*/
/* ------------------------------------ */

#define        AASA05       B269.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 80-95 */
/* SUPPORT TO APPLICATION ALARMS 80-95 */

#define        ASA80        B269.bit._00
#define        ASA81        B269.bit._01
#define        ASA82        B269.bit._02
#define        ASA83        B269.bit._03
#define        ASA84        B269.bit._04
#define        ASA85        B269.bit._05
#define        ASA86        B269.bit._06
#define        ASA87        B269.bit._07
#define        ASA88        B269.bit._08
#define        ASA89        B269.bit._09
#define        ASA90        B269.bit._10
#define        ASA91        B269.bit._11
#define        ASA92        B269.bit._12
#define        ASA93        B269.bit._13
#define        ASA94        B269.bit._14
#define        ASA95        B269.bit._15

/* ------------------------------------ */
/*              WORD B270	            */
/*		 word ASA: ASA96-ASA111    	*/
/* ------------------------------------ */

#define        AASA06       B270.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 96 - 111 */
/* SUPPORT TO APPLICATION ALARMS 96 - 111 */

#define        ASA96        B270.bit._00
#define        ASA97        B270.bit._01
#define        ASA98        B270.bit._02
#define        ASA99        B270.bit._03
#define        ASA100       B270.bit._04
#define        ASA101       B270.bit._05
#define        ASA102       B270.bit._06
#define        ASA103       B270.bit._07
#define        ASA104       B270.bit._08
#define        ASA105       B270.bit._09
#define        ASA106       B270.bit._10
#define        ASA107       B270.bit._11
#define        ASA108       B270.bit._12
#define        ASA109       B270.bit._13
#define        ASA110       B270.bit._14
#define        ASA111       B270.bit._15

/* ------------------------------------ */
/*              WORD B271	            */
/*		 word ASA: ASA112 - ASA127    	*/
/* ------------------------------------ */

#define        AASA07       B271.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 112 - 127 */
/* SUPPORT TO APPLICATION ALARMS 112 - 127 */

#define        ASA112       B271.bit._00
#define        ASA113       B271.bit._01
#define        ASA114       B271.bit._02
#define        ASA115       B271.bit._03
#define        ASA116       B271.bit._04
#define        ASA117       B271.bit._05
#define        ASA118       B271.bit._06
#define        ASA119       B271.bit._07
#define        ASA120       B271.bit._08
#define        ASA121       B271.bit._09
#define        ASA122       B271.bit._10
#define        ASA123       B271.bit._11
#define        ASA124       B271.bit._12
#define        ASA125       B271.bit._13
#define        ASA126       B271.bit._14
#define        ASA127       B271.bit._15

/* ------------------------------------ */
/*              WORD B272	            */
/*		 word ASA: ASA128-ASA143    	*/
/* ------------------------------------ */

#define        AASA08       B272.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 128 - 134 */
/* SUPPORT TO APPLICATION ALARMS 128 - 143 */

#define        ASA128       B272.bit._00
#define        ASA129       B272.bit._01
#define        ASA130       B272.bit._02
#define        ASA131       B272.bit._03
#define        ASA132       B272.bit._04
#define        ASA133       B272.bit._05
#define        ASA134       B272.bit._06
#define        ASA135       B272.bit._07
#define        ASA136       B272.bit._08
#define        ASA137       B272.bit._09
#define        ASA138       B272.bit._10
#define        ASA139       B272.bit._11
#define        ASA140       B272.bit._12
#define        ASA141       B272.bit._13
#define        ASA142       B272.bit._14
#define        ASA143       B272.bit._15

/* ------------------------------------ */
/*              WORD B273	            */
/*		 word ASA: ASA144 - ASA159    	*/
/* ------------------------------------ */

#define        AASA09       B273.word
/* APPOGGIO PER ALLARMI APPLICAZIONE 143 - 160 */
/* SUPPORT TO APPLICATION ALARMS 143 - 160 */

#define        ASA144       B273.bit._00
#define        ASA145       B273.bit._01
#define        ASA146       B273.bit._02
#define        ASA147       B273.bit._03
#define        ASA148       B273.bit._04
#define        ASA149       B273.bit._05
#define        ASA150       B273.bit._06
#define        ASA151       B273.bit._07
#define        ASA152       B273.bit._08
#define        ASA153       B273.bit._09
#define        ASA154       B273.bit._10
#define        ASA155       B273.bit._11
#define        ASA156       B273.bit._12
#define        ASA157       B273.bit._13
#define        ASA158       B273.bit._14
#define        ASA159       B273.bit._15

/* ------------------------------------ */
/*              WORD B274-283           */
/*attenzioni application specific (ASW) */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B274	            */
/*		 word ASW: ASW00-ASW15			*/
/* ------------------------------------ */

#define        AASW00       B274.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 0 - 15 */
/* SUPPORT TO APPLICATION WARNINGS 0 - 15 */

#define        ASW00        B274.bit._00
/* ATTIVAZIONE ASW 0 (prima Attenzione) */
/* ASW 0 ACTIVATION (first Warning) */

#define        ASW01        B274.bit._01
#define        ASW02        B274.bit._02
#define        ASW03        B274.bit._03
#define        ASW04        B274.bit._04
#define        ASW05        B274.bit._05
#define        ASW06        B274.bit._06
#define        ASW07        B274.bit._07
#define        ASW08        B274.bit._08
#define        ASW09        B274.bit._09
#define        ASW10        B274.bit._10
#define        ASW11        B274.bit._11
#define        ASW12        B274.bit._12
#define        ASW13        B274.bit._13
#define        ASW14        B274.bit._14
#define        ASW15        B274.bit._15

/* ------------------------------------ */
/*              WORD B275	            */
/*		 word ASW: ASW16-ASW31			*/
/* ------------------------------------ */

#define        AASW01       B275.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 16 - 31 */
/* SUPPORT TO APPLICATION WARNINGS 16 - 31 */

#define        ASW16        B275.bit._00
#define        ASW17        B275.bit._01
#define        ASW18        B275.bit._02
#define        ASW19        B275.bit._03
#define        ASW20        B275.bit._04
#define        ASW21        B275.bit._05
#define        ASW22        B275.bit._06
#define        ASW23        B275.bit._07
#define        ASW24        B275.bit._08
#define        ASW25        B275.bit._09
#define        ASW26        B275.bit._10
#define        ASW27        B275.bit._11
#define        ASW28        B275.bit._12
#define        ASW29        B275.bit._13
#define        ASW30        B275.bit._14
#define        ASW31        B275.bit._15

/* ------------------------------------ */
/*              WORD B276	            */
/*		 word ASW: ASW32-ASW47			*/
/* ------------------------------------ */

#define        AASW02       B276.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 32-47 */
/* SUPPORT TO APPLICATION WARNINGS 32-47*/

#define        ASW32        B276.bit._00
#define        ASW33        B276.bit._01
#define        ASW34        B276.bit._02
#define        ASW35        B276.bit._03
#define        ASW36        B276.bit._04
#define        ASW37        B276.bit._05
#define        ASW38        B276.bit._06
#define        ASW39        B276.bit._07
#define        ASW40        B276.bit._08
#define        ASW41        B276.bit._09
#define        ASW42        B276.bit._10
#define        ASW43        B276.bit._11
#define        ASW44        B276.bit._12
#define        ASW45        B276.bit._13
#define        ASW46        B276.bit._14
#define        ASW47        B276.bit._15

/* ------------------------------------ */
/*              WORD B277	            */
/*		 word ASW: ASW48-ASW63			*/
/* ------------------------------------ */

#define        AASW03       B277.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 48-63 */
/* SUPPORT TO APPLICATION WARNINGS 38-63 */

#define        ASW48        B277.bit._00
#define        ASW49        B277.bit._01
#define        ASW50        B277.bit._02
#define        ASW51        B277.bit._03
#define        ASW52        B277.bit._04
#define        ASW53        B277.bit._05
#define        ASW54        B277.bit._06
#define        ASW55        B277.bit._07
#define        ASW56        B277.bit._08
#define        ASW57        B277.bit._09
#define        ASW58        B277.bit._10
#define        ASW59        B277.bit._11
#define        ASW60        B277.bit._12
#define        ASW61        B277.bit._13
#define        ASW62        B277.bit._14
#define        ASW63        B277.bit._15

/* ------------------------------------ */
/*              WORD B278	            */
/*		 word ASW: ASW64-ASW79			*/
/* ------------------------------------ */

#define        AASW04       B278.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 64-79 */
/* SUPPORT TO APPLICATION WARNINGS 64-79 */

#define        ASW64        B278.bit._00
#define        ASW65        B278.bit._01
#define        ASW66        B278.bit._02
#define        ASW67        B278.bit._03
#define        ASW68        B278.bit._04
#define        ASW69        B278.bit._05
#define        ASW70        B278.bit._06
#define        ASW71        B278.bit._07
#define        ASW72        B278.bit._08
#define        ASW73        B278.bit._09
#define        ASW74        B278.bit._10
#define        ASW75        B278.bit._11
#define        ASW76        B278.bit._12
#define        ASW77        B278.bit._13
#define        ASW78        B278.bit._14
#define        ASW79        B278.bit._15

/* ------------------------------------ */
/*              WORD B279	            */
/*		 word ASW: ASW80-ASW95			*/
/* ------------------------------------ */

#define        AASW05       B279.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 80-95 */
/* SUPPORT TO APPLICATION WARNINGS 80-95 */

#define        ASW80        B279.bit._00
#define        ASW81        B279.bit._01
#define        ASW82        B279.bit._02
#define        ASW83        B279.bit._03
#define        ASW84        B279.bit._04
#define        ASW85        B279.bit._05
#define        ASW86        B279.bit._06
#define        ASW87        B279.bit._07
#define        ASW88        B279.bit._08
#define        ASW89        B279.bit._09
#define        ASW90        B279.bit._10
#define        ASW91        B279.bit._11
#define        ASW92        B279.bit._12
#define        ASW93        B279.bit._13
#define        ASW94        B279.bit._14
#define        ASW95        B279.bit._15

/* ------------------------------------ */
/*              WORD B280	            */
/*		 word ASW: ASW96-ASW111	    	*/
/* ------------------------------------ */

#define        AASW06       B280.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 96 - 111 */
/* SUPPORT TO APPLICATION WARNINGS 96 - 111 */

#define        ASW96        B280.bit._00
#define        ASW97        B280.bit._01
#define        ASW98        B280.bit._02
#define        ASW99        B280.bit._03
#define        ASW100       B280.bit._04
#define        ASW101       B280.bit._05
#define        ASW102       B280.bit._06
#define        ASW103       B280.bit._07
#define        ASW104       B280.bit._08
#define        ASW105       B280.bit._09
#define        ASW106       B280.bit._10
#define        ASW107       B280.bit._11
#define        ASW108       B280.bit._12
#define        ASW109       B280.bit._13
#define        ASW110       B280.bit._14
#define        ASW111       B280.bit._15

/* ------------------------------------ */
/*              WORD B281	            */
/*		 word ASW: ASW112 - ASW127    	*/
/* ------------------------------------ */

#define        AASW07       B281.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 112 - 127 */
/* SUPPORT TO APPLICATION WARNINGS 112 - 127 */

#define        ASW112       B281.bit._00
#define        ASW113       B281.bit._01
#define        ASW114       B281.bit._02
#define        ASW115       B281.bit._03
#define        ASW116       B281.bit._04
#define        ASW117       B281.bit._05
#define        ASW118       B281.bit._06
#define        ASW119       B281.bit._07
#define        ASW120       B281.bit._08
#define        ASW121       B281.bit._09
#define        ASW122       B281.bit._10
#define        ASW123       B281.bit._11
#define        ASW124       B281.bit._12
#define        ASW125       B281.bit._13
#define        ASW126       B281.bit._14
#define        ASW127       B281.bit._15

/* ------------------------------------ */
/*              WORD B282	            */
/*		 word ASW: ASW128-ASW143    	*/
/* ------------------------------------ */

#define        AASW08       B282.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 128 - 134 */
/* SUPPORT TO APPLICATION WARNINGS 128 - 143 */

#define        ASW128       B282.bit._00
#define        ASW129       B282.bit._01
#define        ASW130       B282.bit._02
#define        ASW131       B282.bit._03
#define        ASW132       B282.bit._04
#define        ASW133       B282.bit._05
#define        ASW134       B282.bit._06
#define        ASW135       B282.bit._07
#define        ASW136       B282.bit._08
#define        ASW137       B282.bit._09
#define        ASW138       B282.bit._10
#define        ASW139       B282.bit._11
#define        ASW140       B282.bit._12
#define        ASW141       B282.bit._13
#define        ASW142       B282.bit._14
#define        ASW143       B282.bit._15

/* ------------------------------------ */
/*              WORD B283	            */
/*  word ASW: ASW144 - ASW159    		*/
/* ------------------------------------ */

#define        AASW09       B283.word
/* APPOGGIO PER ATTENZIONI APPLICAZIONE 143 - 160 */
/* SUPPORT TO APPLICATION WARNINGS 143 - 160 */

#define        ASW144       B283.bit._00
#define        ASW145       B283.bit._01
#define        ASW146       B283.bit._02
#define        ASW147       B283.bit._03
#define        ASW148       B283.bit._04
#define        ASW149       B283.bit._05
#define        ASW150       B283.bit._06
#define        ASW151       B283.bit._07
#define        ASW152       B283.bit._08
#define        ASW153       B283.bit._09
#define        ASW154       B283.bit._10
#define        ASW155       B283.bit._11
#define        ASW156       B283.bit._12
#define        ASW157       B283.bit._13
#define        ASW158       B283.bit._14
#define        ASW159       B283.bit._15

/* ------------------------------------ */
/*              WORD B284-299           */
/* TIMER application specific (TIMECS)  */
/* ------------------------------------ */

/* ------------------------------------ */
/*              WORD B284	            */
/* TIMER ECS: TIMECS00 - TIMECS15		*/
/* ------------------------------------ */

#define        WTIMECS00    B284.word
/* WORD PER TIMER APPLICAZIONE ECS 0 - 15 */
/* ECS APPLICATION TIMER 0 - 15 */

#define        TIMECS00     B284.bit._00
#define        TIMECS01     B284.bit._01
#define        TIMECS02     B284.bit._02
#define        TIMECS03     B284.bit._03
#define        TIMECS04     B284.bit._04
#define        TIMECS05     B284.bit._05
#define        TIMECS06     B284.bit._06
#define        TIMECS07     B284.bit._07
#define        TIMECS08     B284.bit._08
#define        TIMECS09     B284.bit._09
#define        TIMECS10     B284.bit._10
#define        TIMECS11     B284.bit._11
#define        TIMECS12     B284.bit._12
#define        TIMECS13     B284.bit._13
#define        TIMECS14     B284.bit._14
#define        TIMECS15     B284.bit._15

/* ------------------------------------ */
/*              WORD B285	            */
/* TIMER ECS: TIMECS16 - TIMECS31		*/
/* ------------------------------------ */

#define        WTIMECS01    B285.word
/* WORD PER TIMER APPLICAZIONE ECS 16 - 31 */
/* ECS APPLICATION TIMER 16 - 31 */

#define        TIMECS16     B285.bit._00
#define        TIMECS17     B285.bit._01
#define        TIMECS18     B285.bit._02
#define        TIMECS19     B285.bit._03
#define        TIMECS20     B285.bit._04
#define        TIMECS21     B285.bit._05
#define        TIMECS22     B285.bit._06
#define        TIMECS23     B285.bit._07
#define        TIMECS24     B285.bit._08
#define        TIMECS25     B285.bit._09
#define        TIMECS26     B285.bit._10
#define        TIMECS27     B285.bit._11
#define        TIMECS28     B285.bit._12
#define        TIMECS29     B285.bit._13
#define        TIMECS30     B285.bit._14
#define        TIMECS31     B285.bit._15

/* ------------------------------------ */
/*              WORD B286	            */
/* TIMER ECS: TIMECS32 - TIMECS47		*/
/* ------------------------------------ */

#define        WTIMECS02    B286.word
/* WORD PER TIMER APPLICAZIONE ECS 32 - 47 */
/* ECS APPLICATION TIMER 32 - 47 */

#define        TIMECS32     B286.bit._00
#define        TIMECS33     B286.bit._01
#define        TIMECS34     B286.bit._02
#define        TIMECS35     B286.bit._03
#define        TIMECS36     B286.bit._04
#define        TIMECS37     B286.bit._05
#define        TIMECS38     B286.bit._06
#define        TIMECS39     B286.bit._07
#define        TIMECS40     B286.bit._08
#define        TIMECS41     B286.bit._09
#define        TIMECS42     B286.bit._10
#define        TIMECS43     B286.bit._11
#define        TIMECS44     B286.bit._12
#define        TIMECS45     B286.bit._13
#define        TIMECS46     B286.bit._14
#define        TIMECS47     B286.bit._15

/* ------------------------------------ */
/*              WORD B287	            */
/* TIMER ECS: TIMECS48 - TIMECS63		*/
/* ------------------------------------ */

#define        WTIMECS03    B287.word
/* WORD PER TIMER APPLICAZIONE ECS 48 - 63 */
/* ECS APPLICATION TIMER 48 - 63 */

#define        TIMECS48     B287.bit._00
#define        TIMECS49     B287.bit._01
#define        TIMECS50     B287.bit._02
#define        TIMECS51     B287.bit._03
#define        TIMECS52     B287.bit._04
#define        TIMECS53		B287.bit._05
#define        TIMECS54     B287.bit._06
#define        TIMECS55     B287.bit._07
#define        TIMECS56     B287.bit._08
#define        TIMECS57     B287.bit._09
#define        TIMECS58     B287.bit._10
#define        TIMECS59     B287.bit._11
#define        TIMECS60     B287.bit._12
#define        TIMECS61     B287.bit._13
#define        TIMECS62     B287.bit._14
#define        TIMECS63     B287.bit._15

/* ------------------------------------ */
/*              WORD B288	            */
/* TIMER ECS: TIMECS64 - TIMECS79		*/
/* ------------------------------------ */

#define        WTIMECS04    B288.word
/* WORD PER TIMER APPLICAZIONE ECS 0 - 15 */
/* ECS APPLICATION TIMER 0 - 15 */

#define        TIMECS64     B288.bit._00
#define        TIMECS65     B288.bit._01
#define        TIMECS66     B288.bit._02
#define        TIMECS67     B288.bit._03
#define        TIMECS68     B288.bit._04
#define        TIMECS69     B288.bit._05
#define        TIMECS70     B288.bit._06
#define        TIMECS71     B288.bit._07
#define        TIMECS72     B288.bit._08
#define        TIMECS73     B288.bit._09
#define        TIMECS74     B288.bit._10
#define        TIMECS75     B288.bit._11
#define        TIMECS76		B288.bit._12
#define        TIMECS77     B288.bit._13
#define        TIMECS78     B288.bit._14
#define        TIMECS79     B288.bit._15

/* ------------------------------------ */
/*              WORD B289	            */
/* TIMER ECS: TIMECS80 - TIMECS95		*/
/* ------------------------------------ */

#define        WTIMECS05   B289.word
/* WORD PER TIMER APPLICAZIONE ECS 80 - 95 */
/* ECS APPLICATION TIMER 80 - 95 */

#define        TIMECS80     B289.bit._00
#define        TIMECS81     B289.bit._01
#define        TIMECS82     B289.bit._02
#define        TIMECS83     B289.bit._03
#define        TIMECS84     B289.bit._04
#define        TIMECS85     B289.bit._05
#define        TIMECS86     B289.bit._06
#define        TIMECS87     B289.bit._07
#define        TIMECS88     B289.bit._08
#define        TIMECS89     B289.bit._09
#define        TIMECS90     B289.bit._10
#define        TIMECS91     B289.bit._11
#define        TIMECS92     B289.bit._12
#define        TIMECS93     B289.bit._13
#define        TIMECS94     B289.bit._14
#define        TIMECS95     B289.bit._15

/* ------------------------------------ */
/*              WORD B290	            */
/* TIMER ECS: TIMECS96 - TIMECS111		*/
/* ------------------------------------ */

#define        WTIMECS06    B290.word
/* WORD PER TIMER APPLICAZIONE ECS 96 - 111 */
/* ECS APPLICATION TIMER 96 - 111 */

#define        TIMECS96     B290.bit._00
#define        TIMECS97     B290.bit._01
#define        TIMECS98     B290.bit._02
#define        TIMECS99     B290.bit._03
#define        TIMECS100    B290.bit._04
#define        TIMECS101    B290.bit._05
#define        TIMECS102    B290.bit._06
#define        TIMECS103    B290.bit._07
#define        TIMECS104    B290.bit._08
#define        TIMECS105    B290.bit._09
#define        TIMECS106    B290.bit._10
#define        TIMECS107    B290.bit._11
#define        TIMECS108    B290.bit._12
#define        TIMECS109    B290.bit._13
#define        TIMECS110    B290.bit._14
#define        TIMECS111    B290.bit._15

/* ------------------------------------ */
/*              WORD B291	            */
/* TIMER ECS: TIMECS112 - TIMECS127		*/
/* ------------------------------------ */

#define        WTIMECS07    B291.word
/* WORD PER TIMER APPLICAZIONE ECS 112 - 127 */
/* ECS APPLICATION TIMER 112 - 127 */

#define        TIMECS112    B291.bit._00
#define        TIMECS113    B291.bit._01
#define        TIMECS114    B291.bit._02
#define        TIMECS115    B291.bit._03
#define        TIMECS116    B291.bit._04
#define        TIMECS117    B291.bit._05
#define        TIMECS118    B291.bit._06
#define        TIMECS119    B291.bit._07
#define        TIMECS120    B291.bit._08
#define        TIMECS121    B291.bit._09
#define        TIMECS122    B291.bit._10
#define        TIMECS123    B291.bit._11
#define        TIMECS124    B291.bit._12
#define        TIMECS125    B291.bit._13
#define        TIMECS126    B291.bit._14
#define        TIMECS127    B291.bit._15

/* ------------------------------------ */
/*              WORD B292	            */
/* TIMER ECS: TIMECS128 - TIMECS143		*/
/* ------------------------------------ */

#define        WTIMECS08    B292.word
/* WORD PER TIMER APPLICAZIONE ECS 128 - 143 */
/* ECS APPLICATION TIMER 128 - 143 */

#define        TIMECS128    B292.bit._00
#define        TIMECS129    B292.bit._01
#define        TIMECS130	B292.bit._02
#define        TIMECS131    B292.bit._03
#define        TIMECS132    B292.bit._04
#define        TIMECS133    B292.bit._05
#define        TIMECS134    B292.bit._06
#define        TIMECS135    B292.bit._07
#define        TIMECS136    B292.bit._08
#define        TIMECS137    B292.bit._09
#define        TIMECS138    B292.bit._10
#define        TIMECS139    B292.bit._11
#define        TIMECS140    B292.bit._12
#define        TIMECS141	B292.bit._13
#define        TIMECS142    B292.bit._14
#define        TIMECS143    B292.bit._15

/* ------------------------------------ */
/*              WORD B293	            */
/* TIMER ECS: TIMECS144 - TIMECS159		*/
/* ------------------------------------ */

#define        WTIMECS09    B293.word
/* WORD PER TIMER APPLICAZIONE ECS 144 - 159 */
/* ECS APPLICATION TIMER 144 - 159 */

#define        TIMECS144    B293.bit._00
#define        TIMECS145    B293.bit._01
#define        TIMECS146    B293.bit._02
#define        TIMECS147    B293.bit._03
#define        TIMECS148    B293.bit._04
#define        TIMECS149    B293.bit._05
#define        TIMECS150    B293.bit._06
#define        TIMECS151    B293.bit._07
#define        TIMECS152    B293.bit._08
#define        TIMECS153    B293.bit._09
#define        TIMECS154    B293.bit._10
#define        TIMECS155    B293.bit._11
#define        TIMECS156    B293.bit._12
#define        TIMECS157    B293.bit._13
#define        TIMECS158    B293.bit._14
#define        TIMECS159    B293.bit._15

/* ------------------------------------ */
/*              WORD B294	            */
/* TIMER ECS: TIMECS160 - TIMECS175		*/
/* ------------------------------------ */

#define        WTIMECS10    B294.word
/* WORD PER TIMER APPLICAZIONE ECS 160 - 175 */
/* ECS APPLICATION TIMER 160 - 175 */

#define        TIMECS160    B294.bit._00
#define        TIMECS161    B294.bit._01
#define        TIMECS162    B294.bit._02
#define        TIMECS163    B294.bit._03
#define        TIMECS164    B294.bit._04
#define        TIMECS165    B294.bit._05
#define        TIMECS166    B294.bit._06
#define        TIMECS167    B294.bit._07
#define        TIMECS168    B294.bit._08
#define        TIMECS169    B294.bit._09
#define        TIMECS170    B294.bit._10
#define        TIMECS171    B294.bit._11
#define        TIMECS172    B294.bit._12
#define        TIMECS173    B294.bit._13
#define        TIMECS174    B294.bit._14
#define        TIMECS175    B294.bit._15

/* ------------------------------------ */
/*              WORD B295	            */
/* TIMER ECS: TIMECS 176 - TIMECS 191	*/
/* ------------------------------------ */

#define        WTIMECS11    B295.word
/* WORD PER TIMER APPLICAZIONE ECS 176 - 191 */
/* ECS APPLICATION TIMER 176 - 191 */

#define        TIMECS176    B295.bit._00
#define        TIMECS177    B295.bit._01
#define        TIMECS178    B295.bit._02
#define        TIMECS179    B295.bit._03
#define        TIMECS180    B295.bit._04
#define        TIMECS181    B295.bit._05
#define        TIMECS182    B295.bit._06
#define        TIMECS183    B295.bit._07
#define        TIMECS184    B295.bit._08
#define        TIMECS185    B295.bit._09
#define        TIMECS186    B295.bit._10
#define        TIMECS187    B295.bit._11
#define        TIMECS188    B295.bit._12
#define        TIMECS189    B295.bit._13
#define        TIMECS190    B295.bit._14
#define        TIMECS191    B295.bit._15

/* ------------------------------------ */
/*              WORD B296	            */
/* TIMER ECS: TIMECS 192 - TIMECS 207	*/
/* ------------------------------------ */

#define        WTIMECS12    B296.word
/* WORD PER TIMER APPLICAZIONE ECS 192 - 207 */
/* ECS APPLICATION TIMER 192 - 207 */

#define        TIMECS192    B296.bit._00
#define        TIMECS193    B296.bit._01
#define        TIMECS194    B296.bit._02
#define        TIMECS195    B296.bit._03
#define        TIMECS196    B296.bit._04
#define        TIMECS197    B296.bit._05
#define        TIMECS198    B296.bit._06
#define        TIMECS199    B296.bit._07
#define        TIMECS200    B296.bit._08
#define        TIMECS201    B296.bit._09
#define        TIMECS202    B296.bit._10
#define        TIMECS203    B296.bit._20
#define        TIMECS204    B296.bit._21
#define        TIMECS205    B296.bit._13
#define        TIMECS206    B296.bit._14
#define        TIMECS207    B296.bit._15

/* ------------------------------------ */
/*              WORD B297	            */
/* TIMER ECS: TIMECS 208 - TIMECS 223	*/
/* ------------------------------------ */

#define        WTIMECS13    B297.word
/* WORD PER TIMER APPLICAZIONE ECS 208 - 223 */
/* ECS APPLICATION TIMER 208 - 223 */

#define        TIMECS208    B297.bit._00
#define        TIMECS209    B297.bit._01
#define        TIMECS210    B297.bit._02
#define        TIMECS211    B297.bit._03
#define        TIMECS212    B297.bit._04
#define        TIMECS213    B297.bit._05
#define        TIMECS214    B297.bit._06
#define        TIMECS215    B297.bit._07
#define        TIMECS216    B297.bit._08
#define        TIMECS217    B297.bit._09
#define        TIMECS218    B297.bit._10
#define        TIMECS219    B297.bit._20
#define        TIMECS220    B297.bit._21
#define        TIMECS221    B297.bit._13
#define        TIMECS222    B297.bit._14
#define        TIMECS223    B297.bit._15

/* ------------------------------------ */
/*              WORD B298	            */
/* TIMER ECS: TIMECS 224 - TIMECS 239	*/
/* ------------------------------------ */

#define        WTIMECS14    B298.word
/* WORD PER TIMER APPLICAZIONE ECS 224 - 239 */
/* ECS APPLICATION TIMER 224 - 239 */

#define        TIMECS224    B298.bit._00
#define        TIMECS225    B298.bit._01
#define        TIMECS226    B298.bit._02
#define        TIMECS227    B298.bit._03
#define        TIMECS228    B298.bit._04
#define        TIMECS229    B298.bit._05
#define        TIMECS230    B298.bit._06
#define        TIMECS231    B298.bit._07
#define        TIMECS232    B298.bit._08
#define        TIMECS233    B298.bit._09
#define        TIMECS234    B298.bit._10
#define        TIMECS235    B298.bit._20
#define        TIMECS236    B298.bit._21
#define        TIMECS237    B298.bit._13
#define        TIMECS238    B298.bit._14
#define        TIMECS239    B298.bit._15


/* ------------------------------------ */
/*              WORD B299	            */
/* TIMER ECS: TIMECS 240 - TIMECS 255	*/
/* ------------------------------------ */

#define        WTIMECS15    B299.word
/* WORD PER TIMER APPLICAZIONE ECS 240 - 255 */
/* ECS APPLICATION TIMER 240 - 255 */

#define        TIMECS240    B299.bit._00
#define        TIMECS241    B299.bit._01
#define        TIMECS242    B299.bit._02
#define        TIMECS243    B299.bit._03
#define        TIMECS244    B299.bit._04
#define        TIMECS245    B299.bit._05
#define        TIMECS246    B299.bit._06
#define        TIMECS247    B299.bit._07
#define        TIMECS248    B299.bit._08
#define        TIMECS249    B299.bit._09
#define        TIMECS250    B299.bit._10
#define        TIMECS251    B299.bit._20
#define        TIMECS252    B299.bit._21
#define        TIMECS253    B299.bit._13
#define        TIMECS254    B299.bit._14
#define        TIMECS255    B299.bit._15


/* ------------------------------------ */
/*     DOUBLE WORD D_B300 - D_B330      */
/*		 Periodo segnale Capture		*/
/*		  Capture signal period			*/
/* ------------------------------------ */
#define   CAPTURE0_PERIOD     D_B300
/* Periodo segnale Capture su asse di ordine 0 */
/* Capture signal period on order 0 axis	   */
#define   CAPTURE1_PERIOD     D_B302
#define   CAPTURE2_PERIOD     D_B304
#define   CAPTURE3_PERIOD     D_B306
#define   CAPTURE4_PERIOD     D_B308
#define   CAPTURE5_PERIOD     D_B310
#define   CAPTURE6_PERIOD     D_B312
#define   CAPTURE7_PERIOD     D_B314
#define   CAPTURE8_PERIOD     D_B316
#define   CAPTURE9_PERIOD     D_B318
// #define   CAPTURE10_PERIOD    D_B320
// #define   CAPTURE11_PERIOD    D_B322
// #define   CAPTURE12_PERIOD    D_B324
// #define   CAPTURE13_PERIOD    D_B326
// #define   CAPTURE14_PERIOD    D_B328
// #define   CAPTURE15_PERIOD    D_B330
/* Periodo segnale Capture su asse di ordine 15 */
/* Capture signal period on order 15 axis		*/


/* ------------------------------------ */
/*              WORD B332               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_128    B332.bit._00
#define         TIME_129    B332.bit._01
#define         TIME_130    B332.bit._02
#define         TIME_131    B332.bit._03
#define         TIME_132    B332.bit._04
#define         TIME_133    B332.bit._05
#define         TIME_134    B332.bit._06
#define         TIME_135    B332.bit._07
#define         TIME_136    B332.bit._08
#define         TIME_137    B332.bit._09
#define         TIME_138    B332.bit._10
#define         TIME_139    B332.bit._11
#define         TIME_140    B332.bit._12
#define         TIME_141    B332.bit._13
#define         TIME_142    B332.bit._14
#define         TIME_143    B332.bit._15

/* ------------------------------------ */
/*              WORD B333               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_144    B333.bit._00
#define         TIME_145    B333.bit._01
#define         TIME_146    B333.bit._02
#define         TIME_147    B333.bit._03
#define         TIME_148    B333.bit._04
#define         TIME_149    B333.bit._05
#define         TIME_150    B333.bit._06
#define         TIME_151    B333.bit._07
#define         TIME_152    B333.bit._08
#define         TIME_153    B333.bit._09
#define         TIME_154    B333.bit._10
#define         TIME_155    B333.bit._11
#define         TIME_156    B333.bit._12
#define         TIME_157    B333.bit._13
#define         TIME_158    B333.bit._14
#define         TIME_159    B333.bit._15

/* ------------------------------------ */
/*              WORD B334               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_160    B334.bit._00
#define         TIME_161    B334.bit._01
#define         TIME_162    B334.bit._02
#define         TIME_163    B334.bit._03
#define         TIME_164    B334.bit._04
#define         TIME_165    B334.bit._05
#define         TIME_166    B334.bit._06
#define         TIME_167    B334.bit._07
#define         TIME_168    B334.bit._08
#define         TIME_169    B334.bit._09
#define         TIME_170    B334.bit._10
#define         TIME_171    B334.bit._11
#define         TIME_172    B334.bit._12
#define         TIME_173    B334.bit._13
#define         TIME_174    B334.bit._14
#define         TIME_175    B334.bit._15

/* ------------------------------------ */
/*              WORD B335               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_176    B335.bit._00
#define         TIME_177    B335.bit._01
#define         TIME_178    B335.bit._02
#define         TIME_179    B335.bit._03
#define         TIME_180    B335.bit._04
#define         TIME_181    B335.bit._05
#define         TIME_182    B335.bit._06
#define         TIME_183    B335.bit._07
#define         TIME_184    B335.bit._08
#define         TIME_185    B335.bit._09
#define         TIME_186    B335.bit._10
#define         TIME_187    B335.bit._11
#define         TIME_188    B335.bit._12
#define         TIME_189    B335.bit._13
#define         TIME_190    B335.bit._14
#define         TIME_191    B335.bit._15

/* ------------------------------------ */
/*              WORD B336               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_192    B336.bit._00
#define         TIME_193    B336.bit._01
#define         TIME_194    B336.bit._02
#define         TIME_195    B336.bit._03
#define         TIME_196    B336.bit._04
#define         TIME_197    B336.bit._05
#define         TIME_198    B336.bit._06
#define         TIME_199    B336.bit._07
#define         TIME_200    B336.bit._08
#define         TIME_201    B336.bit._09
#define         TIME_202    B336.bit._10
#define         TIME_203    B336.bit._11
#define         TIME_204    B336.bit._12
#define         TIME_205    B336.bit._13
#define         TIME_206    B336.bit._14
#define         TIME_207    B336.bit._15

/* ------------------------------------ */
/*              WORD B337               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_208    B337.bit._00
#define         TIME_209    B337.bit._01
#define         TIME_210    B337.bit._02
#define         TIME_211    B337.bit._03
#define         TIME_212    B337.bit._04
#define         TIME_213    B337.bit._05
#define         TIME_214    B337.bit._06
#define         TIME_215    B337.bit._07
#define         TIME_216    B337.bit._08
#define         TIME_217    B337.bit._09
#define         TIME_218    B337.bit._10
#define         TIME_219    B337.bit._11
#define         TIME_220    B337.bit._12
#define         TIME_221    B337.bit._13
#define         TIME_222    B337.bit._14
#define         TIME_223    B337.bit._15

/* ------------------------------------ */
/*              WORD B338               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_224    B338.bit._00
#define         TIME_225    B338.bit._01
#define         TIME_226    B338.bit._02
#define         TIME_227    B338.bit._03
#define         TIME_228    B338.bit._04
#define         TIME_229    B338.bit._05
#define         TIME_230    B338.bit._06
#define         TIME_231    B338.bit._07
#define         TIME_232    B338.bit._08
#define         TIME_233    B338.bit._09
#define         TIME_234    B338.bit._10
#define         TIME_235    B338.bit._11
#define         TIME_236    B338.bit._12
#define         TIME_237    B338.bit._13
#define         TIME_238    B338.bit._14
#define         TIME_239    B338.bit._15

/* ------------------------------------ */
/*              WORD B339               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_240    B339.bit._00
#define         TIME_241    B339.bit._01
#define         TIME_242    B339.bit._02
#define         TIME_243    B339.bit._03
#define         TIME_244    B339.bit._04
#define         TIME_245    B339.bit._05
#define         TIME_246    B339.bit._06
#define         TIME_247    B339.bit._07
#define         TIME_248    B339.bit._08
#define         TIME_249    B339.bit._09
#define         TIME_250    B339.bit._10
#define         TIME_251    B339.bit._11
#define         TIME_252    B339.bit._12
#define         TIME_253    B339.bit._13
#define         TIME_254    B339.bit._14
#define         TIME_255    B339.bit._15

/* ------------------------------------ */
/*              WORD B340               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_256    B340.bit._00
#define         TIME_257    B340.bit._01
#define         TIME_258    B340.bit._02
#define         TIME_259    B340.bit._03
#define         TIME_260    B340.bit._04
#define         TIME_261    B340.bit._05
#define         TIME_262    B340.bit._06
#define         TIME_263    B340.bit._07
#define         TIME_264    B340.bit._08
#define         TIME_265    B340.bit._09
#define         TIME_266    B340.bit._10
#define         TIME_267    B340.bit._11
#define         TIME_268    B340.bit._12
#define         TIME_269    B340.bit._13
#define         TIME_270    B340.bit._14
#define         TIME_271    B340.bit._15

/* ------------------------------------ */
/*              WORD B341               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_272    B341.bit._00
#define         TIME_273    B341.bit._01
#define         TIME_274    B341.bit._02
#define         TIME_275    B341.bit._03
#define         TIME_276    B341.bit._04
#define         TIME_277    B341.bit._05
#define         TIME_278    B341.bit._06
#define         TIME_279    B341.bit._07
#define         TIME_280    B341.bit._08
#define         TIME_281    B341.bit._09
#define         TIME_282    B341.bit._10
#define         TIME_283    B341.bit._11
#define         TIME_284    B341.bit._12
#define         TIME_285    B341.bit._13
#define         TIME_286    B341.bit._14
#define         TIME_287    B341.bit._15

/* ------------------------------------ */
/*              WORD B342               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_288    B342.bit._00
#define         TIME_289    B342.bit._01
#define         TIME_290    B342.bit._02
#define         TIME_291    B342.bit._03
#define         TIME_292    B342.bit._04
#define         TIME_293    B342.bit._05
#define         TIME_294    B342.bit._06
#define         TIME_295    B342.bit._07
#define         TIME_296    B342.bit._08
#define         TIME_297    B342.bit._09
#define         TIME_298    B342.bit._10
#define         TIME_299    B342.bit._11
#define         TIME_300    B342.bit._12
#define         TIME_301    B342.bit._13
#define         TIME_302    B342.bit._14
#define         TIME_303    B342.bit._15

/* ------------------------------------ */
/*              WORD B343               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_304    B343.bit._00
#define         TIME_305    B343.bit._01
#define         TIME_306    B343.bit._02
#define         TIME_307    B343.bit._03
#define         TIME_308    B343.bit._04
#define         TIME_309    B343.bit._05
#define         TIME_310    B343.bit._06
#define         TIME_311    B343.bit._07
#define         TIME_312    B343.bit._08
#define         TIME_313    B343.bit._09
#define         TIME_314    B343.bit._10
#define         TIME_315    B343.bit._11
#define         TIME_316    B343.bit._12
#define         TIME_317    B343.bit._13
#define         TIME_318    B343.bit._14
#define         TIME_319    B343.bit._15

/* ------------------------------------ */
/*              WORD B344               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_320    B344.bit._00
#define         TIME_321    B344.bit._01
#define         TIME_322    B344.bit._02
#define         TIME_323    B344.bit._03
#define         TIME_324    B344.bit._04
#define         TIME_325    B344.bit._05
#define         TIME_326    B344.bit._06
#define         TIME_327    B344.bit._07
#define         TIME_328    B344.bit._08
#define         TIME_329    B344.bit._09
#define         TIME_330    B344.bit._10
#define         TIME_331    B344.bit._11
#define         TIME_332    B344.bit._12
#define         TIME_333    B344.bit._13
#define         TIME_334    B344.bit._14
#define         TIME_335    B344.bit._15

/* ------------------------------------ */
/*              WORD B345               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_336    B345.bit._00
#define         TIME_337    B345.bit._01
#define         TIME_338    B345.bit._02
#define         TIME_339    B345.bit._03
#define         TIME_340    B345.bit._04
#define         TIME_341    B345.bit._05
#define         TIME_342    B345.bit._06
#define         TIME_343    B345.bit._07
#define         TIME_344    B345.bit._08
#define         TIME_345    B345.bit._09
#define         TIME_346    B345.bit._10
#define         TIME_347    B345.bit._11
#define         TIME_348    B345.bit._12
#define         TIME_349    B345.bit._13
#define         TIME_350    B345.bit._14
#define         TIME_351    B345.bit._15

/* ------------------------------------ */
/*              WORD B346               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_352    B346.bit._00
#define         TIME_353    B346.bit._01
#define         TIME_354    B346.bit._02
#define         TIME_355    B346.bit._03
#define         TIME_356    B346.bit._04
#define         TIME_357    B346.bit._05
#define         TIME_358    B346.bit._06
#define         TIME_359    B346.bit._07
#define         TIME_360    B346.bit._08
#define         TIME_361    B346.bit._09
#define         TIME_362    B346.bit._10
#define         TIME_363    B346.bit._11
#define         TIME_364    B346.bit._12
#define         TIME_365    B346.bit._13
#define         TIME_366    B346.bit._14
#define         TIME_367    B346.bit._15

/* ------------------------------------ */
/*              WORD B347               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_368    B347.bit._00
#define         TIME_369    B347.bit._01
#define         TIME_370    B347.bit._02
#define         TIME_371    B347.bit._03
#define         TIME_372    B347.bit._04
#define         TIME_373    B347.bit._05
#define         TIME_374    B347.bit._06
#define         TIME_375    B347.bit._07
#define         TIME_376    B347.bit._08
#define         TIME_377    B347.bit._09
#define         TIME_378    B347.bit._10
#define         TIME_379    B347.bit._11
#define         TIME_380    B347.bit._12
#define         TIME_381    B347.bit._13
#define         TIME_382    B347.bit._14
#define         TIME_383    B347.bit._15

/* ------------------------------------ */
/*              WORD B348               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_384    B348.bit._00
#define         TIME_385    B348.bit._01
#define         TIME_386    B348.bit._02
#define         TIME_387    B348.bit._03
#define         TIME_388    B348.bit._04
#define         TIME_389    B348.bit._05
#define         TIME_390    B348.bit._06
#define         TIME_391    B348.bit._07
#define         TIME_392    B348.bit._08
#define         TIME_393    B348.bit._09
#define         TIME_394    B348.bit._10
#define         TIME_395    B348.bit._11
#define         TIME_396    B348.bit._12
#define         TIME_397    B348.bit._13
#define         TIME_398    B348.bit._14
#define         TIME_399    B348.bit._15

/* ------------------------------------ */
/*              WORD B349               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_400    B349.bit._00
#define         TIME_401    B349.bit._01
#define         TIME_402    B349.bit._02
#define         TIME_403    B349.bit._03
#define         TIME_404    B349.bit._04
#define         TIME_405    B349.bit._05
#define         TIME_406    B349.bit._06
#define         TIME_407    B349.bit._07
#define         TIME_408    B349.bit._08
#define         TIME_409    B349.bit._09
#define         TIME_410    B349.bit._10
#define         TIME_411    B349.bit._11
#define         TIME_412    B349.bit._12
#define         TIME_413    B349.bit._13
#define         TIME_414    B349.bit._14
#define         TIME_415    B349.bit._15

/* ------------------------------------ */
/*              WORD B350               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_416    B350.bit._00
#define         TIME_417    B350.bit._01
#define         TIME_418    B350.bit._02
#define         TIME_419    B350.bit._03
#define         TIME_420    B350.bit._04
#define         TIME_421    B350.bit._05
#define         TIME_422    B350.bit._06
#define         TIME_423    B350.bit._07
#define         TIME_424    B350.bit._08
#define         TIME_425    B350.bit._09
#define         TIME_426    B350.bit._10
#define         TIME_427    B350.bit._11
#define         TIME_428    B350.bit._12
#define         TIME_429    B350.bit._13
#define         TIME_430    B350.bit._14
#define         TIME_431    B350.bit._15

/* ------------------------------------ */
/*              WORD B351               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_432    B351.bit._00
#define         TIME_433    B351.bit._01
#define         TIME_434    B351.bit._02
#define         TIME_435    B351.bit._03
#define         TIME_436    B351.bit._04
#define         TIME_437    B351.bit._05
#define         TIME_438    B351.bit._06
#define         TIME_439    B351.bit._07
#define         TIME_440    B351.bit._08
#define         TIME_441    B351.bit._09
#define         TIME_442    B351.bit._10
#define         TIME_443    B351.bit._11
#define         TIME_444    B351.bit._12
#define         TIME_445    B351.bit._13
#define         TIME_446    B351.bit._14
#define         TIME_447    B351.bit._15

/* ------------------------------------ */
/*              WORD B352               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_448    B352.bit._00
#define         TIME_449    B352.bit._01
#define         TIME_450    B352.bit._02
#define         TIME_451    B352.bit._03
#define         TIME_452    B352.bit._04
#define         TIME_453    B352.bit._05
#define         TIME_454    B352.bit._06
#define         TIME_455    B352.bit._07
#define         TIME_456    B352.bit._08
#define         TIME_457    B352.bit._09
#define         TIME_458    B352.bit._10
#define         TIME_459    B352.bit._11
#define         TIME_460    B352.bit._12
#define         TIME_461    B352.bit._13
#define         TIME_462    B352.bit._14
#define         TIME_463    B352.bit._15

/* ------------------------------------ */
/*              WORD B353               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_464    B353.bit._00
#define         TIME_465    B353.bit._01
#define         TIME_466    B353.bit._02
#define         TIME_467    B353.bit._03
#define         TIME_468    B353.bit._04
#define         TIME_469    B353.bit._05
#define         TIME_470    B353.bit._06
#define         TIME_471    B353.bit._07
#define         TIME_472    B353.bit._08
#define         TIME_473    B353.bit._09
#define         TIME_474    B353.bit._10
#define         TIME_475    B353.bit._11
#define         TIME_476    B353.bit._12
#define         TIME_477    B353.bit._13
#define         TIME_478    B353.bit._14
#define         TIME_479    B353.bit._15

/* ------------------------------------ */
/*              WORD B354               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_480    B354.bit._00
#define         TIME_481    B354.bit._01
#define         TIME_482    B354.bit._02
#define         TIME_483    B354.bit._03
#define         TIME_484    B354.bit._04
#define         TIME_485    B354.bit._05
#define         TIME_486    B354.bit._06
#define         TIME_487    B354.bit._07
#define         TIME_488    B354.bit._08
#define         TIME_489    B354.bit._09
#define         TIME_490    B354.bit._10
#define         TIME_491    B354.bit._11
#define         TIME_492    B354.bit._12
#define         TIME_493    B354.bit._13
#define         TIME_494    B354.bit._14
#define         TIME_495    B354.bit._15

/* ------------------------------------ */
/*              WORD B355               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_496    B355.bit._00
#define         TIME_497    B355.bit._01
#define         TIME_498    B355.bit._02
#define         TIME_499    B355.bit._03
#define         TIME_500    B355.bit._04
#define         TIME_501    B355.bit._05
#define         TIME_502    B355.bit._06
#define         TIME_503    B355.bit._07
#define         TIME_504    B355.bit._08
#define         TIME_505    B355.bit._09
#define         TIME_506    B355.bit._10
#define         TIME_507    B355.bit._11
#define         TIME_508    B355.bit._12
#define         TIME_509    B355.bit._13
#define         TIME_510    B355.bit._14
#define         TIME_511    B355.bit._15

/* ------------------------------------ */
/*              WORD B356               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_512    B356.bit._00
#define         TIME_513    B356.bit._01
#define         TIME_514    B356.bit._02
#define         TIME_515    B356.bit._03
#define         TIME_516    B356.bit._04
#define         TIME_517    B356.bit._05
#define         TIME_518    B356.bit._06
#define         TIME_519    B356.bit._07
#define         TIME_520    B356.bit._08
#define         TIME_521    B356.bit._09
#define         TIME_522    B356.bit._10
#define         TIME_523    B356.bit._11
#define         TIME_524    B356.bit._12
#define         TIME_525    B356.bit._13
#define         TIME_526    B356.bit._14
#define         TIME_527    B356.bit._15

/* ------------------------------------ */
/*              WORD B357               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_528    B357.bit._00
#define         TIME_529    B357.bit._01
#define         TIME_530    B357.bit._02
#define         TIME_531    B357.bit._03
#define         TIME_532    B357.bit._04
#define         TIME_533    B357.bit._05
#define         TIME_534    B357.bit._06
#define         TIME_535    B357.bit._07
#define         TIME_536    B357.bit._08
#define         TIME_537    B357.bit._09
#define         TIME_538    B357.bit._10
#define         TIME_539    B357.bit._11
#define         TIME_540    B357.bit._12
#define         TIME_541    B357.bit._13
#define         TIME_542    B357.bit._14
#define         TIME_543    B357.bit._15

/* ------------------------------------ */
/*              WORD B358               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_544    B358.bit._00
#define         TIME_545    B358.bit._01
#define         TIME_546    B358.bit._02
#define         TIME_547    B358.bit._03
#define         TIME_548    B358.bit._04
#define         TIME_549    B358.bit._05
#define         TIME_550    B358.bit._06
#define         TIME_551    B358.bit._07
#define         TIME_552    B358.bit._08
#define         TIME_553    B358.bit._09
#define         TIME_554    B358.bit._10
#define         TIME_555    B358.bit._11
#define         TIME_556    B358.bit._12
#define         TIME_557    B358.bit._13
#define         TIME_558    B358.bit._14
#define         TIME_559    B358.bit._15

/* ------------------------------------ */
/*              WORD B359               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_560    B359.bit._00
#define         TIME_561    B359.bit._01
#define         TIME_562    B359.bit._02
#define         TIME_563    B359.bit._03
#define         TIME_564    B359.bit._04
#define         TIME_565    B359.bit._05
#define         TIME_566    B359.bit._06
#define         TIME_567    B359.bit._07
#define         TIME_568    B359.bit._08
#define         TIME_569    B359.bit._09
#define         TIME_570    B359.bit._10
#define         TIME_571    B359.bit._11
#define         TIME_572    B359.bit._12
#define         TIME_573    B359.bit._13
#define         TIME_574    B359.bit._14
#define         TIME_575    B359.bit._15

/* ------------------------------------ */
/*              WORD B360               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_576    B360.bit._00
#define         TIME_577    B360.bit._01
#define         TIME_578    B360.bit._02
#define         TIME_579    B360.bit._03
#define         TIME_580    B360.bit._04
#define         TIME_581    B360.bit._05
#define         TIME_582    B360.bit._06
#define         TIME_583    B360.bit._07
#define         TIME_584    B360.bit._08
#define         TIME_585    B360.bit._09
#define         TIME_586    B360.bit._10
#define         TIME_587    B360.bit._11
#define         TIME_588    B360.bit._12
#define         TIME_589    B360.bit._13
#define         TIME_590    B360.bit._14
#define         TIME_591    B360.bit._15

/* ------------------------------------ */
/*              WORD B361               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_592    B361.bit._00
#define         TIME_593    B361.bit._01
#define         TIME_594    B361.bit._02
#define         TIME_595    B361.bit._03
#define         TIME_596    B361.bit._04
#define         TIME_597    B361.bit._05
#define         TIME_598    B361.bit._06
#define         TIME_599    B361.bit._07
#define         TIME_600    B361.bit._08
#define         TIME_601    B361.bit._09
#define         TIME_602    B361.bit._10
#define         TIME_603    B361.bit._11
#define         TIME_604    B361.bit._12
#define         TIME_605    B361.bit._13
#define         TIME_606    B361.bit._14
#define         TIME_607    B361.bit._15

/* ------------------------------------ */
/*              WORD B362               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_608    B362.bit._00
#define         TIME_609    B362.bit._01
#define         TIME_610    B362.bit._02
#define         TIME_611    B362.bit._03
#define         TIME_612    B362.bit._04
#define         TIME_613    B362.bit._05
#define         TIME_614    B362.bit._06
#define         TIME_615    B362.bit._07
#define         TIME_616    B362.bit._08
#define         TIME_617    B362.bit._09
#define         TIME_618    B362.bit._10
#define         TIME_619    B362.bit._11
#define         TIME_620    B362.bit._12
#define         TIME_621    B362.bit._13
#define         TIME_622    B362.bit._14
#define         TIME_623    B362.bit._15

/* ------------------------------------ */
/*              WORD B363               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_624    B363.bit._00
#define         TIME_625    B363.bit._01
#define         TIME_626    B363.bit._02
#define         TIME_627    B363.bit._03
#define         TIME_628    B363.bit._04
#define         TIME_629    B363.bit._05
#define         TIME_630    B363.bit._06
#define         TIME_631    B363.bit._07
#define         TIME_632    B363.bit._08
#define         TIME_633    B363.bit._09
#define         TIME_634    B363.bit._10
#define         TIME_635    B363.bit._11
#define         TIME_636    B363.bit._12
#define         TIME_637    B363.bit._13
#define         TIME_638    B363.bit._14
#define         TIME_639    B363.bit._15

/* ------------------------------------ */
/*              WORD B364               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_640    B364.bit._00
#define         TIME_641    B364.bit._01
#define         TIME_642    B364.bit._02
#define         TIME_643    B364.bit._03
#define         TIME_644    B364.bit._04
#define         TIME_645    B364.bit._05
#define         TIME_646    B364.bit._06
#define         TIME_647    B364.bit._07
#define         TIME_648    B364.bit._08
#define         TIME_649    B364.bit._09
#define         TIME_650    B364.bit._10
#define         TIME_651    B364.bit._11
#define         TIME_652    B364.bit._12
#define         TIME_653    B364.bit._13
#define         TIME_654    B364.bit._14
#define         TIME_655    B364.bit._15

/* ------------------------------------ */
/*              WORD B365               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_656    B365.bit._00
#define         TIME_657    B365.bit._01
#define         TIME_658    B365.bit._02
#define         TIME_659    B365.bit._03
#define         TIME_660    B365.bit._04
#define         TIME_661    B365.bit._05
#define         TIME_662    B365.bit._06
#define         TIME_663    B365.bit._07
#define         TIME_664    B365.bit._08
#define         TIME_665    B365.bit._09
#define         TIME_666    B365.bit._10
#define         TIME_667    B365.bit._11
#define         TIME_668    B365.bit._12
#define         TIME_669    B365.bit._13
#define         TIME_670    B365.bit._14
#define         TIME_671    B365.bit._15

/* ------------------------------------ */
/*              WORD B366               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_672    B366.bit._00
#define         TIME_673    B366.bit._01
#define         TIME_674    B366.bit._02
#define         TIME_675    B366.bit._03
#define         TIME_676    B366.bit._04
#define         TIME_677    B366.bit._05
#define         TIME_678    B366.bit._06
#define         TIME_679    B366.bit._07
#define         TIME_680    B366.bit._08
#define         TIME_681    B366.bit._09
#define         TIME_682    B366.bit._10
#define         TIME_683    B366.bit._11
#define         TIME_684    B366.bit._12
#define         TIME_685    B366.bit._13
#define         TIME_686    B366.bit._14
#define         TIME_687    B366.bit._15

/* ------------------------------------ */
/*              WORD B367               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_688    B367.bit._00
#define         TIME_689    B367.bit._01
#define         TIME_690    B367.bit._02
#define         TIME_691    B367.bit._03
#define         TIME_692    B367.bit._04
#define         TIME_693    B367.bit._05
#define         TIME_694    B367.bit._06
#define         TIME_695    B367.bit._07
#define         TIME_696    B367.bit._08
#define         TIME_697    B367.bit._09
#define         TIME_698    B367.bit._10
#define         TIME_699    B367.bit._11
#define         TIME_700    B367.bit._12
#define         TIME_701    B367.bit._13
#define         TIME_702    B367.bit._14
#define         TIME_703    B367.bit._15

/* ------------------------------------ */
/*              WORD B368               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_704    B368.bit._00
#define         TIME_705    B368.bit._01
#define         TIME_706    B368.bit._02
#define         TIME_707    B368.bit._03
#define         TIME_708    B368.bit._04
#define         TIME_709    B368.bit._05
#define         TIME_710    B368.bit._06
#define         TIME_711    B368.bit._07
#define         TIME_712    B368.bit._08
#define         TIME_713    B368.bit._09
#define         TIME_714    B368.bit._10
#define         TIME_715    B368.bit._11
#define         TIME_716    B368.bit._12
#define         TIME_717    B368.bit._13
#define         TIME_718    B368.bit._14
#define         TIME_719    B368.bit._15

/* ------------------------------------ */
/*              WORD B369               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_720    B369.bit._00
#define         TIME_721    B369.bit._01
#define         TIME_722    B369.bit._02
#define         TIME_723    B369.bit._03
#define         TIME_724    B369.bit._04
#define         TIME_725    B369.bit._05
#define         TIME_726    B369.bit._06
#define         TIME_727    B369.bit._07
#define         TIME_728    B369.bit._08
#define         TIME_729    B369.bit._09
#define         TIME_730    B369.bit._10
#define         TIME_731    B369.bit._11
#define         TIME_732    B369.bit._12
#define         TIME_733    B369.bit._13
#define         TIME_734    B369.bit._14
#define         TIME_735    B369.bit._15

/* ------------------------------------ */
/*              WORD B370               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_736    B370.bit._00
#define         TIME_737    B370.bit._01
#define         TIME_738    B370.bit._02
#define         TIME_739    B370.bit._03
#define         TIME_740    B370.bit._04
#define         TIME_741    B370.bit._05
#define         TIME_742    B370.bit._06
#define         TIME_743    B370.bit._07
#define         TIME_744    B370.bit._08
#define         TIME_745    B370.bit._09
#define         TIME_746    B370.bit._10
#define         TIME_747    B370.bit._11
#define         TIME_748    B370.bit._12
#define         TIME_749    B370.bit._13
#define         TIME_750    B370.bit._14
#define         TIME_751    B370.bit._15

/* ------------------------------------ */
/*              WORD B371               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_752    B371.bit._00
#define         TIME_753    B371.bit._01
#define         TIME_754    B371.bit._02
#define         TIME_755    B371.bit._03
#define         TIME_756    B371.bit._04
#define         TIME_757    B371.bit._05
#define         TIME_758    B371.bit._06
#define         TIME_759    B371.bit._07
#define         TIME_760    B371.bit._08
#define         TIME_761    B371.bit._09
#define         TIME_762    B371.bit._10
#define         TIME_763    B371.bit._11
#define         TIME_764    B371.bit._12
#define         TIME_765    B371.bit._13
#define         TIME_766    B371.bit._14
#define         TIME_767    B371.bit._15

/* ------------------------------------ */
/*              WORD B372               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_768    B372.bit._00
#define         TIME_769    B372.bit._01
#define         TIME_770    B372.bit._02
#define         TIME_771    B372.bit._03
#define         TIME_772    B372.bit._04
#define         TIME_773    B372.bit._05
#define         TIME_774    B372.bit._06
#define         TIME_775    B372.bit._07
#define         TIME_776    B372.bit._08
#define         TIME_777    B372.bit._09
#define         TIME_778    B372.bit._10
#define         TIME_779    B372.bit._11
#define         TIME_780    B372.bit._12
#define         TIME_781    B372.bit._13
#define         TIME_782    B372.bit._14
#define         TIME_783    B372.bit._15

/* ------------------------------------ */
/*              WORD B373               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_784    B373.bit._00
#define         TIME_785    B373.bit._01
#define         TIME_786    B373.bit._02
#define         TIME_787    B373.bit._03
#define         TIME_788    B373.bit._04
#define         TIME_789    B373.bit._05
#define         TIME_790    B373.bit._06
#define         TIME_791    B373.bit._07
#define         TIME_792    B373.bit._08
#define         TIME_793    B373.bit._09
#define         TIME_794    B373.bit._10
#define         TIME_795    B373.bit._11
#define         TIME_796    B373.bit._12
#define         TIME_797    B373.bit._13
#define         TIME_798    B373.bit._14
#define         TIME_799    B373.bit._15

/* ------------------------------------ */
/*              WORD B374               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_800    B374.bit._00
#define         TIME_801    B374.bit._01
#define         TIME_802    B374.bit._02
#define         TIME_803    B374.bit._03
#define         TIME_804    B374.bit._04
#define         TIME_805    B374.bit._05
#define         TIME_806    B374.bit._06
#define         TIME_807    B374.bit._07
#define         TIME_808    B374.bit._08
#define         TIME_809    B374.bit._09
#define         TIME_810    B374.bit._10
#define         TIME_811    B374.bit._11
#define         TIME_812    B374.bit._12
#define         TIME_813    B374.bit._13
#define         TIME_814    B374.bit._14
#define         TIME_815    B374.bit._15

/* ------------------------------------ */
/*              WORD B375               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_816    B375.bit._00
#define         TIME_817    B375.bit._01
#define         TIME_818    B375.bit._02
#define         TIME_819    B375.bit._03
#define         TIME_820    B375.bit._04
#define         TIME_821    B375.bit._05
#define         TIME_822    B375.bit._06
#define         TIME_823    B375.bit._07
#define         TIME_824    B375.bit._08
#define         TIME_825    B375.bit._09
#define         TIME_826    B375.bit._10
#define         TIME_827    B375.bit._11
#define         TIME_828    B375.bit._12
#define         TIME_829    B375.bit._13
#define         TIME_830    B375.bit._14
#define         TIME_831    B375.bit._15

/* ------------------------------------ */
/*              WORD B376               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_832    B376.bit._00
#define         TIME_833    B376.bit._01
#define         TIME_834    B376.bit._02
#define         TIME_835    B376.bit._03
#define         TIME_836    B376.bit._04
#define         TIME_837    B376.bit._05
#define         TIME_838    B376.bit._06
#define         TIME_839    B376.bit._07
#define         TIME_840    B376.bit._08
#define         TIME_841    B376.bit._09
#define         TIME_842    B376.bit._10
#define         TIME_843    B376.bit._11
#define         TIME_844    B376.bit._12
#define         TIME_845    B376.bit._13
#define         TIME_846    B376.bit._14
#define         TIME_847    B376.bit._15

/* ------------------------------------ */
/*              WORD B377               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_848    B377.bit._00
#define         TIME_849    B377.bit._01
#define         TIME_850    B377.bit._02
#define         TIME_851    B377.bit._03
#define         TIME_852    B377.bit._04
#define         TIME_853    B377.bit._05
#define         TIME_854    B377.bit._06
#define         TIME_855    B377.bit._07
#define         TIME_856    B377.bit._08
#define         TIME_857    B377.bit._09
#define         TIME_858    B377.bit._10
#define         TIME_859    B377.bit._11
#define         TIME_860    B377.bit._12
#define         TIME_861    B377.bit._13
#define         TIME_862    B377.bit._14
#define         TIME_863    B377.bit._15

/* ------------------------------------ */
/*              WORD B378               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_864    B378.bit._00
#define         TIME_865    B378.bit._01
#define         TIME_866    B378.bit._02
#define         TIME_867    B378.bit._03
#define         TIME_868    B378.bit._04
#define         TIME_869    B378.bit._05
#define         TIME_870    B378.bit._06
#define         TIME_871    B378.bit._07
#define         TIME_872    B378.bit._08
#define         TIME_873    B378.bit._09
#define         TIME_874    B378.bit._10
#define         TIME_875    B378.bit._11
#define         TIME_876    B378.bit._12
#define         TIME_877    B378.bit._13
#define         TIME_878    B378.bit._14
#define         TIME_879    B378.bit._15

/* ------------------------------------ */
/*              WORD B379               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_880    B379.bit._00
#define         TIME_881    B379.bit._01
#define         TIME_882    B379.bit._02
#define         TIME_883    B379.bit._03
#define         TIME_884    B379.bit._04
#define         TIME_885    B379.bit._05
#define         TIME_886    B379.bit._06
#define         TIME_887    B379.bit._07
#define         TIME_888    B379.bit._08
#define         TIME_889    B379.bit._09
#define         TIME_890    B379.bit._10
#define         TIME_891    B379.bit._11
#define         TIME_892    B379.bit._12
#define         TIME_893    B379.bit._13
#define         TIME_894    B379.bit._14
#define         TIME_895    B379.bit._15

/* ------------------------------------ */
/*              WORD B380               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_896    B380.bit._00
#define         TIME_897    B380.bit._01
#define         TIME_898    B380.bit._02
#define         TIME_899    B380.bit._03
#define         TIME_900    B380.bit._04
#define         TIME_901    B380.bit._05
#define         TIME_902    B380.bit._06
#define         TIME_903    B380.bit._07
#define         TIME_904    B380.bit._08
#define         TIME_905    B380.bit._09
#define         TIME_906    B380.bit._10
#define         TIME_907    B380.bit._11
#define         TIME_908    B380.bit._12
#define         TIME_909    B380.bit._13
#define         TIME_910    B380.bit._14
#define         TIME_911    B380.bit._15

/* ------------------------------------ */
/*              WORD B381               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_912    B381.bit._00
#define         TIME_913    B381.bit._01
#define         TIME_914    B381.bit._02
#define         TIME_915    B381.bit._03
#define         TIME_916    B381.bit._04
#define         TIME_917    B381.bit._05
#define         TIME_918    B381.bit._06
#define         TIME_919    B381.bit._07
#define         TIME_920    B381.bit._08
#define         TIME_921    B381.bit._09
#define         TIME_922    B381.bit._10
#define         TIME_923    B381.bit._11
#define         TIME_924    B381.bit._12
#define         TIME_925    B381.bit._13
#define         TIME_926    B381.bit._14
#define         TIME_927    B381.bit._15

/* ------------------------------------ */
/*              WORD B382               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_928    B382.bit._00
#define         TIME_929    B382.bit._01
#define         TIME_930    B382.bit._02
#define         TIME_931    B382.bit._03
#define         TIME_932    B382.bit._04
#define         TIME_933    B382.bit._05
#define         TIME_934    B382.bit._06
#define         TIME_935    B382.bit._07
#define         TIME_936    B382.bit._08
#define         TIME_937    B382.bit._09
#define         TIME_938    B382.bit._10
#define         TIME_939    B382.bit._11
#define         TIME_940    B382.bit._12
#define         TIME_941    B382.bit._13
#define         TIME_942    B382.bit._14
#define         TIME_943    B382.bit._15

/* ------------------------------------ */
/*              WORD B383               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_944    B383.bit._00
#define         TIME_945    B383.bit._01
#define         TIME_946    B383.bit._02
#define         TIME_947    B383.bit._03
#define         TIME_948    B383.bit._04
#define         TIME_949    B383.bit._05
#define         TIME_950    B383.bit._06
#define         TIME_951    B383.bit._07
#define         TIME_952    B383.bit._08
#define         TIME_953    B383.bit._09
#define         TIME_954    B383.bit._10
#define         TIME_955    B383.bit._11
#define         TIME_956    B383.bit._12
#define         TIME_957    B383.bit._13
#define         TIME_958    B383.bit._14
#define         TIME_959    B383.bit._15

/* ------------------------------------ */
/*              WORD B384               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_960    B384.bit._00
#define         TIME_961    B384.bit._01
#define         TIME_962    B384.bit._02
#define         TIME_963    B384.bit._03
#define         TIME_964    B384.bit._04
#define         TIME_965    B384.bit._05
#define         TIME_966    B384.bit._06
#define         TIME_967    B384.bit._07
#define         TIME_968    B384.bit._08
#define         TIME_969    B384.bit._09
#define         TIME_970    B384.bit._10
#define         TIME_971    B384.bit._11
#define         TIME_972    B384.bit._12
#define         TIME_973    B384.bit._13
#define         TIME_974    B384.bit._14
#define         TIME_975    B384.bit._15

/* ------------------------------------ */
/*              WORD B385               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_976    B385.bit._00
#define         TIME_977    B385.bit._01
#define         TIME_978    B385.bit._02
#define         TIME_979    B385.bit._03
#define         TIME_980    B385.bit._04
#define         TIME_981    B385.bit._05
#define         TIME_982    B385.bit._06
#define         TIME_983    B385.bit._07
#define         TIME_984    B385.bit._08
#define         TIME_985    B385.bit._09
#define         TIME_986    B385.bit._10
#define         TIME_987    B385.bit._11
#define         TIME_988    B385.bit._12
#define         TIME_989    B385.bit._13
#define         TIME_990    B385.bit._14
#define         TIME_991    B385.bit._15

/* ------------------------------------ */
/*              WORD B386               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_992    B386.bit._00
#define         TIME_993    B386.bit._01
#define         TIME_994    B386.bit._02
#define         TIME_995    B386.bit._03
#define         TIME_996    B386.bit._04
#define         TIME_997    B386.bit._05
#define         TIME_998    B386.bit._06
#define         TIME_999    B386.bit._07
#define         TIME_1000    B386.bit._08
#define         TIME_1001    B386.bit._09
#define         TIME_1002    B386.bit._10
#define         TIME_1003    B386.bit._11
#define         TIME_1004    B386.bit._12
#define         TIME_1005    B386.bit._13
#define         TIME_1006    B386.bit._14
#define         TIME_1007    B386.bit._15

/* ------------------------------------ */
/*              WORD B387               */
/* ------------------------------------ */
/***************************************************************/
/* N.B:  Vedi nota su TIME_00                                  */
/* N.B:  See TIME_00 note                                      */
/***************************************************************/
#define         TIME_1008    B387.bit._00
#define         TIME_1009    B387.bit._01
#define         TIME_1010    B387.bit._02
#define         TIME_1011    B387.bit._03
#define         TIME_1012    B387.bit._04
#define         TIME_1013    B387.bit._05
#define         TIME_1014    B387.bit._06
#define         TIME_1015    B387.bit._07
#define         TIME_1016    B387.bit._08
#define         TIME_1017    B387.bit._09
#define         TIME_1018    B387.bit._10
#define         TIME_1019    B387.bit._11
#define         TIME_1020    B387.bit._12
#define         TIME_1021    B387.bit._13
#define         TIME_1022    B387.bit._14
#define         TIME_1023    B387.bit._15

/* ------------------------------------ */
/*  WORD B388, B389, B390               */
/* ------------------------------------ */
#define         AC_ENABLED   B388.bit._00
/* plc richiede invio codice allarme    */
/* send of alarm code required by plc   */
#define         AC_STROBE    B388.bit._01
/* strobe per nuovo codice allarme      */
/* strobe of new alarm code             */
#define         AC_ACK       B388.bit._02
/* ack per nuovo codice allarme         */
/* ack of new alarm code                */
#define         AC_ADDED     B388.bit._03
/* emesso un nuovo codice allarme       */
/* added a new alarm code               */
#define         AC_REMOVED   B388.bit._04
/* rimosso un precedente codice allarme */
/* removed an existing alarm code       */
#define         AC_OVERFLOW  B388.bit._05
/* superato numero massimo di allarmi   */
/* alarms number overflow               */
#define         AC_AXIS_ORDN B389.word
/* numero d'ordine asse                 */
/* axis ord number                      */
#define         AC_CODE      D_B390
/* valore codice allarme                */
/* alarm code value                     */
#define         AC_SIZE      B392.word
/* numero di allarmi da inviare al plc  */
/* number of alarms to send to the plc  */


/* ------------------------------------ */
/*  WORD B393                           */
/* ------------------------------------ */
#define		   EOE_ENABLE	B393.bit._00
/* Richiesta di abilitare comunicazione EoE. */
/* Request to enable EoE communication. */
#define		   EOE_ENABLED	B393.bit._01
/* Comunicazione EoE abilitata. */
/* EoE communication enabled. */

/* ------------------------------------ */
/*  WORD B394                          */
/* ------------------------------------ */
#define		   ICW	            B394.word
#define		   IC_ACTPOS_NCEXT  B394.bit._00
/* VISUALIZZA QUOTA ATTUALE SENZA CORREZIONE ESTERNA */
/* VIEW ACTUAL POSITION WITHOUT EXTERNAL CORRECITION */

#define        K900_TGRADIL B395.word
/* TEMPERATURA INTERNA (GRADI CELSIUS - LEGACY) */
/* TEMPERATURA INTERNA (GRADI CELSIUS - LEGACY) */

/* ------------------------------------ */
/*              FINE AREA B             */
/* ------------------------------------ */






/***************************************************************/
/* LE WORD F_Bxx (DA 00 A 249) OCCUPANO UNA LORO AREA E NON   */
/* SONO IN CONFLITTO CON LE AREE Bxx E D_Bxx                  */
/* IN DF_BB.INC SONO DEFINITE SOLO LE AREE DA F_B0 A F_B50     */
/* E DA F_B130 A F_B249                                        */
/***************************************************************/

/* ------------------------------------ */
/*               WORD F_B0              */
/* ------------------------------------ */

//Ecs900! #define        CODICR       F_B0
/* COEFFICIENTE DIVISIONE (FILTRO) PER VOLANTINI DA CONSOLE REMOTA */
/* DIVISION FACTOR (FILTER) FOR HANDWHEELS FROM REMOTE CONSOLE */

/* ------------------------------------ */
/*               WORD F_B2              */
/* ------------------------------------ */

#define        CODITAS      F_B2
/* COEF. DIVISIONE (FILTRO) PER VOLANTINI  */
/* DIVISION FACTOR (FILTER) FOR HANDWHEELS */


/* ------------------------------------ */
/*               WORD F_B4              */
/* ------------------------------------ */

#define        CODIIKR      F_B4
/* COEF. DIVISIONE (FILTRO) PER VOLANTINI DA IKR */
/* DIVISION FACTOR (FILTER) FOR HANDWHEELS FROM IKR */


/* ------------------------------------ */
/*               WORD F_B6              */
/* ------------------------------------ */

#define        TAUCNC       F_B6
/* VALORE DEL TAU DEL CNC IN SECONDI */
/* CNC TAU VALUE IN SECONDS */

/* ------------------------------------ */
/*               WORD F_B8              */
/* ------------------------------------ */

#define        TAUPLC       F_B8
/* VALORE DEL TAU DEL PLC IN SECONDI */
/* PLC TAU VALUE IN SECONDS */

/* ------------------------------------ */
/*               WORD F_B10             */
/* ------------------------------------ */

#define        FMDRYRUN     F_B10
/* FEED MASSIMA ASSI IN DRY_RUN         */
/* MAX AXES FEED IN DRY_RUN MODE        */

/* ------------------------------------ */
/*               WORD F_B12             */
/* ------------------------------------ */

#define        VALLIMFD     F_B12
/* FEED LIMITE ASSI SALVATA PER DRY_RUN */
/* SAVED AXES FEED LIMIT FOR DRY_RUN    */

/* ------------------------------------ */
/*               WORD F_B14              */
/* ------------------------------------ */

#define        FVLN         F_B14
/* FILTRO VOLANTINO (0.001 <= FVLN <= 1) */
/* HANDWHEEL FILTER (0.001 <= FVLN <= 1) */


/* ------------------------------------ */
/*       WORD F_B16 - F_B26             */
/* 	Sinonimi per  JOYSTICK default		*/
/* ------------------------------------ */

#define       VEL_DES_JOY1        F_B16
/* VELOCITA DESIDERATA CANALE 1 JOYSTICK */
/* TARGET SPEED JOYSTICK CHANNEL 1		 */

#define       VEL_DES_JOY2        F_B18
/* VELOCITA DESIDERATA CANALE 2 JOYSTICK */
/* TARGET SPEED JOYSTICK CHANNEL 2		 */

#define       VEL_DES_JOY3        F_B20
/* VELOCITA DESIDERATA CANALE 3 JOYSTICK */
/* TARGET SPEED JOYSTICK CHANNEL 3		 */

#define       VEL_ACT_JOY1        F_B22
/* VELOCITA ATTUALE CANALE 1 JOYSTICK    */
/* ACTUAL SPEED JOYSTICK CHANNEL 1       */

#define       VEL_ACT_JOY2        F_B24
/* VELOCITA ATTUALE CANALE 2 JOYSTICK    */
/* ACTUAL SPEED JOYSTICK CHANNEL 2       */

#define       VEL_ACT_JOY3        F_B26
/* VELOCITA ATTUALE CANALE 3 JOYSTICK    */
/* ACTUAL SPEED JOYSTICK CHANNEL 3       */


/* ------------------------------------ */
/*          WORD F_B28                 */
/* ------------------------------------ */

#define        VALUE_HMAP     F_B28
/* VALORE DEL DELTA Z PER HMAP          */
/* VALORE DEL DELTA Z PER HMAP          */

/* ------------------------------------ */
/*          WORD F_B30                 */
/* ------------------------------------ */

#define        POSUT_X        F_B30
/* PROIEZIONE DELL'UTENSILE UNITARIO      */
/* SULL'ASSE X. ATTIVO SE PROGRAMMATO ATW */

#define        POSUT_Y        F_B32
/* PROIEZIONE DELL'UTENSILE UNITARIO      */
/* SULL'ASSE Y. ATTIVO SE PROGRAMMATO ATW */

#define        POSUT_Z        F_B34
/* PROIEZIONE DELL'UTENSILE UNITARIO      */
/* SULL'ASSE Z. ATTIVO SE PROGRAMMATO ATW */


/* ------------------------------------ */
/*          WORD F_B130                 */
/* ------------------------------------ */

#define        FEDMAG       F_B130
/* VELOCITA ASSE MAGAZZINO */
/* FEED OF WAREHOUSE AXIS */

/* ------------------------------------ */
/*          WORD F_B132                 */
/* ------------------------------------ */

#define        PASMAG       F_B132
/* PASSO MAGLIA MAGAZZINO */
/* WAREHOUSE MESH PITCH */

/* ------------------------------------ */
/*            WORD F_B134               */
/* ------------------------------------ */

/* ------------------------------------ */
/*            WORD F_B136               */
/* ------------------------------------ */

/* ------------------------------------ */
/*            WORD F_B138               */
/* ------------------------------------ */

/* ------------------------------------ */
/*          WORD F_B144-F_B148          */
/*   EX appoggi per Console remota ECS  */
/* ------------------------------------ */

/* ------------------------------------ */
/*          WORD F_B190-F_B198          */
/*           ex appoggi per WOOD        */
/* ------------------------------------ */


/* ------------------------------------ */
/*          WORD F_B200-F_B248          */
/* ------------------------------------ */

#define        PARPLC00     F_B200
/* PARAMETRI 00 -:- 24 PER WINDOW PLC (Primo parametro) */
/* 00 -:- 24 PARAMETERS FOR PLC WINDOW (First Parameter) */
#define        PARPLC01     F_B202
#define        PARPLC02     F_B204
#define        PARPLC03     F_B206
#define        PARPLC04     F_B208
#define        PARPLC05     F_B210
#define        PARPLC06     F_B212
#define        PARPLC07     F_B214
#define        PARPLC08     F_B216
#define        PARPLC09     F_B218
#define        PARPLC10     F_B220
#define        PARPLC11     F_B222
#define        PARPLC12     F_B224
#define        PARPLC13     F_B226
#define        PARPLC14     F_B228
#define        PARPLC15     F_B230
#define        PARPLC16     F_B232
#define        PARPLC17     F_B234
#define        PARPLC18     F_B236
#define        PARPLC19     F_B238
#define        PARPLC20     F_B240
#define        PARPLC21     F_B242
#define        PARPLC22     F_B244
#define        PARPLC23     F_B246
#define        PARPLC24     F_B248
/* PARAMETRI 00 -:- 24 PER WINDOW PLC (Ultimo parametro) */
/* 00 -:- 24 PARAMETERS FOR PLC WINDOW (Last Parameter) */

///#endif	// #ifdef QAL_SLOW

/* ------------------------------------ */
/*          WORD F_B256-F_B2254         */
/* ------------------------------------ */

#define        PARPLC900_0000     F_B256
/* PARAMETRI 0000 -:- 0999 PER WINDOW PLC (Primo parametro) */
/* 00 -:- 0999 PARAMETERS FOR PLC WINDOW (First Parameter) */
#define        PARPLC900_0001     F_B258
#define        PARPLC900_0002     F_B260
#define        PARPLC900_0003     F_B262
#define        PARPLC900_0004     F_B264
#define        PARPLC900_0005     F_B266
#define        PARPLC900_0006     F_B268
#define        PARPLC900_0007     F_B270
#define        PARPLC900_0008     F_B272
#define        PARPLC900_0009     F_B274
#define        PARPLC900_0010     F_B276
#define        PARPLC900_0011     F_B278
#define        PARPLC900_0012     F_B280
#define        PARPLC900_0013     F_B282
#define        PARPLC900_0014     F_B284
#define        PARPLC900_0015     F_B286
#define        PARPLC900_0016     F_B288
#define        PARPLC900_0017     F_B290
#define        PARPLC900_0018     F_B292
#define        PARPLC900_0019     F_B294
#define        PARPLC900_0020     F_B296
#define        PARPLC900_0021     F_B298
#define        PARPLC900_0022     F_B300
#define        PARPLC900_0023     F_B302
#define        PARPLC900_0024     F_B304
#define        PARPLC900_0025     F_B306
#define        PARPLC900_0026     F_B308
#define        PARPLC900_0027     F_B310
#define        PARPLC900_0028     F_B312
#define        PARPLC900_0029     F_B314
#define        PARPLC900_0030     F_B316
#define        PARPLC900_0031     F_B318
#define        PARPLC900_0032     F_B320
#define        PARPLC900_0033     F_B322
#define        PARPLC900_0034     F_B324
#define        PARPLC900_0035     F_B326
#define        PARPLC900_0036     F_B328
#define        PARPLC900_0037     F_B330
#define        PARPLC900_0038     F_B332
#define        PARPLC900_0039     F_B334
#define        PARPLC900_0040     F_B336
#define        PARPLC900_0041     F_B338
#define        PARPLC900_0042     F_B340
#define        PARPLC900_0043     F_B342
#define        PARPLC900_0044     F_B344
#define        PARPLC900_0045     F_B346
#define        PARPLC900_0046     F_B348
#define        PARPLC900_0047     F_B350
#define        PARPLC900_0048     F_B352
#define        PARPLC900_0049     F_B354
#define        PARPLC900_0050     F_B356
#define        PARPLC900_0051     F_B358
#define        PARPLC900_0052     F_B360
#define        PARPLC900_0053     F_B362
#define        PARPLC900_0054     F_B364
#define        PARPLC900_0055     F_B366
#define        PARPLC900_0056     F_B368
#define        PARPLC900_0057     F_B370
#define        PARPLC900_0058     F_B372
#define        PARPLC900_0059     F_B374
#define        PARPLC900_0060     F_B376
#define        PARPLC900_0061     F_B378
#define        PARPLC900_0062     F_B380
#define        PARPLC900_0063     F_B382
#define        PARPLC900_0064     F_B384
#define        PARPLC900_0065     F_B386
#define        PARPLC900_0066     F_B388
#define        PARPLC900_0067     F_B390
#define        PARPLC900_0068     F_B392
#define        PARPLC900_0069     F_B394
#define        PARPLC900_0070     F_B396
#define        PARPLC900_0071     F_B398
#define        PARPLC900_0072     F_B400
#define        PARPLC900_0073     F_B402
#define        PARPLC900_0074     F_B404
#define        PARPLC900_0075     F_B406
#define        PARPLC900_0076     F_B408
#define        PARPLC900_0077     F_B410
#define        PARPLC900_0078     F_B412
#define        PARPLC900_0079     F_B414
#define        PARPLC900_0080     F_B416
#define        PARPLC900_0081     F_B418
#define        PARPLC900_0082     F_B420
#define        PARPLC900_0083     F_B422
#define        PARPLC900_0084     F_B424
#define        PARPLC900_0085     F_B426
#define        PARPLC900_0086     F_B428
#define        PARPLC900_0087     F_B430
#define        PARPLC900_0088     F_B432
#define        PARPLC900_0089     F_B434
#define        PARPLC900_0090     F_B436
#define        PARPLC900_0091     F_B438
#define        PARPLC900_0092     F_B440
#define        PARPLC900_0093     F_B442
#define        PARPLC900_0094     F_B444
#define        PARPLC900_0095     F_B446
#define        PARPLC900_0096     F_B448
#define        PARPLC900_0097     F_B450
#define        PARPLC900_0098     F_B452
#define        PARPLC900_0099     F_B454
#define        PARPLC900_0100     F_B456
#define        PARPLC900_0101     F_B458
#define        PARPLC900_0102     F_B460
#define        PARPLC900_0103     F_B462
#define        PARPLC900_0104     F_B464
#define        PARPLC900_0105     F_B466
#define        PARPLC900_0106     F_B468
#define        PARPLC900_0107     F_B470
#define        PARPLC900_0108     F_B472
#define        PARPLC900_0109     F_B474
#define        PARPLC900_0110     F_B476
#define        PARPLC900_0111     F_B478
#define        PARPLC900_0112     F_B480
#define        PARPLC900_0113     F_B482
#define        PARPLC900_0114     F_B484
#define        PARPLC900_0115     F_B486
#define        PARPLC900_0116     F_B488
#define        PARPLC900_0117     F_B490
#define        PARPLC900_0118     F_B492
#define        PARPLC900_0119     F_B494
#define        PARPLC900_0120     F_B496
#define        PARPLC900_0121     F_B498
#define        PARPLC900_0122     F_B500
#define        PARPLC900_0123     F_B502
#define        PARPLC900_0124     F_B504
#define        PARPLC900_0125     F_B506
#define        PARPLC900_0126     F_B508
#define        PARPLC900_0127     F_B510
#define        PARPLC900_0128     F_B512
#define        PARPLC900_0129     F_B514
#define        PARPLC900_0130     F_B516
#define        PARPLC900_0131     F_B518
#define        PARPLC900_0132     F_B520
#define        PARPLC900_0133     F_B522
#define        PARPLC900_0134     F_B524
#define        PARPLC900_0135     F_B526
#define        PARPLC900_0136     F_B528
#define        PARPLC900_0137     F_B530
#define        PARPLC900_0138     F_B532
#define        PARPLC900_0139     F_B534
#define        PARPLC900_0140     F_B536
#define        PARPLC900_0141     F_B538
#define        PARPLC900_0142     F_B540
#define        PARPLC900_0143     F_B542
#define        PARPLC900_0144     F_B544
#define        PARPLC900_0145     F_B546
#define        PARPLC900_0146     F_B548
#define        PARPLC900_0147     F_B550
#define        PARPLC900_0148     F_B552
#define        PARPLC900_0149     F_B554
#define        PARPLC900_0150     F_B556
#define        PARPLC900_0151     F_B558
#define        PARPLC900_0152     F_B560
#define        PARPLC900_0153     F_B562
#define        PARPLC900_0154     F_B564
#define        PARPLC900_0155     F_B566
#define        PARPLC900_0156     F_B568
#define        PARPLC900_0157     F_B570
#define        PARPLC900_0158     F_B572
#define        PARPLC900_0159     F_B574
#define        PARPLC900_0160     F_B576
#define        PARPLC900_0161     F_B578
#define        PARPLC900_0162     F_B580
#define        PARPLC900_0163     F_B582
#define        PARPLC900_0164     F_B584
#define        PARPLC900_0165     F_B586
#define        PARPLC900_0166     F_B588
#define        PARPLC900_0167     F_B590
#define        PARPLC900_0168     F_B592
#define        PARPLC900_0169     F_B594
#define        PARPLC900_0170     F_B596
#define        PARPLC900_0171     F_B598
#define        PARPLC900_0172     F_B600
#define        PARPLC900_0173     F_B602
#define        PARPLC900_0174     F_B604
#define        PARPLC900_0175     F_B606
#define        PARPLC900_0176     F_B608
#define        PARPLC900_0177     F_B610
#define        PARPLC900_0178     F_B612
#define        PARPLC900_0179     F_B614
#define        PARPLC900_0180     F_B616
#define        PARPLC900_0181     F_B618
#define        PARPLC900_0182     F_B620
#define        PARPLC900_0183     F_B622
#define        PARPLC900_0184     F_B624
#define        PARPLC900_0185     F_B626
#define        PARPLC900_0186     F_B628
#define        PARPLC900_0187     F_B630
#define        PARPLC900_0188     F_B632
#define        PARPLC900_0189     F_B634
#define        PARPLC900_0190     F_B636
#define        PARPLC900_0191     F_B638
#define        PARPLC900_0192     F_B640
#define        PARPLC900_0193     F_B642
#define        PARPLC900_0194     F_B644
#define        PARPLC900_0195     F_B646
#define        PARPLC900_0196     F_B648
#define        PARPLC900_0197     F_B650
#define        PARPLC900_0198     F_B652
#define        PARPLC900_0199     F_B654
#define        PARPLC900_0200     F_B656
#define        PARPLC900_0201     F_B658
#define        PARPLC900_0202     F_B660
#define        PARPLC900_0203     F_B662
#define        PARPLC900_0204     F_B664
#define        PARPLC900_0205     F_B666
#define        PARPLC900_0206     F_B668
#define        PARPLC900_0207     F_B670
#define        PARPLC900_0208     F_B672
#define        PARPLC900_0209     F_B674
#define        PARPLC900_0210     F_B676
#define        PARPLC900_0211     F_B678
#define        PARPLC900_0212     F_B680
#define        PARPLC900_0213     F_B682
#define        PARPLC900_0214     F_B684
#define        PARPLC900_0215     F_B686
#define        PARPLC900_0216     F_B688
#define        PARPLC900_0217     F_B690
#define        PARPLC900_0218     F_B692
#define        PARPLC900_0219     F_B694
#define        PARPLC900_0220     F_B696
#define        PARPLC900_0221     F_B698
#define        PARPLC900_0222     F_B700
#define        PARPLC900_0223     F_B702
#define        PARPLC900_0224     F_B704
#define        PARPLC900_0225     F_B706
#define        PARPLC900_0226     F_B708
#define        PARPLC900_0227     F_B710
#define        PARPLC900_0228     F_B712
#define        PARPLC900_0229     F_B714
#define        PARPLC900_0230     F_B716
#define        PARPLC900_0231     F_B718
#define        PARPLC900_0232     F_B720
#define        PARPLC900_0233     F_B722
#define        PARPLC900_0234     F_B724
#define        PARPLC900_0235     F_B726
#define        PARPLC900_0236     F_B728
#define        PARPLC900_0237     F_B730
#define        PARPLC900_0238     F_B732
#define        PARPLC900_0239     F_B734
#define        PARPLC900_0240     F_B736
#define        PARPLC900_0241     F_B738
#define        PARPLC900_0242     F_B740
#define        PARPLC900_0243     F_B742
#define        PARPLC900_0244     F_B744
#define        PARPLC900_0245     F_B746
#define        PARPLC900_0246     F_B748
#define        PARPLC900_0247     F_B750
#define        PARPLC900_0248     F_B752
#define        PARPLC900_0249     F_B754
#define        PARPLC900_0250     F_B756
#define        PARPLC900_0251     F_B758
#define        PARPLC900_0252     F_B760
#define        PARPLC900_0253     F_B762
#define        PARPLC900_0254     F_B764
#define        PARPLC900_0255     F_B766
#define        PARPLC900_0256     F_B768
#define        PARPLC900_0257     F_B770
#define        PARPLC900_0258     F_B772
#define        PARPLC900_0259     F_B774
#define        PARPLC900_0260     F_B776
#define        PARPLC900_0261     F_B778
#define        PARPLC900_0262     F_B780
#define        PARPLC900_0263     F_B782
#define        PARPLC900_0264     F_B784
#define        PARPLC900_0265     F_B786
#define        PARPLC900_0266     F_B788
#define        PARPLC900_0267     F_B790
#define        PARPLC900_0268     F_B792
#define        PARPLC900_0269     F_B794
#define        PARPLC900_0270     F_B796
#define        PARPLC900_0271     F_B798
#define        PARPLC900_0272     F_B800
#define        PARPLC900_0273     F_B802
#define        PARPLC900_0274     F_B804
#define        PARPLC900_0275     F_B806
#define        PARPLC900_0276     F_B808
#define        PARPLC900_0277     F_B810
#define        PARPLC900_0278     F_B812
#define        PARPLC900_0279     F_B814
#define        PARPLC900_0280     F_B816
#define        PARPLC900_0281     F_B818
#define        PARPLC900_0282     F_B820
#define        PARPLC900_0283     F_B822
#define        PARPLC900_0284     F_B824
#define        PARPLC900_0285     F_B826
#define        PARPLC900_0286     F_B828
#define        PARPLC900_0287     F_B830
#define        PARPLC900_0288     F_B832
#define        PARPLC900_0289     F_B834
#define        PARPLC900_0290     F_B836
#define        PARPLC900_0291     F_B838
#define        PARPLC900_0292     F_B840
#define        PARPLC900_0293     F_B842
#define        PARPLC900_0294     F_B844
#define        PARPLC900_0295     F_B846
#define        PARPLC900_0296     F_B848
#define        PARPLC900_0297     F_B850
#define        PARPLC900_0298     F_B852
#define        PARPLC900_0299     F_B854
#define        PARPLC900_0300     F_B856
#define        PARPLC900_0301     F_B858
#define        PARPLC900_0302     F_B860
#define        PARPLC900_0303     F_B862
#define        PARPLC900_0304     F_B864
#define        PARPLC900_0305     F_B866
#define        PARPLC900_0306     F_B868
#define        PARPLC900_0307     F_B870
#define        PARPLC900_0308     F_B872
#define        PARPLC900_0309     F_B874
#define        PARPLC900_0310     F_B876
#define        PARPLC900_0311     F_B878
#define        PARPLC900_0312     F_B880
#define        PARPLC900_0313     F_B882
#define        PARPLC900_0314     F_B884
#define        PARPLC900_0315     F_B886
#define        PARPLC900_0316     F_B888
#define        PARPLC900_0317     F_B890
#define        PARPLC900_0318     F_B892
#define        PARPLC900_0319     F_B894
#define        PARPLC900_0320     F_B896
#define        PARPLC900_0321     F_B898
#define        PARPLC900_0322     F_B900
#define        PARPLC900_0323     F_B902
#define        PARPLC900_0324     F_B904
#define        PARPLC900_0325     F_B906
#define        PARPLC900_0326     F_B908
#define        PARPLC900_0327     F_B910
#define        PARPLC900_0328     F_B912
#define        PARPLC900_0329     F_B914
#define        PARPLC900_0330     F_B916
#define        PARPLC900_0331     F_B918
#define        PARPLC900_0332     F_B920
#define        PARPLC900_0333     F_B922
#define        PARPLC900_0334     F_B924
#define        PARPLC900_0335     F_B926
#define        PARPLC900_0336     F_B928
#define        PARPLC900_0337     F_B930
#define        PARPLC900_0338     F_B932
#define        PARPLC900_0339     F_B934
#define        PARPLC900_0340     F_B936
#define        PARPLC900_0341     F_B938
#define        PARPLC900_0342     F_B940
#define        PARPLC900_0343     F_B942
#define        PARPLC900_0344     F_B944
#define        PARPLC900_0345     F_B946
#define        PARPLC900_0346     F_B948
#define        PARPLC900_0347     F_B950
#define        PARPLC900_0348     F_B952
#define        PARPLC900_0349     F_B954
#define        PARPLC900_0350     F_B956
#define        PARPLC900_0351     F_B958
#define        PARPLC900_0352     F_B960
#define        PARPLC900_0353     F_B962
#define        PARPLC900_0354     F_B964
#define        PARPLC900_0355     F_B966
#define        PARPLC900_0356     F_B968
#define        PARPLC900_0357     F_B970
#define        PARPLC900_0358     F_B972
#define        PARPLC900_0359     F_B974
#define        PARPLC900_0360     F_B976
#define        PARPLC900_0361     F_B978
#define        PARPLC900_0362     F_B980
#define        PARPLC900_0363     F_B982
#define        PARPLC900_0364     F_B984
#define        PARPLC900_0365     F_B986
#define        PARPLC900_0366     F_B988
#define        PARPLC900_0367     F_B990
#define        PARPLC900_0368     F_B992
#define        PARPLC900_0369     F_B994
#define        PARPLC900_0370     F_B996
#define        PARPLC900_0371     F_B998
#define        PARPLC900_0372     F_B1000
#define        PARPLC900_0373     F_B1002
#define        PARPLC900_0374     F_B1004
#define        PARPLC900_0375     F_B1006
#define        PARPLC900_0376     F_B1008
#define        PARPLC900_0377     F_B1010
#define        PARPLC900_0378     F_B1012
#define        PARPLC900_0379     F_B1014
#define        PARPLC900_0380     F_B1016
#define        PARPLC900_0381     F_B1018
#define        PARPLC900_0382     F_B1020
#define        PARPLC900_0383     F_B1022
#define        PARPLC900_0384     F_B1024
#define        PARPLC900_0385     F_B1026
#define        PARPLC900_0386     F_B1028
#define        PARPLC900_0387     F_B1030
#define        PARPLC900_0388     F_B1032
#define        PARPLC900_0389     F_B1034
#define        PARPLC900_0390     F_B1036
#define        PARPLC900_0391     F_B1038
#define        PARPLC900_0392     F_B1040
#define        PARPLC900_0393     F_B1042
#define        PARPLC900_0394     F_B1044
#define        PARPLC900_0395     F_B1046
#define        PARPLC900_0396     F_B1048
#define        PARPLC900_0397     F_B1050
#define        PARPLC900_0398     F_B1052
#define        PARPLC900_0399     F_B1054
#define        PARPLC900_0400     F_B1056
#define        PARPLC900_0401     F_B1058
#define        PARPLC900_0402     F_B1060
#define        PARPLC900_0403     F_B1062
#define        PARPLC900_0404     F_B1064
#define        PARPLC900_0405     F_B1066
#define        PARPLC900_0406     F_B1068
#define        PARPLC900_0407     F_B1070
#define        PARPLC900_0408     F_B1072
#define        PARPLC900_0409     F_B1074
#define        PARPLC900_0410     F_B1076
#define        PARPLC900_0411     F_B1078
#define        PARPLC900_0412     F_B1080
#define        PARPLC900_0413     F_B1082
#define        PARPLC900_0414     F_B1084
#define        PARPLC900_0415     F_B1086
#define        PARPLC900_0416     F_B1088
#define        PARPLC900_0417     F_B1090
#define        PARPLC900_0418     F_B1092
#define        PARPLC900_0419     F_B1094
#define        PARPLC900_0420     F_B1096
#define        PARPLC900_0421     F_B1098
#define        PARPLC900_0422     F_B1100
#define        PARPLC900_0423     F_B1102
#define        PARPLC900_0424     F_B1104
#define        PARPLC900_0425     F_B1106
#define        PARPLC900_0426     F_B1108
#define        PARPLC900_0427     F_B1110
#define        PARPLC900_0428     F_B1112
#define        PARPLC900_0429     F_B1114
#define        PARPLC900_0430     F_B1116
#define        PARPLC900_0431     F_B1118
#define        PARPLC900_0432     F_B1120
#define        PARPLC900_0433     F_B1122
#define        PARPLC900_0434     F_B1124
#define        PARPLC900_0435     F_B1126
#define        PARPLC900_0436     F_B1128
#define        PARPLC900_0437     F_B1130
#define        PARPLC900_0438     F_B1132
#define        PARPLC900_0439     F_B1134
#define        PARPLC900_0440     F_B1136
#define        PARPLC900_0441     F_B1138
#define        PARPLC900_0442     F_B1140
#define        PARPLC900_0443     F_B1142
#define        PARPLC900_0444     F_B1144
#define        PARPLC900_0445     F_B1146
#define        PARPLC900_0446     F_B1148
#define        PARPLC900_0447     F_B1150
#define        PARPLC900_0448     F_B1152
#define        PARPLC900_0449     F_B1154
#define        PARPLC900_0450     F_B1156
#define        PARPLC900_0451     F_B1158
#define        PARPLC900_0452     F_B1160
#define        PARPLC900_0453     F_B1162
#define        PARPLC900_0454     F_B1164
#define        PARPLC900_0455     F_B1166
#define        PARPLC900_0456     F_B1168
#define        PARPLC900_0457     F_B1170
#define        PARPLC900_0458     F_B1172
#define        PARPLC900_0459     F_B1174
#define        PARPLC900_0460     F_B1176
#define        PARPLC900_0461     F_B1178
#define        PARPLC900_0462     F_B1180
#define        PARPLC900_0463     F_B1182
#define        PARPLC900_0464     F_B1184
#define        PARPLC900_0465     F_B1186
#define        PARPLC900_0466     F_B1188
#define        PARPLC900_0467     F_B1190
#define        PARPLC900_0468     F_B1192
#define        PARPLC900_0469     F_B1194
#define        PARPLC900_0470     F_B1196
#define        PARPLC900_0471     F_B1198
#define        PARPLC900_0472     F_B1200
#define        PARPLC900_0473     F_B1202
#define        PARPLC900_0474     F_B1204
#define        PARPLC900_0475     F_B1206
#define        PARPLC900_0476     F_B1208
#define        PARPLC900_0477     F_B1210
#define        PARPLC900_0478     F_B1212
#define        PARPLC900_0479     F_B1214
#define        PARPLC900_0480     F_B1216
#define        PARPLC900_0481     F_B1218
#define        PARPLC900_0482     F_B1220
#define        PARPLC900_0483     F_B1222
#define        PARPLC900_0484     F_B1224
#define        PARPLC900_0485     F_B1226
#define        PARPLC900_0486     F_B1228
#define        PARPLC900_0487     F_B1230
#define        PARPLC900_0488     F_B1232
#define        PARPLC900_0489     F_B1234
#define        PARPLC900_0490     F_B1236
#define        PARPLC900_0491     F_B1238
#define        PARPLC900_0492     F_B1240
#define        PARPLC900_0493     F_B1242
#define        PARPLC900_0494     F_B1244
#define        PARPLC900_0495     F_B1246
#define        PARPLC900_0496     F_B1248
#define        PARPLC900_0497     F_B1250
#define        PARPLC900_0498     F_B1252
#define        PARPLC900_0499     F_B1254
#define        PARPLC900_0500     F_B1256
#define        PARPLC900_0501     F_B1258
#define        PARPLC900_0502     F_B1260
#define        PARPLC900_0503     F_B1262
#define        PARPLC900_0504     F_B1264
#define        PARPLC900_0505     F_B1266
#define        PARPLC900_0506     F_B1268
#define        PARPLC900_0507     F_B1270
#define        PARPLC900_0508     F_B1272
#define        PARPLC900_0509     F_B1274
#define        PARPLC900_0510     F_B1276
#define        PARPLC900_0511     F_B1278
#define        PARPLC900_0512     F_B1280
#define        PARPLC900_0513     F_B1282
#define        PARPLC900_0514     F_B1284
#define        PARPLC900_0515     F_B1286
#define        PARPLC900_0516     F_B1288
#define        PARPLC900_0517     F_B1290
#define        PARPLC900_0518     F_B1292
#define        PARPLC900_0519     F_B1294
#define        PARPLC900_0520     F_B1296
#define        PARPLC900_0521     F_B1298
#define        PARPLC900_0522     F_B1300
#define        PARPLC900_0523     F_B1302
#define        PARPLC900_0524     F_B1304
#define        PARPLC900_0525     F_B1306
#define        PARPLC900_0526     F_B1308
#define        PARPLC900_0527     F_B1310
#define        PARPLC900_0528     F_B1312
#define        PARPLC900_0529     F_B1314
#define        PARPLC900_0530     F_B1316
#define        PARPLC900_0531     F_B1318
#define        PARPLC900_0532     F_B1320
#define        PARPLC900_0533     F_B1322
#define        PARPLC900_0534     F_B1324
#define        PARPLC900_0535     F_B1326
#define        PARPLC900_0536     F_B1328
#define        PARPLC900_0537     F_B1330
#define        PARPLC900_0538     F_B1332
#define        PARPLC900_0539     F_B1334
#define        PARPLC900_0540     F_B1336
#define        PARPLC900_0541     F_B1338
#define        PARPLC900_0542     F_B1340
#define        PARPLC900_0543     F_B1342
#define        PARPLC900_0544     F_B1344
#define        PARPLC900_0545     F_B1346
#define        PARPLC900_0546     F_B1348
#define        PARPLC900_0547     F_B1350
#define        PARPLC900_0548     F_B1352
#define        PARPLC900_0549     F_B1354
#define        PARPLC900_0550     F_B1356
#define        PARPLC900_0551     F_B1358
#define        PARPLC900_0552     F_B1360
#define        PARPLC900_0553     F_B1362
#define        PARPLC900_0554     F_B1364
#define        PARPLC900_0555     F_B1366
#define        PARPLC900_0556     F_B1368
#define        PARPLC900_0557     F_B1370
#define        PARPLC900_0558     F_B1372
#define        PARPLC900_0559     F_B1374
#define        PARPLC900_0560     F_B1376
#define        PARPLC900_0561     F_B1378
#define        PARPLC900_0562     F_B1380
#define        PARPLC900_0563     F_B1382
#define        PARPLC900_0564     F_B1384
#define        PARPLC900_0565     F_B1386
#define        PARPLC900_0566     F_B1388
#define        PARPLC900_0567     F_B1390
#define        PARPLC900_0568     F_B1392
#define        PARPLC900_0569     F_B1394
#define        PARPLC900_0570     F_B1396
#define        PARPLC900_0571     F_B1398
#define        PARPLC900_0572     F_B1400
#define        PARPLC900_0573     F_B1402
#define        PARPLC900_0574     F_B1404
#define        PARPLC900_0575     F_B1406
#define        PARPLC900_0576     F_B1408
#define        PARPLC900_0577     F_B1410
#define        PARPLC900_0578     F_B1412
#define        PARPLC900_0579     F_B1414
#define        PARPLC900_0580     F_B1416
#define        PARPLC900_0581     F_B1418
#define        PARPLC900_0582     F_B1420
#define        PARPLC900_0583     F_B1422
#define        PARPLC900_0584     F_B1424
#define        PARPLC900_0585     F_B1426
#define        PARPLC900_0586     F_B1428
#define        PARPLC900_0587     F_B1430
#define        PARPLC900_0588     F_B1432
#define        PARPLC900_0589     F_B1434
#define        PARPLC900_0590     F_B1436
#define        PARPLC900_0591     F_B1438
#define        PARPLC900_0592     F_B1440
#define        PARPLC900_0593     F_B1442
#define        PARPLC900_0594     F_B1444
#define        PARPLC900_0595     F_B1446
#define        PARPLC900_0596     F_B1448
#define        PARPLC900_0597     F_B1450
#define        PARPLC900_0598     F_B1452
#define        PARPLC900_0599     F_B1454
#define        PARPLC900_0600     F_B1456
#define        PARPLC900_0601     F_B1458
#define        PARPLC900_0602     F_B1460
#define        PARPLC900_0603     F_B1462
#define        PARPLC900_0604     F_B1464
#define        PARPLC900_0605     F_B1466
#define        PARPLC900_0606     F_B1468
#define        PARPLC900_0607     F_B1470
#define        PARPLC900_0608     F_B1472
#define        PARPLC900_0609     F_B1474
#define        PARPLC900_0610     F_B1476
#define        PARPLC900_0611     F_B1478
#define        PARPLC900_0612     F_B1480
#define        PARPLC900_0613     F_B1482
#define        PARPLC900_0614     F_B1484
#define        PARPLC900_0615     F_B1486
#define        PARPLC900_0616     F_B1488
#define        PARPLC900_0617     F_B1490
#define        PARPLC900_0618     F_B1492
#define        PARPLC900_0619     F_B1494
#define        PARPLC900_0620     F_B1496
#define        PARPLC900_0621     F_B1498
#define        PARPLC900_0622     F_B1500
#define        PARPLC900_0623     F_B1502
#define        PARPLC900_0624     F_B1504
#define        PARPLC900_0625     F_B1506
#define        PARPLC900_0626     F_B1508
#define        PARPLC900_0627     F_B1510
#define        PARPLC900_0628     F_B1512
#define        PARPLC900_0629     F_B1514
#define        PARPLC900_0630     F_B1516
#define        PARPLC900_0631     F_B1518
#define        PARPLC900_0632     F_B1520
#define        PARPLC900_0633     F_B1522
#define        PARPLC900_0634     F_B1524
#define        PARPLC900_0635     F_B1526
#define        PARPLC900_0636     F_B1528
#define        PARPLC900_0637     F_B1530
#define        PARPLC900_0638     F_B1532
#define        PARPLC900_0639     F_B1534
#define        PARPLC900_0640     F_B1536
#define        PARPLC900_0641     F_B1538
#define        PARPLC900_0642     F_B1540
#define        PARPLC900_0643     F_B1542
#define        PARPLC900_0644     F_B1544
#define        PARPLC900_0645     F_B1546
#define        PARPLC900_0646     F_B1548
#define        PARPLC900_0647     F_B1550
#define        PARPLC900_0648     F_B1552
#define        PARPLC900_0649     F_B1554
#define        PARPLC900_0650     F_B1556
#define        PARPLC900_0651     F_B1558
#define        PARPLC900_0652     F_B1560
#define        PARPLC900_0653     F_B1562
#define        PARPLC900_0654     F_B1564
#define        PARPLC900_0655     F_B1566
#define        PARPLC900_0656     F_B1568
#define        PARPLC900_0657     F_B1570
#define        PARPLC900_0658     F_B1572
#define        PARPLC900_0659     F_B1574
#define        PARPLC900_0660     F_B1576
#define        PARPLC900_0661     F_B1578
#define        PARPLC900_0662     F_B1580
#define        PARPLC900_0663     F_B1582
#define        PARPLC900_0664     F_B1584
#define        PARPLC900_0665     F_B1586
#define        PARPLC900_0666     F_B1588
#define        PARPLC900_0667     F_B1590
#define        PARPLC900_0668     F_B1592
#define        PARPLC900_0669     F_B1594
#define        PARPLC900_0670     F_B1596
#define        PARPLC900_0671     F_B1598
#define        PARPLC900_0672     F_B1600
#define        PARPLC900_0673     F_B1602
#define        PARPLC900_0674     F_B1604
#define        PARPLC900_0675     F_B1606
#define        PARPLC900_0676     F_B1608
#define        PARPLC900_0677     F_B1610
#define        PARPLC900_0678     F_B1612
#define        PARPLC900_0679     F_B1614
#define        PARPLC900_0680     F_B1616
#define        PARPLC900_0681     F_B1618
#define        PARPLC900_0682     F_B1620
#define        PARPLC900_0683     F_B1622
#define        PARPLC900_0684     F_B1624
#define        PARPLC900_0685     F_B1626
#define        PARPLC900_0686     F_B1628
#define        PARPLC900_0687     F_B1630
#define        PARPLC900_0688     F_B1632
#define        PARPLC900_0689     F_B1634
#define        PARPLC900_0690     F_B1636
#define        PARPLC900_0691     F_B1638
#define        PARPLC900_0692     F_B1640
#define        PARPLC900_0693     F_B1642
#define        PARPLC900_0694     F_B1644
#define        PARPLC900_0695     F_B1646
#define        PARPLC900_0696     F_B1648
#define        PARPLC900_0697     F_B1650
#define        PARPLC900_0698     F_B1652
#define        PARPLC900_0699     F_B1654
#define        PARPLC900_0700     F_B1656
#define        PARPLC900_0701     F_B1658
#define        PARPLC900_0702     F_B1660
#define        PARPLC900_0703     F_B1662
#define        PARPLC900_0704     F_B1664
#define        PARPLC900_0705     F_B1666
#define        PARPLC900_0706     F_B1668
#define        PARPLC900_0707     F_B1670
#define        PARPLC900_0708     F_B1672
#define        PARPLC900_0709     F_B1674
#define        PARPLC900_0710     F_B1676
#define        PARPLC900_0711     F_B1678
#define        PARPLC900_0712     F_B1680
#define        PARPLC900_0713     F_B1682
#define        PARPLC900_0714     F_B1684
#define        PARPLC900_0715     F_B1686
#define        PARPLC900_0716     F_B1688
#define        PARPLC900_0717     F_B1690
#define        PARPLC900_0718     F_B1692
#define        PARPLC900_0719     F_B1694
#define        PARPLC900_0720     F_B1696
#define        PARPLC900_0721     F_B1698
#define        PARPLC900_0722     F_B1700
#define        PARPLC900_0723     F_B1702
#define        PARPLC900_0724     F_B1704
#define        PARPLC900_0725     F_B1706
#define        PARPLC900_0726     F_B1708
#define        PARPLC900_0727     F_B1710
#define        PARPLC900_0728     F_B1712
#define        PARPLC900_0729     F_B1714
#define        PARPLC900_0730     F_B1716
#define        PARPLC900_0731     F_B1718
#define        PARPLC900_0732     F_B1720
#define        PARPLC900_0733     F_B1722
#define        PARPLC900_0734     F_B1724
#define        PARPLC900_0735     F_B1726
#define        PARPLC900_0736     F_B1728
#define        PARPLC900_0737     F_B1730
#define        PARPLC900_0738     F_B1732
#define        PARPLC900_0739     F_B1734
#define        PARPLC900_0740     F_B1736
#define        PARPLC900_0741     F_B1738
#define        PARPLC900_0742     F_B1740
#define        PARPLC900_0743     F_B1742
#define        PARPLC900_0744     F_B1744
#define        PARPLC900_0745     F_B1746
#define        PARPLC900_0746     F_B1748
#define        PARPLC900_0747     F_B1750
#define        PARPLC900_0748     F_B1752
#define        PARPLC900_0749     F_B1754
#define        PARPLC900_0750     F_B1756
#define        PARPLC900_0751     F_B1758
#define        PARPLC900_0752     F_B1760
#define        PARPLC900_0753     F_B1762
#define        PARPLC900_0754     F_B1764
#define        PARPLC900_0755     F_B1766
#define        PARPLC900_0756     F_B1768
#define        PARPLC900_0757     F_B1770
#define        PARPLC900_0758     F_B1772
#define        PARPLC900_0759     F_B1774
#define        PARPLC900_0760     F_B1776
#define        PARPLC900_0761     F_B1778
#define        PARPLC900_0762     F_B1780
#define        PARPLC900_0763     F_B1782
#define        PARPLC900_0764     F_B1784
#define        PARPLC900_0765     F_B1786
#define        PARPLC900_0766     F_B1788
#define        PARPLC900_0767     F_B1790
#define        PARPLC900_0768     F_B1792
#define        PARPLC900_0769     F_B1794
#define        PARPLC900_0770     F_B1796
#define        PARPLC900_0771     F_B1798
#define        PARPLC900_0772     F_B1800
#define        PARPLC900_0773     F_B1802
#define        PARPLC900_0774     F_B1804
#define        PARPLC900_0775     F_B1806
#define        PARPLC900_0776     F_B1808
#define        PARPLC900_0777     F_B1810
#define        PARPLC900_0778     F_B1812
#define        PARPLC900_0779     F_B1814
#define        PARPLC900_0780     F_B1816
#define        PARPLC900_0781     F_B1818
#define        PARPLC900_0782     F_B1820
#define        PARPLC900_0783     F_B1822
#define        PARPLC900_0784     F_B1824
#define        PARPLC900_0785     F_B1826
#define        PARPLC900_0786     F_B1828
#define        PARPLC900_0787     F_B1830
#define        PARPLC900_0788     F_B1832
#define        PARPLC900_0789     F_B1834
#define        PARPLC900_0790     F_B1836
#define        PARPLC900_0791     F_B1838
#define        PARPLC900_0792     F_B1840
#define        PARPLC900_0793     F_B1842
#define        PARPLC900_0794     F_B1844
#define        PARPLC900_0795     F_B1846
#define        PARPLC900_0796     F_B1848
#define        PARPLC900_0797     F_B1850
#define        PARPLC900_0798     F_B1852
#define        PARPLC900_0799     F_B1854
#define        PARPLC900_0800     F_B1856
#define        PARPLC900_0801     F_B1858
#define        PARPLC900_0802     F_B1860
#define        PARPLC900_0803     F_B1862
#define        PARPLC900_0804     F_B1864
#define        PARPLC900_0805     F_B1866
#define        PARPLC900_0806     F_B1868
#define        PARPLC900_0807     F_B1870
#define        PARPLC900_0808     F_B1872
#define        PARPLC900_0809     F_B1874
#define        PARPLC900_0810     F_B1876
#define        PARPLC900_0811     F_B1878
#define        PARPLC900_0812     F_B1880
#define        PARPLC900_0813     F_B1882
#define        PARPLC900_0814     F_B1884
#define        PARPLC900_0815     F_B1886
#define        PARPLC900_0816     F_B1888
#define        PARPLC900_0817     F_B1890
#define        PARPLC900_0818     F_B1892
#define        PARPLC900_0819     F_B1894
#define        PARPLC900_0820     F_B1896
#define        PARPLC900_0821     F_B1898
#define        PARPLC900_0822     F_B1900
#define        PARPLC900_0823     F_B1902
#define        PARPLC900_0824     F_B1904
#define        PARPLC900_0825     F_B1906
#define        PARPLC900_0826     F_B1908
#define        PARPLC900_0827     F_B1910
#define        PARPLC900_0828     F_B1912
#define        PARPLC900_0829     F_B1914
#define        PARPLC900_0830     F_B1916
#define        PARPLC900_0831     F_B1918
#define        PARPLC900_0832     F_B1920
#define        PARPLC900_0833     F_B1922
#define        PARPLC900_0834     F_B1924
#define        PARPLC900_0835     F_B1926
#define        PARPLC900_0836     F_B1928
#define        PARPLC900_0837     F_B1930
#define        PARPLC900_0838     F_B1932
#define        PARPLC900_0839     F_B1934
#define        PARPLC900_0840     F_B1936
#define        PARPLC900_0841     F_B1938
#define        PARPLC900_0842     F_B1940
#define        PARPLC900_0843     F_B1942
#define        PARPLC900_0844     F_B1944
#define        PARPLC900_0845     F_B1946
#define        PARPLC900_0846     F_B1948
#define        PARPLC900_0847     F_B1950
#define        PARPLC900_0848     F_B1952
#define        PARPLC900_0849     F_B1954
#define        PARPLC900_0850     F_B1956
#define        PARPLC900_0851     F_B1958
#define        PARPLC900_0852     F_B1960
#define        PARPLC900_0853     F_B1962
#define        PARPLC900_0854     F_B1964
#define        PARPLC900_0855     F_B1966
#define        PARPLC900_0856     F_B1968
#define        PARPLC900_0857     F_B1970
#define        PARPLC900_0858     F_B1972
#define        PARPLC900_0859     F_B1974
#define        PARPLC900_0860     F_B1976
#define        PARPLC900_0861     F_B1978
#define        PARPLC900_0862     F_B1980
#define        PARPLC900_0863     F_B1982
#define        PARPLC900_0864     F_B1984
#define        PARPLC900_0865     F_B1986
#define        PARPLC900_0866     F_B1988
#define        PARPLC900_0867     F_B1990
#define        PARPLC900_0868     F_B1992
#define        PARPLC900_0869     F_B1994
#define        PARPLC900_0870     F_B1996
#define        PARPLC900_0871     F_B1998
#define        PARPLC900_0872     F_B2000
#define        PARPLC900_0873     F_B2002
#define        PARPLC900_0874     F_B2004
#define        PARPLC900_0875     F_B2006
#define        PARPLC900_0876     F_B2008
#define        PARPLC900_0877     F_B2010
#define        PARPLC900_0878     F_B2012
#define        PARPLC900_0879     F_B2014
#define        PARPLC900_0880     F_B2016
#define        PARPLC900_0881     F_B2018
#define        PARPLC900_0882     F_B2020
#define        PARPLC900_0883     F_B2022
#define        PARPLC900_0884     F_B2024
#define        PARPLC900_0885     F_B2026
#define        PARPLC900_0886     F_B2028
#define        PARPLC900_0887     F_B2030
#define        PARPLC900_0888     F_B2032
#define        PARPLC900_0889     F_B2034
#define        PARPLC900_0890     F_B2036
#define        PARPLC900_0891     F_B2038
#define        PARPLC900_0892     F_B2040
#define        PARPLC900_0893     F_B2042
#define        PARPLC900_0894     F_B2044
#define        PARPLC900_0895     F_B2046
#define        PARPLC900_0896     F_B2048
#define        PARPLC900_0897     F_B2050
#define        PARPLC900_0898     F_B2052
#define        PARPLC900_0899     F_B2054
#define        PARPLC900_0900     F_B2056
#define        PARPLC900_0901     F_B2058
#define        PARPLC900_0902     F_B2060
#define        PARPLC900_0903     F_B2062
#define        PARPLC900_0904     F_B2064
#define        PARPLC900_0905     F_B2066
#define        PARPLC900_0906     F_B2068
#define        PARPLC900_0907     F_B2070
#define        PARPLC900_0908     F_B2072
#define        PARPLC900_0909     F_B2074
#define        PARPLC900_0910     F_B2076
#define        PARPLC900_0911     F_B2078
#define        PARPLC900_0912     F_B2080
#define        PARPLC900_0913     F_B2082
#define        PARPLC900_0914     F_B2084
#define        PARPLC900_0915     F_B2086
#define        PARPLC900_0916     F_B2088
#define        PARPLC900_0917     F_B2090
#define        PARPLC900_0918     F_B2092
#define        PARPLC900_0919     F_B2094
#define        PARPLC900_0920     F_B2096
#define        PARPLC900_0921     F_B2098
#define        PARPLC900_0922     F_B2100
#define        PARPLC900_0923     F_B2102
#define        PARPLC900_0924     F_B2104
#define        PARPLC900_0925     F_B2106
#define        PARPLC900_0926     F_B2108
#define        PARPLC900_0927     F_B2110
#define        PARPLC900_0928     F_B2112
#define        PARPLC900_0929     F_B2114
#define        PARPLC900_0930     F_B2116
#define        PARPLC900_0931     F_B2118
#define        PARPLC900_0932     F_B2120
#define        PARPLC900_0933     F_B2122
#define        PARPLC900_0934     F_B2124
#define        PARPLC900_0935     F_B2126
#define        PARPLC900_0936     F_B2128
#define        PARPLC900_0937     F_B2130
#define        PARPLC900_0938     F_B2132
#define        PARPLC900_0939     F_B2134
#define        PARPLC900_0940     F_B2136
#define        PARPLC900_0941     F_B2138
#define        PARPLC900_0942     F_B2140
#define        PARPLC900_0943     F_B2142
#define        PARPLC900_0944     F_B2144
#define        PARPLC900_0945     F_B2146
#define        PARPLC900_0946     F_B2148
#define        PARPLC900_0947     F_B2150
#define        PARPLC900_0948     F_B2152
#define        PARPLC900_0949     F_B2154
#define        PARPLC900_0950     F_B2156
#define        PARPLC900_0951     F_B2158
#define        PARPLC900_0952     F_B2160
#define        PARPLC900_0953     F_B2162
#define        PARPLC900_0954     F_B2164
#define        PARPLC900_0955     F_B2166
#define        PARPLC900_0956     F_B2168
#define        PARPLC900_0957     F_B2170
#define        PARPLC900_0958     F_B2172
#define        PARPLC900_0959     F_B2174
#define        PARPLC900_0960     F_B2176
#define        PARPLC900_0961     F_B2178
#define        PARPLC900_0962     F_B2180
#define        PARPLC900_0963     F_B2182
#define        PARPLC900_0964     F_B2184
#define        PARPLC900_0965     F_B2186
#define        PARPLC900_0966     F_B2188
#define        PARPLC900_0967     F_B2190
#define        PARPLC900_0968     F_B2192
#define        PARPLC900_0969     F_B2194
#define        PARPLC900_0970     F_B2196
#define        PARPLC900_0971     F_B2198
#define        PARPLC900_0972     F_B2200
#define        PARPLC900_0973     F_B2202
#define        PARPLC900_0974     F_B2204
#define        PARPLC900_0975     F_B2206
#define        PARPLC900_0976     F_B2208
#define        PARPLC900_0977     F_B2210
#define        PARPLC900_0978     F_B2212
#define        PARPLC900_0979     F_B2214
#define        PARPLC900_0980     F_B2216
#define        PARPLC900_0981     F_B2218
#define        PARPLC900_0982     F_B2220
#define        PARPLC900_0983     F_B2222
#define        PARPLC900_0984     F_B2224
#define        PARPLC900_0985     F_B2226
#define        PARPLC900_0986     F_B2228
#define        PARPLC900_0987     F_B2230
#define        PARPLC900_0988     F_B2232
#define        PARPLC900_0989     F_B2234
#define        PARPLC900_0990     F_B2236
#define        PARPLC900_0991     F_B2238
#define        PARPLC900_0992     F_B2240
#define        PARPLC900_0993     F_B2242
#define        PARPLC900_0994     F_B2244
#define        PARPLC900_0995     F_B2246
#define        PARPLC900_0996     F_B2248
#define        PARPLC900_0997     F_B2250
#define        PARPLC900_0998     F_B2252
#define        PARPLC900_0999     F_B2254
/* PARAMETRI 0000 -:- 0999 PER WINDOW PLC (Primo parametro) */
/* 00 -:- 0999 PARAMETERS FOR PLC WINDOW (First Parameter) */

/***********  FINE AREE F_Bxx  *****************/

/* ------------------------------------ */
/*          VARIABILI STRINGA           */
/* ------------------------------------ */

#define        PARPLCSTR_000     p_dplc->wcs[0].s
#define        PARPLCSTR_001     p_dplc->wcs[1].s
#define        PARPLCSTR_002     p_dplc->wcs[2].s
#define        PARPLCSTR_003     p_dplc->wcs[3].s
#define        PARPLCSTR_004     p_dplc->wcs[4].s
#define        PARPLCSTR_005     p_dplc->wcs[5].s
#define        PARPLCSTR_006     p_dplc->wcs[6].s
#define        PARPLCSTR_007     p_dplc->wcs[7].s
#define        PARPLCSTR_008     p_dplc->wcs[8].s
#define        PARPLCSTR_009     p_dplc->wcs[9].s
#define        PARPLCSTR_010     p_dplc->wcs[10].s
#define        PARPLCSTR_011     p_dplc->wcs[11].s
#define        PARPLCSTR_012     p_dplc->wcs[12].s
#define        PARPLCSTR_013     p_dplc->wcs[13].s
#define        PARPLCSTR_014     p_dplc->wcs[14].s
#define        PARPLCSTR_015     p_dplc->wcs[15].s
#define        PARPLCSTR_016     p_dplc->wcs[16].s
#define        PARPLCSTR_017     p_dplc->wcs[17].s
#define        PARPLCSTR_018     p_dplc->wcs[18].s
#define        PARPLCSTR_019     p_dplc->wcs[19].s
#define        PARPLCSTR_020     p_dplc->wcs[20].s
#define        PARPLCSTR_021     p_dplc->wcs[21].s
#define        PARPLCSTR_022     p_dplc->wcs[22].s
#define        PARPLCSTR_023     p_dplc->wcs[23].s
#define        PARPLCSTR_024     p_dplc->wcs[24].s
#define        PARPLCSTR_025     p_dplc->wcs[25].s
#define        PARPLCSTR_026     p_dplc->wcs[26].s
#define        PARPLCSTR_027     p_dplc->wcs[27].s
#define        PARPLCSTR_028     p_dplc->wcs[28].s
#define        PARPLCSTR_029     p_dplc->wcs[29].s
#define        PARPLCSTR_030     p_dplc->wcs[30].s
#define        PARPLCSTR_031     p_dplc->wcs[31].s
#define        PARPLCSTR_032     p_dplc->wcs[32].s
#define        PARPLCSTR_033     p_dplc->wcs[33].s
#define        PARPLCSTR_034     p_dplc->wcs[34].s
#define        PARPLCSTR_035     p_dplc->wcs[35].s
#define        PARPLCSTR_036     p_dplc->wcs[36].s
#define        PARPLCSTR_037     p_dplc->wcs[37].s
#define        PARPLCSTR_038     p_dplc->wcs[38].s
#define        PARPLCSTR_039     p_dplc->wcs[39].s
#define        PARPLCSTR_040     p_dplc->wcs[40].s
#define        PARPLCSTR_041     p_dplc->wcs[41].s
#define        PARPLCSTR_042     p_dplc->wcs[42].s
#define        PARPLCSTR_043     p_dplc->wcs[43].s
#define        PARPLCSTR_044     p_dplc->wcs[44].s
#define        PARPLCSTR_045     p_dplc->wcs[45].s
#define        PARPLCSTR_046     p_dplc->wcs[46].s
#define        PARPLCSTR_047     p_dplc->wcs[47].s
#define        PARPLCSTR_048     p_dplc->wcs[48].s
#define        PARPLCSTR_049     p_dplc->wcs[49].s
#define        PARPLCSTR_050     p_dplc->wcs[50].s
#define        PARPLCSTR_051     p_dplc->wcs[51].s
#define        PARPLCSTR_052     p_dplc->wcs[52].s
#define        PARPLCSTR_053     p_dplc->wcs[53].s
#define        PARPLCSTR_054     p_dplc->wcs[54].s
#define        PARPLCSTR_055     p_dplc->wcs[55].s
#define        PARPLCSTR_056     p_dplc->wcs[56].s
#define        PARPLCSTR_057     p_dplc->wcs[57].s
#define        PARPLCSTR_058     p_dplc->wcs[58].s
#define        PARPLCSTR_059     p_dplc->wcs[59].s
#define        PARPLCSTR_060     p_dplc->wcs[60].s
#define        PARPLCSTR_061     p_dplc->wcs[61].s
#define        PARPLCSTR_062     p_dplc->wcs[62].s
#define        PARPLCSTR_063     p_dplc->wcs[63].s
#define        PARPLCSTR_064     p_dplc->wcs[64].s
#define        PARPLCSTR_065     p_dplc->wcs[65].s
#define        PARPLCSTR_066     p_dplc->wcs[66].s
#define        PARPLCSTR_067     p_dplc->wcs[67].s
#define        PARPLCSTR_068     p_dplc->wcs[68].s
#define        PARPLCSTR_069     p_dplc->wcs[69].s
#define        PARPLCSTR_070     p_dplc->wcs[70].s
#define        PARPLCSTR_071     p_dplc->wcs[71].s
#define        PARPLCSTR_072     p_dplc->wcs[72].s
#define        PARPLCSTR_073     p_dplc->wcs[73].s
#define        PARPLCSTR_074     p_dplc->wcs[74].s
#define        PARPLCSTR_075     p_dplc->wcs[75].s
#define        PARPLCSTR_076     p_dplc->wcs[76].s
#define        PARPLCSTR_077     p_dplc->wcs[77].s
#define        PARPLCSTR_078     p_dplc->wcs[78].s
#define        PARPLCSTR_079     p_dplc->wcs[79].s
#define        PARPLCSTR_080     p_dplc->wcs[80].s
#define        PARPLCSTR_081     p_dplc->wcs[81].s
#define        PARPLCSTR_082     p_dplc->wcs[82].s
#define        PARPLCSTR_083     p_dplc->wcs[83].s
#define        PARPLCSTR_084     p_dplc->wcs[84].s
#define        PARPLCSTR_085     p_dplc->wcs[85].s
#define        PARPLCSTR_086     p_dplc->wcs[86].s
#define        PARPLCSTR_087     p_dplc->wcs[87].s
#define        PARPLCSTR_088     p_dplc->wcs[88].s
#define        PARPLCSTR_089     p_dplc->wcs[89].s
#define        PARPLCSTR_090     p_dplc->wcs[90].s
#define        PARPLCSTR_091     p_dplc->wcs[91].s
#define        PARPLCSTR_092     p_dplc->wcs[92].s
#define        PARPLCSTR_093     p_dplc->wcs[93].s
#define        PARPLCSTR_094     p_dplc->wcs[94].s
#define        PARPLCSTR_095     p_dplc->wcs[95].s
#define        PARPLCSTR_096     p_dplc->wcs[96].s
#define        PARPLCSTR_097     p_dplc->wcs[97].s
#define        PARPLCSTR_098     p_dplc->wcs[98].s
#define        PARPLCSTR_099     p_dplc->wcs[99].s
#define        PARPLCSTR_100     p_dplc->wcs[100].s
#define        PARPLCSTR_101     p_dplc->wcs[101].s
#define        PARPLCSTR_102     p_dplc->wcs[102].s
#define        PARPLCSTR_103     p_dplc->wcs[103].s
#define        PARPLCSTR_104     p_dplc->wcs[104].s
#define        PARPLCSTR_105     p_dplc->wcs[105].s
#define        PARPLCSTR_106     p_dplc->wcs[106].s
#define        PARPLCSTR_107     p_dplc->wcs[107].s
#define        PARPLCSTR_108     p_dplc->wcs[108].s
#define        PARPLCSTR_109     p_dplc->wcs[109].s
#define        PARPLCSTR_110     p_dplc->wcs[110].s
#define        PARPLCSTR_111     p_dplc->wcs[111].s
#define        PARPLCSTR_112     p_dplc->wcs[112].s
#define        PARPLCSTR_113     p_dplc->wcs[113].s
#define        PARPLCSTR_114     p_dplc->wcs[114].s
#define        PARPLCSTR_115     p_dplc->wcs[115].s
#define        PARPLCSTR_116     p_dplc->wcs[116].s
#define        PARPLCSTR_117     p_dplc->wcs[117].s
#define        PARPLCSTR_118     p_dplc->wcs[118].s
#define        PARPLCSTR_119     p_dplc->wcs[119].s
#define        PARPLCSTR_120     p_dplc->wcs[120].s
#define        PARPLCSTR_121     p_dplc->wcs[121].s
#define        PARPLCSTR_122     p_dplc->wcs[122].s
#define        PARPLCSTR_123     p_dplc->wcs[123].s
#define        PARPLCSTR_124     p_dplc->wcs[124].s
#define        PARPLCSTR_125     p_dplc->wcs[125].s
#define        PARPLCSTR_126     p_dplc->wcs[126].s
#define        PARPLCSTR_127     p_dplc->wcs[127].s

///#ifdef QAL_SLOW  abilita sinonimi anche per plc slow
	// Richiesta di definire solo variabili R e PARPLC900 per Slow PLC.
///#else

// Area variabili stringa
#define    ASWCS_0000    p_dplc->aswcs[0].s
#define    ASWCS_0001    p_dplc->aswcs[1].s
#define    ASWCS_0002    p_dplc->aswcs[2].s
#define    ASWCS_0003    p_dplc->aswcs[3].s
#define    ASWCS_0004    p_dplc->aswcs[4].s
#define    ASWCS_0005    p_dplc->aswcs[5].s
#define    ASWCS_0006    p_dplc->aswcs[6].s
#define    ASWCS_0007    p_dplc->aswcs[7].s
#define    ASWCS_0008    p_dplc->aswcs[8].s
#define    ASWCS_0009    p_dplc->aswcs[9].s
#define    ASWCS_0010    p_dplc->aswcs[10].s
#define    ASWCS_0011    p_dplc->aswcs[11].s
#define    ASWCS_0012    p_dplc->aswcs[12].s
#define    ASWCS_0013    p_dplc->aswcs[13].s
#define    ASWCS_0014    p_dplc->aswcs[14].s
#define    ASWCS_0015    p_dplc->aswcs[15].s
#define    ASWCS_0016    p_dplc->aswcs[16].s
#define    ASWCS_0017    p_dplc->aswcs[17].s
#define    ASWCS_0018    p_dplc->aswcs[18].s
#define    ASWCS_0019    p_dplc->aswcs[19].s
#define    ASWCS_0020    p_dplc->aswcs[20].s
#define    ASWCS_0021    p_dplc->aswcs[21].s
#define    ASWCS_0022    p_dplc->aswcs[22].s
#define    ASWCS_0023    p_dplc->aswcs[23].s
#define    ASWCS_0024    p_dplc->aswcs[24].s
#define    ASWCS_0025    p_dplc->aswcs[25].s
#define    ASWCS_0026    p_dplc->aswcs[26].s
#define    ASWCS_0027    p_dplc->aswcs[27].s
#define    ASWCS_0028    p_dplc->aswcs[28].s
#define    ASWCS_0029    p_dplc->aswcs[29].s
#define    ASWCS_0030    p_dplc->aswcs[30].s
#define    ASWCS_0031    p_dplc->aswcs[31].s
#define    ASWCS_0032    p_dplc->aswcs[32].s
#define    ASWCS_0033    p_dplc->aswcs[33].s
#define    ASWCS_0034    p_dplc->aswcs[34].s
#define    ASWCS_0035    p_dplc->aswcs[35].s
#define    ASWCS_0036    p_dplc->aswcs[36].s
#define    ASWCS_0037    p_dplc->aswcs[37].s
#define    ASWCS_0038    p_dplc->aswcs[38].s
#define    ASWCS_0039    p_dplc->aswcs[39].s
#define    ASWCS_0040    p_dplc->aswcs[40].s
#define    ASWCS_0041    p_dplc->aswcs[41].s
#define    ASWCS_0042    p_dplc->aswcs[42].s
#define    ASWCS_0043    p_dplc->aswcs[43].s
#define    ASWCS_0044    p_dplc->aswcs[44].s
#define    ASWCS_0045    p_dplc->aswcs[45].s
#define    ASWCS_0046    p_dplc->aswcs[46].s
#define    ASWCS_0047    p_dplc->aswcs[47].s
#define    ASWCS_0048    p_dplc->aswcs[48].s
#define    ASWCS_0049    p_dplc->aswcs[49].s
#define    ASWCS_0050    p_dplc->aswcs[50].s
#define    ASWCS_0051    p_dplc->aswcs[51].s
#define    ASWCS_0052    p_dplc->aswcs[52].s
#define    ASWCS_0053    p_dplc->aswcs[53].s
#define    ASWCS_0054    p_dplc->aswcs[54].s
#define    ASWCS_0055    p_dplc->aswcs[55].s
#define    ASWCS_0056    p_dplc->aswcs[56].s
#define    ASWCS_0057    p_dplc->aswcs[57].s
#define    ASWCS_0058    p_dplc->aswcs[58].s
#define    ASWCS_0059    p_dplc->aswcs[59].s
#define    ASWCS_0060    p_dplc->aswcs[60].s
#define    ASWCS_0061    p_dplc->aswcs[61].s
#define    ASWCS_0062    p_dplc->aswcs[62].s
#define    ASWCS_0063    p_dplc->aswcs[63].s

/*********  FINE VARIABILI STRINGA  *************/


#define        ACKKCN       acknow
/* ACK A  KCN (VARIE) */
/* ACK to KCN (SUNDRIES) */


/***********************************************/
/* VALORI in doppia precisione (numeri reali), */
/* espressi IN MICRON, delle correzioni assi   */
/* controllate da PLC (correzioni esterne).    */
/***********************************************/

#define        ICORAX0      pio->corr_ext[0].val_input
/* VALORE COMPENSAZIONE TERMICA SU ASSE ORDINE 0 */
/* THERMAL COMPENSATION VALUE ON ORDER #0 AXIS */
#define        ICORAX1      pio->corr_ext[1].val_input
#define        ICORAX2      pio->corr_ext[2].val_input
#define        ICORAX3      pio->corr_ext[3].val_input
#define        ICORAX4      pio->corr_ext[4].val_input
#define        ICORAX5      pio->corr_ext[5].val_input
#define        ICORAX6      pio->corr_ext[6].val_input
#define        ICORAX7      pio->corr_ext[7].val_input
#define        ICORAX8      pio->corr_ext[8].val_input
#define        ICORAX9      pio->corr_ext[9].val_input
#define        ICORAX10     pio->corr_ext[10].val_input
#define        ICORAX11     pio->corr_ext[11].val_input
#define        ICORAX12     pio->corr_ext[12].val_input
#define        ICORAX13     pio->corr_ext[13].val_input
#define        ICORAX14     pio->corr_ext[14].val_input
#define        ICORAX15     pio->corr_ext[15].val_input
/* VALORE COMPENSAZIONE TERMICA SU ASSE ORDINE 15 */
/* THERMAL COMPENSATION VALUE ON ORDER #15 AXIS */

/* --------------------------------------- 	*/
/*           INIZIO TASTIERA CNC900			*/
/*                 JOYSTICK					*/
/*				  VOLANTINI					*/
/*	Gestione override incrementali			*/
/* ---------------------------------------- */
#define        STBKCN       strobe
/* STROBE TASTIERA */
/* KEYBOARD STROBE */

#define        OPZION       keyopz
/* BYTE OPZIONI E TASTIERA PRESENTI */
/* OPTIONS AND KEYBOARD BYTE */

#define        K900_JVALX	joystickX
/* VALORE JOYSTICK ASSE X */
/* VALORE JOYSTICK ASSE X */

#define        K900_JVALY	joystickY
/* VALORE JOYSTICK ASSE Y */
/* VALORE JOYSTICK ASSE Y */

#define        K900_JVALZ	joystickZ
/* VALORE JOYSTICK ASSE Z */
/* VALORE JOYSTICK ASSE Z */

#define        IKMUSEL	KMU_Select
/* TASTIERA 091F211 richiesta  */
/* KEYBOARD 091F211 requested  */

#define        OKMUSEL	KMU_Active
/* TASTIERA 091F211 attiva  */
/* KEYBOARD 091F211 active  */

#define        VOL1K900     keyvol1
/* VALORE VOLANTINO 1 CON INPUT DA TAST. */
/* VALUE OF HANDWHEEL WITH INPUT ON KEYB. */

#define        VOL2K900     keyvol2
/* VALORE VOLANTINO 2 CON INPUT DA TAST. */
/* VALUE OF HANDWHEEL WITH INPUT ON KEYB. */

#define        VOL3K900     keyvol3
/* VALORE VOLANTINO 3 CON INPUT DA TAST. */
/* VALUE OF HANDWHEEL WITH INPUT ON KEYB. */

#define        AIOVF        keyovf
/* VALORE OVERRIDE FEED ASSI DA TAST. */
/* AXES FEED OVERRIDE VALUE FROM KEYB. */

#define        AIOVS        keyovs
/* VALORE OVERRIDE SPEED MANDRINO DA TAST. */
/* SPINDLE SPEED OVERRIDE VALUE FROM KEYB. */

#define        AIOVR        keyovr
/* VALORE OVERRIDE RAPIDO ASSI DA TAST. */
/* AXES RAPID OVERRIDE VALUE FROM KEYB. */
#define        OPZION       keyopz
/* BYTE OPZIONI E TASTIERA PRESENTI */
/* OPTIONS AND KEYBOARD BYTE */

#define        KCNOUTB      keyout
/* WORD USCITE SU TASTIERA (DA AGGIORNARE) */
/* OUTPUTS BYTE ON KEYBOARD (TO UPDATE) */

#define        LKCNOUTB     last_keyout
/* ULTIMO BYTE USCITE SU TASTIERA AGGIORNATO */
/* LAST OUTPUTS KEYBOARD BYTE UPDATED */

#define        VVOL         keyvol1
/* VALORE VOLANTINO CON INPUT DA TASTIERA */
/* VALUE OF HANDWHEEL WITH INPUT ON KEYBOARD */

#define        KCNINPW      keyinp
/* WORD INGRESSI DA TASTIERA  */
/* INPUTS WORD FROM KEYBOARD  */

#define        MEMOVF        MemOvrF
/* MEMORIA VALORE ULTIMO INDICE OVERRIDE FEED; utilizzato solo da gestovr3()  */
/* VALUE MEMORY OF LAST FEED OVERRIDE INDEX; used only by gestovr3() */

#define        MEMOVS        MemOvrS
/* MEMORIA VALORE ULTIMO INDICE OVERRIDE SPEED MANDRINO PRINCIPALE; utilizzato solo da gestovr3() */
/* VALUE MEMORY OF LAST SPINDLE SPEED OVERRIDE INDEX; used only by gestovr3() */

#define        MEMOVR        MemOvrR
/* MEMORIA VALORE ULTIMO INDICE OVERRIDE RAPIDO; utilizzato solo dal gestovr3() */
/* VALUE MEMORY OF LAST RAPID OVERRIDE INDEX; used only by gestovr3() */

#define        MEMOVSS        MemOvrSS
/* MEMORIA VALORE ULTIMO INDICE OVERRIDE SPEED MANDRINO SECONDARIO; utilizzato solo da gestovr3() */
/* VALUE MEMORY OF LAST SECONDARY SPINDLE SPEED OVERRIDE INDEX; used only by gestovr3() */

#define			TIPOVF		TipoOvrF
/* TIPO OVERRIDE DI FEED RILEVATO DA SCHEDA TASTIERA */
/* FEED OVVERIDE TYPE DETECTED BY MACHINE KEYBOARD   */

#define			TIPOVR		TipoOvrR
/* TIPO OVERRIDE DI RAPIDO RILEVATO DA SCHEDA TASTIERA */
/* RAPID OVVERIDE TYPE DETECTED BY MACHINE KEYBOARD   */

#define			TIPOVS		TipoOvrS
/* TIPO OVERRIDE DI SPEED RILEVATO DA SCHEDA TASTIERA */
/* SPEED OVVERIDE TYPE DETECTED BY MACHINE KEYBOARD   */

#define TIPOVSS				TipoOvrSS
/* MEMORIA VALORE ULTIMO INDICE OVERRIDE SPEED MANDRINO SECONDARIO; utilizzato solo da gestovr3() */
/* VALUE MEMORY OF LAST SECONDARY SPINDLE SPEED OVERRIDE INDEX; used only by gestovr3() */


/* ---------------------------------------- */
/*           FINE TASTIERA CNC900			*/
/* ---------------------------------------- */

/**************************************************/
/*     INIZIO DEFINE INPUT / OUTPUT  ASSI         */
/**************************************************/

/* --------------------------------------- */
/*          INPUT ASSE  0  WORD 0          */
/* --------------------------------------- */

#define        IEME0        AX00.bit._00
/* RICHIESTA EMERGENZA ASSE 0 (ASSI o MANDRINO) */
/* AXIS 0 EMERGENCY REQUEST (AXES or SPINDLE) */

#define        ISGA0        AX00.bit._01
/* RICHIESTA SGANCIO ASSE 0 CON RESET (ASSI o MANDRINO) */
/* AXIS 0 RELEASE REQUEST with RESET (AXES or SPINDLE) */

#define        IANA0        AX00.bit._02
/* ANNULLA MOVIMENTO IN CORSO ASSE FRE 0 */
/* CANCELLATION OF THE MOVEMENT IN PROGRESS ON FRE AXIS 0 */

#define        IHLD0        AX00.bit._03
/* HOLD ASSE FRE 0 */
/* HOLD FOR FRE AXIS 0 */

#define        IBLC0        AX00.bit._04
/* ASSE 0 BLOCCATO MECCANICAMENTE (ASSI o MANDRINO)*/
/* AXIS 0 MECHANICALLY CLAMPED (AXES or SPINDLE)*/

#define        ILS0         AX00.bit._05
/* RICHIESTA DI LIBERA SERVO ASSE 0 (ASSI o MANDRINO) */
/* FREE SERVO request for AXIS 0 (AXES or SPINDLE) */

#define        INAL0        AX00.bit._06
/* NON FARE BLOCCO E ALLARME ASSE 0 SU CN (ASSI o MANDRINO); VALIDO SE ASSE FRE O ILSx=1 */
/* DOESN'T DO BLOCK AND ALARM AXIS 0 ON CN (AXES or SPINDLE); VALID IF AXIS FREE OR ILSx=1 */

#define        IDGOFF0      AX00.bit._07
/* RICHIESTA DRIVE DIGITALE ASSE 0 OFF (SPENTO) (ASSI o MANDRINO; IDDCOM EDDCOM) */
/* AXIS 0 DIGITAL DRIVE SWITCH OFF REQUEST (AXES or SPINDLE; IDDCOM EDDCOM) */

#define        IBSET0       AX00.bit._08
/* RICHIESTA DI PERDITA DEL SET ASSE 0 (ASSI o MANDRINO) */
/* LOSS request for AXIS 0 SET (AXES or SPINDLE) */

#define        IDGTAR0      AX00.bit._09
/* RICHIESTA MODO TARATURA DRIVE DIGITALE SERCOS ASSE 0 (ASSI o MANDRINO) */
/* SETTING MODE REQUEST FOR AXIS 0 SERCOS DIGITAL DRIVE (AXES or SPINDLE) */

#define        IDRVON0      AX00.bit._10
/* DRIVE ON, ENABLE del DRIVE DIGITALE - ASSE 0 (ASSI o MANDRINO) */
/* DRIVE ON, ENABLE of the AXIS 0 - DIGITAL DRIVE (AXES or SPINDLE) */

#define        IAXOFF0      AX00.bit._11
/* RICHIESTA ASSE 0 OFF (ASSE IN LIBERA SERVO) (ASSI o MANDRINO; IDDCOM EDDCOM); Richiesta diretta */
/* OFF AXIS 0 request (SERVO AXIS FREE) (AXES or SPINDLE; IDDCOM EDDCOM); direct request */

#define        ISAM0        AX00.bit._12
/* RICHIESTA SOSPENSIONE ALLARME FUGA VELOCITA ASSE 0 (solo MANDRINO) */
/* VELOCITY ESCAPE ALARM SUSPENSION REQUEST (only SPINDLE) */

#define        IANQE0       AX00.bit._13
/* RICHIESTA AZZERA ERRORE QE per ASSE 0 FREE  */
/* ZERO ERROR REQUEST FOR AXIS 0 FREE          */

#define			IATT0		AX00.bit._14
/* RICHIESTA ATTIVAZIONE ASSE IN UN GRUPPO */
/* AXIS IN A GROUP ACTIVATION REQUEST	   */

/* --------------------------------------- */
/*        OUTPUT ASSE  0   WORD 1          */
/* --------------------------------------- */

#define        OBOK0        AX01.bit._08
/* ASSE 0 NON IN ALLARME (ASSI o MANDRINO)*/
/* AXIS 0 NOT IN ALARM (AXES or SPINDLE)*/

#define        OBAT0        AX01.bit._09
/* ATTENZIONE SU ASSE 0 (ASSI o MANDRINO) */
/* ATTENTION ON AXIS 0 (AXES or SPINDLE) */

#define        OBNT0        AX01.bit._12
/* COMANDO IN CORSO ASSE 0 (ASSE FRE o MANDRINO) */
/* COMMAND IN PROGRESS ON AXIS 0 (FRE AXIS or SPINDLE) */

#define        OBNP0        AX01.bit._13
/* COMANDO ASSE 0 ESEGUITO IN PIU' FASI (ASSE FRE o MANDRINO) */
/* AXIS 0 COMMAND PERFORMED IN MORE PHASES (FRE AXIS or SPINDLE) */

/* --------------------------------------- */
/*        OUTPUT ASSE  0   WORD 2          */
/* --------------------------------------- */

#define        OBM00        AX02.bit._00
/* MICRO 0: MARKER ASSE 0 (ASSI o MANDRINO) */
/* MICRO 0: AXIS 0 MARKER (AXES or SPINDLE) */

#define        OBM10        AX02.bit._01
/* MICRO 1: CAMMA ASSE 0 (ASSI o MANDRINO) */
/* MICRO 1: AXIS 0 CAM (AXES or SPINDLE) */

#define        OBSF0        AX02.bit._03
/* SE ='1' REF NEGATIVO ASSE 0 (ASSI o MANDRINO) */
/* if ='1' NEGATIVE REFERENCE FOR AXIS 0 (AXES or SPINDLE) */

#define        OBSE0        AX02.bit._04
/* SET ASSE 0 ESEGUITO (ASSI o MANDRINO) */
/* AXIS 0 SET PERFORMED (AXES or SPINDLE) */

#define        OBCN0        AX02.bit._06
/* ASSE 0 AGGANCIATO IN CONTOURING (ASSI o MANDRINO) */
/* AXIS 0 HOOKED IN CONTOURING (AXES or SPINDLE) */

#define        OBAG0        AX02.bit._07
/* ASSE 0 AGGANCIATO IN PT. A PT. (ASSI o MANDRINO) */
/* AXIS 0 HOOKED IN POINT TO POINT (AXES or SPINDLE) */

#define        OBCG0        AX02.bit._08
/* VELOCITA DI CAMBIO GAMMA MANDRINO ASSE 0 RAGGIUNTA */
/* SPEED OF SPINDLE GEAR CHANGE (AXIS 0) REACHED */

#define        OBVV0        AX02.bit._09
/* ASSE 0 AGGANCIATO IN VELOCITA' (ASSI o MANDRINO) */
/* AXIS 0 HOOKED IN VELOCITY (AXES or SPINDLE) */

#define        OSOK0        AX02.bit._10
/* VELOCITA' MANDRINO ASSE 0 OK */
/* SPINDLE SPEED (AXIS 0) OK */

#define        OBGG0        AX02.bit._11
/* ASSE 0 AGGANCIATO IN GANTRY */
/* AXIS 0 HOOKED IN GANTRY MODE */

#define        OBSP0        AX02.bit._12
/* ASSE 0 IN MODO STEP (VARIE)*/
/* AXIS 0 IN STEP MODE (SUNDRIES)*/

#define        OBIN0        AX02.bit._13
/* MOVIMENTO ASSE 0 INDIETRO */
/* AXIS 0 MOVEMENT BACK */

#define        OBMT0        AX02.bit._14
/* ASSE 0 IN MOTO (ASSE FRE o MANDRINO)*/
/* AXIS 0 IN MOTION (FRE AXIS or SPINDLE) */

#define        OBNA0        AX02.bit._15
/* ASSE 0 NON ARRIVATO (ASSE FRE o MANDRINO)*/
/* AXIS 0 NOT IN POSITION (FRE AXIS or SPINDLE) */

/* --------------------------------------- */
/*        OUTPUT ASSE  0   WORD 3          */
/* --------------------------------------- */

#define        OBLC0        AX03.bit._04
/* ASSE 0 BLOCCABILE MECCANICAMENTE (ASSI o MANDRINO)*/
/* AXIS 0 MECHANICALLY CLAMPABLE (AXES or SPINDLE)*/

#define        OLS0         AX03.bit._05
/* ASSE 0 IN LIBERA SERVO (ASSI o MANDRINO)*/
/* AXIS 0 IN FREE SERVO (AXES or SPINDLE)*/

#define        OSTM0        AX03.bit._06
/* MANDRINO ASSE 0 IN SOGLIA DI STOP */
/* AXIS 0 SPINDLE IN STANDSTILL THRESHOLD */

#define			OATT0		AX03.bit._07
/* ASSE ATTIVATO TRA ALTERNATIVI	 */
/* AXIS ACTIVATED IN A GROUP		 */


/* --------------------------------------- */
/*        OUTPUT ASSE  0   WORD 4          */
/* --------------------------------------- */

#define        OPND0        AX04.bit._00
/* ASSE 0 PENDOLANTE */
/* AXIS 0 HUNTING */

#define        OPQ120       AX04.bit._01
/* ASSE 0 PENDOLANTE FRA 2 QUOTE */
/* AXIS 0 HUNTING BETWEEN 2 DIMENSIONS */

#define        OPVQ10       AX04.bit._02
/* ASSE 0 PENDOLANTE DEVE RAGGIUNGERE LA QUOTA Q1 */
/* AXIS 0 HUNTING HAS TO REACH THE Q1 DIMENSION */

#define        OBGSET0      AX04.bit._03
/* ASSE 0 ASSOLUTO AGGANCIATO IN GANTRY DA RIALLINEARE */
/* ABSOLUTE AXIS 0 HOOKED IN GANTRY NEEDS TO BE LINED UP */

#define        OPSGL0       AX04.bit._05
/* ASSE 0 NON ENTRATO IN SOGLIA SGL DI AXS.TAR (ASSI)*/
/* AXIS 0 DOESN'T GO INTO SGL THRESHOLD OF AXS.TAR (AXES)*/

#define        OPFRM0       AX04.bit._06
/* ASSE 0 NON IN MOTO IN SOGLIA E FERMO (ASSI)*/
/* AXIS 0 NOT IN MOTION, IN THRESHOLD AND STOPPED (AXES)*/

#define        OBGM0        AX04.bit._07
/* ASSE 0 AGGANCIATO IN GANTRY: ASSE MASTER */
/* AXIS 0 HOOKED IN GANTRY: MASTER AXIS */

#define        OBSET0       AX04.bit._08
/* PERDITA DEL SET ASSE 0 A CAUSA DEL SEGNALE IBSET0 */
/* LOSS OF THE AXIS 0 SET DUE TO THE IBSET0 SIGNAL */

#define        OBALAX0      AX04.bit._09
/* SEGNALAZIONE ALLARME ASSE 0 */
/* AXIS 0 ALARM SIGNALING */

#define        ONBAGM0      AX04.bit._10
/* ASSE 0 SGANCIATO IN MOVIMENTO (valido se !OBAG0 -asse sganciato) */
/* UNHOOKED AXIS 0 IN MOVEMENT (valid if !OBAG0 -axis unhooked) */

#define        OSAMAC0      AX04.bit._12
/* SEGNALA RICHIESTA SOSPENSIONE ALLARME MANDRINO IN ACCELERAZIONE. */
/* SPINDLE IN ACCELERATION ALARM SUSPENSION REQUEST  */

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  1  WORD 0          */
/* --------------------------------------- */
#define        IEME1        AX10.bit._00
#define        ISGA1        AX10.bit._01
#define        IANA1        AX10.bit._02
#define        IHLD1        AX10.bit._03
#define        IBLC1        AX10.bit._04
#define        ILS1         AX10.bit._05
#define        INAL1        AX10.bit._06
#define        IDGOFF1      AX10.bit._07
#define        IBSET1       AX10.bit._08
#define        IDGTAR1      AX10.bit._09
#define        IDRVON1      AX10.bit._10
#define        IAXOFF1      AX10.bit._11
#define        ISAM1        AX10.bit._12
#define        IANQE1       AX10.bit._13
#define		   IATT1		AX10.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  1   WORD 1          */
/* --------------------------------------- */
#define        OBOK1        AX11.bit._08
#define        OBAT1        AX11.bit._09
#define        OBNT1        AX11.bit._12
#define        OBNP1        AX11.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  1   WORD 2          */
/* --------------------------------------- */
#define        OBM01        AX12.bit._00
#define        OBM11        AX12.bit._01
#define        OBSF1        AX12.bit._03
#define        OBSE1        AX12.bit._04
#define        OBCN1        AX12.bit._06
#define        OBAG1        AX12.bit._07
#define        OBCG1        AX12.bit._08
#define        OBVV1        AX12.bit._09
#define        OSOK1        AX12.bit._10
#define        OBGG1        AX12.bit._11
#define        OBSP1        AX12.bit._12
#define        OBIN1        AX12.bit._13
#define        OBMT1        AX12.bit._14
#define        OBNA1        AX12.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  1   WORD 3          */
/* --------------------------------------- */
#define        OBLC1        AX13.bit._04
#define        OLS1         AX13.bit._05
#define        OSTM1        AX13.bit._06
#define		   OATT1		AX13.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  1   WORD 4          */
/* --------------------------------------- */
#define        OPND1        AX14.bit._00
#define        OPQ121       AX14.bit._01
#define        OPVQ11       AX14.bit._02
#define        OBGSET1      AX14.bit._03
#define        OPSGL1       AX14.bit._05
#define        OPFRM1       AX14.bit._06
#define        OBGM1        AX14.bit._07
#define        OBSET1       AX14.bit._08
#define        OBALAX1      AX14.bit._09
#define        ONBAGM1      AX14.bit._10
#define        OSAMAC1      AX14.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  2  WORD 0          */
/* --------------------------------------- */
#define        IEME2        AX20.bit._00
#define        ISGA2        AX20.bit._01
#define        IANA2        AX20.bit._02
#define        IHLD2        AX20.bit._03
#define        IBLC2        AX20.bit._04
#define        ILS2         AX20.bit._05
#define        INAL2        AX20.bit._06
#define        IDGOFF2      AX20.bit._07
#define        IBSET2       AX20.bit._08
#define        IDGTAR2      AX20.bit._09
#define        IDRVON2      AX20.bit._10
#define        IAXOFF2      AX20.bit._11
#define        ISAM2        AX20.bit._12
#define        IANQE2       AX20.bit._13
#define		   IATT2		AX20.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  2   WORD 1          */
/* --------------------------------------- */
#define        OBOK2        AX21.bit._08
#define        OBAT2        AX21.bit._09
#define        OBNT2        AX21.bit._12
#define        OBNP2        AX21.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  2   WORD 2          */
/* --------------------------------------- */
#define        OBM02        AX22.bit._00
#define        OBM12        AX22.bit._01
#define        OBSF2        AX22.bit._03
#define        OBSE2        AX22.bit._04
#define        OBCN2        AX22.bit._06
#define        OBAG2        AX22.bit._07
#define        OBCG2        AX22.bit._08
#define        OBVV2        AX22.bit._09
#define        OSOK2        AX22.bit._10
#define        OBGG2        AX22.bit._11
#define        OBSP2        AX22.bit._12
#define        OBIN2        AX22.bit._13
#define        OBMT2        AX22.bit._14
#define        OBNA2        AX22.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  2   WORD 3          */
/* --------------------------------------- */
#define        OBLC2        AX23.bit._04
#define        OLS2         AX23.bit._05
#define        OSTM2        AX23.bit._06
#define		   OATT2		AX23.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  2   WORD 4          */
/* --------------------------------------- */
#define        OPND2        AX24.bit._00
#define        OPQ122       AX24.bit._01
#define        OPVQ12       AX24.bit._02
#define        OBGSET2      AX24.bit._03
#define        OPSGL2       AX24.bit._05
#define        OPFRM2       AX24.bit._06
#define        OBGM2        AX24.bit._07
#define        OBSET2       AX24.bit._08
#define        OBALAX2      AX24.bit._09
#define        ONBAGM2      AX24.bit._10
#define        OSAMAC2      AX24.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  3  WORD 0          */
/* --------------------------------------- */
#define        IEME3        AX30.bit._00
#define        ISGA3        AX30.bit._01
#define        IANA3        AX30.bit._02
#define        IHLD3        AX30.bit._03
#define        IBLC3        AX30.bit._04
#define        ILS3         AX30.bit._05
#define        INAL3        AX30.bit._06
#define        IDGOFF3      AX30.bit._07
#define        IBSET3       AX30.bit._08
#define        IDGTAR3      AX30.bit._09
#define        IDRVON3      AX30.bit._10
#define        IAXOFF3      AX30.bit._11
#define        ISAM3        AX30.bit._12
#define        IANQE3       AX30.bit._13
#define		   IATT3		AX30.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  3   WORD 1          */
/* --------------------------------------- */
#define        OBOK3        AX31.bit._08
#define        OBAT3        AX31.bit._09
#define        OBNT3        AX31.bit._12
#define        OBNP3        AX31.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  3   WORD 2          */
/* --------------------------------------- */
#define        OBM03        AX32.bit._00
#define        OBM13        AX32.bit._01
#define        OBSF3        AX32.bit._03
#define        OBSE3        AX32.bit._04
#define        OBCN3        AX32.bit._06
#define        OBAG3        AX32.bit._07
#define        OBCG3        AX32.bit._08
#define        OBVV3        AX32.bit._09
#define        OSOK3        AX32.bit._10
#define        OBGG3        AX32.bit._11
#define        OBSP3        AX32.bit._12
#define        OBIN3        AX32.bit._13
#define        OBMT3        AX32.bit._14
#define        OBNA3        AX32.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  3   WORD 3          */
/* --------------------------------------- */
#define        OBLC3        AX33.bit._04
#define        OLS3         AX33.bit._05
#define        OSTM3        AX33.bit._06
#define		   OATT3		AX33.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  3   WORD 4          */
/* --------------------------------------- */
#define        OPND3        AX34.bit._00
#define        OPQ123       AX34.bit._01
#define        OPVQ13       AX34.bit._02
#define        OBGSET3      AX34.bit._03
#define        OPSGL3       AX34.bit._05
#define        OPFRM3       AX34.bit._06
#define        OBGM3        AX34.bit._07
#define        OBSET3       AX34.bit._08
#define        OBALAX3      AX34.bit._09
#define        ONBAGM3      AX34.bit._10
#define        OSAMAC3      AX34.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  4  WORD 0          */
/* --------------------------------------- */
#define        IEME4        AX40.bit._00
#define        ISGA4        AX40.bit._01
#define        IANA4        AX40.bit._02
#define        IHLD4        AX40.bit._03
#define        IBLC4        AX40.bit._04
#define        ILS4         AX40.bit._05
#define        INAL4        AX40.bit._06
#define        IDGOFF4      AX40.bit._07
#define        IBSET4       AX40.bit._08
#define        IDGTAR4      AX40.bit._09
#define        IDRVON4      AX40.bit._10
#define        IAXOFF4      AX40.bit._11
#define        ISAM4        AX40.bit._12
#define        IANQE4       AX40.bit._13
#define		   IATT4		AX40.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  4   WORD 1          */
/* --------------------------------------- */
#define        OBOK4        AX41.bit._08
#define        OBAT4        AX41.bit._09
#define        OBNT4        AX41.bit._12
#define        OBNP4        AX41.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  4   WORD 2          */
/* --------------------------------------- */
#define        OBM04        AX42.bit._00
#define        OBM14        AX42.bit._01
#define        OBSF4        AX42.bit._03
#define        OBSE4        AX42.bit._04
#define        OBCN4        AX42.bit._06
#define        OBAG4        AX42.bit._07
#define        OBCG4        AX42.bit._08
#define        OBVV4        AX42.bit._09
#define        OSOK4        AX42.bit._10
#define        OBGG4        AX42.bit._11
#define        OBSP4        AX42.bit._12
#define        OBIN4        AX42.bit._13
#define        OBMT4        AX42.bit._14
#define        OBNA4        AX42.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  4   WORD 3          */
/* --------------------------------------- */
#define        OBLC4        AX43.bit._04
#define        OLS4         AX43.bit._05
#define        OSTM4        AX43.bit._06
#define		   OATT4		AX43.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  4   WORD 4          */
/* --------------------------------------- */
#define        OPND4        AX44.bit._00
#define        OPQ124       AX44.bit._01
#define        OPVQ14       AX44.bit._02
#define        OBGSET4      AX44.bit._03
#define        OPSGL4       AX44.bit._05
#define        OPFRM4       AX44.bit._06
#define        OBGM4        AX44.bit._07
#define        OBSET4       AX44.bit._08
#define        OBALAX4      AX44.bit._09
#define        ONBAGM4      AX44.bit._10
#define        OSAMAC4      AX44.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  5  WORD 0          */
/* --------------------------------------- */
#define        IEME5        AX50.bit._00
#define        ISGA5        AX50.bit._01
#define        IANA5        AX50.bit._02
#define        IHLD5        AX50.bit._03
#define        IBLC5        AX50.bit._04
#define        ILS5         AX50.bit._05
#define        INAL5        AX50.bit._06
#define        IDGOFF5      AX50.bit._07
#define        IBSET5       AX50.bit._08
#define        IDGTAR5      AX50.bit._09
#define        IDRVON5      AX50.bit._10
#define        IAXOFF5      AX50.bit._11
#define        ISAM5        AX50.bit._12
#define        IANQE5       AX50.bit._13
#define		   IATT5		AX50.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  5   WORD 1          */
/* --------------------------------------- */
#define        OBOK5        AX51.bit._08
#define        OBAT5        AX51.bit._09
#define        OBNT5        AX51.bit._12
#define        OBNP5        AX51.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  5   WORD 2          */
/* --------------------------------------- */
#define        OBM05        AX52.bit._00
#define        OBM15        AX52.bit._01
#define        OBSF5        AX52.bit._03
#define        OBSE5        AX52.bit._04
#define        OBCN5        AX52.bit._06
#define        OBAG5        AX52.bit._07
#define        OBCG5        AX52.bit._08
#define        OBVV5        AX52.bit._09
#define        OSOK5        AX52.bit._10
#define        OBGG5        AX52.bit._11
#define        OBSP5        AX52.bit._12
#define        OBIN5        AX52.bit._13
#define        OBMT5        AX52.bit._14
#define        OBNA5        AX52.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  5   WORD 3          */
/* --------------------------------------- */
#define        OBLC5        AX53.bit._04
#define        OLS5         AX53.bit._05
#define        OSTM5        AX53.bit._06
#define		   OATT5		AX53.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  5   WORD 4          */
/* --------------------------------------- */
#define        OPND5        AX54.bit._00
#define        OPQ125       AX54.bit._01
#define        OPVQ15       AX54.bit._02
#define        OBGSET5      AX54.bit._03
#define        OPSGL5       AX54.bit._05
#define        OPFRM5       AX54.bit._06
#define        OBGM5        AX54.bit._07
#define        OBSET5       AX54.bit._08
#define        OBALAX5      AX54.bit._09
#define        ONBAGM5      AX54.bit._10
#define        OSAMAC5      AX54.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  6  WORD 0          */
/* --------------------------------------- */
#define        IEME6        AX60.bit._00
#define        ISGA6        AX60.bit._01
#define        IANA6        AX60.bit._02
#define        IHLD6        AX60.bit._03
#define        IBLC6        AX60.bit._04
#define        ILS6         AX60.bit._05
#define        INAL6        AX60.bit._06
#define        IDGOFF6      AX60.bit._07
#define        IBSET6       AX60.bit._08
#define        IDGTAR6      AX60.bit._09
#define        IDRVON6      AX60.bit._10
#define        IAXOFF6      AX60.bit._11
#define        ISAM6        AX60.bit._12
#define        IANQE6       AX60.bit._13
#define		   IATT6		AX60.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  6   WORD 1          */
/* --------------------------------------- */
#define        OBOK6        AX61.bit._08
#define        OBAT6        AX61.bit._09
#define        OBNT6        AX61.bit._12
#define        OBNP6        AX61.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  6   WORD 2          */
/* --------------------------------------- */
#define        OBM06        AX62.bit._00
#define        OBM16        AX62.bit._01
#define        OBSF6        AX62.bit._03
#define        OBSE6        AX62.bit._04
#define        OBCN6        AX62.bit._06
#define        OBAG6        AX62.bit._07
#define        OBCG6        AX62.bit._08
#define        OBVV6        AX62.bit._09
#define        OSOK6        AX62.bit._10
#define        OBGG6        AX62.bit._11
#define        OBSP6        AX62.bit._12
#define        OBIN6        AX62.bit._13
#define        OBMT6        AX62.bit._14
#define        OBNA6        AX62.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  6   WORD 3          */
/* --------------------------------------- */
#define        OBLC6        AX63.bit._04
#define        OLS6         AX63.bit._05
#define        OSTM6        AX63.bit._06
#define		   OATT6		AX63.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  6   WORD 4          */
/* --------------------------------------- */
#define        OPND6        AX64.bit._00
#define        OPQ126       AX64.bit._01
#define        OPVQ16       AX64.bit._02
#define        OBGSET6      AX64.bit._03
#define        OPSGL6       AX64.bit._05
#define        OPFRM6       AX64.bit._06
#define        OBGM6        AX64.bit._07
#define        OBSET6       AX64.bit._08
#define        OBALAX6      AX64.bit._09
#define        ONBAGM6      AX64.bit._10
#define        OSAMAC6      AX64.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  7  WORD 0          */
/* --------------------------------------- */
#define        IEME7        AX70.bit._00
#define        ISGA7        AX70.bit._01
#define        IANA7        AX70.bit._02
#define        IHLD7        AX70.bit._03
#define        IBLC7        AX70.bit._04
#define        ILS7         AX70.bit._05
#define        INAL7        AX70.bit._06
#define        IDGOFF7      AX70.bit._07
#define        IBSET7       AX70.bit._08
#define        IDGTAR7      AX70.bit._09
#define        IDRVON7      AX70.bit._10
#define        IAXOFF7      AX70.bit._11
#define        ISAM7        AX70.bit._12
#define        IANQE7       AX70.bit._13
#define		   IATT7		AX70.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  7   WORD 1          */
/* --------------------------------------- */
#define        OBOK7        AX71.bit._08
#define        OBAT7        AX71.bit._09
#define        OBNT7        AX71.bit._12
#define        OBNP7        AX71.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  7   WORD 2          */
/* --------------------------------------- */
#define        OBM07        AX72.bit._00
#define        OBM17        AX72.bit._01
#define        OBSF7        AX72.bit._03
#define        OBSE7        AX72.bit._04
#define        OBCN7        AX72.bit._06
#define        OBAG7        AX72.bit._07
#define        OBCG7        AX72.bit._08
#define        OBVV7        AX72.bit._09
#define        OSOK7        AX72.bit._10
#define        OBGG7        AX72.bit._11
#define        OBSP7        AX72.bit._12
#define        OBIN7        AX72.bit._13
#define        OBMT7        AX72.bit._14
#define        OBNA7        AX72.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  7   WORD 3          */
/* --------------------------------------- */
#define        OBLC7        AX73.bit._04
#define        OLS7         AX73.bit._05
#define        OSTM7        AX73.bit._06
#define		   OATT7		AX73.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  7   WORD 4          */
/* --------------------------------------- */
#define        OPND7        AX74.bit._00
#define        OPQ127       AX74.bit._01
#define        OPVQ17       AX74.bit._02
#define        OBGSET7      AX74.bit._03
#define        OPSGL7       AX74.bit._05
#define        OPFRM7       AX74.bit._06
#define        OBGM7        AX74.bit._07
#define        OBSET7       AX74.bit._08
#define        OBALAX7      AX74.bit._09
#define        ONBAGM7      AX74.bit._10
#define        OSAMAC7      AX74.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  8  WORD 0          */
/* --------------------------------------- */
#define        IEME8        AX80.bit._00
#define        ISGA8        AX80.bit._01
#define        IANA8        AX80.bit._02
#define        IHLD8        AX80.bit._03
#define        IBLC8        AX80.bit._04
#define        ILS8         AX80.bit._05
#define        INAL8        AX80.bit._06
#define        IDGOFF8      AX80.bit._07
#define        IBSET8       AX80.bit._08
#define        IDGTAR8      AX80.bit._09
#define        IDRVON8      AX80.bit._10
#define        IAXOFF8      AX80.bit._11
#define        ISAM8        AX80.bit._12
#define        IANQE8       AX80.bit._13
#define		   IATT8		AX80.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  8   WORD 1          */
/* --------------------------------------- */
#define        OBOK8        AX81.bit._08
#define        OBAT8        AX81.bit._09
#define        OBNT8        AX81.bit._12
#define        OBNP8        AX81.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  8   WORD 2          */
/* --------------------------------------- */
#define        OBM08        AX82.bit._00
#define        OBM18        AX82.bit._01
#define        OBSF8        AX82.bit._03
#define        OBSE8        AX82.bit._04
#define        OBCN8        AX82.bit._06
#define        OBAG8        AX82.bit._07
#define        OBCG8        AX82.bit._08
#define        OBVV8        AX82.bit._09
#define        OSOK8        AX82.bit._10
#define        OBGG8        AX82.bit._11
#define        OBSP8        AX82.bit._12
#define        OBIN8        AX82.bit._13
#define        OBMT8        AX82.bit._14
#define        OBNA8        AX82.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  8   WORD 3          */
/* --------------------------------------- */
#define        OBLC8        AX83.bit._04
#define        OLS8         AX83.bit._05
#define        OSTM8        AX83.bit._06
#define		   OATT8		AX83.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  8   WORD 4          */
/* --------------------------------------- */
#define        OPND8        AX84.bit._00
#define        OPQ128       AX84.bit._01
#define        OPVQ18       AX84.bit._02
#define        OBGSET8      AX84.bit._03
#define        OPSGL8       AX84.bit._05
#define        OPFRM8       AX84.bit._06
#define        OBGM8        AX84.bit._07
#define        OBSET8       AX84.bit._08
#define        OBALAX8      AX84.bit._09
#define        ONBAGM8      AX84.bit._10
#define        OSAMAC8      AX84.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  9  WORD 0          */
/* --------------------------------------- */
#define        IEME9        AX90.bit._00
#define        ISGA9        AX90.bit._01
#define        IANA9        AX90.bit._02
#define        IHLD9        AX90.bit._03
#define        IBLC9        AX90.bit._04
#define        ILS9         AX90.bit._05
#define        INAL9        AX90.bit._06
#define        IDGOFF9      AX90.bit._07
#define        IBSET9       AX90.bit._08
#define        IDGTAR9      AX90.bit._09
#define        IDRVON9      AX90.bit._10
#define        IAXOFF9      AX90.bit._11
#define        ISAM9        AX90.bit._12
#define        IANQE9       AX90.bit._13
#define		   IATT9		AX90.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  9   WORD 1          */
/* --------------------------------------- */
#define        OBOK9        AX91.bit._08
#define        OBAT9        AX91.bit._09
#define        OBNT9        AX91.bit._12
#define        OBNP9        AX91.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  9   WORD 2          */
/* --------------------------------------- */
#define        OBM09        AX92.bit._00
#define        OBM19        AX92.bit._01
#define        OBSF9        AX92.bit._03
#define        OBSE9        AX92.bit._04
#define        OBCN9        AX92.bit._06
#define        OBAG9        AX92.bit._07
#define        OBCG9        AX92.bit._08
#define        OBVV9        AX92.bit._09
#define        OSOK9        AX92.bit._10
#define        OBGG9        AX92.bit._11
#define        OBSP9        AX92.bit._12
#define        OBIN9        AX92.bit._13
#define        OBMT9        AX92.bit._14
#define        OBNA9        AX92.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  9   WORD 3          */
/* --------------------------------------- */
#define        OBLC9        AX93.bit._04
#define        OLS9         AX93.bit._05
#define        OSTM9        AX93.bit._06
#define		   OATT9		AX93.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  9   WORD 4          */
/* --------------------------------------- */
#define        OPND9        AX94.bit._00
#define        OPQ129       AX94.bit._01
#define        OPVQ19       AX94.bit._02
#define        OBGSET9      AX94.bit._03
#define        OPSGL9       AX94.bit._05
#define        OPFRM9       AX94.bit._06
#define        OBGM9        AX94.bit._07
#define        OBSET9       AX94.bit._08
#define        OBALAX9      AX94.bit._09
#define        ONBAGM9      AX94.bit._10
#define        OSAMAC9      AX94.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  10  WORD 0         */
/* --------------------------------------- */
#define        IEME10       AX100.bit._00
#define        ISGA10       AX100.bit._01
#define        IANA10       AX100.bit._02
#define        IHLD10       AX100.bit._03
#define        IBLC10       AX100.bit._04
#define        ILS10        AX100.bit._05
#define        INAL10       AX100.bit._06
#define        IDGOFF10     AX100.bit._07
#define        IBSET10      AX100.bit._08
#define        IDGTAR10     AX100.bit._09
#define        IDRVON10     AX100.bit._10
#define        IAXOFF10     AX100.bit._11
#define        ISAM10       AX100.bit._12
#define        IANQE10      AX100.bit._13
#define		   IATT10		AX100.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  10   WORD 1         */
/* --------------------------------------- */
#define        OBOK10       AX101.bit._08
#define        OBAT10       AX101.bit._09
#define        OBNT10       AX101.bit._12
#define        OBNP10       AX101.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  10   WORD 2         */
/* --------------------------------------- */
#define        OBM010       AX102.bit._00
#define        OBM110       AX102.bit._01
#define        OBSF10       AX102.bit._03
#define        OBSE10       AX102.bit._04
#define        OBCN10       AX102.bit._06
#define        OBAG10       AX102.bit._07
#define        OBCG10       AX102.bit._08
#define        OBVV10       AX102.bit._09
#define        OSOK10       AX102.bit._10
#define        OBGG10       AX102.bit._11
#define        OBSP10       AX102.bit._12
#define        OBIN10       AX102.bit._13
#define        OBMT10       AX102.bit._14
#define        OBNA10       AX102.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  10   WORD 3         */
/* --------------------------------------- */
#define        OBLC10       AX103.bit._04
#define        OLS10        AX103.bit._05
#define        OSTM10       AX103.bit._06
#define		   OATT10		AX103.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  10   WORD 4         */
/* --------------------------------------- */
#define        OPND10       AX104.bit._00
#define        OPQ1210      AX104.bit._01
#define        OPVQ110      AX104.bit._02
#define        OBGSET10     AX104.bit._03
#define        OPSGL10      AX104.bit._05
#define        OPFRM10      AX104.bit._06
#define        OBGM10       AX104.bit._07
#define        OBSET10      AX104.bit._08
#define        OBALAX10     AX104.bit._09
#define        ONBAGM10     AX104.bit._10
#define        OSAMAC10     AX104.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  11  WORD 0         */
/* --------------------------------------- */
#define        IEME11       AX110.bit._00
#define        ISGA11       AX110.bit._01
#define        IANA11       AX110.bit._02
#define        IHLD11       AX110.bit._03
#define        IBLC11       AX110.bit._04
#define        ILS11        AX110.bit._05
#define        INAL11       AX110.bit._06
#define        IDGOFF11     AX110.bit._07
#define        IBSET11      AX110.bit._08
#define        IDGTAR11     AX110.bit._09
#define        IDRVON11     AX110.bit._10
#define        IAXOFF11     AX110.bit._11
#define        ISAM11       AX110.bit._12
#define        IANQE11      AX110.bit._13
#define		   IATT11		AX110.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  11   WORD 1         */
/* --------------------------------------- */
#define        OBOK11       AX111.bit._08
#define        OBAT11       AX111.bit._09
#define        OBNT11       AX111.bit._12
#define        OBNP11       AX111.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  11   WORD 2         */
/* --------------------------------------- */
#define        OBM011       AX112.bit._00
#define        OBM111       AX112.bit._01
#define        OBSF11       AX112.bit._03
#define        OBSE11       AX112.bit._04
#define        OBCN11       AX112.bit._06
#define        OBAG11       AX112.bit._07
#define        OBCG11       AX112.bit._08
#define        OBVV11       AX112.bit._09
#define        OSOK11       AX112.bit._10
#define        OBGG11       AX112.bit._11
#define        OBSP11       AX112.bit._12
#define        OBIN11       AX112.bit._13
#define        OBMT11       AX112.bit._14
#define        OBNA11       AX112.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  11   WORD 3         */
/* --------------------------------------- */
#define        OBLC11       AX113.bit._04
#define        OLS11        AX113.bit._05
#define        OSTM11       AX113.bit._06
#define		   OATT11		AX113.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  11   WORD 4         */
/* --------------------------------------- */
#define        OPND11       AX114.bit._00
#define        OPQ1211      AX114.bit._01
#define        OPVQ111      AX114.bit._02
#define        OBGSET11     AX114.bit._03
#define        OPSGL11      AX114.bit._05
#define        OPFRM11      AX114.bit._06
#define        OBGM11       AX114.bit._07
#define        OBSET11      AX114.bit._08
#define        OBALAX11     AX114.bit._09
#define        ONBAGM11     AX114.bit._10
#define        OSAMAC11     AX114.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  12  WORD 0         */
/* --------------------------------------- */
#define        IEME12       AX120.bit._00
#define        ISGA12       AX120.bit._01
#define        IANA12       AX120.bit._02
#define        IHLD12       AX120.bit._03
#define        IBLC12       AX120.bit._04
#define        ILS12        AX120.bit._05
#define        INAL12       AX120.bit._06
#define        IDGOFF12     AX120.bit._07
#define        IBSET12      AX120.bit._08
#define        IDGTAR12     AX120.bit._09
#define        IDRVON12     AX120.bit._10
#define        IAXOFF12     AX120.bit._11
#define        ISAM12       AX120.bit._12
#define        IANQE12      AX120.bit._13
#define		   IATT12		AX120.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  12   WORD 1         */
/* --------------------------------------- */
#define        OBOK12       AX121.bit._08
#define        OBAT12       AX121.bit._09
#define        OBNT12       AX121.bit._12
#define        OBNP12       AX121.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  12   WORD 2         */
/* --------------------------------------- */
#define        OBM012       AX122.bit._00
#define        OBM112       AX122.bit._01
#define        OBSF12       AX122.bit._03
#define        OBSE12       AX122.bit._04
#define        OBCN12       AX122.bit._06
#define        OBAG12       AX122.bit._07
#define        OBCG12       AX122.bit._08
#define        OBVV12       AX122.bit._09
#define        OSOK12       AX122.bit._10
#define        OBGG12       AX122.bit._11
#define        OBSP12       AX122.bit._12
#define        OBIN12       AX122.bit._13
#define        OBMT12       AX122.bit._14
#define        OBNA12       AX122.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  12   WORD 3         */
/* --------------------------------------- */
#define        OBLC12       AX123.bit._04
#define        OLS12        AX123.bit._05
#define        OSTM12       AX123.bit._06
#define		   OATT12		AX123.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  12   WORD 4         */
/* --------------------------------------- */
#define        OPND12       AX124.bit._00
#define        OPQ1212      AX124.bit._01
#define        OPVQ112      AX124.bit._02
#define        OBGSET12     AX124.bit._03
#define        OPSGL12      AX124.bit._05
#define        OPFRM12      AX124.bit._06
#define        OBGM12       AX124.bit._07
#define        OBSET12      AX124.bit._08
#define        OBALAX12     AX124.bit._09
#define        ONBAGM12     AX124.bit._10
#define        OSAMAC12     AX124.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  13  WORD 0         */
/* --------------------------------------- */
#define        IEME13       AX130.bit._00
#define        ISGA13       AX130.bit._01
#define        IANA13       AX130.bit._02
#define        IHLD13       AX130.bit._03
#define        IBLC13       AX130.bit._04
#define        ILS13        AX130.bit._05
#define        INAL13       AX130.bit._06
#define        IDGOFF13     AX130.bit._07
#define        IBSET13      AX130.bit._08
#define        IDGTAR13     AX130.bit._09
#define        IDRVON13     AX130.bit._10
#define        IAXOFF13     AX130.bit._11
#define        ISAM13       AX130.bit._12
#define        IANQE13      AX130.bit._13
#define		   IATT13		AX130.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  13   WORD 1         */
/* --------------------------------------- */
#define        OBOK13       AX131.bit._08
#define        OBAT13       AX131.bit._09
#define        OBNT13       AX131.bit._12
#define        OBNP13       AX131.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  13   WORD 2         */
/* --------------------------------------- */
#define        OBM013       AX132.bit._00
#define        OBM113       AX132.bit._01
#define        OBSF13       AX132.bit._03
#define        OBSE13       AX132.bit._04
#define        OBCN13       AX132.bit._06
#define        OBAG13       AX132.bit._07
#define        OBCG13       AX132.bit._08
#define        OBVV13       AX132.bit._09
#define        OSOK13       AX132.bit._10
#define        OBGG13       AX132.bit._11
#define        OBSP13       AX132.bit._12
#define        OBIN13       AX132.bit._13
#define        OBMT13       AX132.bit._14
#define        OBNA13       AX132.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  13   WORD 3         */
/* --------------------------------------- */
#define        OBLC13       AX133.bit._04
#define        OLS13        AX133.bit._05
#define        OSTM13       AX133.bit._06
#define		   OATT13		AX133.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  13   WORD 4         */
/* --------------------------------------- */
#define        OPND13       AX134.bit._00
#define        OPQ1213      AX134.bit._01
#define        OPVQ113      AX134.bit._02
#define        OBGSET13     AX134.bit._03
#define        OPSGL13      AX134.bit._05
#define        OPFRM13      AX134.bit._06
#define        OBGM13       AX134.bit._07
#define        OBSET13      AX134.bit._08
#define        OBALAX13     AX134.bit._09
#define        ONBAGM13     AX134.bit._10
#define        OSAMAC13     AX134.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  14  WORD 0         */
/* --------------------------------------- */
#define        IEME14       AX140.bit._00
#define        ISGA14       AX140.bit._01
#define        IANA14       AX140.bit._02
#define        IHLD14       AX140.bit._03
#define        IBLC14       AX140.bit._04
#define        ILS14        AX140.bit._05
#define        INAL14       AX140.bit._06
#define        IDGOFF14     AX140.bit._07
#define        IBSET14      AX140.bit._08
#define        IDGTAR14     AX140.bit._09
#define        IDRVON14     AX140.bit._10
#define        IAXOFF14     AX140.bit._11
#define        ISAM14       AX140.bit._12
#define        IANQE14      AX140.bit._13
#define		   IATT14		AX140.bit._14

/* --------------------------------------- */
/*        OUTPUT ASSE  14   WORD 1         */
/* --------------------------------------- */
#define        OBOK14       AX141.bit._08
#define        OBAT14       AX141.bit._09
#define        OBNT14       AX141.bit._12
#define        OBNP14       AX141.bit._13

/* --------------------------------------- */
/*        OUTPUT ASSE  14   WORD 2         */
/* --------------------------------------- */
#define        OBM014       AX142.bit._00
#define        OBM114       AX142.bit._01
#define        OBSF14       AX142.bit._03
#define        OBSE14       AX142.bit._04
#define        OBCN14       AX142.bit._06
#define        OBAG14       AX142.bit._07
#define        OBCG14       AX142.bit._08
#define        OBVV14       AX142.bit._09
#define        OSOK14       AX142.bit._10
#define        OBGG14       AX142.bit._11
#define        OBSP14       AX142.bit._12
#define        OBIN14       AX142.bit._13
#define        OBMT14       AX142.bit._14
#define        OBNA14       AX142.bit._15

/* --------------------------------------- */
/*        OUTPUT ASSE  14   WORD 3         */
/* --------------------------------------- */
#define        OBLC14       AX143.bit._04
#define        OLS14        AX143.bit._05
#define        OSTM14       AX143.bit._06
#define		   OATT14		AX143.bit._07

/* --------------------------------------- */
/*        OUTPUT ASSE  14   WORD 4         */
/* --------------------------------------- */
#define        OPND14       AX144.bit._00
#define        OPQ1214      AX144.bit._01
#define        OPVQ114      AX144.bit._02
#define        OBGSET14     AX144.bit._03
#define        OPSGL14      AX144.bit._05
#define        OPFRM14      AX144.bit._06
#define        OBGM14       AX144.bit._07
#define        OBSET14      AX144.bit._08
#define        OBALAX14     AX144.bit._09
#define        ONBAGM14     AX144.bit._10
#define        OSAMAC14     AX144.bit._12

/*******************************************/
/* --------------------------------------- */
/*          INPUT ASSE  15  WORD 0         */
/* --------------------------------------- */

#define        IEME15       AX150.bit._00
/* RICHIESTA EMERGENZA ASSE 15 (ASSI o MANDRINO) */
/* AXIS 15 EMERGENCY REQUEST (AXES or SPINDLE) */

#define        ISGA15       AX150.bit._01
/* RICHIESTA SGANCIO ASSE 15 CON RESET (ASSI o MANDRINO) */
/* AXIS 15 RELEASE REQUEST with RESET (AXES or SPINDLE) */

#define        IANA15       AX150.bit._02
/* ANNULLA MOVIMENTO IN CORSO ASSE FRE 15 */
/* CANCELLATION OF THE MOVEMENT IN PROGRESS ON FRE AXIS 15 */

#define        IHLD15       AX150.bit._03
/* HOLD ASSE FRE 15 */
/* HOLD FOR FRE AXIS 15 */

#define        IBLC15       AX150.bit._04
/* ASSE 15 BLOCCATO MECCANICAMENTE (ASSI o MANDRINO)*/
/* AXIS 15 MECHANICALLY CLAMPED (AXES or SPINDLE)*/

#define        ILS15        AX150.bit._05
/* RICHIESTA DI LIBERA SERVO ASSE 15 (ASSI o MANDRINO) */
/* FREE SERVO request for AXIS 15 (AXES or SPINDLE) */

#define        INAL15       AX150.bit._06
/* NON FARE BLOCCO E ALLARME ASSE 15 SU CN (ASSI o MANDRINO); VALIDO SE ASSE FRE O ILSx=1 */
/* DOESN'T DO BLOCK AND ALARM AXIS 15 ON CN (AXES or SPINDLE); VALID IF AXIS FREE OR ILSx=1 */

#define        IDGOFF15     AX150.bit._07
/* RICHIESTA DRIVE DIGITALE ASSE 15 OFF (SPENTO) (ASSI o MANDRINO; IDDCOM EDDCOM) */
/* AXIS 15 DIGITAL DRIVE SWITCH OFF REQUEST (AXES or SPINDLE; IDDCOM EDDCOM) */

#define        IBSET15      AX150.bit._08
/* RICHIESTA DI PERDITA DEL SET ASSE 15 (ASSI o MANDRINO) */
/* LOSS request for AXIS 15 SET (AXES or SPINDLE) */

#define        IDGTAR15     AX150.bit._09
/* RICHIESTA MODO TARATURA DRIVE DIGITALE SERCOS ASSE 15 (ASSI o MANDRINO) */
/* SETTING MODE REQUEST FOR AXIS 15 SERCOS DIGITAL DRIVE (AXES or SPINDLE) */

#define        IDRVON15     AX150.bit._10
/* DRIVE ON, ENABLE del DRIVE DIGITALE - ASSE 15 (ASSI o MANDRINO) */
/* DRIVE ON, ENABLE of the AXIS 15 - DIGITAL DRIVE (AXES or SPINDLE) */

#define        IAXOFF15     AX150.bit._11
/* RICHIESTA ASSE 15 OFF (ASSE IN LIBERA SERVO) (ASSI o MANDRINO); Richiesta diretta */
/* OFF AXIS 15 request (SERVO AXIS FREE) (AXES or SPINDLE); direct request */

#define        ISAM15       AX150.bit._12
/* RICHIESTA SOSPENSIONE ALLARME FUGA VELOCITA ASSE 15 (solo MANDRINO) */
/* AXIS 15 VELOCITY ESCAPE ALARM SUSPENSION REQUEST (only SPINDLE) */

#define        IANQE15      AX150.bit._13
/* RICHIESTA AZZERA ERRORE QE per ASSE 0 FREE  */
/* ZERO ERROR REQUEST FOR AXIS 15 FREE   */

#define			IATT15		AX150.bit._14
/* RICHIESTA ATTIVAZIONE ASSE IN UN GRUPPO */
/* AXIS IN A GROUP ACTIVATION REQUEST	   */


/* --------------------------------------- */
/*        OUTPUT ASSE  15   WORD 1         */
/* --------------------------------------- */

#define        OBOK15       AX151.bit._08
/* ASSE 15 NON IN ALLARME (ASSI o MANDRINO)*/
/* AXIS 15 NOT IN ALARM (AXES or SPINDLE)*/

#define        OBAT15       AX151.bit._09
/* ATTENZIONE SU ASSE 15 (ASSI o MANDRINO) */
/* ATTENTION ON AXIS 15 (AXES or SPINDLE) */

#define        OBNT15       AX151.bit._12
/* COMANDO IN CORSO ASSE 15 (ASSE FRE o MANDRINO) */
/* COMMAND IN PROGRESS ON AXIS 15 (FRE AXIS or SPINDLE) */

#define        OBNP15       AX151.bit._13
/* COMANDO ASSE 15 ESEGUITO IN PIU' FASI (ASSE FRE o MANDRINO) */
/* AXIS 15 COMMAND PERFORMED IN MORE PHASES (FRE AXIS or SPINDLE) */

/* --------------------------------------- */
/*        OUTPUT ASSE  15   WORD 2         */
/* --------------------------------------- */

#define        OBM015       AX152.bit._00
/* MICRO 0: MARKER ASSE 15 (ASSI o MANDRINO) */
/* MICRO 0: AXIS 15 MARKER (AXES or SPINDLE) */

#define        OBM151       AX152.bit._01
/* MICRO 1: CAMMA ASSE 15 (ASSI o MANDRINO) */
/* MICRO 1: AXIS 15 CAM (AXES or SPINDLE) */

#define        OBSF15       AX152.bit._03
/* SE ='1' REF NEGATIVO ASSE 15 (ASSI o MANDRINO) */
/* if ='1' NEGATIVE REFERENCE FOR AXIS 15 (AXES or SPINDLE) */

#define        OBSE15       AX152.bit._04
/* SET ASSE 15 ESEGUITO (ASSI o MANDRINO) */
/* AXIS 15 SET PERFORMED (AXES or SPINDLE) */

#define        OBCN15       AX152.bit._06
/* ASSE 15 AGGANCIATO IN CONTOURING (ASSI o MANDRINO) */
/* AXIS 15 HOOKED IN CONTOURING (AXES or SPINDLE) */

#define        OBAG15       AX152.bit._07
/* ASSE 15 AGGANCIATO IN PT. A PT. (ASSI o MANDRINO) */
/* AXIS 15 HOOKED IN POINT TO POINT (AXES or SPINDLE) */

#define        OBCG15       AX152.bit._08
/* VELOCITA DI CAMBIO GAMMA MANDRINO ASSE 15 RAGGIUNTA */
/* SPEED OF SPINDLE GEAR CHANGE (AXIS 15) REACHED */

#define        OBVV15       AX152.bit._09
/* ASSE 15 AGGANCIATO IN VELOCITA' (ASSI o MANDRINO) */
/* AXIS 15 HOOKED IN VELOCITY (AXES or SPINDLE) */

#define        OSOK15       AX152.bit._10
/* VELOCITA' MANDRINO ASSE 15 OK */
/* SPINDLE SPEED (AXIS 15) OK */

#define        OBGG15       AX152.bit._11
/* ASSE 15 AGGANCIATO IN GANTRY */
/* AXIS 15 HOOKED IN GANTRY MODE */

#define        OBSP15       AX152.bit._12
/* ASSE 15 IN MODO STEP */
/* AXIS 15 IN STEP MODE */

#define        OBIN15       AX152.bit._13
/* MOVIMENTO ASSE 15 INDIETRO */
/* AXIS 15 MOVEMENT BACK */

#define        OBMT15       AX152.bit._14
/* ASSE 15 IN MOTO (ASSE FRE o MANDRINO)*/
/* AXIS 15 IN MOTION (FRE AXIS or SPINDLE) */

#define        OBNA15       AX152.bit._15
/* ASSE 15 NON ARRIVATO (ASSE FRE o MANDRINO)*/
/* AXIS 15 NOT IN POSITION (FRE AXIS or SPINDLE) */

/* --------------------------------------- */
/*        OUTPUT ASSE  15   WORD 3         */
/* --------------------------------------- */

#define        OBLC15       AX153.bit._04
/* ASSE 15 BLOCCABILE MECCANICAMENTE (ASSI o MANDRINO)*/
/* AXIS 15 MECHANICALLY CLAMPABLE (AXES or SPINDLE)*/

#define        OLS15        AX153.bit._05
/* ASSE 15 IN LIBERA SERVO (ASSI o MANDRINO)*/
/* AXIS 15 IN FREE SERVO (AXES or SPINDLE)*/

#define        OSTM15       AX153.bit._06
/* MANDRINO ASSE 15 IN SOGLIA DI STOP */
/* AXIS 15 SPINDLE IN STANDSTILL THRESHOLD */

#define		   OATT15		AX153.bit._07
/* ASSE ATTIVATO TRA ALTERNATIVI	 */
/* AXIS ACTIVATED IN A GROUP		 */


/* --------------------------------------- */
/*        OUTPUT ASSE  15   WORD 4         */
/* --------------------------------------- */

#define        OPND15       AX154.bit._00
/* ASSE 15 PENDOLANTE */
/* AXIS 15 HUNTING */

#define        OPQ1215      AX154.bit._01
/* ASSE 15 PENDOLANTE FRA 2 QUOTE */
/* AXIS 15 HUNTING BETWEEN 2 DIMENSIONS */

#define        OPVQ151      AX154.bit._02
/* ASSE 15 PENDOLANTE DEVE RAGGIUNGERE LA QUOTA Q1 */
/* AXIS 15 HUNTING HAS TO REACH THE Q1 DIMENSION */

#define        OBGSET15     AX154.bit._03
/* ASSE 15 ASSOLUTO AGGANCIATO IN GANTRY DA RIALLINEARE */
/* ABSOLUTE AXIS 15 HOOKED IN GANTRY NEEDS TO BE LINED UP */

#define        OPSGL15      AX154.bit._05
/* ASSE 15 NON ENTRATO IN SOGLIA SGL DI AXS.TAR (ASSI)*/
/* AXIS 15 DOESN'T GO INTO SGL THRESHOLD OF AXS.TAR (AXES)*/

#define        OPFRM15      AX154.bit._06
/* ASSE 15 NON IN MOTO IN SOGLIA E FERMO (ASSI)*/
/* AXIS 15 NOT IN MOTION, IN THRESHOLD AND STOPPED (AXES)*/

#define        OBGM15       AX154.bit._07
/* ASSE 15 AGGANCIATO IN GANTRY: ASSE MASTER */
/* AXIS 15 HOOKED IN GANTRY: MASTER AXIS */

#define        OBSET15      AX154.bit._08
/* PERDITA DEL SET ASSE 15 A CAUSA DEL SEGNALE IBSET15 */
/* LOSS OF THE AXIS 15 SET DUE TO THE IBSET15 SIGNAL */

#define        OBALAX15     AX154.bit._09
/* SEGNALAZIONE ALLARME ASSE 15 */
/* AXIS 15 ALARM SIGNALING */

#define        ONBAGM15     AX154.bit._10
/* ASSE 15 SGANCIATO IN MOVIMENTO (valido se !OBAG15-asse sganciato) */
/* UNHOOKED AXIS 15 IN MOVEMENT (valid if !OBAG15 -axis unhooked) */

#define        OSAMAC15     AX154.bit._12
/* SEGNALA RICHIESTA SOSPENSIONE ALLARME MANDRINO IN ACCELERAZIONE. */
/* SPINDLE IN ACCELERATION ALARM SUSPENSION REQUEST  */

/*******************************************/

/* --------------------------------------- */
/*   INPUT VOLANTINI DA I/O  O DA IKR      */
/* --------------------------------------- */

#define        VVOL1        RV0.word
#define        VVOLIO1      RV0.word
/* VALORE VOLANTINO 1 DA INPUT I/O         */
/* VALUE OF HANDWHEEL 1 WITH INPUT ON I/O */

#define        VVOL2        RV1.word
#define        VVOLIO2      RV1.word
/* VALORE VOLANTINO 2 DA INPUT I/O */
/* VALUE OF HANDWHEEL 2 WITH INPUT ON I/O */

#define        VVOL3        RV2.word
#define        VVOLIO3      RV2.word
/* VALORE VOLANTINO 3 DA INPUT I/O */
/* VALUE OF HANDWHEEL 3 WITH INPUT I/O */

#define        VVOL4        RV3.word
#define        VVOLIO4      RV3.word
/* VALORE VOLANTINO 4 DA INPUT I/O */
/* VALUE OF HANDWHEEL 4 WITH INPUT ON I/O */

#define        VOL1IKR      RS4.word
/* VALORE VOLANTINO 1  DA IKR */
/* VALUE OF HANDWHEEL 1 FROM IKR */

#define        VOL2IKR      RS5.word
/* VALORE VOLANTINO 2  DA IKR */
/* VALUE OF HANDWHEEL 2 FROM IKR */

#define        VOL3IKR      RS6.word
/* VALORE VOLANTINO 3  DA IKR */
/* VALUE OF HANDWHEEL 3 FROM IKR */

/* --------------------------------------- */
/*                VARIE IKR                */
/* --------------------------------------- */

#define        STBIKR       RS0.bit._00
/* Strobe Tasti IKR premuti */
/* Strobe IKR key pressed */

#define        ACKIKR       TS0.bit._00
/* Acknowledge Tasti IKR premuti     */
/* Acknowledge IKR key pressed */

/* --------------------------------------- */
/*      CONVERTITORI D/A CARTE ASSI        */
/* --------------------------------------- */

#define        VDA0         pio->tda[0]
/* USCITA PRIMO CONVERTITORE D/A */
/* FIRST D/A CONVERTER OUTPUT */

#define        VDA1         pio->tda[1]
/* USCITA SECONDO CONVERTITORE D/A */
/* SECOND D/A CONVERTER OUTPUT */

#define        VDA2         pio->tda[2]
/* USCITA TERZO CONVERTITORE D/A */
/* THIRD D/A CONVERTER OUTPUT */

#define        VDA3         pio->tda[3]
#define        VDA4         pio->tda[4]
#define        VDA5         pio->tda[5]
#define        VDA6         pio->tda[6]
#define        VDA7         pio->tda[7]
#define        VDA8         pio->tda[8]
#define        VDA9         pio->tda[9]
#define        VDA10        pio->tda[10]
#define        VDA11        pio->tda[11]
/* USCITA DODICESIMO CONVERTITORE D/A */
/* TWELFTH D/A CONVERTER OUTPUT */

/* ------------------------------------------------------------ */
/* CONFIGURAZIONE DEI CONVERTITORI A/D							*/
/* collegati ad input analogici Ethercat                        */
/*                     =1   0 -> +5  Volt                       */
/*                     =2     +/- 5  Volt                       */
/*                     =3   0 -> +10 Volt                       */
/*                     =4     +/- 10 Volt                       */
/* ------------------------------------------------------------ */
#define        IADCNF0      pn_iosignal->AnalogDigitalCnf[0]
/* CONFIGURAZIONE DEL PRIMO CONVERTITORE A/D INTEGRATO */
/* CONFIGURATION  OF FIRST INTEGRATED A/D CONVERTER */

#define        IADCNF1      pn_iosignal->AnalogDigitalCnf[1]
#define        IADCNF2      pn_iosignal->AnalogDigitalCnf[2]
#define        IADCNF3      pn_iosignal->AnalogDigitalCnf[3]
/* CONFIGURAZIONE DEL QUARTO CONVERTITORE A/D INTEGRATO */
/* CONFIGURATION  OF FOURTH INTEGRATED A/D CONVERTER */

#define		   IADRES0	    pn_iosignal->AnalogDigitalRes[0]
/* RISOLUZIONE DEL PRIMO CONVERTITORE A/D		*/
/* FIRST A/D CONVERTER RESOLUTION				*/

#define		   IADRES1	    pn_iosignal->AnalogDigitalRes[1]
#define		   IADRES2	    pn_iosignal->AnalogDigitalRes[2]
#define		   IADRES3	    pn_iosignal->AnalogDigitalRes[3]
/* RISOLUZIONE DEL QUARTO CONVERTITORE A/D		*/
/* FORTH A/D CONVERTER RESOLUTION				*/


/* ---------------------------------------------------------------- */
/*   Riposizionamento Automatico                                    */
/* ---------------------------------------------------------------- */
#define        IRIP2CER    pn_iosignal->IRip2Cer
/* NEL RIPOSIZ. "RIENTRO TAGLIANDO" L'ARCO DI CERCHIO VA DIVISO IN DUE PARTI */
/* ..... */


/* ---------------------------------------------------------------- */
/* CONVERTITORI A/D	Collegati ad input analogici Ethercat (RT)		*/
/* ---------------------------------------------------------------- */
#define        IADRT0       pn_iosignal->IAnalogDigitalRt[0]
/* INGRESSO PRIMO CONVERTITORE A/D INTEGRATO */
/* INPUT OF FIRST INTEGRATED A/D CONVERTER */

#define        IADRT1       pn_iosignal->IAnalogDigitalRt[1]
#define        IADRT2       pn_iosignal->IAnalogDigitalRt[2]
#define        IADRT3       pn_iosignal->IAnalogDigitalRt[3]
/* INGRESSO QUARTO CONVERTITORE A/D INTEGRATO */
/* INPUT OF FOURTH INTEGRATED A/D CONVERTER */

/* ---------------------------------------------------------------- */
/* CONVERTITORI A/D	Collegati ad input analogici Ethercat (SLOW)	*/
/* ---------------------------------------------------------------- */
#define        IAD0         pn_iosignal->IAnalogDigitalSlow[0]
/* INGRESSO PRIMO CONVERTITORE A/D INTEGRATO */
/* INPUT OF FIRST INTEGRATED A/D CONVERTER */

#define        IAD1         pn_iosignal->IAnalogDigitalSlow[1]
#define        IAD2         pn_iosignal->IAnalogDigitalSlow[2]
#define        IAD3         pn_iosignal->IAnalogDigitalSlow[3]
/* INGRESSO QUARTO CONVERTITORE A/D INTEGRATO */
/* INPUT OF FOURTH INTEGRATED A/D CONVERTER */

/* ---------------------------------------------------- */
/* WORD DI COLLOQUIO    Editor Variabili Cn <--> PLC    */
/* ---------------------------------------------------- */
#define        EDVARCN0     pn_iosignal->EdVarCn0
#define        EDVARCN1     pn_iosignal->EdVarCn1
/* ---------------------------------------------------- */

/* ---------------------------------------------------- */
/* WORD DI STATO   dell'applicativo WINVIS              */
/*              0   Winvis Non Attivo                   */
/*              1   Winvis Attivo                       */
/* ---------------------------------------------------- */
#define        WINVIS_STATUS pn_iosignal->WinvisStatus
/* ---------------------------------------------------- */

/* ---------------------------------------------------- */
/* WORD DI STATO del Controllo di Altezza               */
/*              0   Non attivo                          */
/*              1   Attivo                              */
/*              2   Sospeso                             */
/*              3   Sospeso per Tensione Limite         */
/* ---------------------------------------------------- */
#define        OHCTRL0          pn_iosignal->OHControl[0]
#define        OHCTRL1          pn_iosignal->OHControl[1]
#define        OHCTRL2          pn_iosignal->OHControl[2]
#define        OHCTRL3          pn_iosignal->OHControl[3]
#define        OHCTRL4          pn_iosignal->OHControl[4]
#define        OHCTRL5          pn_iosignal->OHControl[5]
#define        OHCTRL6          pn_iosignal->OHControl[6]
#define        OHCTRL7          pn_iosignal->OHControl[7]
#define        OHCTRL8          pn_iosignal->OHControl[8]
#define        OHCTRL9          pn_iosignal->OHControl[9]
#define        OHCTRL10         pn_iosignal->OHControl[10]
#define        OHCTRL11         pn_iosignal->OHControl[11]
#define        OHCTRL12         pn_iosignal->OHControl[12]
#define        OHCTRL13         pn_iosignal->OHControl[13]
#define        OHCTRL14         pn_iosignal->OHControl[14]
#define        OHCTRL15         pn_iosignal->OHControl[15]
/* ---------------------------------------------------- */

/* ---------------------------------------------------- */
/* SEGNO della regolazione del Controllo di Altezza     */
/* (+1 / -1)                                            */
/* ---------------------------------------------------- */
#define        OSIGNHCTRL0      pn_iosignal->hcs_par[0].Sign
#define        OSIGNHCTRL1      pn_iosignal->hcs_par[1].Sign
#define        OSIGNHCTRL2      pn_iosignal->hcs_par[2].Sign
#define        OSIGNHCTRL3      pn_iosignal->hcs_par[3].Sign
#define        OSIGNHCTRL4      pn_iosignal->hcs_par[4].Sign
#define        OSIGNHCTRL5      pn_iosignal->hcs_par[5].Sign
#define        OSIGNHCTRL6      pn_iosignal->hcs_par[6].Sign
#define        OSIGNHCTRL7      pn_iosignal->hcs_par[7].Sign
#define        OSIGNHCTRL8      pn_iosignal->hcs_par[8].Sign
#define        OSIGNHCTRL9      pn_iosignal->hcs_par[9].Sign
#define        OSIGNHCTRL10     pn_iosignal->hcs_par[10].Sign
#define        OSIGNHCTRL11     pn_iosignal->hcs_par[11].Sign
#define        OSIGNHCTRL12     pn_iosignal->hcs_par[12].Sign
#define        OSIGNHCTRL13     pn_iosignal->hcs_par[13].Sign
#define        OSIGNHCTRL14     pn_iosignal->hcs_par[14].Sign
#define        OSIGNHCTRL15     pn_iosignal->hcs_par[15].Sign
/* ---------------------------------------------------- */

/* ---------------------------------------------------- */
/* TENSIONE DESIDERATA del Controllo di Altezza         */
/* =10000 Tensione in auto-apprendimento                */
/* ---------------------------------------------------- */
#define        OVOLTHCTRL0      pn_iosignal->hcs_par[0].Volt
#define        OVOLTHCTRL1      pn_iosignal->hcs_par[1].Volt
#define        OVOLTHCTRL2      pn_iosignal->hcs_par[2].Volt
#define        OVOLTHCTRL3      pn_iosignal->hcs_par[3].Volt
#define        OVOLTHCTRL4      pn_iosignal->hcs_par[4].Volt
#define        OVOLTHCTRL5      pn_iosignal->hcs_par[5].Volt
#define        OVOLTHCTRL6      pn_iosignal->hcs_par[6].Volt
#define        OVOLTHCTRL7      pn_iosignal->hcs_par[7].Volt
#define        OVOLTHCTRL8      pn_iosignal->hcs_par[8].Volt
#define        OVOLTHCTRL9      pn_iosignal->hcs_par[9].Volt
#define        OVOLTHCTRL10      pn_iosignal->hcs_par[10].Volt
#define        OVOLTHCTRL11      pn_iosignal->hcs_par[11].Volt
#define        OVOLTHCTRL12      pn_iosignal->hcs_par[12].Volt
#define        OVOLTHCTRL13      pn_iosignal->hcs_par[13].Volt
#define        OVOLTHCTRL14      pn_iosignal->hcs_par[14].Volt
#define        OVOLTHCTRL15      pn_iosignal->hcs_par[15].Volt
/* ---------------------------------------------------- */

/* ---------------------------------------------------- */
/* WORD DI PREDISPOSIZIONE del Controllo di Altezza     */
/* OSTONHCTRL=1     MODE=ON   o OnHcsControl()          */
/* OSTONHCTRL=0     MODE=OFF  o OffHcsControl()         */
/* OSTSUSPHCTRL=1   MODE=SON  o SuspendOnHcsControl()   */
/* OSTSUSPHCTRL=0   MODE=SOFF o SuspendOffHcsControl()  */
/* ---------------------------------------------------- */
#define        OSTONHCTRL0      pn_iosignal->hcs_par[0].ModeON
#define        OSTONHCTRL1      pn_iosignal->hcs_par[1].ModeON
#define        OSTONHCTRL2      pn_iosignal->hcs_par[2].ModeON
#define        OSTONHCTRL3      pn_iosignal->hcs_par[3].ModeON
#define        OSTONHCTRL4      pn_iosignal->hcs_par[4].ModeON
#define        OSTONHCTRL5      pn_iosignal->hcs_par[5].ModeON
#define        OSTONHCTRL6      pn_iosignal->hcs_par[6].ModeON
#define        OSTONHCTRL7      pn_iosignal->hcs_par[7].ModeON
#define        OSTONHCTRL8      pn_iosignal->hcs_par[8].ModeON
#define        OSTONHCTRL9      pn_iosignal->hcs_par[9].ModeON
#define        OSTONHCTRL10     pn_iosignal->hcs_par[10].ModeON
#define        OSTONHCTRL11     pn_iosignal->hcs_par[11].ModeON
#define        OSTONHCTRL12     pn_iosignal->hcs_par[12].ModeON
#define        OSTONHCTRL13     pn_iosignal->hcs_par[13].ModeON
#define        OSTONHCTRL14     pn_iosignal->hcs_par[14].ModeON
#define        OSTONHCTRL15     pn_iosignal->hcs_par[15].ModeON

#define        OSTSUSPHCTRL0    pn_iosignal->hcs_par[0].ModeSON
#define        OSTSUSPHCTRL1    pn_iosignal->hcs_par[1].ModeSON
#define        OSTSUSPHCTRL2    pn_iosignal->hcs_par[2].ModeSON
#define        OSTSUSPHCTRL3    pn_iosignal->hcs_par[3].ModeSON
#define        OSTSUSPHCTRL4    pn_iosignal->hcs_par[4].ModeSON
#define        OSTSUSPHCTRL5    pn_iosignal->hcs_par[5].ModeSON
#define        OSTSUSPHCTRL6    pn_iosignal->hcs_par[6].ModeSON
#define        OSTSUSPHCTRL7    pn_iosignal->hcs_par[7].ModeSON
#define        OSTSUSPHCTRL8    pn_iosignal->hcs_par[8].ModeSON
#define        OSTSUSPHCTRL9    pn_iosignal->hcs_par[9].ModeSON
#define        OSTSUSPHCTRL10   pn_iosignal->hcs_par[10].ModeSON
#define        OSTSUSPHCTRL11   pn_iosignal->hcs_par[11].ModeSON
#define        OSTSUSPHCTRL12   pn_iosignal->hcs_par[12].ModeSON
#define        OSTSUSPHCTRL13   pn_iosignal->hcs_par[13].ModeSON
#define        OSTSUSPHCTRL14   pn_iosignal->hcs_par[14].ModeSON
#define        OSTSUSPHCTRL15   pn_iosignal->hcs_par[15].ModeSON
/* ---------------------------------------------------- */

/* -------------------------------------- */
/* [mm], Spazio residuo al TAG <OUT:9;15> */
/* -1 = Tag non programmato nei blocchi   */
/* -------------------------------------- */
#define        OTRAETOTAG     pn_iosignal->OTraeToTag
/* -------------------------------------- */

/* --------------------------------------- */
/*      OVERRIDE ASSI INDIPENDENTI         */
/* --------------------------------------- */

#define        OVRFRE0      pn_xin->overfre[0]
/* VALORE OVERRIDE ASSE FRE ORDINE 0 */
/* OVERRIDE VALUE OF FRE AXIS #0 */
#define        OVRFRE1      pn_xin->overfre[1]
#define        OVRFRE2      pn_xin->overfre[2]
#define        OVRFRE3      pn_xin->overfre[3]
#define        OVRFRE4      pn_xin->overfre[4]
#define        OVRFRE5      pn_xin->overfre[5]
#define        OVRFRE6      pn_xin->overfre[6]
#define        OVRFRE7      pn_xin->overfre[7]
#define        OVRFRE8      pn_xin->overfre[8]
#define        OVRFRE9      pn_xin->overfre[9]
#define        OVRFRE10     pn_xin->overfre[10]
#define        OVRFRE11     pn_xin->overfre[11]
#define        OVRFRE12     pn_xin->overfre[12]
#define        OVRFRE13     pn_xin->overfre[13]
#define        OVRFRE14     pn_xin->overfre[14]
#define        OVRFRE15     pn_xin->overfre[15]
/* VALORE OVERRIDE ASSE FRE ORDINE 15 */
/* OVERRIDE VALUE OF FRE AXIS #15 */


/* --------------------------------- */
/* ASSE GESTITO E MOVIMENTATO DA PLC */
/* --------------------------------- */

/* --- ASSE PLC ORDINE 0 --- */

#define IAXPLC0 (iosignal[0].IAxPlc)
/* Richiesta asse 0 gestito e movimentato da PLC (ASSE PLC)*/
/* Request of management of the axis #0 by the PLC (PLC AXIS) */

#define OAXPLC0 (iosignal[0].OAxPlc)
/* Stato attuale asse 0 gestito e movimentato da PLC (ASSE PLC)*/
/* Actual status of the axis #0 managed by the PLC (PLC AXIS) */

#define IJOGP0 (iosignal[0].IJogP)
/* Richiesta JOG+ di velocita' IN RAPIDO ASSE PLC 0*/
/* Request velocity JOG+ IN RAPID PLC AXIS #0 */

#define IJOGN0 (iosignal[0].IJogN)
/* Richiesta JOG- di velocita' IN RAPIDO ASSE PLC 0*/
/* Request velocity JOG- IN RAPID PLC AXIS #0 */

#define OCPLC0 (iosignal[0].OCodAxPlcMov)
/* Codice di stato della richiesta di movimentazione (short) ASSE PLC 0*/
/* Status Code (short) of the last movement request for PLC AXIS #0 */

#define OAXSLV0 (iosignal[0].OAxPlcSynch)
/* Asse 0 programmato per il sincronismo */
/* Axis 0 scheduled for the synchronism */

#define OIDSLV0 (iosignal[0].OIndSynch)
/* Indice struttura di sincronismo Asse 0 */
/* Synchronism structure index for axis #0 */

#define OSQSLV0 (iosignal[0].OSqSynch)
/* Contatore perdita di sequenza sincronismo Asse 0 */
/* Synchronism sequence loss counter Axis #0 */

#define IDGSTS0 (iosignal[0].IStatusDgDrive)
/* Status di Input per Asse 0 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Status of input for axis 0 connected to digital driver (IDDCOM EDDCOM) */

#define ODGSTS0 (iosignal[0].OStatusDgDrive)
/* Status di Output per Asse 0 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Status of output for axis 0 connected to digital driver (IDDCOM EDDCOM) */

#define ODGMON0 (iosignal[0].OMonitorDgDrive)
/* Variabile Monitor di Output per Asse 0 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Output monitor variable for axis 0 connected to digital driver (IDDCOM EDDCOM) */

#define OCURR0 (iosignal[0].OTorqueForceFeedBackValue)
/* % Corrente assorbita dall'Asse 0 SERCOS (valido solo per asse Mandrino) */
/* % Current absorbed by the axis 0 SERCOS (valid only for SPINDLE Axis) */

#define OAXOFF0 (iosignal[0].OAxBRK)
/* Asse 0 momentaneamente NON utilizzabile */
/* Axis 0 momentarily NOT usable */

#define OAXRTR0 (iosignal[0].OAxRTR)
/* Asse 0 in movimento di RETRACT */
/* Axis 0 RETRACT movement        */

#define OTAX0 (iosignal[0].OT_Axis)
/* Stato dell'"Asse T" (Asse 0) */
/* "T Axis" status  (Axis 0)    */

#define OITRAX0 (iosignal[0].IOAxisSmtRef)
/* Asse soggetto a Inizializzazione con istruzione <ITR:...> */
/* Asse soggetto a Inizializzazione con istruzione <ITR:...> */

#define OCORIGPLC0 (iosignal[0].OCodAxPlcOrig)
/* Codice di stato della richiesta di Formazione Origine (short) ASSE PLC 0*/
/* Status Code (short) of the last Form Origin request for PLC AXIS #0 */

#define ITPOFENA0 (iosignal[0].ITPOnFlyEna)
/* Richiesta di abilitare la modifica quota target asse p.to p.to ASSE PLC 0*/
/* Request to enable change of the point to point axis target position PLC AXIS #0 */

#define ITPOFSTB0 (iosignal[0].ITPOnFlyStb)
/* STROBE di nuova quota target asse p.to p.to ASSE PLC 0*/
/* STROBE of the new point to point axis target position PLC AXIS #0 */

#define OTPOFACK0 (iosignal[0].OTPOnFlyAck)
/* ACKNOWLEDGE di nuova quota target asse p.to p.to ASSE PLC 0*/
/* ACKNOWLEDGE of the new point to point axis target position PLC AXIS #0 */

/* --- ASSE PLC ORDINE 1 --- */

#define IAXPLC1 (iosignal[1].IAxPlc)
#define OAXPLC1 (iosignal[1].OAxPlc)
#define IJOGP1 (iosignal[1].IJogP)
#define IJOGN1 (iosignal[1].IJogN)
#define OCPLC1 (iosignal[1].OCodAxPlcMov)
#define OAXSLV1 (iosignal[1].OAxPlcSynch)
#define OIDSLV1 (iosignal[1].OIndSynch)
#define OSQSLV1 (iosignal[1].OSqSynch)
#define IDGSTS1 (iosignal[1].IStatusDgDrive)
#define ODGSTS1 (iosignal[1].OStatusDgDrive)
#define ODGMON1 (iosignal[1].OMonitorDgDrive)
#define OCURR1 (iosignal[1].OTorqueForceFeedBackValue)
#define OAXOFF1 (iosignal[1].OAxBRK)
#define OAXRTR1 (iosignal[1].OAxRTR)
#define OTAX1 (iosignal[1].OT_Axis)
#define OITRAX1 (iosignal[1].IOAxisSmtRef)
#define OCORIGPLC1 (iosignal[1].OCodAxPlcOrig)
#define ITPOFENA1 (iosignal[1].ITPOnFlyEna)
#define ITPOFSTB1 (iosignal[1].ITPOnFlyStb)
#define OTPOFACK1 (iosignal[1].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 2 --- */

#define IAXPLC2 (iosignal[2].IAxPlc)
#define OAXPLC2 (iosignal[2].OAxPlc)
#define IJOGP2 (iosignal[2].IJogP)
#define IJOGN2 (iosignal[2].IJogN)
#define OCPLC2 (iosignal[2].OCodAxPlcMov)
#define OAXSLV2 (iosignal[2].OAxPlcSynch)
#define OIDSLV2 (iosignal[2].OIndSynch)
#define OSQSLV2 (iosignal[2].OSqSynch)
#define IDGSTS2 (iosignal[2].IStatusDgDrive)
#define ODGSTS2 (iosignal[2].OStatusDgDrive)
#define ODGMON2 (iosignal[2].OMonitorDgDrive)
#define OCURR2 (iosignal[2].OTorqueForceFeedBackValue)
#define OAXOFF2 (iosignal[2].OAxBRK)
#define OAXRTR2 (iosignal[2].OAxRTR)
#define OTAX2 (iosignal[2].OT_Axis)
#define OITRAX2 (iosignal[2].IOAxisSmtRef)
#define OCORIGPLC2 (iosignal[2].OCodAxPlcOrig)
#define ITPOFENA2 (iosignal[2].ITPOnFlyEna)
#define ITPOFSTB2 (iosignal[2].ITPOnFlyStb)
#define OTPOFACK2 (iosignal[2].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 3 --- */

#define IAXPLC3 (iosignal[3].IAxPlc)
#define OAXPLC3 (iosignal[3].OAxPlc)
#define IJOGP3 (iosignal[3].IJogP)
#define IJOGN3 (iosignal[3].IJogN)
#define OCPLC3 (iosignal[3].OCodAxPlcMov)
#define OAXSLV3 (iosignal[3].OAxPlcSynch)
#define OIDSLV3 (iosignal[3].OIndSynch)
#define OSQSLV3 (iosignal[3].OSqSynch)
#define IDGSTS3 (iosignal[3].IStatusDgDrive)
#define ODGSTS3 (iosignal[3].OStatusDgDrive)
#define ODGMON3 (iosignal[3].OMonitorDgDrive)
#define OCURR3 (iosignal[3].OTorqueForceFeedBackValue)
#define OAXOFF3 (iosignal[3].OAxBRK)
#define OAXRTR3 (iosignal[3].OAxRTR)
#define OTAX3 (iosignal[3].OT_Axis)
#define OITRAX3 (iosignal[3].IOAxisSmtRef)
#define OCORIGPLC3 (iosignal[3].OCodAxPlcOrig)
#define ITPOFENA3 (iosignal[3].ITPOnFlyEna)
#define ITPOFSTB3 (iosignal[3].ITPOnFlyStb)
#define OTPOFACK3 (iosignal[3].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 4 --- */

#define IAXPLC4 (iosignal[4].IAxPlc)
#define OAXPLC4 (iosignal[4].OAxPlc)
#define IJOGP4 (iosignal[4].IJogP)
#define IJOGN4 (iosignal[4].IJogN)
#define OCPLC4 (iosignal[4].OCodAxPlcMov)
#define OAXSLV4 (iosignal[4].OAxPlcSynch)
#define OIDSLV4 (iosignal[4].OIndSynch)
#define OSQSLV4 (iosignal[4].OSqSynch)
#define IDGSTS4 (iosignal[4].IStatusDgDrive)
#define ODGSTS4 (iosignal[4].OStatusDgDrive)
#define ODGMON4 (iosignal[4].OMonitorDgDrive)
#define OCURR4 (iosignal[4].OTorqueForceFeedBackValue)
#define OAXOFF4 (iosignal[4].OAxBRK)
#define OAXRTR4 (iosignal[4].OAxRTR)
#define OTAX4 (iosignal[4].OT_Axis)
#define OITRAX4 (iosignal[4].IOAxisSmtRef)
#define OCORIGPLC4 (iosignal[4].OCodAxPlcOrig)
#define ITPOFENA4 (iosignal[4].ITPOnFlyEna)
#define ITPOFSTB4 (iosignal[4].ITPOnFlyStb)
#define OTPOFACK4 (iosignal[4].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 5 --- */

#define IAXPLC5 (iosignal[5].IAxPlc)
#define OAXPLC5 (iosignal[5].OAxPlc)
#define IJOGP5 (iosignal[5].IJogP)
#define IJOGN5 (iosignal[5].IJogN)
#define OCPLC5 (iosignal[5].OCodAxPlcMov)
#define OAXSLV5 (iosignal[5].OAxPlcSynch)
#define OIDSLV5 (iosignal[5].OIndSynch)
#define OSQSLV5 (iosignal[5].OSqSynch)
#define IDGSTS5 (iosignal[5].IStatusDgDrive)
#define ODGSTS5 (iosignal[5].OStatusDgDrive)
#define ODGMON5 (iosignal[5].OMonitorDgDrive)
#define OCURR5 (iosignal[5].OTorqueForceFeedBackValue)
#define OAXOFF5 (iosignal[5].OAxBRK)
#define OAXRTR5 (iosignal[5].OAxRTR)
#define OTAX5 (iosignal[5].OT_Axis)
#define OITRAX5 (iosignal[5].IOAxisSmtRef)
#define OCORIGPLC5 (iosignal[5].OCodAxPlcOrig)
#define ITPOFENA5 (iosignal[5].ITPOnFlyEna)
#define ITPOFSTB5 (iosignal[5].ITPOnFlyStb)
#define OTPOFACK5 (iosignal[5].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 6 --- */

#define IAXPLC6 (iosignal[6].IAxPlc)
#define OAXPLC6 (iosignal[6].OAxPlc)
#define IJOGP6 (iosignal[6].IJogP)
#define IJOGN6 (iosignal[6].IJogN)
#define OCPLC6 (iosignal[6].OCodAxPlcMov)
#define OAXSLV6 (iosignal[6].OAxPlcSynch)
#define OIDSLV6 (iosignal[6].OIndSynch)
#define OSQSLV6 (iosignal[6].OSqSynch)
#define IDGSTS6 (iosignal[6].IStatusDgDrive)
#define ODGSTS6 (iosignal[6].OStatusDgDrive)
#define ODGMON6 (iosignal[6].OMonitorDgDrive)
#define OCURR6 (iosignal[6].OTorqueForceFeedBackValue)
#define OAXOFF6 (iosignal[6].OAxBRK)
#define OAXRTR6 (iosignal[6].OAxRTR)
#define OTAX6 (iosignal[6].OT_Axis)
#define OITRAX6 (iosignal[6].IOAxisSmtRef)
#define OCORIGPLC6 (iosignal[6].OCodAxPlcOrig)
#define ITPOFENA6 (iosignal[6].ITPOnFlyEna)
#define ITPOFSTB6 (iosignal[6].ITPOnFlyStb)
#define OTPOFACK6 (iosignal[6].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 7 --- */

#define IAXPLC7 (iosignal[7].IAxPlc)
#define OAXPLC7 (iosignal[7].OAxPlc)
#define IJOGP7 (iosignal[7].IJogP)
#define IJOGN7 (iosignal[7].IJogN)
#define OCPLC7 (iosignal[7].OCodAxPlcMov)
#define OAXSLV7 (iosignal[7].OAxPlcSynch)
#define OIDSLV7 (iosignal[7].OIndSynch)
#define OSQSLV7 (iosignal[7].OSqSynch)
#define IDGSTS7 (iosignal[7].IStatusDgDrive)
#define ODGSTS7 (iosignal[7].OStatusDgDrive)
#define ODGMON7 (iosignal[7].OMonitorDgDrive)
#define OCURR7 (iosignal[7].OTorqueForceFeedBackValue)
#define OAXOFF7 (iosignal[7].OAxBRK)
#define OAXRTR7 (iosignal[7].OAxRTR)
#define OTAX7 (iosignal[7].OT_Axis)
#define OITRAX7 (iosignal[7].IOAxisSmtRef)
#define OCORIGPLC7 (iosignal[7].OCodAxPlcOrig)
#define ITPOFENA7 (iosignal[7].ITPOnFlyEna)
#define ITPOFSTB7 (iosignal[7].ITPOnFlyStb)
#define OTPOFACK7 (iosignal[7].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 8 --- */

#define IAXPLC8 (iosignal[8].IAxPlc)
#define OAXPLC8 (iosignal[8].OAxPlc)
#define IJOGP8 (iosignal[8].IJogP)
#define IJOGN8 (iosignal[8].IJogN)
#define OCPLC8 (iosignal[8].OCodAxPlcMov)
#define OAXSLV8 (iosignal[8].OAxPlcSynch)
#define OIDSLV8 (iosignal[8].OIndSynch)
#define OSQSLV8 (iosignal[8].OSqSynch)
#define IDGSTS8 (iosignal[8].IStatusDgDrive)
#define ODGSTS8 (iosignal[8].OStatusDgDrive)
#define ODGMON8 (iosignal[8].OMonitorDgDrive)
#define OCURR8 (iosignal[8].OTorqueForceFeedBackValue)
#define OAXOFF8 (iosignal[8].OAxBRK)
#define OAXRTR8 (iosignal[8].OAxRTR)
#define OTAX8 (iosignal[8].OT_Axis)
#define OITRAX8 (iosignal[8].IOAxisSmtRef)
#define OCORIGPLC8 (iosignal[8].OCodAxPlcOrig)
#define ITPOFENA8 (iosignal[8].ITPOnFlyEna)
#define ITPOFSTB8 (iosignal[8].ITPOnFlyStb)
#define OTPOFACK8 (iosignal[8].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 9 --- */

#define IAXPLC9 (iosignal[9].IAxPlc)
#define OAXPLC9 (iosignal[9].OAxPlc)
#define IJOGP9 (iosignal[9].IJogP)
#define IJOGN9 (iosignal[9].IJogN)
#define OCPLC9 (iosignal[9].OCodAxPlcMov)
#define OAXSLV9 (iosignal[9].OAxPlcSynch)
#define OIDSLV9 (iosignal[9].OIndSynch)
#define OSQSLV9 (iosignal[9].OSqSynch)
#define IDGSTS9 (iosignal[9].IStatusDgDrive)
#define ODGSTS9 (iosignal[9].OStatusDgDrive)
#define ODGMON9 (iosignal[9].OMonitorDgDrive)
#define OCURR9 (iosignal[9].OTorqueForceFeedBackValue)
#define OAXOFF9 (iosignal[9].OAxBRK)
#define OAXRTR9 (iosignal[9].OAxRTR)
#define OTAX9 (iosignal[9].OT_Axis)
#define OITRAX9 (iosignal[9].IOAxisSmtRef)
#define OCORIGPLC9 (iosignal[9].OCodAxPlcOrig)
#define ITPOFENA9 (iosignal[9].ITPOnFlyEna)
#define ITPOFSTB9 (iosignal[9].ITPOnFlyStb)
#define OTPOFACK9 (iosignal[9].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 10 --- */

#define IAXPLC10 (iosignal[10].IAxPlc)
#define OAXPLC10 (iosignal[10].OAxPlc)
#define IJOGP10 (iosignal[10].IJogP)
#define IJOGN10 (iosignal[10].IJogN)
#define OCPLC10 (iosignal[10].OCodAxPlcMov)
#define OAXSLV10 (iosignal[10].OAxPlcSynch)
#define OIDSLV10 (iosignal[10].OIndSynch)
#define OSQSLV10 (iosignal[10].OSqSynch)
#define IDGSTS10 (iosignal[10].IStatusDgDrive)
#define ODGSTS10 (iosignal[10].OStatusDgDrive)
#define ODGMON10 (iosignal[10].OMonitorDgDrive)
#define OCURR10 (iosignal[10].OTorqueForceFeedBackValue)
#define OAXOFF10 (iosignal[10].OAxBRK)
#define OAXRTR10 (iosignal[10].OAxRTR)
#define OTAX10 (iosignal[10].OT_Axis)
#define OITRAX10 (iosignal[10].IOAxisSmtRef)
#define OCORIGPLC10 (iosignal[10].OCodAxPlcOrig)
#define ITPOFENA10 (iosignal[10].ITPOnFlyEna)
#define ITPOFSTB10 (iosignal[10].ITPOnFlyStb)
#define OTPOFACK10 (iosignal[10].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 11 --- */

#define IAXPLC11 (iosignal[11].IAxPlc)
#define OAXPLC11 (iosignal[11].OAxPlc)
#define IJOGP11 (iosignal[11].IJogP)
#define IJOGN11 (iosignal[11].IJogN)
#define OCPLC11 (iosignal[11].OCodAxPlcMov)
#define OAXSLV11 (iosignal[11].OAxPlcSynch)
#define OIDSLV11 (iosignal[11].OIndSynch)
#define OSQSLV11 (iosignal[11].OSqSynch)
#define IDGSTS11 (iosignal[11].IStatusDgDrive)
#define ODGSTS11 (iosignal[11].OStatusDgDrive)
#define ODGMON11 (iosignal[11].OMonitorDgDrive)
#define OCURR11 (iosignal[11].OTorqueForceFeedBackValue)
#define OAXOFF11 (iosignal[11].OAxBRK)
#define OAXRTR11 (iosignal[11].OAxRTR)
#define OTAX11 (iosignal[11].OT_Axis)
#define OITRAX11 (iosignal[11].IOAxisSmtRef)
#define OCORIGPLC11 (iosignal[11].OCodAxPlcOrig)
#define ITPOFENA11 (iosignal[11].ITPOnFlyEna)
#define ITPOFSTB11 (iosignal[11].ITPOnFlyStb)
#define OTPOFACK11 (iosignal[11].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 12 --- */

#define IAXPLC12 (iosignal[12].IAxPlc)
#define OAXPLC12 (iosignal[12].OAxPlc)
#define IJOGP12 (iosignal[12].IJogP)
#define IJOGN12 (iosignal[12].IJogN)
#define OCPLC12 (iosignal[12].OCodAxPlcMov)
#define OAXSLV12 (iosignal[12].OAxPlcSynch)
#define OIDSLV12 (iosignal[12].OIndSynch)
#define OSQSLV12 (iosignal[12].OSqSynch)
#define IDGSTS12 (iosignal[12].IStatusDgDrive)
#define ODGSTS12 (iosignal[12].OStatusDgDrive)
#define ODGMON12 (iosignal[12].OMonitorDgDrive)
#define OCURR12 (iosignal[12].OTorqueForceFeedBackValue)
#define OAXOFF12 (iosignal[12].OAxBRK)
#define OAXRTR12 (iosignal[12].OAxRTR)
#define OTAX12 (iosignal[12].OT_Axis)
#define OITRAX12 (iosignal[12].IOAxisSmtRef)
#define OCORIGPLC12 (iosignal[12].OCodAxPlcOrig)
#define ITPOFENA12 (iosignal[12].ITPOnFlyEna)
#define ITPOFSTB12 (iosignal[12].ITPOnFlyStb)
#define OTPOFACK12 (iosignal[12].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 13 --- */

#define IAXPLC13 (iosignal[13].IAxPlc)
#define OAXPLC13 (iosignal[13].OAxPlc)
#define IJOGP13 (iosignal[13].IJogP)
#define IJOGN13 (iosignal[13].IJogN)
#define OCPLC13 (iosignal[13].OCodAxPlcMov)
#define OAXSLV13 (iosignal[13].OAxPlcSynch)
#define OIDSLV13 (iosignal[13].OIndSynch)
#define OSQSLV13 (iosignal[13].OSqSynch)
#define IDGSTS13 (iosignal[13].IStatusDgDrive)
#define ODGSTS13 (iosignal[13].OStatusDgDrive)
#define ODGMON13 (iosignal[13].OMonitorDgDrive)
#define OCURR13 (iosignal[13].OTorqueForceFeedBackValue)
#define OAXOFF13 (iosignal[13].OAxBRK)
#define OAXRTR13 (iosignal[13].OAxRTR)
#define OTAX13 (iosignal[13].OT_Axis)
#define OITRAX13 (iosignal[13].IOAxisSmtRef)
#define OCORIGPLC13 (iosignal[13].OCodAxPlcOrig)
#define ITPOFENA13 (iosignal[13].ITPOnFlyEna)
#define ITPOFSTB13 (iosignal[13].ITPOnFlyStb)
#define OTPOFACK13 (iosignal[13].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 14 --- */

#define IAXPLC14 (iosignal[14].IAxPlc)
#define OAXPLC14 (iosignal[14].OAxPlc)
#define IJOGP14 (iosignal[14].IJogP)
#define IJOGN14 (iosignal[14].IJogN)
#define OCPLC14 (iosignal[14].OCodAxPlcMov)
#define OAXSLV14 (iosignal[14].OAxPlcSynch)
#define OIDSLV14 (iosignal[14].OIndSynch)
#define OSQSLV14 (iosignal[14].OSqSynch)
#define IDGSTS14 (iosignal[14].IStatusDgDrive)
#define ODGSTS14 (iosignal[14].OStatusDgDrive)
#define ODGMON14 (iosignal[14].OMonitorDgDrive)
#define OCURR14 (iosignal[14].OTorqueForceFeedBackValue)
#define OAXOFF14 (iosignal[14].OAxBRK)
#define OAXRTR14 (iosignal[14].OAxRTR)
#define OTAX14 (iosignal[14].OT_Axis)
#define OITRAX14 (iosignal[14].IOAxisSmtRef)
#define OCORIGPLC14 (iosignal[14].OCodAxPlcOrig)
#define ITPOFENA14 (iosignal[14].ITPOnFlyEna)
#define ITPOFSTB14 (iosignal[14].ITPOnFlyStb)
#define OTPOFACK14 (iosignal[14].OTPOnFlyAck)

/* --- ASSE PLC ORDINE 15 --- */

#define IAXPLC15 (iosignal[15].IAxPlc)
/* Richiesta asse 15 gestito e movimentato da PLC (ASSE PLC)*/
/* Request of management of the axis #15 by the PLC (PLC AXIS) */

#define OAXPLC15 (iosignal[15].OAxPlc)
/* Stato attuale asse 15 gestito e movimentato da PLC (ASSE PLC)*/
/* Actual status of the axis #15 managed by the PLC (PLC AXIS) */

#define IJOGP15 (iosignal[15].IJogP)
/* Richiesta JOG+ di velocita' IN RAPIDO ASSE PLC 15*/
/* Request velocity JOG+ IN RAPID PLC AXIS #15 */

#define IJOGN15 (iosignal[15].IJogN)
/* Richiesta JOG- di velocita' IN RAPIDO ASSE PLC 15*/
/* Request velocity JOG- IN RAPID PLC AXIS #15 */

#define OCPLC15 (iosignal[15].OCodAxPlcMov)
/* Codice di stato della richiesta di movimentazione (short) ASSE PLC 15*/
/* Status Code (short) of the last movement request for PLC AXIS #15 */

#define OAXSLV15 (iosignal[15].OAxPlcSynch)
/* Asse 15 programmato per il sincronismo */
/* Axis 15 scheduled for the synchronism */

#define OIDSLV15 (iosignal[15].OIndSynch)
/* Indice struttua di sincronismo Asse 15*/
/* Synchronism structure index for axis #15 */

#define OSQSLV15 (iosignal[15].OSqSynch)
/* Contatore perdita di sequenza sincronismo Asse 15*/
/* Synchronism sequence loss counter Axis #15 */

#define IDGSTS15 (iosignal[15].IStatusDgDrive)
/* Status di Input per Asse 15 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Status of input for axis 15 connected to digital driver (IDDCOM EDDCOM) */

#define ODGSTS15 (iosignal[15].OStatusDgDrive)
/* Status di Output per Asse 15 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Status of output for axis 15 connected to digital driver (IDDCOM EDDCOM) */

#define ODGMON15 (iosignal[15].OMonitorDgDrive)
/* Variabile Monitor di Output per Asse 15 collegato a Driver Digitale (IDDCOM EDDCOM) */
/* Output monitor variable for axis 15 connected to digital driver (IDDCOM EDDCOM) */

#define OCURR15 (iosignal[15].OTorqueForceFeedBackValue)
/* % Corrente assorbita dall'Asse 15 SERCOS (valido solo per asse Mandrino) */
/* % Current absorbed by the axis 15 SERCOS (valid only for SPINDLE Axis) */

#define OAXOFF15 (iosignal[15].OAxBRK)
/* Asse 15 momentaneamente NON utilizzabile */
/* Axis 15 momentarily NOT usable */

#define OAXRTR15 (iosignal[15].OAxRTR)
/* Asse 15 in movimento di RETRACT */
/* Axis 15 RETRACT movement        */

#define OTAX15 (iosignal[15].OT_Axis)
/* Stato dell'"Asse T" (Asse 15) */
/* "T Axis" status  (Axis 15)    */

#define OITRAX15 (iosignal[15].IOAxisSmtRef)
/* Asse soggetto a Inizializzazione con istruzione <ITR:...> */
/* Asse soggetto a Inizializzazione con istruzione <ITR:...> */

#define OCORIGPLC15 (iosignal[15].OCodAxPlcOrig)
/* Codice di stato della richiesta di Formazione Origine (short) ASSE PLC 15*/
/* Status Code (short) of the last Form Origin request for PLC AXIS #15 */

#define ITPOFENA15 (iosignal[15].ITPOnFlyEna)
/* Richiesta di abilitare la modifica quota target asse p.to p.to ASSE PLC 15*/
/* Request to enable change of the point to point axis target position PLC AXIS #15 */

#define ITPOFSTB15 (iosignal[15].ITPOnFlyStb)
/* STROBE di nuova quota target asse p.to p.to ASSE PLC 15*/
/* STROBE of the new point to point axis target position PLC AXIS #15 */

#define OTPOFACK15 (iosignal[15].OTPOnFlyAck)
/* ACKNOWLEDGE di nuova quota target asse p.to p.to ASSE PLC 15*/
/* ACKNOWLEDGE of the new point to point axis target position PLC AXIS #15 */

/* --------------------------------- */
/* --------------------------------- */

#define IOPLCSTS pn_visplc->Status
/* Codice di stato (short) dell'ultimo comando inoltrato dal PLC al CNC (VARIE) */
/* Status Code (short) of the last command forwarded by PLC to CNC (SUNDRIES) */

#define IOPLCRET pn_visplc->Result
/* Esito (short) dell'ultimo comando inoltrato dal PLC al CNC (VARIE) */
/* Result (short) of the last command forwarded by PLC to CNC (SUNDRIES) */

#define PARTPSTS pn_visplc->PLCPartPStatus
/* Variabile stato per nuova selezione o modifica Part Program */
/* Status variable for new selection or edit Part Program */

#define ISTBQUOTE pn_visplc->WstrobeQuote
/* Strobe (char) per Nuova visualizzazione Quote */
/* Strobe (char) per Nuova visualizzazione Quote */

#define OACKQUOTE pn_visplc->WackQuote
/* Acknolowdge (char) per Nuova visualizzazione Quote */
/* Acknolowdge (char) per Nuova visualizzazione Quote */

#define ICODTASFA pn_visplc->CodTastoFormAut
/* Codice tasto MDI - RPZ - SET per richiesta formati Automatici */
/* Codice tasto MDI - RPZ - SET per richiesta formati Automatici */

#define VALUEDWORKTIME pn_visplc->ValuedWorkTime
/* Tempo di lavoro stimato in secondi (unsigned long) */
/* Valued working time (sec) (unsigned long)      */

#define REALWORKTIME pn_visplc->RealWorkTime
/* Tempo di lavoro effettivo in secondi (unsigned long) */
/* Real working time (sec) (unsigned long)      */

#define CODTASVIR pn_visplc->CodTastoVirtuale
/* Codice tasto Virtuale per VIS */
/* Status variable for new selection or edit Part Program */

#define ISTBTASVIR pn_visplc->WstrobeTastoVirtuale
/* Strobe (char) per Nuovo Codice Tasto Virtuale */
/* Strobe (char) per Nuovo Codice Tasto Virtuale */

#define OACKTASVIR pn_visplc->WackTastoVirtuale
/* Acknolowdge (char) per Nuovo Codice Tasto Virtuale */
/* Acknolowdge (char) per Nuovo Codice Tasto Virtuale */

/* --------------------------------- */
/* --------------------------------- */
#define IRTR pn_iosignal->IAxesRetract
/* Richiesta RETRACT assi */
/* Request RETRACT axes   */

#define ORTR pn_iosignal->OAxesRetract
/* RETRACT attivo sugli assi */
/* RETRACT activated on axes */

#define RTSREQUEST pn_iosignal->rts_par.usRts_ON
/* Codice (unsigned short) richiesta RTS */
/* Code (unsigned short) RTS Request */
#define RTSACTIVE pn_iosignal->rts_par.usActivated
/* Variabile di stato (unsigned short) RTS attivO */
/* Status variable (unsigned short) for RTS active */
#define RTSMAXTIME pn_iosignal->rts_par.ulTimeMax
/* Tempo massimo (unsigned long) espresso in secondi per RTS */
/* Max time (unsigned long) in second for RTS */
#define RTSMAXSAMPLE pn_iosignal->rts_par.ulNSamplesMax
/* Numero massimo (unsigned long) campionature per RTS */
/* Max number (unsigned long) of sata sample for RTS */
#define RTSCONFIGFILE pn_iosignal->rts_par.szConfigFileNamePath
/* Percorso completo (stringa) nome file di configurazione RTS */
/* Configuration file path name (string) for RTS */
#define RTSDATAFILE pn_iosignal->rts_par.szDataFileNamePath
/* Percorso completo nome (stringa) file dati RTS */
/* Data sample file path name (string) for RTS */
#define RTSBASEDIRECTORY pn_iosignal->rts_par.szBaseDirPath
/* Percorso completo direttorio (stringa) file dati e configurazione RTS */
/* Directory path (string) for storing Data and configuration files for RTS */

/* ---------------------------------- */
/* SINONIMI STATO VISUALIZZAZIONI 900 */
/* ---------------------------------- */
#define VIS900STATUS	pn_visplc->StatoVis
/* Stato visualizzazioni di VIS900 */
/* Status of VIS900 display */

#define   ALTEXE_TR_COUNT     pn_visplc->alt_exe_transition_counter
/* Numero di transizioni ALT-EXE dal bootstrap del CNC. */
/* Number of ALT-EXE trasnitions from the bootstrap. */

#define AXANDIAG1_00 (iosignal[0].AxAnDiag1)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG1_01 (iosignal[1].AxAnDiag1)
#define AXANDIAG1_02 (iosignal[2].AxAnDiag1)
#define AXANDIAG1_03 (iosignal[3].AxAnDiag1)
#define AXANDIAG1_04 (iosignal[4].AxAnDiag1)
#define AXANDIAG1_05 (iosignal[5].AxAnDiag1)
#define AXANDIAG1_06 (iosignal[6].AxAnDiag1)
#define AXANDIAG1_07 (iosignal[7].AxAnDiag1)
#define AXANDIAG1_08 (iosignal[8].AxAnDiag1)
#define AXANDIAG1_09 (iosignal[9].AxAnDiag1)
#define AXANDIAG1_10 (iosignal[10].AxAnDiag1)
#define AXANDIAG1_11 (iosignal[11].AxAnDiag1)
#define AXANDIAG1_12 (iosignal[12].AxAnDiag1)
#define AXANDIAG1_13 (iosignal[13].AxAnDiag1)
#define AXANDIAG1_14 (iosignal[14].AxAnDiag1)
#define AXANDIAG1_15 (iosignal[15].AxAnDiag1)

#define AXANDIAG2_00 (iosignal[0].AxAnDiag2)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG2_01 (iosignal[1].AxAnDiag2)
#define AXANDIAG2_02 (iosignal[2].AxAnDiag2)
#define AXANDIAG2_03 (iosignal[3].AxAnDiag2)
#define AXANDIAG2_04 (iosignal[4].AxAnDiag2)
#define AXANDIAG2_05 (iosignal[5].AxAnDiag2)
#define AXANDIAG2_06 (iosignal[6].AxAnDiag2)
#define AXANDIAG2_07 (iosignal[7].AxAnDiag2)
#define AXANDIAG2_08 (iosignal[8].AxAnDiag2)
#define AXANDIAG2_09 (iosignal[9].AxAnDiag2)
#define AXANDIAG2_10 (iosignal[10].AxAnDiag2)
#define AXANDIAG2_11 (iosignal[11].AxAnDiag2)
#define AXANDIAG2_12 (iosignal[12].AxAnDiag2)
#define AXANDIAG2_13 (iosignal[13].AxAnDiag2)
#define AXANDIAG2_14 (iosignal[14].AxAnDiag2)
#define AXANDIAG2_15 (iosignal[15].AxAnDiag2)

#define AXANDIAG3_00 (iosignal[0].AxAnDiag3)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG3_01 (iosignal[1].AxAnDiag3)
#define AXANDIAG3_02 (iosignal[2].AxAnDiag3)
#define AXANDIAG3_03 (iosignal[3].AxAnDiag3)
#define AXANDIAG3_04 (iosignal[4].AxAnDiag3)
#define AXANDIAG3_05 (iosignal[5].AxAnDiag3)
#define AXANDIAG3_06 (iosignal[6].AxAnDiag3)
#define AXANDIAG3_07 (iosignal[7].AxAnDiag3)
#define AXANDIAG3_08 (iosignal[8].AxAnDiag3)
#define AXANDIAG3_09 (iosignal[9].AxAnDiag3)
#define AXANDIAG3_10 (iosignal[10].AxAnDiag3)
#define AXANDIAG3_11 (iosignal[11].AxAnDiag3)
#define AXANDIAG3_12 (iosignal[12].AxAnDiag3)
#define AXANDIAG3_13 (iosignal[13].AxAnDiag3)
#define AXANDIAG3_14 (iosignal[14].AxAnDiag3)
#define AXANDIAG3_15 (iosignal[15].AxAnDiag3)

#define AXANDIAG4_00 (iosignal[0].AxAnDiag4)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG4_01 (iosignal[1].AxAnDiag4)
#define AXANDIAG4_02 (iosignal[2].AxAnDiag4)
#define AXANDIAG4_03 (iosignal[3].AxAnDiag4)
#define AXANDIAG4_04 (iosignal[4].AxAnDiag4)
#define AXANDIAG4_05 (iosignal[5].AxAnDiag4)
#define AXANDIAG4_06 (iosignal[6].AxAnDiag4)
#define AXANDIAG4_07 (iosignal[7].AxAnDiag4)
#define AXANDIAG4_08 (iosignal[8].AxAnDiag4)
#define AXANDIAG4_09 (iosignal[9].AxAnDiag4)
#define AXANDIAG4_10 (iosignal[10].AxAnDiag4)
#define AXANDIAG4_11 (iosignal[11].AxAnDiag4)
#define AXANDIAG4_12 (iosignal[12].AxAnDiag4)
#define AXANDIAG4_13 (iosignal[13].AxAnDiag4)
#define AXANDIAG4_14 (iosignal[14].AxAnDiag4)
#define AXANDIAG4_15 (iosignal[15].AxAnDiag4)

#define AXANDIAG5_00 (iosignal[0].AxAnDiag5)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG5_01 (iosignal[1].AxAnDiag5)
#define AXANDIAG5_02 (iosignal[2].AxAnDiag5)
#define AXANDIAG5_03 (iosignal[3].AxAnDiag5)
#define AXANDIAG5_04 (iosignal[4].AxAnDiag5)
#define AXANDIAG5_05 (iosignal[5].AxAnDiag5)
#define AXANDIAG5_06 (iosignal[6].AxAnDiag5)
#define AXANDIAG5_07 (iosignal[7].AxAnDiag5)
#define AXANDIAG5_08 (iosignal[8].AxAnDiag5)
#define AXANDIAG5_09 (iosignal[9].AxAnDiag5)
#define AXANDIAG5_10 (iosignal[10].AxAnDiag5)
#define AXANDIAG5_11 (iosignal[11].AxAnDiag5)
#define AXANDIAG5_12 (iosignal[12].AxAnDiag5)
#define AXANDIAG5_13 (iosignal[13].AxAnDiag5)
#define AXANDIAG5_14 (iosignal[14].AxAnDiag5)
#define AXANDIAG5_15 (iosignal[15].AxAnDiag5)

#define AXANDIAG6_00 (iosignal[0].AxAnDiag6)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG6_01 (iosignal[1].AxAnDiag6)
#define AXANDIAG6_02 (iosignal[2].AxAnDiag6)
#define AXANDIAG6_03 (iosignal[3].AxAnDiag6)
#define AXANDIAG6_04 (iosignal[4].AxAnDiag6)
#define AXANDIAG6_05 (iosignal[5].AxAnDiag6)
#define AXANDIAG6_06 (iosignal[6].AxAnDiag6)
#define AXANDIAG6_07 (iosignal[7].AxAnDiag6)
#define AXANDIAG6_08 (iosignal[8].AxAnDiag6)
#define AXANDIAG6_09 (iosignal[9].AxAnDiag6)
#define AXANDIAG6_10 (iosignal[10].AxAnDiag6)
#define AXANDIAG6_11 (iosignal[11].AxAnDiag6)
#define AXANDIAG6_12 (iosignal[12].AxAnDiag6)
#define AXANDIAG6_13 (iosignal[13].AxAnDiag6)
#define AXANDIAG6_14 (iosignal[14].AxAnDiag6)
#define AXANDIAG6_15 (iosignal[15].AxAnDiag6)

#define AXANDIAG7_00 (iosignal[0].AxAnDiag7)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG7_01 (iosignal[1].AxAnDiag7)
#define AXANDIAG7_02 (iosignal[2].AxAnDiag7)
#define AXANDIAG7_03 (iosignal[3].AxAnDiag7)
#define AXANDIAG7_04 (iosignal[4].AxAnDiag7)
#define AXANDIAG7_05 (iosignal[5].AxAnDiag7)
#define AXANDIAG7_06 (iosignal[6].AxAnDiag7)
#define AXANDIAG7_07 (iosignal[7].AxAnDiag7)
#define AXANDIAG7_08 (iosignal[8].AxAnDiag7)
#define AXANDIAG7_09 (iosignal[9].AxAnDiag7)
#define AXANDIAG7_10 (iosignal[10].AxAnDiag7)
#define AXANDIAG7_11 (iosignal[11].AxAnDiag7)
#define AXANDIAG7_12 (iosignal[12].AxAnDiag7)
#define AXANDIAG7_13 (iosignal[13].AxAnDiag7)
#define AXANDIAG7_14 (iosignal[14].AxAnDiag7)
#define AXANDIAG7_15 (iosignal[15].AxAnDiag7)

#define AXANDIAG8_00 (iosignal[0].AxAnDiag8)
/* Stato dell'asse analogico ethercat (parola a bit) */
/* Status word of the ethercat analogical axis (word bit) */
#define AXANDIAG8_01 (iosignal[1].AxAnDiag8)
#define AXANDIAG8_02 (iosignal[2].AxAnDiag8)
#define AXANDIAG8_03 (iosignal[3].AxAnDiag8)
#define AXANDIAG8_04 (iosignal[4].AxAnDiag8)
#define AXANDIAG8_05 (iosignal[5].AxAnDiag8)
#define AXANDIAG8_06 (iosignal[6].AxAnDiag8)
#define AXANDIAG8_07 (iosignal[7].AxAnDiag8)
#define AXANDIAG8_08 (iosignal[8].AxAnDiag8)
#define AXANDIAG8_09 (iosignal[9].AxAnDiag8)
#define AXANDIAG8_10 (iosignal[10].AxAnDiag8)
#define AXANDIAG8_11 (iosignal[11].AxAnDiag8)
#define AXANDIAG8_12 (iosignal[12].AxAnDiag8)
#define AXANDIAG8_13 (iosignal[13].AxAnDiag8)
#define AXANDIAG8_14 (iosignal[14].AxAnDiag8)
#define AXANDIAG8_15 (iosignal[15].AxAnDiag8)


/* ---------------------------------------------------- */
/* SINONIMI DELL'AREA DEI DATI DELL'ISTRUZIONE <CTP:..> */
/* ---------------------------------------------------- */
#define   OCTP_0     pn_iosignal->DatiCTP[0]
#define   OCTP_1     pn_iosignal->DatiCTP[1]
#define   OCTP_2     pn_iosignal->DatiCTP[2]
#define   OCTP_3     pn_iosignal->DatiCTP[3]
#define   OCTP_4     pn_iosignal->DatiCTP[4]
#define   OCTP_5     pn_iosignal->DatiCTP[5]
#define   OCTP_6     pn_iosignal->DatiCTP[6]
#define   OCTP_7     pn_iosignal->DatiCTP[7]
#define   OCTP_8     pn_iosignal->DatiCTP[8]
#define   OCTP_9     pn_iosignal->DatiCTP[9]

#define   OCTP_10     pn_iosignal->DatiCTP[10]
#define   OCTP_11     pn_iosignal->DatiCTP[11]
#define   OCTP_12     pn_iosignal->DatiCTP[12]
#define   OCTP_13     pn_iosignal->DatiCTP[13]
#define   OCTP_14     pn_iosignal->DatiCTP[14]
#define   OCTP_15     pn_iosignal->DatiCTP[15]
#define   OCTP_16     pn_iosignal->DatiCTP[16]
#define   OCTP_17     pn_iosignal->DatiCTP[17]
#define   OCTP_18     pn_iosignal->DatiCTP[18]
#define   OCTP_19     pn_iosignal->DatiCTP[19]

#define   OCTP_20     pn_iosignal->DatiCTP[20]
#define   OCTP_21     pn_iosignal->DatiCTP[21]
#define   OCTP_22     pn_iosignal->DatiCTP[22]
#define   OCTP_23     pn_iosignal->DatiCTP[23]
#define   OCTP_24     pn_iosignal->DatiCTP[24]
#define   OCTP_25     pn_iosignal->DatiCTP[25]
#define   OCTP_26     pn_iosignal->DatiCTP[26]
#define   OCTP_27     pn_iosignal->DatiCTP[27]
#define   OCTP_28     pn_iosignal->DatiCTP[28]
#define   OCTP_29     pn_iosignal->DatiCTP[29]

#define   OCTP_30     pn_iosignal->DatiCTP[30]
#define   OCTP_31     pn_iosignal->DatiCTP[31]
#define   OCTP_32     pn_iosignal->DatiCTP[32]
#define   OCTP_33     pn_iosignal->DatiCTP[33]
#define   OCTP_34     pn_iosignal->DatiCTP[34]
#define   OCTP_35     pn_iosignal->DatiCTP[35]
#define   OCTP_36     pn_iosignal->DatiCTP[36]
#define   OCTP_37     pn_iosignal->DatiCTP[37]
#define   OCTP_38     pn_iosignal->DatiCTP[38]
#define   OCTP_39     pn_iosignal->DatiCTP[39]

#define   OCTP_40     pn_iosignal->DatiCTP[40]
#define   OCTP_41     pn_iosignal->DatiCTP[41]
#define   OCTP_42     pn_iosignal->DatiCTP[42]
#define   OCTP_43     pn_iosignal->DatiCTP[43]
#define   OCTP_44     pn_iosignal->DatiCTP[44]
#define   OCTP_45     pn_iosignal->DatiCTP[45]
#define   OCTP_46     pn_iosignal->DatiCTP[46]
#define   OCTP_47     pn_iosignal->DatiCTP[47]
#define   OCTP_48     pn_iosignal->DatiCTP[48]
#define   OCTP_49     pn_iosignal->DatiCTP[49]

#define   OCTP_50     pn_iosignal->DatiCTP[50]
#define   OCTP_51     pn_iosignal->DatiCTP[51]
#define   OCTP_52     pn_iosignal->DatiCTP[52]
#define   OCTP_53     pn_iosignal->DatiCTP[53]
#define   OCTP_54     pn_iosignal->DatiCTP[54]
#define   OCTP_55     pn_iosignal->DatiCTP[55]
#define   OCTP_56     pn_iosignal->DatiCTP[56]
#define   OCTP_57     pn_iosignal->DatiCTP[57]
#define   OCTP_58     pn_iosignal->DatiCTP[58]
#define   OCTP_59     pn_iosignal->DatiCTP[59]

#define   OCTP_60     pn_iosignal->DatiCTP[60]
#define   OCTP_61     pn_iosignal->DatiCTP[61]
#define   OCTP_62     pn_iosignal->DatiCTP[62]
#define   OCTP_63     pn_iosignal->DatiCTP[63]
#define   OCTP_64     pn_iosignal->DatiCTP[64]
#define   OCTP_65     pn_iosignal->DatiCTP[65]
#define   OCTP_66     pn_iosignal->DatiCTP[66]
#define   OCTP_67     pn_iosignal->DatiCTP[67]
#define   OCTP_68     pn_iosignal->DatiCTP[68]
#define   OCTP_69     pn_iosignal->DatiCTP[69]

#define   OCTP_70     pn_iosignal->DatiCTP[70]
#define   OCTP_71     pn_iosignal->DatiCTP[71]
#define   OCTP_72     pn_iosignal->DatiCTP[72]
#define   OCTP_73     pn_iosignal->DatiCTP[73]
#define   OCTP_74     pn_iosignal->DatiCTP[74]
#define   OCTP_75     pn_iosignal->DatiCTP[75]
#define   OCTP_76     pn_iosignal->DatiCTP[76]
#define   OCTP_77     pn_iosignal->DatiCTP[77]
#define   OCTP_78     pn_iosignal->DatiCTP[78]
#define   OCTP_79     pn_iosignal->DatiCTP[79]

#define   OCTP_80     pn_iosignal->DatiCTP[80]
#define   OCTP_81     pn_iosignal->DatiCTP[81]
#define   OCTP_82     pn_iosignal->DatiCTP[82]
#define   OCTP_83     pn_iosignal->DatiCTP[83]
#define   OCTP_84     pn_iosignal->DatiCTP[84]
#define   OCTP_85     pn_iosignal->DatiCTP[85]
#define   OCTP_86     pn_iosignal->DatiCTP[86]
#define   OCTP_87     pn_iosignal->DatiCTP[87]
#define   OCTP_88     pn_iosignal->DatiCTP[88]
#define   OCTP_89     pn_iosignal->DatiCTP[89]

#define   OCTP_90     pn_iosignal->DatiCTP[90]
#define   OCTP_91     pn_iosignal->DatiCTP[91]
#define   OCTP_92     pn_iosignal->DatiCTP[92]
#define   OCTP_93     pn_iosignal->DatiCTP[93]
#define   OCTP_94     pn_iosignal->DatiCTP[94]
#define   OCTP_95     pn_iosignal->DatiCTP[95]
#define   OCTP_96     pn_iosignal->DatiCTP[96]
#define   OCTP_97     pn_iosignal->DatiCTP[97]
#define   OCTP_98     pn_iosignal->DatiCTP[98]
#define   OCTP_99     pn_iosignal->DatiCTP[99]

#define   OCTP_100     pn_iosignal->DatiCTP[100]
#define   OCTP_101     pn_iosignal->DatiCTP[101]
#define   OCTP_102     pn_iosignal->DatiCTP[102]
#define   OCTP_103     pn_iosignal->DatiCTP[103]
#define   OCTP_104     pn_iosignal->DatiCTP[104]
#define   OCTP_105     pn_iosignal->DatiCTP[105]
#define   OCTP_106     pn_iosignal->DatiCTP[106]
#define   OCTP_107     pn_iosignal->DatiCTP[107]
#define   OCTP_108     pn_iosignal->DatiCTP[108]
#define   OCTP_109     pn_iosignal->DatiCTP[109]

#define   OCTP_110     pn_iosignal->DatiCTP[110]
#define   OCTP_111     pn_iosignal->DatiCTP[111]
#define   OCTP_112     pn_iosignal->DatiCTP[112]
#define   OCTP_113     pn_iosignal->DatiCTP[113]
#define   OCTP_114     pn_iosignal->DatiCTP[114]
#define   OCTP_115     pn_iosignal->DatiCTP[115]
#define   OCTP_116     pn_iosignal->DatiCTP[116]
#define   OCTP_117     pn_iosignal->DatiCTP[117]
#define   OCTP_118     pn_iosignal->DatiCTP[118]
#define   OCTP_119     pn_iosignal->DatiCTP[119]

#define   OCTP_120     pn_iosignal->DatiCTP[120]
#define   OCTP_121     pn_iosignal->DatiCTP[121]
#define   OCTP_122     pn_iosignal->DatiCTP[122]
#define   OCTP_123     pn_iosignal->DatiCTP[123]
#define   OCTP_124     pn_iosignal->DatiCTP[124]
#define   OCTP_125     pn_iosignal->DatiCTP[125]
#define   OCTP_126     pn_iosignal->DatiCTP[126]
#define   OCTP_127     pn_iosignal->DatiCTP[127]

///#endif	// #ifdef QAL_SLOW
